@@ -11,16 +11,16 @@
 #
 # DOLFIN is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+# along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 #
-# Modified by Johannes Ring, 2011
+# Modified by Johannes Ring, 2011, 2012
 #
 # First added:  2010-03-26
-# Last changed: 2011-04-05
+# Last changed: 2012-03-15
 
 import os, sys, time
 
@@ -29,12 +29,7 @@ failed = []
 def run_bench(arg, directory, files):
 
     # Skip directories not containing a benchmark
-    bench_exec = "bench"
-    if directory.endswith("cpp") and \
-           "bench_" + directory.split(os.path.sep)[-2] in files:
-        bench_exec = "bench_" + directory.split(os.path.sep)[-2]
-
-
+    bench_exec = "bench_" + "_".join(directory.split(os.path.sep)[1:])
     if not bench_exec in files:
         return
 
@@ -75,22 +70,22 @@ def run_bench(arg, directory, files):
 
     # Get timings (if any)
     f = open(logfile)
-    timings = [("", elapsed_time)]
+    run_timings = [("", elapsed_time)]
     for line in [line for line in f.read().split("\n") if "BENCH" in line]:
         words = [word.strip() for word in line.split(" ")]
         # Override total time
         if len(words) == 2:
-            timings[0] = ("", float(words[1]))
+            run_timings[0] = ("", float(words[1]))
         # Add sub timing
         elif len(words) == 3:
-            timings.append((words[1].lower(), float(words[2])))
+            run_timings.append((words[1].lower(), float(words[2])))
     f.close()
 
     # Append to log file
     d = time.gmtime()
     date = str((d.tm_year, d.tm_mon, d.tm_mday, d.tm_hour, d.tm_min, d.tm_sec))
     f = open(os.path.join("logs", "bench.log"), "a")
-    for (postfix, timing) in timings:
+    for (postfix, timing) in run_timings:
         if postfix == "":
             n = name
             d = description
