@@ -31,7 +31,8 @@ double assemble_form(Form& form)
   // Assemble once
   const double t0 = time();
   Matrix A;
-  assemble(A, form);
+  Assembler assembler;
+  assembler.assemble(A, form);
   return time() - t0;
 }
 
@@ -39,11 +40,13 @@ double reassemble_form(Form& form)
 {
   // Assemble once
   Matrix A;
-  assemble(A, form);
+  Assembler assembler;
+  assembler.assemble(A, form);
 
   // Reassemble
   const double t0 = time();
-  assemble(A, form, false);
+  assembler.reset_sparsity = false;
+  assembler.assemble(A, form);
   return time() - t0;
 }
 
@@ -52,6 +55,8 @@ int main(int argc, char* argv[])
   info("Assembly for various forms and backends");
   set_log_active(false);
 
+  parameters["reorder_dofs_serial"] = false;
+
   // Forms
   std::vector<std::string> forms;
   forms.push_back("poisson1");
@@ -67,7 +72,6 @@ int main(int argc, char* argv[])
   backends.push_back("uBLAS");
   backends.push_back("PETSc");
   backends.push_back("Epetra");
-  backends.push_back("MTL4");
   backends.push_back("STL");
 
   // Override forms and backends with command-line arguments
