@@ -29,7 +29,7 @@
 #include "Poisson.h"
 #include "NavierStokes.h"
 
-#define MAX_NUM_THREADS 1
+#define MAX_NUM_THREADS 4
 #define SIZE 32
 #define NUM_REPS 10
 
@@ -57,11 +57,16 @@ class NavierStokesFactory
   {
     boost::shared_ptr<FunctionSpace> _V(new NavierStokes::FunctionSpace(mesh));
 
-    boost::shared_ptr<FunctionSpace> W0(new NavierStokes::Form_a_FunctionSpace_2(mesh));
-    boost::shared_ptr<FunctionSpace> W1(new NavierStokes::Form_a_FunctionSpace_3(mesh));
-    boost::shared_ptr<FunctionSpace> W2(new NavierStokes::Form_a_FunctionSpace_4(mesh));
-    boost::shared_ptr<FunctionSpace> W3(new NavierStokes::Form_a_FunctionSpace_5(mesh));
-    boost::shared_ptr<FunctionSpace> W4(new NavierStokes::Form_a_FunctionSpace_6(mesh));
+    boost::shared_ptr<FunctionSpace>
+      W0(new NavierStokes::Form_a_FunctionSpace_2(mesh));
+    boost::shared_ptr<FunctionSpace>
+      W1(new NavierStokes::Form_a_FunctionSpace_3(mesh));
+    boost::shared_ptr<FunctionSpace>
+      W2(new NavierStokes::Form_a_FunctionSpace_4(mesh));
+    boost::shared_ptr<FunctionSpace>
+      W3(new NavierStokes::Form_a_FunctionSpace_5(mesh));
+    boost::shared_ptr<FunctionSpace>
+      W4(new NavierStokes::Form_a_FunctionSpace_6(mesh));
 
     boost::shared_ptr<Function> w0(new Function(W0));
     boost::shared_ptr<Function> w1(new Function(W1));
@@ -84,7 +89,8 @@ class NavierStokesFactory
 double bench(std::string form, boost::shared_ptr<const Form> a)
 {
   std::size_t num_threads = parameters["num_threads"];
-  info_underline("Benchmarking %s, num_threads = %d", form.c_str(), num_threads);
+  info_underline("Benchmarking %s, num_threads = %d", form.c_str(),
+                 num_threads);
 
   // Create matrix
   Matrix A;
@@ -121,9 +127,6 @@ int main(int argc, char* argv[])
   old_mesh.color("vertex");
   Mesh mesh = old_mesh.renumber_by_color();
 
-  // Disable dof reordering because the NS dof maps are very large
-  parameters["reorder_dofs_serial"] = false;
-
   // Test cases
   std::vector<std::pair<std::string, boost::shared_ptr<const Form> > > forms;
   forms.push_back(std::make_pair("Poisson", PoissonFactory::a(mesh)));
@@ -158,11 +161,15 @@ int main(int argc, char* argv[])
         std::stringstream s;
         s << num_threads << " threads";
         run_timings(s.str(), forms[i].first) = t;
-        speedups(s.str(), forms[i].first) = run_timings.get_value("0 threads", forms[i].first) / t;
+        speedups(s.str(), forms[i].first)
+          = run_timings.get_value("0 threads", forms[i].first)/t;
         if (num_threads == 0)
           speedups(s.str(), "(rel 1 thread " + forms[i].first + ")") = "-";
         else
-          speedups(s.str(),  "(rel 1 thread " + forms[i].first + ")") = run_timings.get_value("1 threads", forms[i].first) / t;
+        {
+          speedups(s.str(),  "(rel 1 thread " + forms[i].first + ")")
+            = run_timings.get_value("1 threads", forms[i].first)/t;
+        }
       }
     }
 
