@@ -16,7 +16,7 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-09-15
-// Last changed: 2010-05-03
+// Last changed: 2012-12-12
 //
 // Simple Poisson assembler
 
@@ -37,7 +37,7 @@ int main(int argc, char* argv[])
   int n = atoi(argv[1]);
 
   // Create mesh and function space
-  UnitCube mesh(n, n, n);
+  UnitCubeMesh mesh(n, n, n);
   Poisson::FunctionSpace V(mesh);
 
   // Assemble matrix
@@ -45,7 +45,8 @@ int main(int argc, char* argv[])
   Matrix A;
   dolfin::MPI::barrier();
   double t = time();
-  assemble(A, a);
+  Assembler assembler;
+  assembler.assemble(A, a);
   dolfin::MPI::barrier();
   t = time() - t;
 
@@ -56,7 +57,8 @@ int main(int argc, char* argv[])
   // Re-assemble matrix
   dolfin::MPI::barrier();
   t = time();
-  assemble(A, a, false);
+  assembler.reset_sparsity = false;
+  assembler.assemble(A, a);
   dolfin::MPI::barrier();
   t = time() - t;
 
