@@ -9,14 +9,14 @@
 //
 // DOLFIN is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2006-11-01
-// Last changed: 2010-05-03
+// Last changed: 2012-12-12
 
 #include <dolfin.h>
 
@@ -32,7 +32,7 @@ int main(int argc, char* argv[])
 
   parameters.parse(argc, argv);
 
-  UnitCube mesh(SIZE, SIZE, SIZE);
+  UnitCubeMesh mesh(SIZE, SIZE, SIZE);
 
   int sum = 0;
   tic();
