@@ -16,7 +16,7 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-09-29
-// Last changed: 2012-12-12
+// Last changed: 2013-11-11
 //
 // This demo illustrates the built-in mesh types.
 
@@ -26,12 +26,9 @@ using namespace dolfin;
 
 int main()
 {
-  if (dolfin::MPI::num_processes() == 1)
-  {
-    UnitIntervalMesh interval(10);
-    info("Plotting a UnitIntervalMesh");
-    plot(interval, "Unit interval");
-  }
+  UnitIntervalMesh interval(20);
+  info("Plotting a UnitIntervalMesh");
+  plot(interval, "Unit interval");
 
   UnitSquareMesh square_default(10, 10);
   info("Plotting a UnitSquareMesh");
@@ -57,6 +54,7 @@ int main()
   info("Plotting a RectangleMesh");
   plot(rectangle_right_left, "Rectangle (right/left)");
 
+#ifdef HAS_CGAL
   UnitCircleMesh circle_rotsumn(20, "right", "rotsumn");
   info("Plotting a UnitCircleMesh");
   plot(circle_rotsumn, "Unit circle (rotsum)");
@@ -68,6 +66,7 @@ int main()
   UnitCircleMesh circle_maxn(20, "right", "maxn");
   info("Plotting a UnitCircleMesh");
   plot(circle_maxn, "Unit circle (maxn)");
+#endif
 
   UnitCubeMesh cube(10, 10, 10);
   info("Plotting a UnitCubeMesh");
