@@ -20,11 +20,15 @@
 //
 // Eddy currents phenomena in low conducting body can be
 // described using electric vector potential and curl-curl operator:
+//
 //    \nabla \times \nabla \times T = - \frac{\partial B}{\partial t}
+//
 // Electric vector potential defined as:
+//
 //    \nabla \times T = J
 //
 // Boundary condition
+//
 //    J_n = 0,
 //    T_t=T_w=0, \frac{\partial T_n}{\partial n} = 0
 // which is naturaly fulfilled for zero Dirichlet BC with Nedelec (edge)
@@ -81,9 +85,8 @@ int main()
     }
   };
 
-  // Create demo mesh
-  Sphere sphere(Point(0, 0, 0), 1.0);
-  Mesh mesh(sphere, 16);
+  // Create sphere mesh
+  SphereMesh mesh(Point(0.0, 0.0, 0.0), 1.0, 0.1);
 
   // Define functions
   Source dbdt;
