@@ -1,4 +1,4 @@
-// Copyright (C) 2008 Anders Logg
+// Copyright (C) 2008-2011 Anders Logg
 //
 // This file is part of DOLFIN.
 //
@@ -9,14 +9,14 @@
 //
 // DOLFIN is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2008-03-11
-// Last changed: 2011-01-19
+// Last changed: 2012-11-12
 //
 // Demonstrating function evaluation at arbitrary points.
 
@@ -43,10 +43,8 @@ public:
 
 int main()
 {
-  not_working_in_parallel("This demo");
-
   // Create mesh and a point in the mesh
-  UnitCube mesh(8, 8, 8);
+  UnitCubeMesh mesh(8, 8, 8);
   Point x(0.31, 0.32, 0.33);
 
   // A user-defined function
@@ -57,9 +55,8 @@ int main()
   Projection::BilinearForm a(V, V);
   Projection::LinearForm L(V);
   L.f = f;
-  VariationalProblem pde(a, L);
   Function g(V);
-  pde.solve(g);
+  solve(a == L, g);
 
   // Evaluate user-defined function f
   info("f(x) = %g", f(x));
