@@ -16,7 +16,7 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-06-17
-// Last changed:
+// Last changed: 2012-07-05
 
 //
 // This program demonstrates the interpolation of functions on non-matching
@@ -45,8 +45,8 @@ public:
 int main()
 {
   // Create meshes
-  UnitSquare mesh0(16, 16);
-  UnitSquare mesh1(64, 64);
+  UnitSquareMesh mesh0(16, 16);
+  UnitSquareMesh mesh1(64, 64);
 
   // Create function spaces
   P3::FunctionSpace V0(mesh0);
@@ -66,6 +66,7 @@ int main()
   // Plot results
   plot(f0);
   plot(f1);
+  interactive();
 
   return 0;
 }
