@@ -16,7 +16,7 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-11-11
-// Last changed: 2011-02-25
+// Last changed: 2012-11-12
 //
 // This program demonstrates the use of the TimeSeries
 // class for storing a series of meshes and vectors.
@@ -31,7 +31,7 @@ int main()
   TimeSeries series("primal");
 
   // Create a mesh and a vector
-  UnitSquare unit_square(2, 2);
+  UnitSquareMesh unit_square(2, 2);
   Mesh mesh(unit_square);
   Vector x;
 
@@ -44,9 +44,9 @@ int main()
     x.resize(mesh.num_vertices());
 
     // Set some vector values
-    Array<double> values(x.local_size());
-    const dolfin::uint offset = x.local_range().first;
-    for (dolfin::uint i = 0; i < x.local_size(); i++)
+    std::vector<double> values(x.local_size());
+    const std::size_t offset = x.local_range().first;
+    for (std::size_t i = 0; i < x.local_size(); i++)
       values[i] = (t + 1.0)*static_cast<double>(offset + i);
     x.set_local(values);
     x.apply("insert");
@@ -64,6 +64,7 @@ int main()
 
   // Plot mesh
   plot(mesh);
+  interactive();
 
   return 0;
 }
