@@ -20,7 +20,7 @@
 // First added:  2010-09-16
 // Last changed: 2011-03-23
 
-#include <armadillo>
+#include <Eigen/Dense>
 #include <boost/scoped_ptr.hpp>
 
 #include <dolfin/common/NoDeleter.h>
@@ -28,7 +28,6 @@
 #include <dolfin/common/types.h>
 #include <dolfin/common/Hierarchical.h>
 #include <dolfin/fem/assemble.h>
-#include <dolfin/fem/BoundaryCondition.h>
 #include <dolfin/fem/DirichletBC.h>
 #include <dolfin/fem/GenericDofMap.h>
 #include <dolfin/fem/DofMap.h>
@@ -95,7 +94,7 @@ ErrorControl::ErrorControl(boost::shared_ptr<Form> a_star,
 }
 //-----------------------------------------------------------------------------
 double ErrorControl::estimate_error(const Function& u,
-  const std::vector<boost::shared_ptr<const BoundaryCondition> > bcs)
+  const std::vector<boost::shared_ptr<const DirichletBC> > bcs)
 {
   // Compute discrete dual approximation
   dolfin_assert(_a_star);
@@ -129,23 +128,18 @@ double ErrorControl::estimate_error(const Function& u,
 }
 //-----------------------------------------------------------------------------
 void ErrorControl::compute_dual(Function& z,
-   const std::vector<boost::shared_ptr<const BoundaryCondition> > bcs)
+   const std::vector<boost::shared_ptr<const DirichletBC> > bcs)
 {
   log(PROGRESS, "Solving dual problem.");
 
   // Create dual boundary conditions by homogenizing
-  std::vector<boost::shared_ptr<const BoundaryCondition> > dual_bcs;
+  std::vector<boost::shared_ptr<const DirichletBC> > dual_bcs;
   for (std::size_t i = 0; i < bcs.size(); i++)
   {
-    // Only handle DirichletBCs
-    const DirichletBC* bc_ptr = dynamic_cast<const DirichletBC*>(bcs[i].get());
-    if (!bc_ptr)
-      dolfin_error("ErrorControl.cpp",
-                   "compute dual solution",
-                   "Only DirichletBCs can be homogenized (for now)");
+    dolfin_assert(bcs[i]);
 
     // Create shared_ptr to boundary condition
-    boost::shared_ptr<DirichletBC> dual_bc_ptr(new DirichletBC(*bc_ptr));
+    boost::shared_ptr<DirichletBC> dual_bc_ptr(new DirichletBC(*bcs[i]));
 
     // Run homogenize
     dual_bc_ptr->homogenize();
@@ -165,7 +159,7 @@ void ErrorControl::compute_dual(Function& z,
 }
 //-----------------------------------------------------------------------------
 void ErrorControl::compute_extrapolation(const Function& z,
-   const std::vector<boost::shared_ptr<const BoundaryCondition> > bcs)
+   const std::vector<boost::shared_ptr<const DirichletBC> > bcs)
 {
   log(PROGRESS, "Extrapolating dual solution.");
 
@@ -220,7 +214,7 @@ void ErrorControl::compute_indicators(MeshFunction<double>& indicators,
   _eta_T->set_coefficient(3, _Pi_E_z_h);
 
   // Assemble error indicator form
-  Vector x(indicators.mesh().num_cells());
+  Vector x(indicators.mesh()->num_cells());
   assemble(x, *_eta_T);
 
   // Take absolute value of indicators
@@ -230,7 +224,7 @@ void ErrorControl::compute_indicators(MeshFunction<double>& indicators,
   dolfin_assert(_eta_T->function_space(0));
   dolfin_assert(_eta_T->function_space(0)->dofmap());
   const GenericDofMap& dofmap(*_eta_T->function_space(0)->dofmap());
-  const Mesh& mesh(indicators.mesh());
+  const Mesh& mesh= *indicators.mesh();
 
   // Convert DG_0 vector to mesh function over cells
   for (CellIterator cell(mesh); !cell.end(); ++cell)
@@ -294,9 +288,8 @@ void ErrorControl::compute_cell_residual(Function& R_T, const Function& u)
   // Define matrices for cell-residual problems
   dolfin_assert(V.element());
   const std::size_t N = V.element()->space_dimension();
-  arma::mat A(N, N);
-  arma::mat b(N, 1);
-  arma::vec x(N);
+  Eigen::MatrixXd A(N, N), b(N, 1);
+  Eigen::VectorXd x(N);
 
   // Extract cell_domains etc from right-hand side form
   const MeshFunction<std::size_t>*
@@ -307,23 +300,30 @@ void ErrorControl::compute_cell_residual(Function& R_T, const Function& u)
     interior_facet_domains = _L_R_T->interior_facet_domains().get();
 
   // Assemble and solve local linear systems
+  ufc::cell ufc_cell;
+  std::vector<double> vertex_coordinates;
   for (CellIterator cell(mesh); !cell.end(); ++cell)
   {
+    // Get cell vertices
+    cell->get_vertex_coordinates(vertex_coordinates);
+
     // Assemble local linear system
-    LocalAssembler::assemble(A, ufc_lhs, *cell, cell_domains,
+    LocalAssembler::assemble(A, ufc_lhs, vertex_coordinates,
+                             ufc_cell, *cell, cell_domains,
                              exterior_facet_domains, interior_facet_domains);
-    LocalAssembler::assemble(b, ufc_rhs, *cell, cell_domains,
+    LocalAssembler::assemble(b, ufc_rhs, vertex_coordinates, ufc_cell,
+                             *cell, cell_domains,
                              exterior_facet_domains, interior_facet_domains);
 
     // Solve linear system and convert result
-    x = arma::solve(A, b);
+    x = A.partialPivLu().solve(b);
 
     // Get local-to-global dof map for cell
     const std::vector<dolfin::la_index>& dofs = dofmap.cell_dofs(cell->index());
 
     // Plug local solution into global vector
     dolfin_assert(R_T.vector());
-    R_T.vector()->set(x.memptr(), N, &dofs[0]);
+    R_T.vector()->set(x.data(), N, &dofs[0]);
   }
   end();
 }
@@ -371,9 +371,8 @@ void ErrorControl::compute_facet_residual(SpecialFacetFunction& R_dT,
   const GenericDofMap& dofmap = *V.dofmap();
 
   // Define matrices for facet-residual problems
-  arma::mat A(N, N);
-  arma::mat b(N, 1);
-  arma::vec x(N);
+  Eigen::MatrixXd A(N, N), b(N, 1);
+  Eigen::VectorXd x(N);
 
   // Variables to be used for the construction of the cone function
   const std::size_t num_cells = mesh.num_cells();
@@ -398,7 +397,8 @@ void ErrorControl::compute_facet_residual(SpecialFacetFunction& R_dT,
     dolfin_assert(_cell_cone->vector());
     *(_cell_cone->vector()) = 0.0;
     facet_dofs.clear();
-    const std::size_t local_facet_dof = local_cone_dim - (dim + 1) + local_facet;
+    const std::size_t local_facet_dof = local_cone_dim - (dim + 1)
+      + local_facet;
     dolfin_assert(_cell_cone->function_space());
     dolfin_assert(_cell_cone->function_space()->dofmap());
     const GenericDofMap& cone_dofmap(*(_cell_cone->function_space()->dofmap()));
@@ -415,12 +415,19 @@ void ErrorControl::compute_facet_residual(SpecialFacetFunction& R_dT,
     UFC ufc_rhs(*_L_R_dT);
 
     // Assemble and solve local linear systems
+    ufc::cell ufc_cell;
+    std::vector<double> vertex_coordinates;
     for (CellIterator cell(mesh); !cell.end(); ++cell)
     {
+      // Get cell vertex_coordinates
+      cell->get_vertex_coordinates(vertex_coordinates);
+
       // Assemble linear system
-      LocalAssembler::assemble(A, ufc_lhs, *cell, cell_domains,
+      LocalAssembler::assemble(A, ufc_lhs, vertex_coordinates,
+                               ufc_cell, *cell, cell_domains,
                                exterior_facet_domains, interior_facet_domains);
-      LocalAssembler::assemble(b, ufc_rhs, *cell, cell_domains,
+      LocalAssembler::assemble(b, ufc_rhs, vertex_coordinates,
+                               ufc_cell, *cell, cell_domains,
                                exterior_facet_domains, interior_facet_domains);
 
       // Non-singularize local matrix
@@ -434,36 +441,35 @@ void ErrorControl::compute_facet_residual(SpecialFacetFunction& R_dT,
       }
 
       // Solve linear system and convert result
-      x = arma::solve(A, b);
+      x = A.partialPivLu().solve(b);
 
       // Get local-to-global dof map for cell
-      const std::vector<dolfin::la_index>& dofs = dofmap.cell_dofs(cell->index());
+      const std::vector<dolfin::la_index>& dofs
+        = dofmap.cell_dofs(cell->index());
 
       // Plug local solution into global vector
       dolfin_assert(R_dT[local_facet].vector());
-      R_dT[local_facet].vector()->set(x.memptr(), N, &dofs[0]);
+      R_dT[local_facet].vector()->set(x.data(), N, &dofs[0]);
     }
   }
   end();
 }
 //-----------------------------------------------------------------------------
 void ErrorControl::apply_bcs_to_extrapolation(
-const std::vector<boost::shared_ptr<const BoundaryCondition> > bcs)
+const std::vector<boost::shared_ptr<const DirichletBC> > bcs)
 {
   // Create boundary conditions for extrapolated dual, and apply
   // these.
   for (std::size_t i = 0; i < bcs.size(); i++)
   {
-    // Only handle DirichletBCs
-    const DirichletBC* bc = dynamic_cast<const DirichletBC*>(bcs[i].get());
-    dolfin_assert(bc);
+    dolfin_assert(bcs[i]);
 
     // Extract SubSpace component
-    dolfin_assert(bc->function_space());
-    const std::vector<std::size_t> component = bc->function_space()->component();
+    dolfin_assert(bcs[i]->function_space());
+    const std::vector<std::size_t> component = bcs[i]->function_space()->component();
 
     // Extract sub-domain
-    boost::shared_ptr<const SubDomain> sub_domain = bc->user_sub_domain();
+    boost::shared_ptr<const SubDomain> sub_domain = bcs[i]->user_sub_domain();
 
     // Create zero-valued boundary condition on extrapolation space.
     // (Sub-spaces need special handling, and boundary conditions can
@@ -473,17 +479,17 @@ const std::vector<boost::shared_ptr<const BoundaryCondition> > bcs)
     if (component.empty())
     {
       if (sub_domain)
-        e_bc.reset(new DirichletBC(_E, bc->value(), sub_domain, bc->method()));
+        e_bc.reset(new DirichletBC(_E, bcs[i]->value(), sub_domain, bcs[i]->method()));
       else
-        e_bc.reset(new DirichletBC(_E, bc->value(), bc->markers(), bc->method()));
+        e_bc.reset(new DirichletBC(_E, bcs[i]->value(), bcs[i]->markers(), bcs[i]->method()));
     }
     else
     {
       boost::shared_ptr<SubSpace> S(new SubSpace(*_E, component));
       if (sub_domain)
-        e_bc.reset(new DirichletBC(S, bc->value(), sub_domain, bc->method()));
+        e_bc.reset(new DirichletBC(S, bcs[i]->value(), sub_domain, bcs[i]->method()));
       else
-        e_bc.reset(new DirichletBC(S, bc->value(), bc->markers(), bc->method()));
+        e_bc.reset(new DirichletBC(S, bcs[i]->value(), bcs[i]->markers(), bcs[i]->method()));
     }
     e_bc->homogenize();
 
