@@ -27,15 +27,10 @@
 #include <map>
 #include <set>
 #include <vector>
+#include <Eigen/Dense>
 
 #include <dolfin/common/types.h>
 
-namespace arma
-{
-  template <typename T> class Mat;
-  template <typename T> class Col;
-}
-
 namespace ufc
 {
   class cell;
@@ -72,40 +67,43 @@ namespace dolfin
 
     // Build data structures for unique dofs on patch of given cell
     static void build_unique_dofs(std::set<std::size_t>& unique_dofs,
-                                  std::map<std::size_t, std::map<std::size_t, std::size_t> >& cell2dof2row,
+                        std::map<std::size_t, std::map<std::size_t, std::size_t> >& cell2dof2row,
                                   const Cell& cell0,
-                                  const ufc::cell& c0,
                                   const FunctionSpace& V);
 
     // Compute unique dofs in given cell
     static std::map<std::size_t, std::size_t>
-        compute_unique_dofs(const Cell& cell, const ufc::cell& c,
-                            const FunctionSpace& V,
-                            std::size_t& row, std::set<std::size_t>& unique_dofs);
+      compute_unique_dofs(const Cell& cell, const FunctionSpace& V,
+                          std::size_t& row, std::set<std::size_t>& unique_dofs);
 
     // Compute coefficients on given cell
-    static void compute_coefficients(std::vector<std::vector<double> >& coefficients,
-                                     const Function&v, const FunctionSpace& V,
-                                     const FunctionSpace& W, const Cell& cell0,
-                                     const ufc::cell& c0,
-                                     const std::vector<dolfin::la_index>& dofs,
-                                     std::size_t& offset);
+    static void
+      compute_coefficients(std::vector<std::vector<double> >& coefficients,
+                           const Function&v, const FunctionSpace& V,
+                           const FunctionSpace& W, const Cell& cell0,
+                           const std::vector<double>& vertex_coordinates0,
+                           const ufc::cell& c0,
+                           const std::vector<dolfin::la_index>& dofs,
+                           std::size_t& offset);
 
     // Add equations for current cell
-    static void add_cell_equations(arma::Mat<double>& A,
-                                   arma::Col<double>& b,
-                                   const Cell& cell0,
-                                   const Cell& cell1,
-                                   const ufc::cell& c0,
-                                   const ufc::cell& c1,
-                                   const FunctionSpace& V,
-                                   const FunctionSpace& W,
-                                   const Function& v,
-                                   std::map<std::size_t, std::size_t>& dof2row);
+    static void add_cell_equations(Eigen::MatrixXd& A,
+                                 Eigen::VectorXd& b,
+                                 const Cell& cell0,
+                                 const Cell& cell1,
+                                 const std::vector<double>& vertex_coordinates0,
+                                 const std::vector<double>& vertex_coordinates1,
+                                 const ufc::cell& c0,
+                                 const ufc::cell& c1,
+                                 const FunctionSpace& V,
+                                 const FunctionSpace& W,
+                                 const Function& v,
+                                 std::map<std::size_t, std::size_t>& dof2row);
 
     // Average coefficients
-    static void average_coefficients(Function& w,
-                                     std::vector<std::vector<double> >& coefficients);
+    static void
+      average_coefficients(Function& w,
+                           std::vector<std::vector<double> >& coefficients);
 
   };
 
