@@ -90,7 +90,8 @@ namespace dolfin
     ///     interpolate (bool)
     ///         Optional argument: If true (default), interpolate
     ///         time samples closest to t if t is not present.
-    void retrieve(GenericVector& vector, double t, bool interpolate=true) const;
+    void retrieve(GenericVector& vector, double t,
+                  bool interpolate=true) const;
 
     /// Retrieve mesh at given time
     ///
@@ -134,7 +135,8 @@ namespace dolfin
     ///     std::string
     ///         The filename
     static std::string filename_data(std::string series_name,
-                                     std::string type_name, std::size_t index,
+                                     std::string type_name,
+                                     std::size_t index,
 				     bool compressed);
 
     /// Return filename for times
@@ -177,10 +179,9 @@ namespace dolfin
                                    std::string type_name);
 
     // Find index pair closest to given time
-    static std::pair<std::size_t, std::size_t> find_closest_pair(double t,
-                                                   const std::vector<double>& times,
-                                                   std::string series_name,
-                                                   std::string type_name);
+    static std::pair<std::size_t, std::size_t>
+      find_closest_pair(double t, const std::vector<double>& times,
+                        std::string series_name, std::string type_name);
 
     // Name of series
     std::string _name;
