@@ -297,7 +297,7 @@ dolfin::adapt(const LinearVariationalProblem& problem,
   boost::shared_ptr<const Form> a = problem.bilinear_form();
   boost::shared_ptr<const Form> L = problem.linear_form();
   boost::shared_ptr<const Function> u = problem.solution();
-  std::vector<boost::shared_ptr<const BoundaryCondition> > bcs = problem.bcs();
+  std::vector<boost::shared_ptr<const DirichletBC> > bcs = problem.bcs();
 
   // Refine forms
   dolfin_assert(a);
@@ -310,20 +310,19 @@ dolfin::adapt(const LinearVariationalProblem& problem,
   // Refine solution variable
   dolfin_assert(u);
   adapt(*u, adapted_mesh);
-  boost::shared_ptr<Function> refined_u =
-    reference_to_no_delete_pointer(const_cast<Function&>(u->child()));
+  boost::shared_ptr<Function> refined_u
+    = reference_to_no_delete_pointer(const_cast<Function&>(u->child()));
 
   // Refine bcs
   boost::shared_ptr<const FunctionSpace> V(problem.trial_space());
-  std::vector<boost::shared_ptr<const BoundaryCondition> > refined_bcs;
+  std::vector<boost::shared_ptr<const DirichletBC> > refined_bcs;
   for (std::size_t i = 0; i < bcs.size(); i++)
   {
-    const DirichletBC* bc = dynamic_cast<const DirichletBC*>(bcs[i].get());
-    if (bc != 0)
+    if (bcs[i] != 0)
     {
       dolfin_assert(V);
-      adapt(*bc, adapted_mesh, *V);
-      refined_bcs.push_back(bc->child_shared_ptr());
+      adapt(*bcs[i], adapted_mesh, *V);
+      refined_bcs.push_back(bcs[i]->child_shared_ptr());
     }
     else
     {
@@ -364,7 +363,7 @@ dolfin::adapt(const NonlinearVariationalProblem& problem,
   boost::shared_ptr<const Form> F = problem.residual_form();
   boost::shared_ptr<const Form> J = problem.jacobian_form();
   boost::shared_ptr<const Function> u = problem.solution();
-  std::vector<boost::shared_ptr<const BoundaryCondition> > bcs = problem.bcs();
+  std::vector<boost::shared_ptr<const DirichletBC> > bcs = problem.bcs();
 
   // Refine forms
   dolfin_assert(F);
@@ -382,22 +381,13 @@ dolfin::adapt(const NonlinearVariationalProblem& problem,
 
   // Refine bcs
   boost::shared_ptr<const FunctionSpace> V(problem.trial_space());
-  std::vector<boost::shared_ptr<const BoundaryCondition> > refined_bcs;
+  std::vector<boost::shared_ptr<const DirichletBC> > refined_bcs;
   for (std::size_t i = 0; i < bcs.size(); i++)
   {
-    const DirichletBC* bc = dynamic_cast<const DirichletBC*>(bcs[i].get());
-    if (bc != 0)
-    {
-      dolfin_assert(V);
-      adapt(*bc, adapted_mesh, *V);
-      refined_bcs.push_back(bc->child_shared_ptr());
-    }
-    else
-    {
-      dolfin_error("adapt.cpp",
-                   "adapt nonlinear variational problem",
-                   "Only implemented for Dirichlet boundary conditions");
-    }
+    dolfin_assert(bcs[i] != 0);
+    dolfin_assert(V);
+    adapt(*bcs[i], adapted_mesh, *V);
+    refined_bcs.push_back(bcs[i]->child_shared_ptr());
   }
 
   // Create new problem
@@ -405,14 +395,18 @@ dolfin::adapt(const NonlinearVariationalProblem& problem,
   dolfin_assert(u);
   boost::shared_ptr<NonlinearVariationalProblem> refined_problem;
   if (J)
+  {
     refined_problem.reset(new NonlinearVariationalProblem(F->child_shared_ptr(),
                                                           refined_u,
                                                           refined_bcs,
                                                           J->child_shared_ptr()));
+  }
   else
+  {
     refined_problem.reset(new NonlinearVariationalProblem(F->child_shared_ptr(),
                                                           refined_u,
                                                           refined_bcs));
+  }
 
   // Set parent / child
   set_parent_child(problem, refined_problem);
@@ -469,11 +463,11 @@ const dolfin::DirichletBC& dolfin::adapt(const DirichletBC& bc,
   else
   {
     // Extract markers
-    const std::vector<std::pair<std::size_t, std::size_t> >& markers = bc.markers();
+    const std::vector<std::size_t>& markers = bc.markers();
 
     // Create refined markers
     dolfin_assert(W->mesh());
-    std::vector<std::pair<std::size_t, std::size_t> > refined_markers;
+    std::vector<std::size_t> refined_markers;
     adapt_markers(refined_markers, *adapted_mesh, markers, *W->mesh());
 
     refined_bc.reset(new DirichletBC(V, g_ptr, refined_markers, bc.method()));
@@ -537,20 +531,27 @@ const dolfin::MeshFunction<std::size_t>&
     return mesh_function.child();
   }
 
-  const Mesh& mesh = mesh_function.mesh();
+  dolfin_assert(mesh_function.mesh());
+  const Mesh& mesh = *mesh_function.mesh();
   const std::size_t dim = mesh.topology().dim();
 
   // Extract parent map from data of refined mesh
-  boost::shared_ptr<MeshFunction<std::size_t> > parent;
+  const std::vector<std::size_t>* parent = NULL;
   if (mesh_function.dim() == dim)
-    parent = adapted_mesh->data().mesh_function("parent_cell");
+  {
+    if (adapted_mesh->data().exists("parent_cell", dim))
+      parent = &(adapted_mesh->data().array("parent_cell", dim));
+  }
   else if (mesh_function.dim() == (dim - 1))
-    parent = adapted_mesh->data().mesh_function("parent_facet");
+  {
+    if (adapted_mesh->data().exists("parent_facet", dim - 1))
+      parent = &(adapted_mesh->data().array("parent_facet", dim - 1));
+  }
   else
     dolfin_not_implemented();
 
   // Check that parent map exists
-  if (!parent.get())
+  if (!parent)
   {
     dolfin_error("adapt.cpp",
                  "adapt mesh function",
@@ -563,7 +564,7 @@ const dolfin::MeshFunction<std::size_t>&
   // Map values of mesh function into refined mesh function
   boost::shared_ptr<MeshFunction<std::size_t> >
     adapted_mesh_function(new MeshFunction<std::size_t>(*adapted_mesh,
-                                                 mesh_function.dim()));
+                                                        mesh_function.dim()));
   for (std::size_t i = 0; i < adapted_mesh_function->size(); i++)
   {
     const std::size_t parent_index = (*parent)[i];
@@ -580,75 +581,50 @@ const dolfin::MeshFunction<std::size_t>&
   return *adapted_mesh_function;
 }
 //-----------------------------------------------------------------------------
-void dolfin::adapt_markers(std::vector<std::pair<std::size_t, std::size_t> >& refined_markers,
+void dolfin::adapt_markers(std::vector<std::size_t>& refined_markers,
                            const Mesh& adapted_mesh,
-                           const std::vector<std::pair<std::size_t, std::size_t> >& markers,
+                           const std::vector<std::size_t>& markers,
                            const Mesh& mesh)
 {
-
-  // Extract parent map from data of refined mesh
-  boost::shared_ptr<MeshFunction<std::size_t> > parent_cells = \
-    adapted_mesh.data().mesh_function("parent_cell");
-  boost::shared_ptr<MeshFunction<std::size_t> > parent_facets = \
-    adapted_mesh.data().mesh_function("parent_facet");
+  // Topological dimension
+  const std::size_t D = mesh.topology().dim();
 
   // Check that parent maps exist
-  if (!parent_cells.get() || !parent_facets.get())
+  if (!adapted_mesh.data().exists("parent_facet", D - 1))
   {
     dolfin_error("adapt.cpp",
                  "adapt markers",
                  "Unable to extract information about parent mesh entites");
   }
 
+  // Extract parent map from data of refined mesh
+  const std::vector<std::size_t>& parent_facets
+    = adapted_mesh.data().array("parent_facet", D - 1);
+
   // Create map (parent_cell, parent_local_facet) -> [(child_cell,
   // child_local_facet), ...] for boundary facets
-  std::pair<std::size_t, std::size_t> child;
-  std::pair<std::size_t, std::size_t> parent;
-  std::map< std::pair<std::size_t, std::size_t>,
-    std::vector< std::pair<std::size_t, std::size_t> > > children;
 
-  const std::size_t D = mesh.topology().dim();
+  std::map<std::size_t, std::vector<std::size_t> > children;
   for (FacetIterator facet(adapted_mesh); !facet.end(); ++facet)
   {
     // Ignore interior facets
     if (facet->num_entities(D) == 2)
       continue;
 
-    // Extract cell and local facet number
-    Cell cell(adapted_mesh, facet->entities(D)[0]);
-    const std::size_t local_facet = cell.index(*facet);
-
-    child.first = cell.index();
-    child.second = local_facet;
-
-    // Extract parent cell
-    Cell parent_cell(mesh, (*parent_cells)[cell]);
-
-    // Extract (global) index of parent facet
-    const std::size_t parent_facet_index = (*parent_facets)[*facet];
-
-    // Extract local number of parent facet wrt parent cell
-    Facet parent_facet(mesh, parent_facet_index);
-    const std::size_t parent_local_facet = parent_cell.index(parent_facet);
-
-    parent.first = parent_cell.index();
-    parent.second = parent_local_facet;
-
-    // Add this (cell, local_facet) to list of child facets
-    children[parent].push_back(child);
+    // Extract index of parent facet
+    const std::size_t parent_facet_index = parent_facets[facet->index()];
 
+    children[parent_facet_index].push_back(facet->index());
   }
 
   // Use above map to construct refined markers
-  std::vector<std::pair<std::size_t, std::size_t> >  child_facets;
-  std::vector<std::pair<std::size_t, std::size_t> >::const_iterator it;
+  std::vector<std::size_t> child_facets;
+  std::vector<std::size_t>::const_iterator it;
   for (it = markers.begin(); it != markers.end(); ++it)
   {
     child_facets = children[*it];
     for (std::size_t k = 0; k < child_facets.size(); k++)
-    {
       refined_markers.push_back(child_facets[k]);
-    }
   }
 }
 //-----------------------------------------------------------------------------
