@@ -16,11 +16,14 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2008-08-11
-// Last changed: 2008-08-11
+// Last changed: 2013-03-06
 
 #ifndef __HARMONIC_SMOOTHING_H
 #define __HARMONIC_SMOOTHING_H
 
+#include <boost/shared_ptr.hpp>
+#include "MeshDisplacement.h"
+
 namespace dolfin
 {
 
@@ -37,7 +40,9 @@ namespace dolfin
   public:
 
     /// Move coordinates of mesh according to new boundary coordinates
-    static void move(Mesh& mesh, const BoundaryMesh& new_boundary);
+    /// and return the displacement
+    static boost::shared_ptr<MeshDisplacement> move(Mesh& mesh, 
+                                        const BoundaryMesh& new_boundary);
 
   };
 
