@@ -16,7 +16,7 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2011-01-30
-// Last changed: 2012-11-29
+// Last changed: 2013-03-11
 
 #ifndef __HIERARCHICAL_H
 #define __HIERARCHICAL_H
@@ -71,7 +71,7 @@ namespace dolfin
     ///     bool
     ///         The return value is true iff the object has a parent.
     bool has_parent() const
-    { return _parent; }
+    { return _parent ? true : false; }
 
     /// Check if the object has a child.
     ///
@@ -79,7 +79,7 @@ namespace dolfin
     ///     bool
     ///         The return value is true iff the object has a child.
     bool has_child() const
-    { return _child; }
+    { return _child ? true : false; }
 
     /// Return parent in hierarchy. An error is thrown if the object
     /// has no parent.
