@@ -1,4 +1,4 @@
-// Copyright (C) 2003-2010 Anders Logg
+// Copyright (C) 2003-2011 Anders Logg
 //
 // This file is part of DOLFIN.
 //
@@ -9,14 +9,14 @@
 //
 // DOLFIN is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2003-12-21
-// Last changed: 2010-11-16
+// Last changed: 2012-11-01
 
 // Uncomment this for testing std::clock
 //#define _WIN32
@@ -27,7 +27,9 @@
 #include <sys/time.h>
 #endif
 
+#include "MPI.h"
 #include <dolfin/log/log.h>
+#include <dolfin/log/LogManager.h>
 #include "timing.h"
 
 // We use boost::timer (std::clock) on Windows and otherwise the
@@ -75,8 +77,41 @@ double dolfin::time()
   struct timeval tv;
   struct timezone tz;
   if (gettimeofday(&tv, &tz) != 0)
-    error("Timing failed, gettimeofday() failed.");
+  {
+    dolfin_error("timing.cpp",
+                 "return current time",
+                 "Call to gettimeofday() failed");
+  }
   return static_cast<double>(tv.tv_sec) + static_cast<double>(tv.tv_usec)*1e-6;
 #endif
 }
 //-----------------------------------------------------------------------------
+void dolfin::list_timings(bool reset)
+{
+  // Optimization
+  if (!LogManager::logger.is_active())
+    return;
+
+  // Only print summary for process 0
+  if (MPI::process_number() != 0)
+    return;
+
+  LogManager::logger.list_timings(reset);
+}
+//-----------------------------------------------------------------------------
+Table dolfin::timings(bool reset)
+{
+  return LogManager::logger.timings(reset);
+}
+//-----------------------------------------------------------------------------
+void dolfin::summary(bool reset)
+{
+  warning("The summary() function is deprecated, use list_timings().");
+  list_timings(reset);
+}
+//-----------------------------------------------------------------------------
+double dolfin::timing(std::string task, bool reset)
+{
+  return LogManager::logger.timing(task, reset);
+}
+//-----------------------------------------------------------------------------
