@@ -8,17 +8,17 @@
 #include <dolfin/log/dolfin_log.h>
 #include <dolfin/la/dolfin_la.h>
 #include <dolfin/nls/dolfin_nls.h>
-#include <dolfin/intersection/dolfin_intersection.h>
 #include <dolfin/mesh/dolfin_mesh.h>
 #include <dolfin/generation/dolfin_generation.h>
+#include <dolfin/geometry/dolfin_geometry.h>
 #include <dolfin/refinement/dolfin_refinement.h>
 #include <dolfin/function/dolfin_function.h>
 #include <dolfin/graph/dolfin_graph.h>
 #include <dolfin/plot/dolfin_plot.h>
 #include <dolfin/math/dolfin_math.h>
-#include <dolfin/quadrature/dolfin_quadrature.h>
 #include <dolfin/ale/dolfin_ale.h>
 #include <dolfin/fem/dolfin_fem.h>
+#include <dolfin/multistage/dolfin_multistage.h>
 #include <dolfin/adaptivity/dolfin_adaptivity.h>
 #include <dolfin/io/dolfin_io.h>
 
