@@ -22,7 +22,7 @@
 // Modified by Martin Alnaes 2013
 //
 // First added:  2007-01-17
-// Last changed: 2013-01-18
+// Last changed: 2013-09-19
 
 #include <boost/scoped_ptr.hpp>
 
@@ -146,7 +146,10 @@ void Assembler::assemble_cells(GenericTensor& A,
   bool use_domains = domains && !domains->empty();
 
   // Assemble over cells
-  Progress p(AssemblerBase::progress_message(A.rank(), "cells"), mesh.num_cells());
+  ufc::cell ufc_cell;
+  std::vector<double> vertex_coordinates;
+  Progress p(AssemblerBase::progress_message(A.rank(), "cells"),
+             mesh.num_cells());
   for (CellIterator cell(mesh); !cell.end(); ++cell)
   {
     // Get integral for sub domain (if any)
@@ -158,7 +161,9 @@ void Assembler::assemble_cells(GenericTensor& A,
       continue;
 
     // Update to current cell
-    ufc.update(*cell);
+    cell->get_cell_data(ufc_cell);
+    cell->get_vertex_coordinates(vertex_coordinates);
+    ufc.update(*cell, vertex_coordinates, ufc_cell);
 
     // Get local-to-global dof maps for cell
     bool empty_dofmap = false;
@@ -173,9 +178,9 @@ void Assembler::assemble_cells(GenericTensor& A,
       continue;
 
     // Tabulate cell tensor
-    integral->tabulate_tensor(&ufc.A[0], ufc.w(),
-                              &ufc.cell.vertex_coordinates[0],
-                              ufc.cell.orientation);
+    integral->tabulate_tensor(ufc.A.data(), ufc.w(),
+                              vertex_coordinates.data(),
+                              ufc_cell.orientation);
 
     // Add entries to global tensor. Either store values cell-by-cell
     // (currently only available for functionals)
@@ -216,7 +221,8 @@ void Assembler::assemble_exterior_facets(GenericTensor& A,
   std::vector<const std::vector<dolfin::la_index>* > dofs(form_rank);
 
   // Exterior facet integral
-  const ufc::exterior_facet_integral* integral = ufc.default_exterior_facet_integral.get();
+  const ufc::exterior_facet_integral* integral
+    = ufc.default_exterior_facet_integral.get();
 
   // Check whether integral is domain-dependent
   bool use_domains = domains && !domains->empty();
@@ -228,6 +234,8 @@ void Assembler::assemble_exterior_facets(GenericTensor& A,
   dolfin_assert(mesh.ordered());
 
   // Assemble over exterior facets (the cells of the boundary)
+  ufc::cell ufc_cell;
+  std::vector<double> vertex_coordinates;
   Progress p(AssemblerBase::progress_message(A.rank(), "exterior facets"),
              mesh.num_facets());
   for (FacetIterator facet(mesh); !facet.end(); ++facet)
@@ -254,17 +262,21 @@ void Assembler::assemble_exterior_facets(GenericTensor& A,
     // Get local index of facet with respect to the cell
     const std::size_t local_facet = mesh_cell.index(*facet);
 
-    // Update to current cell
-    ufc.update(mesh_cell, local_facet);
+    // Update UFC cell
+    mesh_cell.get_cell_data(ufc_cell, local_facet);
+    mesh_cell.get_vertex_coordinates(vertex_coordinates);
+
+    // Update UFC object
+    ufc.update(mesh_cell, vertex_coordinates, ufc_cell);
 
     // Get local-to-global dof maps for cell
     for (std::size_t i = 0; i < form_rank; ++i)
       dofs[i] = &(dofmaps[i]->cell_dofs(mesh_cell.index()));
 
     // Tabulate exterior facet tensor
-    integral->tabulate_tensor(&ufc.A[0],
+    integral->tabulate_tensor(ufc.A.data(),
                               ufc.w(),
-                              &ufc.cell.vertex_coordinates[0],
+                              vertex_coordinates.data(),
                               local_facet);
 
     // Add entries to global tensor
@@ -274,11 +286,10 @@ void Assembler::assemble_exterior_facets(GenericTensor& A,
   }
 }
 //-----------------------------------------------------------------------------
-void Assembler::assemble_interior_facets(GenericTensor& A,
-                                         const Form& a,
-                                         UFC& ufc,
-                                         const MeshFunction<std::size_t>* domains,
-                                         std::vector<double>* values)
+void Assembler::assemble_interior_facets(GenericTensor& A, const Form& a,
+                                      UFC& ufc,
+                                      const MeshFunction<std::size_t>* domains,
+                                      std::vector<double>* values)
 {
   // Skip assembly if there are no interior facet integrals
   if (!ufc.form.has_interior_facet_integrals())
@@ -309,7 +320,8 @@ void Assembler::assemble_interior_facets(GenericTensor& A,
   }
 
   // Interior facet integral
-  const ufc::interior_facet_integral* integral = ufc.default_interior_facet_integral.get();
+  const ufc::interior_facet_integral* integral
+    = ufc.default_interior_facet_integral.get();
 
   // Check whether integral is domain-dependent
   bool use_domains = domains && !domains->empty();
@@ -321,17 +333,20 @@ void Assembler::assemble_interior_facets(GenericTensor& A,
   dolfin_assert(mesh.ordered());
 
   // Get interior facet directions (if any)
-  boost::shared_ptr<MeshFunction<std::size_t> >
-    facet_orientation = mesh.data().mesh_function("facet_orientation");
-  if (facet_orientation && facet_orientation->dim() != D - 1)
+  const std::vector<std::size_t>* facet_orientation = NULL;
+  if (mesh.data().exists("facet_orientation", D - 1))
+    facet_orientation = &(mesh.data().array("facet_orientation", D - 1));
+
+  if (facet_orientation && facet_orientation->size() != mesh.num_facets())
   {
     dolfin_error("Assembler.cpp",
                  "assemble form over interior facets",
-                 "Expecting facet orientation to be defined on facets (not dimension %d)",
-                 facet_orientation->dim());
+                 "Expecting facet orientation to be defined on facets");
   }
 
   // Assemble over interior facets (the facets of the mesh)
+  ufc::cell ufc_cell[2];
+  std::vector<double> vertex_coordinates[2];
   Progress p(AssemblerBase::progress_message(A.rank(), "interior facets"),
              mesh.num_facets());
   for (FacetIterator facet(mesh); !facet.end(); ++facet)
@@ -353,7 +368,7 @@ void Assembler::assemble_interior_facets(GenericTensor& A,
 
     // Get cells incident with facet
     std::pair<const Cell, const Cell>
-      cells = facet->adjacent_cells(facet_orientation.get());
+      cells = facet->adjacent_cells(facet_orientation);
     const Cell& cell0 = cells.first;
     const Cell& cell1 = cells.second;
 
@@ -362,14 +377,22 @@ void Assembler::assemble_interior_facets(GenericTensor& A,
     std::size_t local_facet1 = cell1.index(*facet);
 
     // Update to current pair of cells
-    ufc.update(cell0, local_facet0, cell1, local_facet1);
+    cell0.get_cell_data(ufc_cell[0], local_facet0);
+    cell0.get_vertex_coordinates(vertex_coordinates[0]);
+    cell1.get_cell_data(ufc_cell[1], local_facet1);
+    cell1.get_vertex_coordinates(vertex_coordinates[1]);
+
+    ufc.update(cell0, vertex_coordinates[0], ufc_cell[0],
+               cell1, vertex_coordinates[1], ufc_cell[1]);
 
     // Tabulate dofs for each dimension on macro element
     for (std::size_t i = 0; i < form_rank; i++)
     {
       // Get dofs for each cell
-      const std::vector<dolfin::la_index>& cell_dofs0 = dofmaps[i]->cell_dofs(cell0.index());
-      const std::vector<dolfin::la_index>& cell_dofs1 = dofmaps[i]->cell_dofs(cell1.index());
+      const std::vector<dolfin::la_index>& cell_dofs0
+        = dofmaps[i]->cell_dofs(cell0.index());
+      const std::vector<dolfin::la_index>& cell_dofs1
+        = dofmaps[i]->cell_dofs(cell1.index());
 
       // Create space in macro dof vector
       macro_dofs[i].resize(cell_dofs0.size() + cell_dofs1.size());
@@ -382,10 +405,10 @@ void Assembler::assemble_interior_facets(GenericTensor& A,
     }
 
     // Tabulate interior facet tensor on macro element
-    integral->tabulate_tensor(&ufc.macro_A[0],
+    integral->tabulate_tensor(ufc.macro_A.data(),
                               ufc.macro_w(),
-                              &ufc.cell0.vertex_coordinates[0],
-                              &ufc.cell1.vertex_coordinates[0],
+                              vertex_coordinates[0].data(),
+                              vertex_coordinates[1].data(),
                               local_facet0,
                               local_facet1);
 
