@@ -21,7 +21,7 @@
 // Modified by Johannes Ring, 2012
 //
 // First added:  2007-01-17
-// Last changed: 2012-03-02
+// Last changed: 2013-09-19
 
 #include <boost/scoped_ptr.hpp>
 #include <dolfin/common/Timer.h>
@@ -43,7 +43,6 @@
 #include "SparsityPatternBuilder.h"
 #include "AssemblerBase.h"
 
-
 using namespace dolfin;
 
 //-----------------------------------------------------------------------------
@@ -51,13 +50,7 @@ void AssemblerBase::init_global_tensor(GenericTensor& A, const Form& a)
 {
   dolfin_assert(a.ufc_form());
 
-  // Check that we should not add values
-  if (reset_sparsity && add_values)
-  {
-    dolfin_error("AssemblerBase.cpp",
-                 "assemble form",
-                 "Can not add values when the sparsity pattern is reset");
-  }
+  check_parameters();
 
   // Get dof maps
   std::vector<const GenericDofMap*> dofmaps;
@@ -69,18 +62,32 @@ void AssemblerBase::init_global_tensor(GenericTensor& A, const Form& a)
     Timer t0("Build sparsity");
 
     // Create layout for initialising tensor
-    boost::shared_ptr<TensorLayout> tensor_layout = A.factory().create_layout(a.rank());
+    boost::shared_ptr<TensorLayout> tensor_layout;
+    tensor_layout = A.factory().create_layout(a.rank());
     dolfin_assert(tensor_layout);
 
-    std::vector<std::size_t> global_dimensions(a.rank());
-    std::vector<std::pair<std::size_t, std::size_t> > local_range(a.rank());
+    // Get dimensions
+    std::vector<std::size_t> global_dimensions;
+    std::vector<std::pair<std::size_t, std::size_t> > local_range;
+    std::vector<std::size_t> block_sizes;
     for (std::size_t i = 0; i < a.rank(); i++)
     {
       dolfin_assert(dofmaps[i]);
-      global_dimensions[i] = dofmaps[i]->global_dimension();
-      local_range[i]       = dofmaps[i]->ownership_range();
+      global_dimensions.push_back(dofmaps[i]->global_dimension());
+      local_range.push_back(dofmaps[i]->ownership_range());
+      block_sizes.push_back(dofmaps[i]->block_size);
     }
-    tensor_layout->init(global_dimensions, local_range);
+
+    // Set block size for sparsity graphs
+    std::size_t block_size = 1;
+    if (a.rank() == 2)
+    {
+      const std::vector<std::size_t> _bs(a.rank(), dofmaps[0]->block_size);
+      block_size = (block_sizes == _bs) ? dofmaps[0]->block_size : 1;
+    }
+
+    // Initialise tensor layout
+    tensor_layout->init(global_dimensions, block_size, local_range);
 
     // Build sparsity pattern if required
     if (tensor_layout->sparsity_pattern())
@@ -112,7 +119,8 @@ void AssemblerBase::init_global_tensor(GenericTensor& A, const Form& a)
       // Loop over rows and insert 0.0 on the diagonal
       const double block = 0.0;
       const std::pair<std::size_t, std::size_t> row_range = A.local_range(0);
-      for (std::size_t i = row_range.first; i < row_range.second; i++)
+      const std::size_t range = std::min(row_range.second, A.size(1));
+      for (std::size_t i = row_range.first; i < range; i++)
       {
         dolfin::la_index _i = i;
         _A.set(&block, 1, &_i, 1, &_i);
@@ -144,12 +152,11 @@ void AssemblerBase::init_global_tensor(GenericTensor& A, const Form& a)
 //-----------------------------------------------------------------------------
 void AssemblerBase::check_parameters() const
 {
-  if (finalize_tensor && keep_diagonal)
+  if (reset_sparsity && add_values)
   {
     dolfin_error("AssemblerBase.cpp",
                  "check parameters",
-                 "Finalizing the tensor and keeping diagonal entries are incompatible.\
-Finalizing tensor will remove any zeroes ");
+                 "Can not add values when the sparsity pattern is reset");
   }
 
   if (!reset_sparsity && keep_diagonal)
