@@ -23,8 +23,9 @@
 // Last changed: 2012-11-14
 //
 // FIXME: This class needs some cleanup, in particular collecting
-// FIXME: all data from different representations into a common
-// FIXME: data structure (perhaps an std::vector<std::size_t> with facet indices).
+//        all data from different representations into a common
+//        data structure (perhaps an std::vector<std::size_t> with
+//        facet indices).
 
 #ifndef __DIRICHLET_BC_H
 #define __DIRICHLET_BC_H
@@ -33,12 +34,13 @@
 #include <set>
 #include <string>
 #include <vector>
+#include <boost/multi_array.hpp>
 #include <boost/shared_ptr.hpp>
 #include <boost/unordered_map.hpp>
 
 #include <dolfin/common/types.h>
 #include <dolfin/common/Hierarchical.h>
-#include "BoundaryCondition.h"
+#include <dolfin/common/Variable.h>
 
 namespace dolfin
 {
@@ -82,22 +84,34 @@ namespace dolfin
   /// mesh. This is handled automatically when exporting a mesh from
   /// for example VMTK.
   ///
-  /// The ``method`` variable may be used to specify the type of
-  /// method used to identify degrees of freedom on the
-  /// boundary. Available methods are: topological approach (default),
-  /// geometric approach, and pointwise approach. The topological
-  /// approach is faster, but will only identify degrees of freedom
-  /// that are located on a facet that is entirely on the boundary. In
-  /// particular, the topological approach will not identify degrees
-  /// of freedom for discontinuous elements (which are all internal to
-  /// the cell).  A remedy for this is to use the geometric
-  /// approach. To apply pointwise boundary conditions
-  /// e.g. pointloads, one will have to use the pointwise approach
-  /// which in turn is the slowest of the three possible methods.  The
-  /// three possibilties are "topological", "geometric" and
-  /// "pointwise".
-
-  class DirichletBC : public BoundaryCondition, public Hierarchical<DirichletBC>
+  /// The 'method' variable may be used to specify the type of method
+  /// used to identify degrees of freedom on the boundary. Available
+  /// methods are: topological approach (default), geometric approach,
+  /// and pointwise approach. The topological approach is faster, but
+  /// will only identify degrees of freedom that are located on a
+  /// facet that is entirely on the boundary. In particular, the
+  /// topological approach will not identify degrees of freedom for
+  /// discontinuous elements (which are all internal to the cell). A
+  /// remedy for this is to use the geometric approach. In the
+  /// geometric approach, each dof on each facet that matches the
+  /// boundary condition will be checked. To apply pointwise boundary
+  /// conditions e.g. pointloads, one will have to use the pointwise
+  /// approach which in turn is the slowest of the three possible
+  /// methods. The three possibilties are "topological", "geometric"
+  /// and "pointwise".
+  ///
+  /// The 'check_midpoint' variable can be used to decide whether or
+  /// not the midpoint of each facet should be checked when a
+  /// user-defined _SubDomain_ is used to define the domain of the
+  /// boundary condition. By default, midpoints are always checked.
+  /// Note that this variable may be of importance close to corners,
+  /// in which case it is sometimes important to check the midpoint to
+  /// avoid including facets "on the diagonal close" to a corner. This
+  /// variable is also of importance for curved boundaries (like on a
+  /// sphere or cylinder), in which case it is important *not* to
+  /// check the midpoint which will be located in the interior of a
+  /// domain defined relative to a radius.
+  class DirichletBC : public Hierarchical<DirichletBC>, public Variable
   {
 
   public:
@@ -119,7 +133,8 @@ namespace dolfin
     DirichletBC(const FunctionSpace& V,
                 const GenericFunction& g,
                 const SubDomain& sub_domain,
-                std::string method="topological");
+                std::string method="topological",
+                bool check_midpoint=true);
 
     /// Create boundary condition for subdomain
     ///
@@ -136,7 +151,8 @@ namespace dolfin
     DirichletBC(boost::shared_ptr<const FunctionSpace> V,
                 boost::shared_ptr<const GenericFunction> g,
                 boost::shared_ptr<const SubDomain> sub_domain,
-                std::string method="topological");
+                std::string method="topological",
+                bool check_midpoint=true);
 
     /// Create boundary condition for subdomain specified by index
     ///
@@ -227,7 +243,8 @@ namespace dolfin
     ///         method to identify dofs.
     DirichletBC(boost::shared_ptr<const FunctionSpace> V,
                 boost::shared_ptr<const GenericFunction> g,
-                const std::vector<std::pair<std::size_t, std::size_t> >& markers,
+                const std::vector<std::size_t>&
+                markers,
                 std::string method="topological");
 
     /// Copy constructor
@@ -306,7 +323,6 @@ namespace dolfin
     void get_boundary_values(Map& boundary_values,
                              std::string method="default") const;
 
-
     /// Get boundary values from neighbour processes. If a method other than
     /// "pointwise" is used, this is necessary to ensure all boundary dofs are
     /// marked on all processes.
@@ -335,7 +351,8 @@ namespace dolfin
     ///         The vector
     ///     diag_val (double)
     ///         This parameter would normally be -1, 0 or 1.
-    void zero_columns(GenericMatrix& A, GenericVector& b, double diag_val=0) const;
+    void zero_columns(GenericMatrix& A, GenericVector& b,
+                      double diag_val=0) const;
 
     /// Return boundary markers
     ///
@@ -343,7 +360,15 @@ namespace dolfin
     ///     std::vector<std::pair<std::size_t, std::size_t> >
     ///         Boundary markers (facets stored as pairs of cells and
     ///         local facet numbers).
-    const std::vector<std::pair<std::size_t, std::size_t> >& markers() const;
+    const std::vector<std::size_t>& markers() const;
+
+    /// Return function space V
+    ///
+    /// *Returns*
+    ///     _FunctionSPace_
+    ///         The function space to which boundary conditions are applied.
+    boost::shared_ptr<const FunctionSpace> function_space() const
+    { return _function_space; }
 
     /// Return boundary value g
     ///
@@ -407,11 +432,11 @@ namespace dolfin
 
   private:
 
-    // FIXME: Make this function pure virtual in BoundaryCondition and reuse code
-    // for different apply methods
+    class LocalData;
 
     // Apply boundary conditions, common method
-    void apply(GenericMatrix* A, GenericVector* b, const GenericVector* x) const;
+    void apply(GenericMatrix* A, GenericVector* b,
+               const GenericVector* x) const;
 
     // Check input data to constructor
     void check() const;
@@ -420,7 +445,8 @@ namespace dolfin
     void init_facets() const;
 
     // Initialize sub domain markers from sub domain
-    void init_from_sub_domain(boost::shared_ptr<const SubDomain> sub_domain) const;
+    void
+      init_from_sub_domain(boost::shared_ptr<const SubDomain> sub_domain) const;
 
     // Initialize sub domain markers from MeshFunction
     void init_from_mesh_function(const MeshFunction<std::size_t>& sub_domains,
@@ -431,23 +457,31 @@ namespace dolfin
 
     // Compute dofs and values for application of boundary conditions using
     // given method
-    void compute_bc(Map& boundary_values,
-                    BoundaryCondition::LocalData& data, std::string method) const;
+    void compute_bc(Map& boundary_values, LocalData& data,
+                    std::string method) const;
 
     // Compute boundary values for facet (topological approach)
     void compute_bc_topological(Map& boundary_values,
-                                BoundaryCondition::LocalData& data) const;
+                                LocalData& data) const;
 
     // Compute boundary values for facet (geometrical approach)
     void compute_bc_geometric(Map& boundary_values,
-                              BoundaryCondition::LocalData& data) const;
+                              LocalData& data) const;
 
     // Compute boundary values for facet (pointwise approach)
     void compute_bc_pointwise(Map& boundary_values,
-                              BoundaryCondition::LocalData& data) const;
+                              LocalData& data) const;
 
     // Check if the point is in the same plane as the given facet
-    bool on_facet(double* coordinates, Facet& facet) const;
+    bool on_facet(const double* coordinates, const Facet& facet) const;
+
+    // Check arguments
+    void check_arguments(GenericMatrix* A,
+                         GenericVector* b,
+                         const GenericVector* x) const;
+
+    // The function space (possibly a sub function space)
+    boost::shared_ptr<const FunctionSpace> _function_space;
 
     // The function
     boost::shared_ptr<const GenericFunction> _g;
@@ -459,18 +493,44 @@ namespace dolfin
     static const std::set<std::string> methods;
 
   public:
+
     // User defined sub domain
     boost::shared_ptr<const SubDomain> _user_sub_domain;
+
   private:
 
-    // Boundary facets, stored as pairs (cell, local facet number)
-    mutable std::vector<std::pair<std::size_t, std::size_t> > facets;
+    // Boundary facets, stored by facet index (local to process)
+    mutable std::vector<std::size_t> _facets;
 
     // User defined mesh function
     boost::shared_ptr<const MeshFunction<std::size_t> > _user_mesh_function;
 
     // User defined sub domain marker for mesh or mesh function
     std::size_t _user_sub_domain_marker;
+
+    // Flag for whether midpoints should be checked
+    bool _check_midpoint;
+
+    // Local data for application of boundary conditions
+    class LocalData
+    {
+    public:
+
+      // Constructor
+      LocalData(const FunctionSpace& V);
+
+      // Coefficients
+      std::vector<double> w;
+
+      // Facet dofs
+      std::vector<std::size_t> facet_dofs;
+
+      // Coordinates for dofs
+      boost::multi_array<double, 2> coordinates;
+
+    };
+
+
   };
 
 }
