@@ -9,14 +9,14 @@
 //
 // DOLFIN is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2011-03-09
-// Last changed: 2011-03-11
+// Last changed: 2011-06-01
 
 #ifndef __DOMAIN_ASSIGNER_H
 #define __DOMAIN_ASSIGNER_H
@@ -27,13 +27,13 @@ namespace dolfin
 {
 
   class Form;
-  template <class T> class MeshFunction;
+  template <typename T> class MeshFunction;
 
   /// These classes are used for assignment of domains to forms:
   ///
-  ///   a.cell_domains = cell_domains
-  ///   a.exterior_facet_domains = exterior_facet_domains
-  ///   a.interior_facet_domains = interior_facet_domains
+  ///   a.dx = cell_domains
+  ///   a.ds = exterior_facet_domains
+  ///   a.dS = interior_facet_domains
   ///
   /// where the arguments can be either objects/references or
   /// shared pointers to MeshFunctions.
@@ -44,18 +44,18 @@ namespace dolfin
   public:
 
     // Constructor
-    CellDomainAssigner(Form& form) : form(form) {}
+    CellDomainAssigner(Form& form) : _form(form) {}
 
     // Assign reference
-    const CellDomainAssigner& operator= (const MeshFunction<uint>& domains);
+    const CellDomainAssigner& operator= (const MeshFunction<std::size_t>& domains);
 
     // Assign shared pointer
-    const CellDomainAssigner& operator= (boost::shared_ptr<const MeshFunction<uint> > domains);
+    const CellDomainAssigner& operator= (boost::shared_ptr<const MeshFunction<std::size_t> > domains);
 
   private:
 
     // The form
-    Form& form;
+    Form& _form;
 
   };
 
@@ -65,18 +65,18 @@ namespace dolfin
   public:
 
     // Constructor
-    ExteriorFacetDomainAssigner(Form& form) : form(form) {}
+    ExteriorFacetDomainAssigner(Form& form) : _form(form) {}
 
     // Assign reference
-    const ExteriorFacetDomainAssigner& operator= (const MeshFunction<uint>& domains);
+    const ExteriorFacetDomainAssigner& operator= (const MeshFunction<std::size_t>& domains);
 
     // Assign shared pointer
-    const ExteriorFacetDomainAssigner& operator= (boost::shared_ptr<const MeshFunction<uint> > domains);
+    const ExteriorFacetDomainAssigner& operator= (boost::shared_ptr<const MeshFunction<std::size_t> > domains);
 
   private:
 
     // The form
-    Form& form;
+    Form& _form;
 
   };
 
@@ -86,18 +86,18 @@ namespace dolfin
   public:
 
     // Constructor
-    InteriorFacetDomainAssigner(Form& form) : form(form) {}
+    InteriorFacetDomainAssigner(Form& form) : _form(form) {}
 
     // Assign reference
-    const InteriorFacetDomainAssigner& operator= (const MeshFunction<uint>& domains);
+    const InteriorFacetDomainAssigner& operator= (const MeshFunction<std::size_t>& domains);
 
     // Assign shared pointer
-    const InteriorFacetDomainAssigner& operator= (boost::shared_ptr<const MeshFunction<uint> > domains);
+    const InteriorFacetDomainAssigner& operator= (boost::shared_ptr<const MeshFunction<std::size_t> > domains);
 
   private:
 
     // The form
-    Form& form;
+    Form& _form;
 
   };
 
