@@ -55,14 +55,18 @@ namespace dolfin
   {
   public:
 
+    /// Constructor
+    GenericDofMap() : block_size(1) {}
+
     /// True if dof map is a view into another map (is a sub-dofmap)
     virtual bool is_view() const = 0;
 
-    /// Return the dimension of the global finite element function space
+    /// Return the dimension of the global finite element function
+    /// space
     virtual std::size_t global_dimension() const = 0;
 
-    /// Return the dimension of the local finite element function space
-    /// on a cell
+    /// Return the dimension of the local finite element function
+    /// space on a cell
     virtual std::size_t cell_dimension(std::size_t index) const = 0;
 
     /// Return the maximum dimension of the local finite element
@@ -93,34 +97,47 @@ namespace dolfin
       off_process_owner() const = 0;
 
     /// Local-to-global mapping of dofs on a cell
-    virtual const std::vector<dolfin::la_index>& cell_dofs(std::size_t cell_index) const = 0;
+    virtual const std::vector<dolfin::la_index>&
+      cell_dofs(std::size_t cell_index) const = 0;
 
     /// Tabulate local-local facet dofs
     virtual void tabulate_facet_dofs(std::vector<std::size_t>& dofs,
                                      std::size_t local_facet) const = 0;
 
-    /// Tabulate the local-to-local mapping of dofs on entity (dim, local_entity)
+    /// Tabulate the local-to-local mapping of dofs on entity
+    /// (dim, local_entity)
     virtual void tabulate_entity_dofs(std::vector<std::size_t>& dofs,
-				      std::size_t dim, std::size_t local_entity) const = 0;
+				      std::size_t dim,
+                                      std::size_t local_entity) const = 0;
 
     /// Return a map between vertices and dofs
-    virtual std::vector<dolfin::la_index> dof_to_vertex_map(Mesh& mesh) const = 0;
+    virtual std::vector<dolfin::la_index>
+      dof_to_vertex_map(const Mesh& mesh) const = 0;
 
     /// Return a map between vertices and dofs
-    virtual std::vector<std::size_t> vertex_to_dof_map(Mesh& mesh) const = 0;
+    virtual std::vector<std::size_t>
+      vertex_to_dof_map(const Mesh& mesh) const = 0;
 
     /// Tabulate the coordinates of all dofs on a cell (UFC cell version)
-    virtual void tabulate_coordinates(boost::multi_array<double, 2>& coordinates,
-                                      const ufc::cell& ufc_cell) const = 0;
+    virtual
+      void tabulate_coordinates(boost::multi_array<double, 2>& coordinates,
+                                const std::vector<double>& vertex_coordinates,
+                                const Cell& cell) const = 0;
 
-    /// Tabulate the coordinates of all dofs owned by this process
-    virtual std::vector<double> tabulate_all_coordinates(const Mesh& mesh) const = 0;
+    /// Tabulate the coordinates of all dofs owned by this
+    /// process. This function is typically used by preconditioners
+    /// that require the spatial coordinates of dofs, for example
+    /// for re-partitioning or nullspace computations. The format for
+    /// the return vector is [x0, y0, z0, x1, y1, z1, . . .].
+    virtual std::vector<double>
+      tabulate_all_coordinates(const Mesh& mesh) const = 0;
 
     /// Create a copy of the dof map
     virtual boost::shared_ptr<GenericDofMap> copy() const = 0;
 
     /// Create a new dof map on new mesh
-    virtual boost::shared_ptr<GenericDofMap> create(const Mesh& new_mesh) const = 0;
+    virtual boost::shared_ptr<GenericDofMap>
+      create(const Mesh& new_mesh) const = 0;
 
     /// Extract sub dofmap component
     virtual boost::shared_ptr<GenericDofMap>
@@ -132,20 +149,27 @@ namespace dolfin
         collapse(boost::unordered_map<std::size_t, std::size_t>& collapsed_map,
                  const Mesh& mesh) const = 0;
 
-    /// Set dof entries in vector to a specified value. Parallel layout
-    /// of vector must be consistent with dof map range.
+    /// Return list of global dof indices on this process
+    virtual std::vector<dolfin::la_index> dofs() const = 0;
+
+    /// Set dof entries in vector to a specified value. Parallel
+    /// layout of vector must be consistent with dof map range. This
+    /// function is typically used to construct the null space of a
+    /// matrix operator
     virtual void set(GenericVector& x, double value) const = 0;
 
     /// Set dof entries in vector to the value*x[i], where x[i] is the
     /// spatial coordinate of the dof. Parallel layout of vector must
-    /// be consistent with dof map range.
+    /// be consistent with dof map range. This function is typically
+    /// used to construct the null space of a matrix operator, e.g. rigid
+    /// body rotations.
     virtual void set_x(GenericVector& x, double value, std::size_t component,
                        const Mesh& mesh) const = 0;
 
-    /// Return map from shared dofs to the processes (not including the current
-    /// process) that share it.
-    virtual const boost::unordered_map<std::size_t, std::vector<unsigned int> >&
-      shared_dofs() const = 0;
+    /// Return map from shared dofs to the processes (not including
+    /// the current process) that share it.
+    virtual const boost::unordered_map<std::size_t,
+      std::vector<unsigned int> >& shared_dofs() const = 0;
 
     /// Return set of processes that share dofs with the this process
     virtual const std::set<std::size_t>& neighbours() const = 0;
@@ -153,9 +177,13 @@ namespace dolfin
     /// Return informal string representation (pretty-print)
     virtual std::string str(bool verbose) const = 0;
 
-    // Subdomain mapping constrained boundaries, e.g. periodic conditions
+    /// Subdomain mapping constrained boundaries, e.g. periodic conditions
     boost::shared_ptr<const SubDomain> constrained_domain;
 
+    /// Dofmap block size, e.g. 3 for 3D elasticity with a suitable
+    // ordered dofmap
+    std::size_t block_size;
+
   };
 
 }
