@@ -15,8 +15,10 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
+// Modified by Corrado Maurini, 2013.
+//
 // First added:  2011-06-22
-// Last changed: 2011-07-17
+// Last changed: 2013-03-20
 
 #include <dolfin/common/NoDeleter.h>
 #include <dolfin/function/Function.h>
@@ -53,7 +55,7 @@ NonlinearVariationalProblem(const Form& F,
 NonlinearVariationalProblem::
 NonlinearVariationalProblem(const Form& F,
                             Function& u,
-                            const BoundaryCondition& bc)
+                            const DirichletBC& bc)
   : Hierarchical<NonlinearVariationalProblem>(*this),
     _F(reference_to_no_delete_pointer(F)),
     _u(reference_to_no_delete_pointer(u))
@@ -68,7 +70,7 @@ NonlinearVariationalProblem(const Form& F,
 NonlinearVariationalProblem::
 NonlinearVariationalProblem(const Form& F,
                             Function& u,
-                            const BoundaryCondition& bc,
+                            const DirichletBC& bc,
                             const Form& J)
   : Hierarchical<NonlinearVariationalProblem>(*this),
     _F(reference_to_no_delete_pointer(F)),
@@ -85,7 +87,7 @@ NonlinearVariationalProblem(const Form& F,
 NonlinearVariationalProblem::
 NonlinearVariationalProblem(const Form& F,
                             Function& u,
-                            std::vector<const BoundaryCondition*> bcs)
+                            std::vector<const DirichletBC*> bcs)
   : Hierarchical<NonlinearVariationalProblem>(*this),
     _F(reference_to_no_delete_pointer(F)),
     _u(reference_to_no_delete_pointer(u))
@@ -101,7 +103,7 @@ NonlinearVariationalProblem(const Form& F,
 NonlinearVariationalProblem::
 NonlinearVariationalProblem(const Form& F,
                             Function& u,
-                            std::vector<const BoundaryCondition*> bcs,
+                            std::vector<const DirichletBC*> bcs,
                             const Form& J)
   : Hierarchical<NonlinearVariationalProblem>(*this),
     _F(reference_to_no_delete_pointer(F)),
@@ -119,7 +121,7 @@ NonlinearVariationalProblem(const Form& F,
 NonlinearVariationalProblem::
 NonlinearVariationalProblem(boost::shared_ptr<const Form> F,
                             boost::shared_ptr<Function> u,
-                            std::vector<boost::shared_ptr<const BoundaryCondition> > bcs)
+                            std::vector<boost::shared_ptr<const DirichletBC> > bcs)
   : Hierarchical<NonlinearVariationalProblem>(*this),
     _F(F), _u(u)
 {
@@ -134,7 +136,7 @@ NonlinearVariationalProblem(boost::shared_ptr<const Form> F,
 NonlinearVariationalProblem::
 NonlinearVariationalProblem(boost::shared_ptr<const Form> F,
                             boost::shared_ptr<Function> u,
-                            std::vector<boost::shared_ptr<const BoundaryCondition> > bcs,
+                            std::vector<boost::shared_ptr<const DirichletBC> > bcs,
                             boost::shared_ptr<const Form> J)
   : Hierarchical<NonlinearVariationalProblem>(*this),
     _F(F), _J(J), _u(u)
@@ -147,6 +149,29 @@ NonlinearVariationalProblem(boost::shared_ptr<const Form> F,
   check_forms();
 }
 //-----------------------------------------------------------------------------
+void NonlinearVariationalProblem::set_bounds(boost::shared_ptr<const Function> lb_func, boost::shared_ptr<const Function> ub_func)
+{
+    set_bounds(*lb_func,*ub_func);
+}
+//-----------------------------------------------------------------------------
+void NonlinearVariationalProblem::set_bounds(const Function& lb_func, const Function& ub_func)
+{
+    set_bounds(lb_func.vector(),ub_func.vector());
+}
+//-----------------------------------------------------------------------------
+void NonlinearVariationalProblem::set_bounds(const GenericVector& lb, const GenericVector& ub)
+{
+    set_bounds(reference_to_no_delete_pointer(lb),reference_to_no_delete_pointer(ub));
+}
+//-----------------------------------------------------------------------------
+void NonlinearVariationalProblem::set_bounds(boost::shared_ptr<const GenericVector> lb, boost::shared_ptr<const GenericVector> ub)
+{
+    this->_lb = lb;
+    this->_ub = ub;
+    dolfin_assert(_lb);
+    dolfin_assert(_ub);
+}
+//-----------------------------------------------------------------------------
 boost::shared_ptr<const Form> NonlinearVariationalProblem::residual_form() const
 {
   return _F;
@@ -167,7 +192,7 @@ boost::shared_ptr<const Function> NonlinearVariationalProblem::solution() const
   return _u;
 }
 //-----------------------------------------------------------------------------
-std::vector<boost::shared_ptr<const BoundaryCondition> >
+std::vector<boost::shared_ptr<const DirichletBC> >
 NonlinearVariationalProblem::bcs() const
 {
   return _bcs;
@@ -187,9 +212,34 @@ NonlinearVariationalProblem::test_space() const
   return _F->function_space(0);
 }
 //-----------------------------------------------------------------------------
+boost::shared_ptr<const GenericVector> NonlinearVariationalProblem::lower_bound() const
+{
+  dolfin_assert(_lb);
+  return _lb;
+}
+//-----------------------------------------------------------------------------
+boost::shared_ptr<const GenericVector> NonlinearVariationalProblem::upper_bound() const
+{
+  dolfin_assert(_ub);
+  return _ub;
+}
+//-----------------------------------------------------------------------------
 bool NonlinearVariationalProblem::has_jacobian() const
 {
-  return _J; // cast to bool
+  return _J ?  true : false;
+  //return _J; // cast to bool
+}
+//-----------------------------------------------------------------------------
+bool NonlinearVariationalProblem::has_lower_bound() const
+{
+  return _lb ?  true : false;
+  //return _lb; // cast to bool
+}
+//-----------------------------------------------------------------------------
+bool NonlinearVariationalProblem::has_upper_bound() const
+{
+  return _ub ?  true : false;
+  //return _ub; // cast to bool
 }
 //-----------------------------------------------------------------------------
 void NonlinearVariationalProblem::check_forms() const
@@ -197,17 +247,21 @@ void NonlinearVariationalProblem::check_forms() const
   // Check rank of residual F
   dolfin_assert(_F);
   if (_F->rank() != 1)
-    dolfin_error("NonlinearVariationalProblem.cpp",
+  {
+   dolfin_error("NonlinearVariationalProblem.cpp",
                  "define nonlinear variational problem F(u; v) = 0 for all v",
                  "Expecting the residual F to be a linear form (not rank %d)",
                  _F->rank());
+  }
 
   // Check rank of Jacobian J
   if (_J && _J->rank() != 2)
+  {
     dolfin_error("NonlinearVariationalProblem.cpp",
                  "define nonlinear variational problem F(u; v) = 0 for all v",
                  "Expecting the Jacobian J to be a bilinear form (not rank %d)",
                  _J->rank());
+  }
 
   /*
   // Check value of right-hand side
