@@ -15,8 +15,10 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
+// Modified by Corrado Maurini, 2013.
+//
 // First added:  2011-06-22
-// Last changed: 2012-08-17
+// Last changed: 2013-03-20
 
 #ifndef __NONLINEAR_VARIATIONAL_PROBLEM_H
 #define __NONLINEAR_VARIATIONAL_PROBLEM_H
@@ -31,7 +33,8 @@ namespace dolfin
   class Form;
   class Function;
   class FunctionSpace;
-  class BoundaryCondition;
+  class DirichletBC;
+  class GenericVector;
 
   /// This class represents a nonlinear variational problem:
   ///
@@ -63,14 +66,14 @@ namespace dolfin
     /// nonlinear solver that does not rely on the Jacobian.
     NonlinearVariationalProblem(const Form& F,
                                 Function& u,
-                                const BoundaryCondition& bc);
+                                const DirichletBC& bc);
 
     /// Create nonlinear variational problem with a single boundary condition.
     /// The Jacobian form is specified which allows the use of a nonlinear
     /// solver that relies on the Jacobian (using Newton's method).
     NonlinearVariationalProblem(const Form& F,
                                 Function& u,
-                                const BoundaryCondition& bc,
+                                const DirichletBC& bc,
                                 const Form& J);
 
     /// Create nonlinear variational problem with a list of boundary conditions.
@@ -78,14 +81,14 @@ namespace dolfin
     /// nonlinear solver that does not rely on the Jacobian.
     NonlinearVariationalProblem(const Form& F,
                                 Function& u,
-                                std::vector<const BoundaryCondition*> bcs);
+                                std::vector<const DirichletBC*> bcs);
 
     /// Create nonlinear variational problem with a list of boundary conditions.
     /// The Jacobian form is specified which allows the use of a nonlinear
     /// solver that relies on the Jacobian (using Newton's method).
     NonlinearVariationalProblem(const Form& F,
                                 Function& u,
-                                std::vector<const BoundaryCondition*> bcs,
+                                std::vector<const DirichletBC*> bcs,
                                 const Form& J);
 
     /// Create nonlinear variational problem, shared pointer version.
@@ -93,16 +96,32 @@ namespace dolfin
     /// nonlinear solver that does not rely on the Jacobian.
     NonlinearVariationalProblem(boost::shared_ptr<const Form> F,
                                 boost::shared_ptr<Function> u,
-                                std::vector<boost::shared_ptr<const BoundaryCondition> > bcs);
+                                std::vector<boost::shared_ptr<const DirichletBC> > bcs);
 
     /// Create nonlinear variational problem, shared pointer version.
     /// The Jacobian form is specified which allows the use of a nonlinear
     /// solver that relies on the Jacobian (using Newton's method).
     NonlinearVariationalProblem(boost::shared_ptr<const Form> F,
                                 boost::shared_ptr<Function> u,
-                                std::vector<boost::shared_ptr<const BoundaryCondition> > bcs,
+                                std::vector<boost::shared_ptr<const DirichletBC> > bcs,
                                 boost::shared_ptr<const Form> J);
 
+    /// Set the bounds for bound constrained solver
+    void set_bounds(boost::shared_ptr<const GenericVector> lb,
+                    boost::shared_ptr<const GenericVector> ub);
+    
+    /// Set the bounds for bound constrained solver
+    void set_bounds(const GenericVector& lb,
+                    const GenericVector& ub);
+    
+    /// Set the bounds for bound constrained solver
+    void set_bounds(boost::shared_ptr<const Function> lb_func,
+                    boost::shared_ptr<const Function> ub_func);
+    
+    /// Set the bounds for bound constrained solver
+    void set_bounds(const Function& lb_func,
+                    const Function& ub_func);
+    
     /// Return residual form
     boost::shared_ptr<const Form> residual_form() const;
 
@@ -116,16 +135,28 @@ namespace dolfin
     boost::shared_ptr<const Function> solution() const;
 
     /// Return boundary conditions
-    std::vector<boost::shared_ptr<const BoundaryCondition> > bcs() const;
+    std::vector<boost::shared_ptr<const DirichletBC> > bcs() const;
 
     /// Return trial space
     boost::shared_ptr<const FunctionSpace> trial_space() const;
 
     /// Return test space
     boost::shared_ptr<const FunctionSpace> test_space() const;
+    
+    /// Return lower bound 
+    boost::shared_ptr<const GenericVector> lower_bound() const;
 
+    /// Return upper bound 
+    boost::shared_ptr<const GenericVector> upper_bound() const;
+    
     /// Check whether Jacobian has been defined
     bool has_jacobian() const;
+    
+    /// Check whether lower bound has been defined
+    bool has_lower_bound() const; 
+    
+    /// Check whether upper bound have has defined
+    bool has_upper_bound() const;
 
   private:
 
@@ -142,8 +173,11 @@ namespace dolfin
     boost::shared_ptr<Function> _u;
 
     // The boundary conditions
-    std::vector<boost::shared_ptr<const BoundaryCondition> > _bcs;
+    std::vector<boost::shared_ptr<const DirichletBC> > _bcs;
 
+    // The lower and upper bounds (pointers may be zero if not provided)
+    boost::shared_ptr<const GenericVector> _lb;
+    boost::shared_ptr<const GenericVector> _ub;
   };
 
 }
