@@ -5,10 +5,10 @@
 
 #include <dolfin/fem/GenericDofMap.h>
 #include <dolfin/fem/DofMap.h>
+#include <dolfin/fem/fem_utils.h>
 #include <dolfin/fem/Equation.h>
 #include <dolfin/fem/FiniteElement.h>
 #include <dolfin/fem/BasisFunction.h>
-#include <dolfin/fem/BoundaryCondition.h>
 #include <dolfin/fem/DirichletBC.h>
 #include <dolfin/fem/PointSource.h>
 #include <dolfin/fem/assemble.h>
@@ -23,6 +23,9 @@
 #include <dolfin/fem/LinearVariationalSolver.h>
 #include <dolfin/fem/NonlinearVariationalProblem.h>
 #include <dolfin/fem/NonlinearVariationalSolver.h>
+#include <dolfin/fem/CCFEMForm.h>
+#include <dolfin/fem/CCFEMDofMap.h>
+#include <dolfin/fem/CCFEMAssembler.h>
 
 // Move up when ready or merge with Assembler.h
 #include <dolfin/fem/OpenMpAssembler.h>
