@@ -20,7 +20,7 @@
 // Modified by Andre Massing 2009
 //
 // First added:  2003-11-28
-// Last changed: 2012-10-25
+// Last changed: 2013-10-25
 
 #include <algorithm>
 #include <map>
@@ -29,13 +29,13 @@
 #include <boost/assign/list_of.hpp>
 
 #include <dolfin/adaptivity/Extrapolation.h>
-#include <dolfin/common/utils.h>
-#include <dolfin/common/Timer.h>
 #include <dolfin/common/Array.h>
+#include <dolfin/common/Timer.h>
+#include <dolfin/common/utils.h>
 #include <dolfin/fem/FiniteElement.h>
 #include <dolfin/fem/GenericDofMap.h>
 #include <dolfin/fem/DirichletBC.h>
-#include <dolfin/fem/UFC.h>
+#include <dolfin/geometry/Point.h>
 #include <dolfin/io/File.h>
 #include <dolfin/io/XMLFile.h>
 #include <dolfin/la/GenericVector.h>
@@ -43,9 +43,9 @@
 #include <dolfin/log/log.h>
 #include <dolfin/mesh/Mesh.h>
 #include <dolfin/mesh/Vertex.h>
-#include <dolfin/mesh/Point.h>
 #include <dolfin/mesh/Restriction.h>
 #include <dolfin/parameter/GlobalParameters.h>
+#include <dolfin/geometry/BoundingBoxTree.h>
 #include "Expression.h"
 #include "FunctionSpace.h"
 #include "Function.h"
@@ -91,8 +91,8 @@ Function::Function(boost::shared_ptr<const FunctionSpace> V,
   : Hierarchical<Function>(*this), _function_space(V), _vector(x),
     allow_extrapolation(dolfin::parameters["allow_extrapolation"])
 {
-  // We do not check for a subspace since this constructor is used for creating
-  // subfunctions
+  // We do not check for a subspace since this constructor is used for
+  // creating subfunctions
 
   // Assertion uses '<=' to deal with sub-functions
   dolfin_assert(V->dofmap());
@@ -187,8 +187,9 @@ const Function& Function::operator= (const Function& v)
 {
   dolfin_assert(v._vector);
 
-  // Make a copy of all the data, or if v is a sub-function, then we collapse
-  // the dof map and copy only the relevant entries from the vector of v.
+  // Make a copy of all the data, or if v is a sub-function, then we
+  // collapse the dof map and copy only the relevant entries from the
+  // vector of v.
   if (v._vector->size() == v._function_space->dim())
   {
     // Copy function space
@@ -206,10 +207,6 @@ const Function& Function::operator= (const Function& v)
     boost::unordered_map<std::size_t, std::size_t> collapsed_map;
     _function_space = v._function_space->collapse(collapsed_map);
 
-    // FIXME: This dolfin_assertion doesn't work in parallel
-    //dolfin_assert(collapsed_map.size() == _function_space->dofmap()->global_dimension());
-    //dolfin_assert(collapsed_map.size() == _function_space->dofmap()->local_dimension());
-
     // Get row indices of original and new vectors
     boost::unordered_map<std::size_t, std::size_t>::const_iterator entry;
     std::vector<dolfin::la_index> new_rows(collapsed_map.size());
@@ -229,10 +226,12 @@ const Function& Function::operator= (const Function& v)
     // Initial new vector (global)
     init_vector();
     dolfin_assert(_function_space->dofmap());
-    dolfin_assert(_vector->size() == _function_space->dofmap()->global_dimension());
+    dolfin_assert(_vector->size()
+                  == _function_space->dofmap()->global_dimension());
 
     // Set values in vector
-    this->_vector->set(&gathered_values[0], collapsed_map.size(), &new_rows[0]);
+    this->_vector->set(gathered_values.data(), collapsed_map.size(),
+                       new_rows.data());
     this->_vector->apply("insert");
   }
 
@@ -250,15 +249,18 @@ const Function& Function::operator= (const Expression& v)
 //-----------------------------------------------------------------------------
 Function& Function::operator[] (std::size_t i) const
 {
-  // Check if sub-Function is in the cache, otherwise create and add to cache
-  boost::ptr_map<std::size_t, Function>::iterator sub_function = sub_functions.find(i);
+  // Check if sub-Function is in the cache, otherwise create and add
+  // to cache
+  boost::ptr_map<std::size_t, Function>::iterator sub_function
+    = sub_functions.find(i);
   if (sub_function != sub_functions.end())
     return *(sub_function->second);
   else
   {
     // Extract function subspace
     std::vector<std::size_t> component = boost::assign::list_of(i);
-    boost::shared_ptr<const FunctionSpace> sub_space(_function_space->extract_sub_space(component));
+    boost::shared_ptr<const FunctionSpace>
+      sub_space(_function_space->extract_sub_space(component));
 
     // Insert sub-Function into map and return reference
     sub_functions.insert(i, new Function(sub_space, _vector));
@@ -266,6 +268,56 @@ Function& Function::operator[] (std::size_t i) const
   }
 }
 //-----------------------------------------------------------------------------
+FunctionAXPY Function::operator+(const Function& other) const
+{
+  return FunctionAXPY(*this, other, FunctionAXPY::ADD_ADD);
+}
+//-----------------------------------------------------------------------------
+FunctionAXPY Function::operator+(const FunctionAXPY& axpy) const
+{
+  return FunctionAXPY(axpy, *this, FunctionAXPY::ADD_ADD);
+}
+//-----------------------------------------------------------------------------
+FunctionAXPY Function::operator-(const Function& other) const
+{
+  return FunctionAXPY(*this, other, FunctionAXPY::ADD_SUB);
+}
+//-----------------------------------------------------------------------------
+FunctionAXPY Function::operator-(const FunctionAXPY& axpy) const
+{
+  return FunctionAXPY(axpy, *this, FunctionAXPY::SUB_ADD);
+}
+//-----------------------------------------------------------------------------
+FunctionAXPY Function::operator*(double scalar) const
+{
+  return FunctionAXPY(*this, scalar);
+}
+//-----------------------------------------------------------------------------
+FunctionAXPY Function::operator/(double scalar) const
+{
+  return FunctionAXPY(*this, 1.0/scalar);
+}
+//-----------------------------------------------------------------------------
+void Function::operator=(const FunctionAXPY& axpy)
+{
+  if (axpy.pairs().size() == 0)
+  {
+    dolfin_error("Function.cpp",
+                 "assign function",
+                 "FunctionAXPY is empty.");
+  }
+
+  // Make an initial assign and scale
+  *this = *(axpy.pairs()[0].second);
+  if (axpy.pairs()[0].first != 1.0)
+    *_vector *= axpy.pairs()[0].first;
+
+  // Start from item 2 and axpy
+  std::vector<std::pair<double, const Function*> >::const_iterator it;
+  for (it = axpy.pairs().begin()+1; it != axpy.pairs().end(); it++)
+    _vector->axpy(it->first, *(it->second->vector()));
+}
+//-----------------------------------------------------------------------------
 boost::shared_ptr<const FunctionSpace> Function::function_space() const
 {
   dolfin_assert(_function_space);
@@ -280,8 +332,6 @@ boost::shared_ptr<GenericVector> Function::vector()
   // Check that this is not a sub function.
   if (_vector->size() != _function_space->dofmap()->global_dimension())
   {
-    cout << "Size of vector: " << _vector->size() << endl;
-    cout << "Size of function space: " << _function_space->dofmap()->global_dimension() << endl;
     dolfin_error("Function.cpp",
                  "access vector of degrees of freedom",
                  "Cannot access a non-const vector from a subfunction");
@@ -318,37 +368,45 @@ void Function::eval(Array<double>& values, const Array<double>& x) const
   // Find the cell that contains x
   const double* _x = x.data();
   const Point point(mesh.geometry().dim(), _x);
-  int id = mesh.intersected_cell(point);
+
+  // FIXME: Testing
+  int ID = 0;
+
+  // Get index of first cell containing point
+  unsigned int id
+    = mesh.bounding_box_tree()->compute_first_entity_collision(point);
 
   // If not found, use the closest cell
-  if (id == -1)
+  if (id == std::numeric_limits<unsigned int>::max())
   {
     if (allow_extrapolation)
     {
-      id = mesh.closest_cell(point);
-      cout << "Extrapolating function value at x = " << point << " (not inside domain)." << endl;
+      id = mesh.bounding_box_tree()->compute_closest_entity(point).first;
+      cout << "Extrapolating function value at x = " << point
+           << " (not inside domain)." << endl;
     }
     else
     {
-      cout << "Evaluating at x = " << point << endl;
+      cout << point << endl;
       dolfin_error("Function.cpp",
                    "evaluate function at point",
                    "The point is not inside the domain. Consider setting \"allow_extrapolation\" to allow extrapolation");
     }
   }
 
+  ID = id;
+
   // Create cell that contains point
-  const Cell cell(mesh, id);
-  const UFCCell ufc_cell(cell);
+  const Cell cell(mesh, ID);
+  ufc::cell ufc_cell;
+  cell.get_cell_data(ufc_cell);
 
   // Call evaluate function
   eval(values, x, cell, ufc_cell);
 }
 //-----------------------------------------------------------------------------
-void Function::eval(Array<double>& values,
-                    const Array<double>& x,
-                    const Cell& dolfin_cell,
-                    const ufc::cell& ufc_cell) const
+void Function::eval(Array<double>& values, const Array<double>& x,
+                    const Cell& dolfin_cell, const ufc::cell& ufc_cell) const
 {
   // Developer note: work arrays/vectors are re-created each time this
   //                 function is called for thread-safety
@@ -364,8 +422,13 @@ void Function::eval(Array<double>& values,
   // Create work vector for expansion coefficients
   std::vector<double> coefficients(element.space_dimension());
 
+  // Cell vertices (re-allocated inside function for thread safety)
+  std::vector<double> vertex_coordinates;
+  dolfin_cell.get_vertex_coordinates(vertex_coordinates);
+
   // Restrict function to cell
-  restrict(&coefficients[0], element, dolfin_cell, ufc_cell);
+  restrict(coefficients.data(), element, dolfin_cell,
+           vertex_coordinates.data(), ufc_cell);
 
   // Create work vector for basis
   std::vector<double> basis(value_size_loc);
@@ -378,7 +441,8 @@ void Function::eval(Array<double>& values,
   const int cell_orientation = 0;
   for (std::size_t i = 0; i < element.space_dimension(); ++i)
   {
-    element.evaluate_basis(i, &basis[0], &x[0], &ufc_cell.vertex_coordinates[0],
+    element.evaluate_basis(i, basis.data(), x.data(),
+                           vertex_coordinates.data(),
                            cell_orientation);
     for (std::size_t j = 0; j < value_size_loc; ++j)
       values[j] += coefficients[i]*basis[j];
@@ -417,7 +481,8 @@ std::size_t Function::value_dimension(std::size_t i) const
   return _function_space->element()->value_dimension(i);
 }
 //-----------------------------------------------------------------------------
-void Function::eval(Array<double>& values, const Array<double>& x,
+void Function::eval(Array<double>& values,
+                    const Array<double>& x,
                     const ufc::cell& ufc_cell) const
 {
   dolfin_assert(_function_space);
@@ -426,6 +491,7 @@ void Function::eval(Array<double>& values, const Array<double>& x,
 
   // Check if UFC cell comes from mesh, otherwise redirect to
   // evaluate on non-matching cell
+  dolfin_assert(ufc_cell.mesh_identifier >= 0);
   if (ufc_cell.mesh_identifier == (int) mesh.id())
   {
     const Cell cell(mesh, ufc_cell.index);
@@ -444,13 +510,18 @@ void Function::non_matching_eval(Array<double>& values,
   const Mesh& mesh = *_function_space->mesh();
 
   const double* _x = x.data();
-  const std::size_t dim = mesh.geometry().dim();
-  const Point point(dim, _x);
+  const std::size_t gdim = mesh.geometry().dim();
+  const Point point(gdim, _x);
+
+  // FIXME: Testing
+  int ID = 0;
 
   // Alternative 1: Find cell that point (x) intersects
-  int id = mesh.intersected_cell(point);
+  unsigned int id
+    = mesh.bounding_box_tree()->compute_first_entity_collision(point);
 
-  if (id == -1 && !allow_extrapolation)
+  // Check whether we are allowed to extrapolate to evaluate
+  if (id == std::numeric_limits<unsigned int>::max() && !allow_extrapolation)
   {
     dolfin_error("Function.cpp",
                  "evaluate function at point",
@@ -458,46 +529,31 @@ void Function::non_matching_eval(Array<double>& values,
   }
 
   // Alternative 2: Compute closest cell to point (x)
-  if (id == -1 && allow_extrapolation && dim == 2)
-    id = mesh.closest_cell(point);
+  if (id == std::numeric_limits<unsigned int>::max() && allow_extrapolation)
+    id = mesh.bounding_box_tree()->compute_closest_entity(point).first;
 
-  // Alternative 3: Compute cell that contains barycenter of ufc_cell
-  // NB: This is slightly heuristic, but should work well for
-  // evaluation of points on refined meshes
-  if (id == -1 && allow_extrapolation)
-  {
-    // Extract vertices of ufc_cell
-    const double * const * vertices = ufc_cell.coordinates;
-
-    Point barycenter;
-    for (std::size_t i = 0; i <= dim; i++)
-    {
-      Point vertex(dim, vertices[i]);
-      barycenter += vertex;
-    }
-    barycenter /= (dim + 1);
-    id = mesh.intersected_cell(barycenter);
-  }
-
-  // Throw error if all alternatives failed.
-  if (id == -1)
+  // Throw error if all alternatives failed
+  if (id == std::numeric_limits<unsigned int>::max())
   {
     dolfin_error("Function.cpp",
                  "evaluate function at point",
                  "No matching cell found");
   }
 
+  ID = id;
+
   // Create cell that contains point
-  const Cell cell(mesh, id);
-  const UFCCell new_ufc_cell(cell);
+  const Cell cell(mesh, ID);
+  ufc::cell new_ufc_cell;
+  cell.get_cell_data(new_ufc_cell);
 
   // Call evaluate function
   eval(values, x, cell, new_ufc_cell);
 }
 //-----------------------------------------------------------------------------
-void Function::restrict(double* w,
-                        const FiniteElement& element,
+void Function::restrict(double* w, const FiniteElement& element,
                         const Cell& dolfin_cell,
+                        const double* vertex_coordinates,
                         const ufc::cell& ufc_cell) const
 {
   dolfin_assert(w);
@@ -510,7 +566,8 @@ void Function::restrict(double* w,
   {
     // Get dofmap for cell
     const GenericDofMap& dofmap = *_function_space->dofmap();
-    const std::vector<dolfin::la_index>& dofs = dofmap.cell_dofs(dolfin_cell.index());
+    const std::vector<dolfin::la_index>& dofs
+      = dofmap.cell_dofs(dolfin_cell.index());
 
     // Pick values from vector(s)
     _vector->get_local(w, dofs.size(), dofs.data());
@@ -518,7 +575,8 @@ void Function::restrict(double* w,
   else
   {
     // Restrict as UFC function (by calling eval)
-    restrict_as_ufc_function(w, element, dolfin_cell, ufc_cell);
+    restrict_as_ufc_function(w, element, dolfin_cell, vertex_coordinates,
+                             ufc_cell);
   }
 }
 //-----------------------------------------------------------------------------
@@ -530,8 +588,8 @@ void Function::compute_vertex_values(std::vector<double>& vertex_values,
 
   // Check that the mesh matches. Notice that the hash is only
   // compared if the pointers are not matching.
-  if (&mesh != _function_space->mesh().get() &&
-      mesh.hash() != _function_space->mesh()->hash())
+  if (&mesh != _function_space->mesh().get()
+      && mesh.hash() != _function_space->mesh()->hash())
   {
     dolfin_error("Function.cpp",
                  "interpolate function values at vertices",
@@ -550,7 +608,8 @@ void Function::compute_vertex_values(std::vector<double>& vertex_values,
     = _function_space->dofmap()->restriction();
 
   // Local data for interpolation on each cell
-  const std::size_t num_cell_vertices = mesh.type().num_vertices(mesh.topology().dim());
+  const std::size_t num_cell_vertices
+    = mesh.type().num_vertices(mesh.topology().dim());
 
   // Compute in tensor (one for scalar function, . . .)
   const std::size_t value_size_loc = value_size();
@@ -566,7 +625,8 @@ void Function::compute_vertex_values(std::vector<double>& vertex_values,
 
   // Interpolate vertex values on each cell (using last computed value
   // if not continuous, e.g. discontinuous Galerkin methods)
-  UFCCell ufc_cell(mesh);
+  ufc::cell ufc_cell;
+  std::vector<double> vertex_coordinates;
   for (CellIterator cell(mesh); !cell.end(); ++cell)
   {
     // Skip cells not included in restriction
@@ -574,15 +634,18 @@ void Function::compute_vertex_values(std::vector<double>& vertex_values,
       continue;
 
     // Update to current cell
-    ufc_cell.update(*cell);
+    cell->get_vertex_coordinates(vertex_coordinates);
+    cell->get_cell_data(ufc_cell);
 
     // Pick values from global vector
-    restrict(&coefficients[0], element, *cell, ufc_cell);
+    restrict(coefficients.data(), element, *cell, vertex_coordinates.data(),
+             ufc_cell);
 
     // Interpolate values at the vertices
     const int cell_orientation = 0;
-    element.interpolate_vertex_values(&cell_vertex_values[0],
-                                      &coefficients[0],
+    element.interpolate_vertex_values(cell_vertex_values.data(),
+                                      coefficients.data(),
+                                      vertex_coordinates.data(),
                                       cell_orientation,
                                       ufc_cell);
 
@@ -592,7 +655,7 @@ void Function::compute_vertex_values(std::vector<double>& vertex_values,
       for (std::size_t i = 0; i < value_size_loc; ++i)
       {
         const std::size_t local_index  = vertex.pos()*value_size_loc + i;
-        const std::size_t global_index = i*mesh.num_vertices() + vertex->index();
+        const std::size_t global_index = i*mesh.num_vertices()+vertex->index();
         vertex_values[global_index] = cell_vertex_values[local_index];
       }
     }
@@ -608,8 +671,7 @@ void Function::compute_vertex_values(std::vector<double>& vertex_values)
 //-----------------------------------------------------------------------------
 void Function::update() const
 {
-  if (MPI::num_processes() > 1)
-    _vector->update_ghost_values();
+  _vector->update_ghost_values();
 }
 //-----------------------------------------------------------------------------
 void Function::init_vector()
@@ -629,11 +691,12 @@ void Function::init_vector()
   const std::size_t N = _function_space->dofmap()->global_dimension();
 
   // Get local range
-  const std::pair<std::size_t, std::size_t> range = _function_space->dofmap()->ownership_range();
+  const std::pair<std::size_t, std::size_t> range
+    = _function_space->dofmap()->ownership_range();
   const std::size_t local_size = range.second - range.first;
 
   // Determine ghost vertices if dof map is distributed
-  std::vector<std::size_t> ghost_indices;
+  std::vector<la_index> ghost_indices;
   if (N > local_size)
     compute_ghost_indices(range, ghost_indices);
 
@@ -650,8 +713,9 @@ void Function::init_vector()
   _vector->zero();
 }
 //-----------------------------------------------------------------------------
-void Function::compute_ghost_indices(std::pair<std::size_t, std::size_t> range,
-                                     std::vector<std::size_t>& ghost_indices) const
+void
+Function::compute_ghost_indices(std::pair<std::size_t, std::size_t> range,
+                                std::vector<la_index>& ghost_indices) const
 {
   // Clear data
   ghost_indices.clear();
@@ -680,8 +744,11 @@ void Function::compute_ghost_indices(std::pair<std::size_t, std::size_t> range,
       if (dof < n0 || dof >= n1)
       {
         // FIXME: Could we use dolfin::Set here? Or unordered_set?
-        if (std::find(ghost_indices.begin(), ghost_indices.end(), dof) == ghost_indices.end())
+        if (std::find(ghost_indices.begin(), ghost_indices.end(), dof)
+            == ghost_indices.end())
+        {
           ghost_indices.push_back(dof);
+        }
       }
     }
   }
