@@ -31,7 +31,7 @@ using namespace dolfin;
 
 //-----------------------------------------------------------------------------
 MeshCoordinates::MeshCoordinates(const Mesh& mesh)
-  : Expression(mesh.geometry().dim()), mesh(mesh)
+  : Expression(mesh.geometry().dim()), _mesh(mesh)
 {
   // Do nothing
 }
@@ -40,15 +40,15 @@ void MeshCoordinates::eval(Array<double>& values,
                            const Array<double>& x,
                            const ufc::cell& cell) const
 {
-  dolfin_assert(cell.geometric_dimension == mesh.geometry().dim());
-  dolfin_assert(x.size() == mesh.geometry().dim());
+  dolfin_assert(cell.geometric_dimension == _mesh.geometry().dim());
+  dolfin_assert(x.size() == _mesh.geometry().dim());
 
-  for (uint i = 0; i < cell.geometric_dimension; ++i)
+  for (std::size_t i = 0; i < cell.geometric_dimension; ++i)
     values[i] = x[i];
 }
 //-----------------------------------------------------------------------------
 FacetArea::FacetArea(const Mesh& mesh)
-  : mesh(mesh),
+  : _mesh(mesh),
     not_on_boundary("*** Warning: evaluating special function FacetArea on a "
                     "non-facet domain, returning zero.")
 {
@@ -59,11 +59,11 @@ void FacetArea::eval(Array<double>& values,
                      const Array<double>& x,
                      const ufc::cell& cell) const
 {
-  dolfin_assert(cell.geometric_dimension == mesh.geometry().dim());
+  dolfin_assert(cell.geometric_dimension == _mesh.geometry().dim());
 
   if (cell.local_facet >= 0)
   {
-    Cell c(mesh, cell.index);
+    Cell c(_mesh, cell.index);
     values[0] = c.facet_area(cell.local_facet);
   }
   else
