@@ -26,42 +26,23 @@
 #ifndef __UNIT_CIRCLE_MESH_H
 #define __UNIT_CIRCLE_MESH_H
 
-#include <dolfin/mesh/Mesh.h>
+#include <string>
+#include <dolfin/generation/EllipseMesh.h>
 
 namespace dolfin
 {
 
-  /// Tetrahedral mesh of the unit circle.
+  /// This class is deprecated.
 
-  class UnitCircleMesh : public Mesh
+  class UnitCircleMesh : public CircleMesh
   {
   public:
 
-    /// Create a uniform finite element _Mesh_ over the unit circle.
-    ///
-    /// *Arguments*
-    ///     n (std::size_t)
-    ///         Resolution of the mesh.
-    ///     diagonal (std::string)
-    ///         Optional argument: A std::string indicating
-    ///         the direction of the diagonals.
-    ///     transformation (std::string)
-    ///         Optional argument: A std::string indicating
-    ///         the type of transformation used.
+    /// This class is deprecated
     UnitCircleMesh(std::size_t n,
                    std::string diagonal="crossed",
                    std::string transformation="rotsumn");
 
-  private:
-
-    std::vector<double> transform(const std::vector<double>& x,
-                                  const std::string transformation);
-
-    double max(const std::vector<double>& x) const
-    {
-      return ((std::abs(x[0]) > std::abs(x[1])) ? std::abs(x[0]) : std::abs(x[1]));
-    }
-
   };
 
 }
