@@ -3,10 +3,13 @@
 
 // DOLFIN mesh generation interface
 
+#include <dolfin/generation/ImplicitDomainMeshGenerator.h>
 #include <dolfin/generation/PolygonalMeshGenerator.h>
 #include <dolfin/generation/PolyhedralMeshGenerator.h>
 #include <dolfin/generation/Triangulate.h>
 #include <dolfin/generation/BoxMesh.h>
+#include <dolfin/generation/EllipseMesh.h>
+#include <dolfin/generation/EllipsoidMesh.h>
 #include <dolfin/generation/IntervalMesh.h>
 #include <dolfin/generation/Interval.h>
 #include <dolfin/generation/RectangleMesh.h>
