@@ -35,15 +35,9 @@ namespace dolfin
   /// Typedefs for simple graph data structures
 
   /// Vector of unordered sets
-  typedef dolfin::Set<unsigned int> graph_set_type;
-  //typedef boost::unordered_set<unsigned int> graph_set_type;
+  typedef dolfin::Set<std::size_t> graph_set_type;
   typedef std::vector<graph_set_type> Graph;
 
-  // Boost graph typedefs
-  typedef boost::adjacency_list<boost::vecS, boost::vecS, boost::directedS> BoostDirectedGraph;
-  typedef boost::adjacency_list<boost::vecS, boost::vecS, boost::undirectedS> BoostUndirectedGraph;
-  typedef boost::adjacency_list<boost::vecS, boost::vecS, boost::bidirectionalS> BoostBidirectionalGraph;
-
 }
 
 #endif
