@@ -52,8 +52,10 @@ Graph GraphBuilder::local_graph(const Mesh& mesh, const GenericDofMap& dofmap0,
   // Build graph
   for (CellIterator cell(mesh); !cell.end(); ++cell)
   {
-    const std::vector<dolfin::la_index>& dofs0 = dofmap0.cell_dofs(cell->index());
-    const std::vector<dolfin::la_index>& dofs1 = dofmap1.cell_dofs(cell->index());
+    const std::vector<dolfin::la_index>& dofs0
+      = dofmap0.cell_dofs(cell->index());
+    const std::vector<dolfin::la_index>& dofs1
+      = dofmap1.cell_dofs(cell->index());
     std::vector<dolfin::la_index>::const_iterator node0, node1;
     for (node0 = dofs0.begin(); node0 != dofs0.end(); ++node0)
       for (node1 = dofs1.begin(); node1 != dofs1.end(); ++node1)
@@ -67,6 +69,12 @@ Graph GraphBuilder::local_graph(const Mesh& mesh, const GenericDofMap& dofmap0,
 Graph GraphBuilder::local_graph(const Mesh& mesh,
                                 const std::vector<std::size_t>& coloring_type)
 {
+  // Initialise mesh
+  for (std::size_t i = 0; i < coloring_type.size(); ++i)
+    mesh.init(coloring_type[i]);
+  for (std::size_t i = 1; i < coloring_type.size(); ++i)
+    mesh.init(coloring_type[i - 1], coloring_type[i]);
+
   // Check coloring type
   dolfin_assert(coloring_type.size() >= 2);
   dolfin_assert(coloring_type.front() == coloring_type.back());
@@ -76,29 +84,36 @@ Graph GraphBuilder::local_graph(const Mesh& mesh,
   Graph graph(num_verticies);
 
   // Build graph
-  for (MeshEntityIterator vertex_entity(mesh, coloring_type[0]); !vertex_entity.end(); ++vertex_entity)
+  for (MeshEntityIterator vertex_entity(mesh, coloring_type[0]);
+       !vertex_entity.end(); ++vertex_entity)
   {
+    const std::size_t vertex_entity_index = vertex_entity->index();
+
     boost::unordered_set<std::size_t> entity_list0;
     boost::unordered_set<std::size_t> entity_list1;
-    entity_list0.insert(vertex_entity->index());
+    entity_list0.insert(vertex_entity_index);
 
     // Build list of entities, moving between levels
     for (std::size_t level = 1; level < coloring_type.size(); ++level)
     {
       for (boost::unordered_set<std::size_t>::const_iterator entity_index
-              = entity_list0.begin(); entity_index != entity_list0.end(); ++entity_index)
+             = entity_list0.begin(); entity_index != entity_list0.end();
+           ++entity_index)
       {
         const MeshEntity entity(mesh, coloring_type[level -1], *entity_index);
-        for (MeshEntityIterator neighbor(entity, coloring_type[level]); !neighbor.end(); ++neighbor)
+        for (MeshEntityIterator neighbor(entity, coloring_type[level]);
+             !neighbor.end(); ++neighbor)
+        {
           entity_list1.insert(neighbor->index());
+        }
       }
       entity_list0 = entity_list1;
       entity_list1.clear();
     }
 
     // Add edges to graph
-    const std::size_t vertex_entity_index = vertex_entity->index();
-    graph[vertex_entity_index].insert(entity_list0.begin(), entity_list0.end());
+    graph[vertex_entity_index].insert(entity_list0.begin(),
+                                      entity_list0.end());
   }
 
   return graph;
@@ -107,18 +122,29 @@ Graph GraphBuilder::local_graph(const Mesh& mesh,
 Graph GraphBuilder::local_graph(const Mesh& mesh,
                                 std::size_t dim0, std::size_t dim1)
 {
+  mesh.init(dim0);
+  mesh.init(dim1);
+  mesh.init(dim0, dim1);
+  mesh.init(dim1, dim0);
+
   // Create graph
   const std::size_t num_verticies = mesh.num_entities(dim0);
   Graph graph(num_verticies);
 
   // Build graph
-  for (MeshEntityIterator colored_entity(mesh, dim0); !colored_entity.end(); ++colored_entity)
+  for (MeshEntityIterator colored_entity(mesh, dim0); !colored_entity.end();
+       ++colored_entity)
   {
     const std::size_t colored_entity_index = colored_entity->index();
-    for (MeshEntityIterator entity(*colored_entity, dim1); !entity.end(); ++entity)
+    for (MeshEntityIterator entity(*colored_entity, dim1); !entity.end();
+         ++entity)
     {
-      for (MeshEntityIterator neighbor(*entity, dim0); !neighbor.end(); ++neighbor)
-        graph[colored_entity_index].insert(neighbor->index());
+      for (MeshEntityIterator neighbor(*entity, dim0); !neighbor.end();
+           ++neighbor)
+      {
+        if (colored_entity_index != neighbor->index())
+          graph[colored_entity_index].insert(neighbor->index());
+      }
     }
   }
 
@@ -133,7 +159,8 @@ void GraphBuilder::compute_dual_graph(const LocalMeshData& mesh_data,
 
   #ifdef HAS_MPI
   compute_local_dual_graph(mesh_data, local_graph, facet_cell_map);
-  compute_nonlocal_dual_graph(mesh_data, local_graph, facet_cell_map, ghost_vertices);
+  compute_nonlocal_dual_graph(mesh_data, local_graph, facet_cell_map,
+                              ghost_vertices);
   #else
   compute_local_dual_graph(mesh_data, local_graph, facet_cell_map);
   #endif
@@ -146,7 +173,8 @@ void GraphBuilder::compute_local_dual_graph(const LocalMeshData& mesh_data,
   Timer timer("Compute local dual graph");
 
   // List of cell vertices
-  const boost::multi_array<std::size_t, 2>& cell_vertices = mesh_data.cell_vertices;
+  const boost::multi_array<std::size_t, 2>& cell_vertices
+    = mesh_data.cell_vertices;
   const std::size_t num_local_cells = mesh_data.global_cell_indices.size();
   const std::size_t num_vertices_per_cell = mesh_data.num_vertices_per_cell;
   const std::size_t num_vertices_per_facet = num_vertices_per_cell - 1;
@@ -157,23 +185,26 @@ void GraphBuilder::compute_local_dual_graph(const LocalMeshData& mesh_data,
   local_graph.resize(num_local_cells);
   facet_cell_map.clear();
 
-  // Compute local edges (cell-cell connections) using global (internal
-  // to this function, not the user numbering) numbering
+  // Compute local edges (cell-cell connections) using global
+  // (internal to this function, not the user numbering) numbering
 
   // Get offset for this process
   const std::size_t cell_offset = MPI::global_offset(num_local_cells, true);
 
   // Create map from facet (list of vertex indices) to cells
-  facet_cell_map.rehash((facet_cell_map.size() + num_local_cells)/facet_cell_map.max_load_factor() + 1);
+  facet_cell_map.rehash((facet_cell_map.size()
+                     + num_local_cells)/facet_cell_map.max_load_factor() + 1);
 
   // Iterate over all cells
   std::vector<std::size_t> cellvtx(num_vertices_per_cell);
-  std::pair<std::vector<std::size_t>, std::size_t> map_entry(std::vector<std::size_t>(num_vertices_per_facet), 0);
+  std::pair<std::vector<std::size_t>, std::size_t>
+    map_entry(std::vector<std::size_t>(num_vertices_per_facet), 0);
   for (std::size_t i = 0; i < num_local_cells; ++i)
   {
     // Copy cell vertices and sort into order, taking a subset (minus
     // one vertex) to form a set of facet vertices
-    std::copy(cell_vertices[i].begin(), cell_vertices[i].end(), cellvtx.begin());
+    std::copy(cell_vertices[i].begin(), cell_vertices[i].end(),
+              cellvtx.begin());
     std::sort(cellvtx.begin(), cellvtx.end());
 
     // Copy data to map_entry
@@ -184,7 +215,8 @@ void GraphBuilder::compute_local_dual_graph(const LocalMeshData& mesh_data,
     for (std::size_t j = 0; j < num_vertices_per_cell; ++j)
     {
       // Map lookup/insert
-      std::pair<FacetCellMap::iterator, bool> map_lookup = facet_cell_map.insert(map_entry);
+      std::pair<FacetCellMap::iterator, bool> map_lookup
+        = facet_cell_map.insert(map_entry);
 
       // If facet was already in the map
       if (!map_lookup.second)
@@ -213,11 +245,12 @@ void GraphBuilder::compute_nonlocal_dual_graph(const LocalMeshData& mesh_data,
 {
   Timer timer("Compute non-local dual graph");
 
-  // At this stage facet_cell map only contains facets->cells with edge
-  // facets either interprocess or external boundaries
+  // At this stage facet_cell map only contains facets->cells with
+  // edge facets either interprocess or external boundaries
 
   // List of cell vertices
-  const boost::multi_array<std::size_t, 2>& cell_vertices = mesh_data.cell_vertices;
+  const boost::multi_array<std::size_t, 2>& cell_vertices
+    = mesh_data.cell_vertices;
   const std::size_t num_local_cells = mesh_data.global_cell_indices.size();
   const std::size_t num_vertices_per_cell = mesh_data.num_vertices_per_cell;
   const std::size_t num_vertices_per_facet = num_vertices_per_cell - 1;
@@ -225,8 +258,8 @@ void GraphBuilder::compute_nonlocal_dual_graph(const LocalMeshData& mesh_data,
   dolfin_assert(num_local_cells == cell_vertices.shape()[0]);
   dolfin_assert(num_vertices_per_cell == cell_vertices.shape()[1]);
 
-  // Compute local edges (cell-cell connections) using global (internal
-  // to this function, not the user numbering) numbering
+  // Compute local edges (cell-cell connections) using global
+  // (internal to this function, not the user numbering) numbering
 
   // Get offset for this process
   const std::size_t offset = MPI::global_offset(num_local_cells, true);
@@ -237,14 +270,16 @@ void GraphBuilder::compute_nonlocal_dual_graph(const LocalMeshData& mesh_data,
   std::vector<std::vector<std::size_t> > received_buffer(num_processes);
 
   // Pack map data and send to match-maker process
-  boost::unordered_map<std::vector<std::size_t>, std::size_t>::const_iterator it;
+  boost::unordered_map<std::vector<std::size_t>,
+                       std::size_t>::const_iterator it;
   for (it = facet_cell_map.begin(); it != facet_cell_map.end(); ++it)
   {
     // FIXME: Could use a better index? First vertex is slightly skewed
     //        towards low values - may not be important
 
     // Use first vertex of facet to partition into blocks
-    std::size_t dest_proc = MPI::index_owner((it->first)[0], mesh_data.num_global_vertices);
+    std::size_t dest_proc = MPI::index_owner((it->first)[0],
+                                             mesh_data.num_global_vertices);
 
     // Pack map into vectors to send
     for (std::size_t i = 0; i < num_vertices_per_facet; ++i)
@@ -266,23 +301,27 @@ void GraphBuilder::compute_nonlocal_dual_graph(const LocalMeshData& mesh_data,
   MatchMap matchmap;
 
   // Look for matches to send back to other processes
-  std::pair<std::vector<std::size_t>, std::pair<std::size_t, std::size_t> > key;
+  std::pair<std::vector<std::size_t>,
+            std::pair<std::size_t, std::size_t> > key;
   key.first.resize(num_vertices_per_facet);
   for (std::size_t p = 0; p < num_processes; ++p)
   {
     // Unpack into map
     const std::vector<std::size_t>& data_p = received_buffer[p];
-    for (std::size_t i = 0; i < data_p.size(); i += (num_vertices_per_facet + 1))
+    for (std::size_t i = 0; i < data_p.size();
+         i += (num_vertices_per_facet + 1))
     {
       // Build map key
-      std::copy(&data_p[i], &data_p[i] + num_vertices_per_facet, key.first.begin());
+      std::copy(&data_p[i], &data_p[i] + num_vertices_per_facet,
+                key.first.begin());
       key.second.first = p;
       key.second.second = data_p[i + num_vertices_per_facet];
 
       // Perform map insertion/look-up
       std::pair<MatchMap::iterator, bool> data = matchmap.insert(key);
 
-      // If data is already in the map, extract data and remove from map
+      // If data is already in the map, extract data and remove from
+      // map
       if (!data.second)
       {
         // Found a match of two facets - send back to owners
