@@ -21,15 +21,14 @@
 #ifndef __GRAPH_COLORING_H
 #define __GRAPH_COLORING_H
 
-#include <dolfin/common/types.h>
+
+#include <cstddef>
+#include <vector>
 #include "Graph.h"
 
 namespace dolfin
 {
 
-  template<typename T> class Array;
-  class Mesh;
-
   /// This class provides a common interface to graph coloring libraries
 
   class GraphColoring
@@ -38,8 +37,8 @@ namespace dolfin
   public:
 
     /// Compute vertex colors
-    static uint compute_local_vertex_coloring(const Graph& graph,
-                                              Array<uint>& colors);
+    static std::size_t compute_local_vertex_coloring(const Graph& graph,
+                                            std::vector<std::size_t>& colors);
 
   };
 }
