@@ -32,19 +32,40 @@ namespace dolfin
   // Forward declarations
   class LocalMeshData;
 
+  class ParMETISDualGraph;
+
   /// This class proivdes an interface to ParMETIS
 
   class ParMETIS
   {
   public:
 
-    /// Compute cell partition
+    /// Compute cell partition using ParMETIS. The mode argument
+    /// determines which ParMETIS function is called. It can be one of
+    /// "partition", "adaptive_repartition" or "refine". For meshes
+    /// that have already been partitioned or are already well
+    /// partitioned, it can be advantageous to use
+    /// "adaptive_repartition" or "refine".
     static void compute_partition(std::vector<std::size_t>& cell_partition,
-                                  const LocalMeshData& mesh_data);
+                                  const LocalMeshData& mesh_data,
+                                  std::string mode="partition");
+
+  private:
+
+#ifdef HAS_PARMETIS
+    // Standard ParMETIS partition
+    static void partition(std::vector<std::size_t>& cell_partition,
+                          ParMETISDualGraph& g);
+
+    // ParMETIS adaptive repartition
+    static void adaptive_repartition(std::vector<std::size_t>& cell_partition,
+                                     ParMETISDualGraph& g);
+
+    // ParMETIS refine repartition
+    static void refine(std::vector<std::size_t>& cell_partition,
+                       ParMETISDualGraph& g);
+#endif
 
-    /// Compute cell partition
-    static void recompute_partition(std::vector<std::size_t>& cell_partition,
-                                    const LocalMeshData& mesh_data);
 
   };
 
