@@ -24,6 +24,7 @@
 #include <map>
 #include <numeric>
 #include <set>
+#include <boost/lexical_cast.hpp>
 
 #include <dolfin/common/Set.h>
 #include <dolfin/common/Timer.h>
@@ -32,6 +33,8 @@
 #include "GraphBuilder.h"
 #include "SCOTCH.h"
 
+#include <dolfin/common/dolfin_common.h>
+
 #ifdef HAS_SCOTCH
 extern "C"
 {
@@ -59,37 +62,46 @@ void SCOTCH::compute_partition(std::vector<std::size_t>& cell_partition,
 
   // Compute partitions
   const std::size_t num_global_vertices = mesh_data.num_global_cells;
-  const std::vector<std::size_t>& global_cell_indices = mesh_data.global_cell_indices;
+  const std::vector<std::size_t>& global_cell_indices
+    = mesh_data.global_cell_indices;
   partition(local_graph, ghost_vertices, global_cell_indices,
             num_global_vertices, cell_partition);
 }
 //-----------------------------------------------------------------------------
-std::vector<std::size_t> SCOTCH::compute_reordering(const Graph& graph)
+std::vector<std::size_t> SCOTCH::compute_gps(const Graph& graph,
+                                             std::size_t num_passes)
+{
+  // Create strategy string for Gibbs-Poole-Stockmayer ordering
+  std::string strategy = "g{pass= "
+    + boost::lexical_cast<std::string>(num_passes) + "}";
+
+  return compute_reordering(graph, strategy);
+}
+//-----------------------------------------------------------------------------
+std::vector<std::size_t> SCOTCH::compute_reordering(const Graph& graph,
+                                                    std::string scotch_strategy)
 {
   std::vector<std::size_t> permutation, inverse_permutation;
-  compute_reordering(graph, permutation, inverse_permutation);
+  compute_reordering(graph, permutation, inverse_permutation, scotch_strategy);
   return permutation;
 }
 //-----------------------------------------------------------------------------
 void SCOTCH::compute_reordering(const Graph& graph,
-                               std::vector<std::size_t>& permutation,
-                               std::vector<std::size_t>& inverse_permutation)
+                                std::vector<std::size_t>& permutation,
+                                std::vector<std::size_t>& inverse_permutation,
+                                std::string scotch_strategy)
 {
-  // Remove graph loops
-  Graph _graph = graph;
-  for(std::size_t i = 0; i < _graph.size(); ++i)
-  {
-    _graph[i].set().erase(std::remove(_graph[i].set().begin(), _graph[i].set().end(), i), _graph[i].set().end());
-  }
+  Timer timer("SCOTCH graph ordering");
 
   // Number of local graph vertices (cells)
-  const SCOTCH_Num vertnbr = _graph.size();
+  const SCOTCH_Num vertnbr = graph.size();
 
-  // Data structures for graph input to SCOTCH (add 1 for case that graph size is zero)
+  // Data structures for graph input to SCOTCH (add 1 for case that
+  // graph size is zero)
   std::vector<SCOTCH_Num> verttab;
   verttab.reserve(vertnbr + 1);
   std::vector<SCOTCH_Num> edgetab;
-  edgetab.reserve(10*vertnbr);
+  edgetab.reserve(20*vertnbr);
 
   // Build local graph input for SCOTCH
   // (number of local + ghost graph vertices (cells),
@@ -97,7 +109,7 @@ void SCOTCH::compute_reordering(const Graph& graph,
   SCOTCH_Num edgenbr = 0;
   verttab.push_back(0);
   Graph::const_iterator vertex;
-  for(vertex = _graph.begin(); vertex != _graph.end(); ++vertex)
+  for(vertex = graph.begin(); vertex != graph.end(); ++vertex)
   {
     edgenbr += vertex->size();
     verttab.push_back(verttab.back() + vertex->size());
@@ -129,6 +141,7 @@ void SCOTCH::compute_reordering(const Graph& graph,
   }
 
   // Check graph data for consistency
+  /*
   #ifdef DEBUG
   if (SCOTCH_graphCheck(&scotch_graph))
   {
@@ -137,16 +150,24 @@ void SCOTCH::compute_reordering(const Graph& graph,
                  "Consistency error in SCOTCH graph");
   }
   #endif
+  */
 
   // Re-ordering strategy
   SCOTCH_Strat strat;
   SCOTCH_stratInit(&strat);
 
+  // Set SCOTCH strategy (if provided)
+  //SCOTCH_stratGraphOrderBuild(&strat, SCOTCH_STRATQUALITY, 0, 0);
+  //SCOTCH_stratGraphOrderBuild(&strat, SCOTCH_STRATSPEED, 0, 0);
+  if (!scotch_strategy.empty())
+    SCOTCH_stratGraphOrder(&strat, scotch_strategy.c_str());
+
   // Vector to hold permutation vectors
   std::vector<SCOTCH_Num> permutation_indices(vertnbr);
   std::vector<SCOTCH_Num> inverse_permutation_indices(vertnbr);
 
-  // Reset SCOTCH random number generator to produce deterministic partitions
+  // Reset SCOTCH random number generator to produce deterministic
+  // partitions
   SCOTCH_randomReset();
 
   // Compute re-ordering
@@ -193,7 +214,8 @@ void SCOTCH::partition(const std::vector<std::set<std::size_t> >& local_graph,
   // Number of local graph vertices (cells)
   const SCOTCH_Num vertlocnbr = local_graph.size();
 
-  // Data structures for graph input to SCOTCH (add 1 for case that local graph size is zero)
+  // Data structures for graph input to SCOTCH (add 1 for case that
+  // local graph size is zero)
   std::vector<SCOTCH_Num> vertloctab;
   vertloctab.reserve(local_graph.size() + 1);
   std::vector<SCOTCH_Num> edgeloctab;
@@ -226,8 +248,12 @@ void SCOTCH::partition(const std::vector<std::set<std::size_t> >& local_graph,
   // Array containing . . . . (some sanity checks)
   std::vector<std::size_t> procvrttab(num_processes + 1);
   for (std::size_t i = 0; i < num_processes; ++i)
-    procvrttab[i] = std::accumulate(proccnttab.begin(), proccnttab.begin() + i, 0);
-  procvrttab[num_processes] = procvrttab[num_processes - 1] + proccnttab[num_processes - 1];
+  {
+    procvrttab[i] = std::accumulate(proccnttab.begin(),
+                                    proccnttab.begin() + i, 0);
+  }
+  procvrttab[num_processes] = procvrttab[num_processes - 1]
+    + proccnttab[num_processes - 1];
 
   // Sanity check
   for (std::size_t i = 1; i <= proc_num; ++i)
@@ -357,7 +383,8 @@ void SCOTCH::partition(const std::vector<std::set<std::size_t> >& local_graph,
 
   // Copy partition
   cell_partition.resize(_cell_partition.size());
-  std::copy(_cell_partition.begin(), _cell_partition.end(), cell_partition.begin());
+  std::copy(_cell_partition.begin(), _cell_partition.end(),
+            cell_partition.begin());
 }
 //-----------------------------------------------------------------------------
 #else
@@ -370,6 +397,36 @@ void SCOTCH::compute_partition(std::vector<std::size_t>& cell_partition,
                "DOLFIN has been configured without support for SCOTCH");
 }
 //-----------------------------------------------------------------------------
+std::vector<std::size_t> SCOTCH::compute_gps(const Graph& graph,
+                                             std::size_t num_passes)
+{
+  dolfin_error("SCOTCH.cpp",
+               "re-order graph using SCOTCH",
+               "DOLFIN has been configured without support for SCOTCH");
+  return std::vector<std::size_t>();
+}
+//-----------------------------------------------------------------------------
+std::vector<std::size_t>
+SCOTCH::compute_reordering(const Graph& graph,
+                           std::string scotch_strategy)
+{
+  dolfin_error("SCOTCH.cpp",
+               "re-order graph using SCOTCH",
+               "DOLFIN has been configured without support for SCOTCH");
+  return std::vector<std::size_t>();
+}
+//-----------------------------------------------------------------------------
+void SCOTCH::compute_reordering(const Graph& graph,
+                                std::vector<std::size_t>& permutation,
+                                std::vector<std::size_t>& inverse_permutation,
+                                std::string scotch_strategy)
+
+{
+  dolfin_error("SCOTCH.cpp",
+               "re-order graph using SCOTCH",
+               "DOLFIN has been configured without support for SCOTCH");
+}
+//-----------------------------------------------------------------------------
 void SCOTCH::partition(const std::vector<std::set<std::size_t> >& local_graph,
                        const std::set<std::size_t>& ghost_vertices,
                        const std::vector<std::size_t>& global_cell_indices,
@@ -381,23 +438,5 @@ void SCOTCH::partition(const std::vector<std::set<std::size_t> >& local_graph,
                "DOLFIN has been configured without support for SCOTCH");
 }
 //-----------------------------------------------------------------------------
-std::vector<std::size_t> SCOTCH::compute_reordering(const Graph& graph)
-{
-  dolfin_error("SCOTCH.cpp",
-               "re-order graph using SCOTCH",
-               "DOLFIN has been configured without support for SCOTCH");
-  std::vector<std::size_t> x;
-  return x;
-}
-//-----------------------------------------------------------------------------
-void SCOTCH::compute_reordering(const Graph& graph,
-                                 std::vector<std::size_t>& permutation,
-                                 std::vector<std::size_t>& inverse_permutation)
-{
-  dolfin_error("SCOTCH.cpp",
-               "re-order graph using SCOTCH",
-               "DOLFIN has been configured without support for SCOTCH");
-}
-//-----------------------------------------------------------------------------
 
 #endif
