@@ -23,7 +23,6 @@
 
 #include <fstream>
 #include <boost/iostreams/filtering_streambuf.hpp>
-#include <dolfin/common/types.h>
 #include "GenericFile.h"
 
 namespace dolfin
@@ -84,23 +83,25 @@ namespace dolfin
     // Close file for writing
     void close_write();
 
-    // Read uint
-    uint read_uint();
+    // Read std::size_t
+    std::size_t read_uint();
 
-    // Read array (uint)
-    void read_array(uint n, uint* values);
+    // Read array (std::size_t)
+    template<typename T>
+    void read_array(std::size_t n, T* values);
 
     // Read array (double)
-    void read_array(uint n, double* values);
+    //void read_array(std::size_t n, double* values);
 
-    // Write uint
-    void write_uint(uint value);
+    // Write std::size_t
+    void write_uint(std::size_t value);
 
-    // Write array (uint)
-    void write_array(uint n, const uint* values);
+    // Write array (std::size_t)
+    template<typename T>
+    void write_array(std::size_t n, const T* values);
 
     // Write array (double)
-    void write_array(uint n, const double* values);
+    //void write_array(std::size_t n, const double* values);
 
     // Store all connectivity in a mesh
     bool _store_connectivity;
