@@ -21,7 +21,7 @@
 // Modified by Ola Skavhaug 2009.
 //
 // First added:  2002-11-12
-// Last changed: 2013-03-04
+// Last changed: 2013-03-11
 
 #include <fstream>
 #include <string>
@@ -31,12 +31,15 @@
 #include <dolfin/function/Function.h>
 #include <dolfin/log/dolfin_log.h>
 #include "BinaryFile.h"
+#include "ExodusFile.h"
 #include "RAWFile.h"
-#include "VTKFile.h"
-#include "XMLFile.h"
-#include "XYZFile.h"
-#include "XDMFFile.h"
 #include "SVGFile.h"
+#include "VTKFile.h"
+#include "X3DFile.h"
+#include "XMLFile.h"
+#include "XDMFFile.h"
+#include "XYZFile.h"
+
 #include "File.h"
 
 using namespace dolfin;
@@ -69,10 +72,18 @@ File::File(const std::string filename, std::string encoding)
                    ext.c_str(), filename.c_str());
     }
   }
+  else if (extension == ".x3d")
+    file.reset(new X3DFile(filename));
   else if (extension == ".xml")
     file.reset(new XMLFile(filename));
   else if (extension == ".pvd")
     file.reset(new VTKFile(filename, encoding));
+#ifdef HAS_VTK
+#ifdef HAS_VTK_EXODUS
+  else if (extension == ".e")
+    file.reset(new ExodusFile(filename));
+#endif
+#endif
   else if (extension == ".raw")
     file.reset(new RAWFile(filename));
   else if (extension == ".xyz")
@@ -98,6 +109,9 @@ File::File(const std::string filename, Type type, std::string encoding)
 {
   switch (type)
   {
+  case x3d:
+    file.reset(new X3DFile(filename));
+    break;
   case xdmf:
 #ifdef HAS_HDF5
     file.reset(new XDMFFile(filename));
@@ -136,6 +150,37 @@ File::~File()
   // Do nothing
 }
 //-----------------------------------------------------------------------------
+void File::operator<<(const std::pair<const Mesh*, double> mesh)
+{
+  file->write();
+  *file << mesh;
+}
+//-----------------------------------------------------------------------------
+void File::operator<<(const std::pair<const MeshFunction<int>*, double> f)
+{
+  file->write();
+  *file << f;
+}
+//-----------------------------------------------------------------------------
+void
+File::operator<<(const std::pair<const MeshFunction<std::size_t>*, double> f)
+{
+  file->write();
+  *file << f;
+}
+//-----------------------------------------------------------------------------
+void File::operator<<(const std::pair<const MeshFunction<double>*, double> f)
+{
+  file->write();
+  *file << f;
+}
+//-----------------------------------------------------------------------------
+void File::operator<<(const std::pair<const MeshFunction<bool>*, double> f)
+{
+  file->write();
+  *file << f;
+}
+//-----------------------------------------------------------------------------
 void File::operator<<(const std::pair<const Function*, double> u)
 {
   u.first->update();
@@ -158,8 +203,8 @@ bool File::exists(std::string filename)
 void File::create_parent_path(std::string filename)
 {
   const boost::filesystem::path path(filename);
-
-  if (path.has_parent_path() && !boost::filesystem::is_directory(path.parent_path()))
+  if (path.has_parent_path()
+      && !boost::filesystem::is_directory(path.parent_path()))
   {
     boost::filesystem::create_directories(path.parent_path());
     if (!boost::filesystem::is_directory(path.parent_path()))
