@@ -20,7 +20,7 @@
 // Modified by Ola Skavhaug 2009
 //
 // First added:  2002-11-12
-// Last changed: 2012-12-01
+// Last changed: 2013-03-11
 
 #ifndef __FILE_H
 #define __FILE_H
@@ -40,20 +40,21 @@ namespace dolfin
 
   /// A list of objects that can be read/written to file can be found in
   /// GenericFile.h. Compatible file formats include:
+  ///     * Binary (.bin)
+  ///     * RAW    (.raw)
+  ///     * SVG    (.svg)
+  ///     * XD3    (.xd3)
   ///     * XDMF   (.xdmf)
   ///     * XML    (.xml)
-  ///     * VTK    (.pvd)
-  ///     * RAW    (.raw)
   ///     * XYZ    (.xyz)
-  ///     * Binary (.bin)
-  ///     * SVG    (.svg)
+  ///     * VTK    (.pvd)
 
   class File
   {
   public:
 
     /// File formats
-    enum Type {xdmf, xml, vtk, raw, xyz, binary, svg};
+    enum Type {x3d, xdmf, xml, vtk, raw, xyz, binary, svg};
 
     /// Create a file with given name
     ///
@@ -116,6 +117,56 @@ namespace dolfin
     /// Write Function to file
     //void operator<<(const Function& u);
 
+    /// Write Mesh to file with time
+    ///
+    /// *Example*
+    ///     .. code-block:: c++
+    ///
+    ///         File file("mesh.pvd", "compressed");
+    ///         file << std::make_pair<const Mesh*, double>(&mesh, t);
+    ///
+    void operator<<(const std::pair<const Mesh*, double> mesh);
+
+    /// Write MeshFunction to file with time
+    ///
+    /// *Example*
+    ///     .. code-block:: c++
+    ///
+    ///         File file("markers.pvd", "compressed");
+    ///         file << std::make_pair<const MeshFunction<int>*, double>(&f, t);
+    ///
+    void operator<<(const std::pair<const MeshFunction<int>*, double> f);
+
+    /// Write MeshFunction to file with time
+    ///
+    /// *Example*
+    ///     .. code-block:: c++
+    ///
+    ///         File file("markers.pvd", "compressed");
+    ///         file << std::make_pair<const MeshFunction<std::size_t>*, double>(&f, t);
+    ///
+    void operator<<(const std::pair<const MeshFunction<std::size_t>*, double> f);
+
+    /// Write MeshFunction to file with time
+    ///
+    /// *Example*
+    ///     .. code-block:: c++
+    ///
+    ///         File file("markers.pvd", "compressed");
+    ///         file << std::make_pair<const MeshFunction<double>*, double>(&f, t);
+    ///
+    void operator<<(const std::pair<const MeshFunction<double>*, double> f);
+
+    /// Write MeshFunction to file with time
+    ///
+    /// *Example*
+    ///     .. code-block:: c++
+    ///
+    ///         File file("markers.pvd", "compressed");
+    ///         file << std::make_pair<const MeshFunction<bool>*, double>(&f, t);
+    ///
+    void operator<<(const std::pair<const MeshFunction<bool>*, double> f);
+
     /// Write Function to file with time
     ///
     /// *Example*
