@@ -18,7 +18,7 @@
 // Modified by Ola Skavhaug 2009.
 //
 // First added:  2003-07-15
-// Last changed: 2011-09-14
+// Last changed: 2013-03-11
 
 #ifndef __GENERIC_FILE_H
 #define __GENERIC_FILE_H
@@ -94,7 +94,12 @@ namespace dolfin
     virtual void operator<< (const MeshValueCollection<bool>& mesh_markers);
     virtual void operator<< (const Function& u);
 
-    // Output function with time
+    // Output with time
+    virtual void operator<< (const std::pair<const Mesh*, double> mesh);
+    virtual void operator<< (const std::pair<const MeshFunction<int>*, double> f);
+    virtual void operator<< (const std::pair<const MeshFunction<std::size_t>*, double> f);
+    virtual void operator<< (const std::pair<const MeshFunction<double>*, double> f);
+    virtual void operator<< (const std::pair<const MeshFunction<bool>*, double> f);
     virtual void operator<< (const std::pair<const Function*, double> u);
 
     virtual void operator<< (const Parameters& parameters);
