@@ -34,10 +34,8 @@ namespace dolfin
   public:
 
     /// Write results in raw format
-    /// Much lighter than the other formats
-    /// A Xd3d format for instance
 
-    RAWFile(const std::string filename);
+    explicit RAWFile(const std::string filename);
 
     ~RAWFile();
 
