@@ -22,7 +22,7 @@
 // Modified by Johannes Ring 2012
 //
 // First added:  2005-07-05
-// Last changed: 2012-09-14
+// Last changed: 2013-03-11
 
 #include <ostream>
 #include <sstream>
@@ -93,49 +93,27 @@ VTKFile::~VTKFile()
 //----------------------------------------------------------------------------
 void VTKFile::operator<<(const Mesh& mesh)
 {
-  Timer t("Write mesh to PVD/VTK file");
-
-  // Get vtu file name and intialise out files
-  std::string vtu_filename = init(mesh, mesh.topology().dim());
-
-  // Write local mesh to vtu file
-  VTKWriter::write_mesh(mesh, mesh.topology().dim(), vtu_filename, binary, compress);
-
-  // Parallel-specific files
-  if (MPI::num_processes() > 1 && MPI::process_number() == 0)
-  {
-    std::string pvtu_filename = vtu_name(0, 0, counter, ".pvtu");
-    pvtu_write_mesh(pvtu_filename);
-    pvd_file_write(counter, counter, pvtu_filename);
-  }
-  else if (MPI::num_processes() == 1)
-    pvd_file_write(counter, counter, vtu_filename);
-
-  // Finalise
-  finalize(vtu_filename, counter);
-
-  log(TRACE, "Saved mesh %s (%s) to file %s in VTK format.",
-      mesh.name().c_str(), mesh.label().c_str(), _filename.c_str());
+  write_mesh(mesh, counter);
 }
 //----------------------------------------------------------------------------
 void VTKFile::operator<<(const MeshFunction<bool>& meshfunction)
 {
-  mesh_function_write(meshfunction);
+  mesh_function_write(meshfunction, counter);
 }
 //----------------------------------------------------------------------------
 void VTKFile::operator<<(const MeshFunction<std::size_t>& meshfunction)
 {
-  mesh_function_write(meshfunction);
+  mesh_function_write(meshfunction, counter);
 }
 //----------------------------------------------------------------------------
 void VTKFile::operator<<(const MeshFunction<int>& meshfunction)
 {
-  mesh_function_write(meshfunction);
+  mesh_function_write(meshfunction, counter);
 }
 //----------------------------------------------------------------------------
 void VTKFile::operator<<(const MeshFunction<double>& meshfunction)
 {
-  mesh_function_write(meshfunction);
+  mesh_function_write(meshfunction, counter);
 }
 //----------------------------------------------------------------------------
 void VTKFile::operator<<(const Function& u)
@@ -144,6 +122,37 @@ void VTKFile::operator<<(const Function& u)
   write_function(u, counter);
 }
 //----------------------------------------------------------------------------
+void VTKFile::operator<<(const std::pair<const Mesh*, double> mesh)
+{
+  dolfin_assert(mesh.first);
+  write_mesh(*(mesh.first), mesh.second);
+}
+//----------------------------------------------------------------------------
+void VTKFile::operator<<(const std::pair<const MeshFunction<int>*, double> f)
+{
+  dolfin_assert(f.first);
+  mesh_function_write(*(f.first), f.second);
+}
+//----------------------------------------------------------------------------
+void VTKFile::operator<<(const std::pair<const MeshFunction<std::size_t>*,
+                                         double> f)
+{
+  dolfin_assert(f.first);
+  mesh_function_write(*(f.first), f.second);
+}
+//----------------------------------------------------------------------------
+void VTKFile::operator<<(const std::pair<const MeshFunction<double>*, double> f)
+{
+  dolfin_assert(f.first);
+  mesh_function_write(*(f.first), f.second);
+}
+//----------------------------------------------------------------------------
+void VTKFile::operator<<(const std::pair<const MeshFunction<bool>*, double> f)
+{
+  dolfin_assert(f.first);
+  mesh_function_write(*(f.first), f.second);
+}
+//----------------------------------------------------------------------------
 void VTKFile::operator<<(const std::pair<const Function*, double> u)
 {
   dolfin_assert(u.first);
@@ -183,6 +192,34 @@ void VTKFile::write_function(const Function& u, double time)
       u.name().c_str(), u.label().c_str(), _filename.c_str());
 }
 //----------------------------------------------------------------------------
+void VTKFile::write_mesh(const Mesh& mesh, double time)
+{
+  Timer t("Write mesh to PVD/VTK file");
+
+  // Get vtu file name and intialise out files
+  std::string vtu_filename = init(mesh, mesh.topology().dim());
+
+  // Write local mesh to vtu file
+  VTKWriter::write_mesh(mesh, mesh.topology().dim(), vtu_filename, binary,
+                        compress);
+
+  // Parallel-specific files
+  if (MPI::num_processes() > 1 && MPI::process_number() == 0)
+  {
+    std::string pvtu_filename = vtu_name(0, 0, counter, ".pvtu");
+    pvtu_write_mesh(pvtu_filename);
+    pvd_file_write(counter, time, pvtu_filename);
+  }
+  else if (MPI::num_processes() == 1)
+    pvd_file_write(counter, time, vtu_filename);
+
+  // Finalise
+  finalize(vtu_filename, time);
+
+  log(TRACE, "Saved mesh %s (%s) to file %s in VTK format.",
+      mesh.name().c_str(), mesh.label().c_str(), _filename.c_str());
+}
+//----------------------------------------------------------------------------
 std::string VTKFile::init(const Mesh& mesh, std::size_t cell_dim) const
 {
   // Get vtu file name and clear file
@@ -497,12 +534,14 @@ void VTKFile::pvtu_write_function(std::size_t dim, std::size_t rank,
   pugi::xml_node data_array_node = data_node.append_child("PDataArray");
   data_array_node.append_attribute("type") = "Float64";
   data_array_node.append_attribute("Name") = name.c_str();
-  data_array_node.append_attribute("NumberOfComponents") = (unsigned int) num_components;
+  data_array_node.append_attribute("NumberOfComponents")
+    = (unsigned int) num_components;
 
   // Write vtu file list
   for(std::size_t i = 0; i < MPI::num_processes(); i++)
   {
-    const std::string tmp_string = strip_path(vtu_name(i, MPI::num_processes(), counter, ".vtu"));
+    const std::string tmp_string = strip_path(vtu_name(i, MPI::num_processes(),
+                                                       counter, ".vtu"));
     pugi::xml_node piece_node = grid_node.append_child("Piece");
     piece_node.append_attribute("Source") = tmp_string.c_str();
   }
@@ -526,7 +565,8 @@ void VTKFile::pvtu_write_mesh(const std::string fname) const
   // Write vtu file list
   for(std::size_t i = 0; i < MPI::num_processes(); i++)
   {
-    const std::string tmp_string = strip_path(vtu_name(i, MPI::num_processes(), counter, ".vtu"));
+    const std::string tmp_string = strip_path(vtu_name(i, MPI::num_processes(),
+                                                       counter, ".vtu"));
     pugi::xml_node piece_node = grid_node.append_child("Piece");
     piece_node.append_attribute("Source") = tmp_string.c_str();
   }
@@ -596,9 +636,11 @@ void VTKFile::vtk_header_open(std::size_t num_vertices, std::size_t num_cells,
 
   // Write headers
   file << "<?xml version=\"1.0\"?>" << std::endl;
-  file << "<VTKFile type=\"UnstructuredGrid\"  version=\"0.1\" " << endianness <<  " " << compressor << ">" << std::endl;
+  file << "<VTKFile type=\"UnstructuredGrid\"  version=\"0.1\" " << endianness
+       <<  " " << compressor << ">" << std::endl;
   file << "<UnstructuredGrid>" << std::endl;
-  file << "<Piece  NumberOfPoints=\"" << num_vertices << "\" NumberOfCells=\"" << num_cells << "\">" << std::endl;
+  file << "<Piece  NumberOfPoints=\"" << num_vertices << "\" NumberOfCells=\""
+       << num_cells << "\">" << std::endl;
 
   // Close file
   file.close();
@@ -617,7 +659,8 @@ void VTKFile::vtk_header_close(std::string vtu_filename) const
   }
 
   // Close headers
-  file << "</Piece>" << std::endl << "</UnstructuredGrid>" << std::endl << "</VTKFile>";
+  file << "</Piece>" << std::endl << "</UnstructuredGrid>" << std::endl
+       << "</VTKFile>";
 
   // Close file
   file.close();
@@ -651,18 +694,11 @@ std::string VTKFile::vtu_name(const int process, const int num_processes,
 }
 //----------------------------------------------------------------------------
 template<typename T>
-void VTKFile::mesh_function_write(T& meshfunction)
+void VTKFile::mesh_function_write(T& meshfunction, double time)
 {
-  const Mesh& mesh = meshfunction.mesh();
+  const Mesh& mesh = *meshfunction.mesh();
   const std::size_t cell_dim = meshfunction.dim();
 
-  //if (cell_dim != mesh.topology().dim() && cell_dim != mesh.topology().dim() - 1 && cell_dim != 0)
-  //{
-  //  dolfin_error("VTKFile.cpp",
-  //               "write mesh function to VTK file",
-  //               "VTK output of mesh functions is implemented for cell-, facet- and vertex-based functions only");
-  //}
-
   // Update vtu file name and clear file
   std::string vtu_filename = init(mesh, cell_dim);
 
@@ -673,7 +709,8 @@ void VTKFile::mesh_function_write(T& meshfunction)
   std::ofstream fp(vtu_filename.c_str(), std::ios_base::app);
   fp.precision(16);
   fp << "<CellData  Scalars=\"" << meshfunction.name() << "\">" << std::endl;
-  fp << "<DataArray  type=\"Float64\"  Name=\"" << meshfunction.name() << "\"  format=\"ascii\">";
+  fp << "<DataArray  type=\"Float64\"  Name=\"" << meshfunction.name()
+     << "\"  format=\"ascii\">";
 
   // Write data
   for (MeshEntityIterator cell(mesh, cell_dim); !cell.end(); ++cell)
@@ -691,13 +728,13 @@ void VTKFile::mesh_function_write(T& meshfunction)
   {
     std::string pvtu_filename = vtu_name(0, 0, counter, ".pvtu");
     pvtu_write_function(1, 0, "cell", meshfunction.name(), pvtu_filename);
-    pvd_file_write(counter, counter, pvtu_filename);
+    pvd_file_write(counter, time, pvtu_filename);
   }
   else if (MPI::num_processes() == 1)
-    pvd_file_write(counter, counter, vtu_filename);
+    pvd_file_write(counter, time, vtu_filename);
 
   // Write pvd files
-  finalize(vtu_filename, counter);
+  finalize(vtu_filename, time);
 
   log(TRACE, "Saved mesh function %s (%s) to file %s in VTK format.",
       mesh.name().c_str(), mesh.label().c_str(), _filename.c_str());
