@@ -18,7 +18,7 @@
 // Modified by Garth N. Wells, 2012
 //
 // First added:  2012-05-28
-// Last changed: 2013-03-04
+// Last changed: 2013-10-15
 
 #ifdef HAS_HDF5
 
@@ -38,11 +38,12 @@
 #include <dolfin/fem/GenericDofMap.h>
 #include <dolfin/la/GenericVector.h>
 #include <dolfin/mesh/Cell.h>
+#include <dolfin/mesh/DistributedMeshTools.h>
 #include <dolfin/mesh/MeshEntityIterator.h>
 #include <dolfin/mesh/Mesh.h>
 #include <dolfin/mesh/Vertex.h>
 #include "HDF5File.h"
-#include "HDF5Interface.h"
+#include "HDF5Utility.h"
 #include "XDMFFile.h"
 
 using namespace dolfin;
@@ -58,14 +59,13 @@ XDMFFile::XDMFFile(const std::string filename) : GenericFile(filename, "XDMF")
   // File mode will be set when reading or writing
   hdf5_filemode = "";
 
-  // Rewrite the mesh at every time step in a time series
-  // Should be turned off if the mesh remains constant
+  // Rewrite the mesh at every time step in a time series. Should be
+  // turned off if the mesh remains constant.
   parameters.add("rewrite_function_mesh", true);
 
-  // Flush datasets to disk at each timestep
-  // Allows inspection of the HDF5 file whilst running, at some performance cost
+  // Flush datasets to disk at each timestep. Allows inspection of the
+  // HDF5 file whilst running, at some performance cost.
   parameters.add("flush_output", false);
-
 }
 //----------------------------------------------------------------------------
 XDMFFile::~XDMFFile()
@@ -81,60 +81,57 @@ void XDMFFile::operator<< (const Function& u)
 //----------------------------------------------------------------------------
 void XDMFFile::operator<< (const std::pair<const Function*, double> ut)
 {
-
-  if(hdf5_filemode != "w")
+  // Prepate HDF5 file
+  if (hdf5_filemode != "w")
   {
     // Create HDF5 file (truncate)
     hdf5_file.reset(new HDF5File(hdf5_filename, "w"));
     hdf5_filemode = "w";
   }
-  
+  dolfin_assert(hdf5_file);
+
+  // Access Function, Mesh, dofmap  and time step
   dolfin_assert(ut.first);
   const Function& u = *(ut.first);
-  const double time_step = ut.second;
 
-  // Update any ghost values
-  u.update();
-
-  // Get Mesh object
   dolfin_assert(u.function_space()->mesh());
   const Mesh& mesh = *u.function_space()->mesh();
 
-  // Geometric dimension
-  const std::size_t gdim = mesh.geometry().dim();
-
-  // Get DOF map
   dolfin_assert(u.function_space()->dofmap());
   const GenericDofMap& dofmap = *u.function_space()->dofmap();
 
+  const double time_step = ut.second;
+
+  // FIXME: Can we avoid this?
+  // Update any ghost values
+  u.update();
+
+  // Geometric and topological dimension
+  const std::size_t gdim = mesh.geometry().dim();
+  const std::size_t tdim = mesh.topology().dim();
+
   // Get some Function and cell information
   const std::size_t value_rank = u.value_rank();
   const std::size_t value_size = u.value_size();
-  const std::size_t cell_dim = mesh.topology().dim();
+
   std::size_t padded_value_size = value_size;
 
   // Test for cell-centred data
   std::size_t cell_based_dim = 1;
   for (std::size_t i = 0; i < value_rank; i++)
-    cell_based_dim *= cell_dim;
+    cell_based_dim *= tdim;
   const bool vertex_data = !(dofmap.max_cell_dimension() == cell_based_dim);
 
   // Get number of local/global cells/vertices
-
   const std::size_t num_local_cells = mesh.num_cells();
   const std::size_t num_local_vertices = mesh.num_vertices();
-  const std::size_t num_global_cells = MPI::sum(num_local_cells);
-  std::size_t num_total_vertices = MPI::sum(num_local_vertices);
+  const std::size_t num_global_cells = mesh.size_global(tdim);
 
   // Get Function data at vertices/cell centres
   std::vector<double> data_values;
 
-  std::size_t num_local_entities = 0;
-  std::size_t num_total_entities = 0;
   if (vertex_data)
   {
-    num_local_entities = num_local_vertices; // includes duplicates
-    num_total_entities = num_total_vertices;
     u.compute_vertex_values(data_values, mesh);
 
     // Interleave the values for vector or tensor fields and pad 2D
@@ -146,14 +143,15 @@ void XDMFFile::operator<< (const std::pair<const Function*, double> ut)
       if (value_size == 4)
         padded_value_size = 9;
 
-      std::vector<double> _data_values(padded_value_size*num_local_entities, 0.0);
-      for(std::size_t i = 0; i < num_local_entities; i++)
+      std::vector<double> _data_values(padded_value_size*num_local_vertices,
+                                       0.0);
+      for (std::size_t i = 0; i < num_local_vertices; i++)
       {
         for (std::size_t j = 0; j < value_size; j++)
         {
           std::size_t tensor_2d_offset = (j > 1 && value_size == 4) ? 1 : 0;
           _data_values[i*padded_value_size + j + tensor_2d_offset]
-              = data_values[i + j*num_local_entities];
+              = data_values[i + j*num_local_vertices];
         }
       }
       data_values = _data_values;
@@ -161,8 +159,6 @@ void XDMFFile::operator<< (const std::pair<const Function*, double> ut)
   }
   else
   {
-    num_local_entities = num_local_cells;
-    num_total_entities = num_global_cells;
     dolfin_assert(u.function_space()->dofmap());
     dolfin_assert(u.vector());
 
@@ -176,12 +172,14 @@ void XDMFFile::operator<< (const std::pair<const Function*, double> ut)
     for (CellIterator cell(mesh); !cell.end(); ++cell)
     {
       // Tabulate dofs
-      const std::vector<dolfin::la_index>& dofs = dofmap.cell_dofs(cell->index());
-      for(std::size_t i = 0; i < dofmap.cell_dimension(cell->index()); ++i)
+      const std::vector<dolfin::la_index>& dofs
+        = dofmap.cell_dofs(cell->index());
+      for (std::size_t i = 0; i < dofmap.cell_dimension(cell->index()); ++i)
         dof_set.push_back(dofs[i]);
 
       // Add local dimension to cell offset and increment
-      *(cell_offset + 1) = *(cell_offset) + dofmap.cell_dimension(cell->index());
+      *(cell_offset + 1) = *(cell_offset)
+        + dofmap.cell_dimension(cell->index());
       ++cell_offset;
     }
 
@@ -196,7 +194,7 @@ void XDMFFile::operator<< (const std::pair<const Function*, double> ut)
       padded_value_size = 9;
 
     cell_offset = offset.begin();
-    std::vector<double> _data_values(padded_value_size*num_local_entities, 0.0);
+    std::vector<double> _data_values(padded_value_size*num_local_cells, 0.0);
     std::size_t count = 0;
     if (value_rank == 1 && value_size == 2)
     {
@@ -213,10 +211,8 @@ void XDMFFile::operator<< (const std::pair<const Function*, double> ut)
       // Pad with 0.0 to 2D tensors to make them 3D
       for (CellIterator cell(mesh); !cell.end(); ++cell)
       {
-        for(std::size_t i = 0; i < 2; i++)
+        for (std::size_t i = 0; i < 2; i++)
         {
-          //          cout << "test: " << *cell_offset + 2*i << ", " << *cell_offset + 2*i + 1
-          //   << ", " << data_values[*cell_offset + 2*i] << ", " << data_values[*cell_offset + 2*i + 1] << endl;
           _data_values[count++] = data_values[*cell_offset + 2*i];
           _data_values[count++] = data_values[*cell_offset + 2*i + 1];
           count++;
@@ -243,41 +239,42 @@ void XDMFFile::operator<< (const std::pair<const Function*, double> ut)
   // Write mesh to HDF5 file
   if (parameters["rewrite_function_mesh"] || counter == 0)
   {
-      current_mesh_name = boost::lexical_cast<std::string>(counter);
+      current_mesh_name = "/Mesh/" + boost::lexical_cast<std::string>(counter);
       hdf5_file->write(mesh, current_mesh_name);
   }
 
-  // Vertex/cell values are saved in the hdf5 group /VisualisationVector
-  // as distinct from /Vector which is used for solution vectors.
-
-  // Save data values to HDF5 file
-
+  // Remove duplicates for vertex-based data
   std::vector<std::size_t> global_size(2);
-  global_size[0] = num_total_entities;
   global_size[1] = padded_value_size;
-
-  if(vertex_data)
+  if (vertex_data)
   {
-    hdf5_file->reorder_values_by_global_indices(mesh, data_values, global_size);
-    num_total_vertices = global_size[0];
+    HDF5Utility::reorder_values_by_global_indices(mesh, data_values, 
+                                                  padded_value_size);
+    global_size[0] = mesh.size_global(0);
   }
+  else
+    global_size[0] = mesh.size_global(tdim);
 
+  // Save data values to HDF5 file.  Vertex/cell values are saved in
+  // the hdf5 group /VisualisationVector as distinct from /Vector
+  // which is used for solution vectors.
   const std::string dataset_name = "/VisualisationVector/"
     + boost::lexical_cast<std::string>(counter);
 
   hdf5_file->write_data(dataset_name, data_values, global_size);
 
-  // Flush file. Improves chances of recovering data if interrupted. Also
-  // makes file somewhat readable between writes.
-  if(parameters["flush_output"])
+  // Flush file. Improves chances of recovering data if
+  // interrupted. Also makes file somewhat readable between writes.
+  if (parameters["flush_output"])
     hdf5_file->flush();
 
-  // Write the XML meta description (see http://www.xdmf.org) on process zero
+  // Write the XML meta description (see http://www.xdmf.org) on
+  // process zero
+  const std::size_t num_total_vertices = mesh.size_global(0);
   if (MPI::process_number() == 0)
   {
-    output_xml(time_step, vertex_data,
-               cell_dim, num_global_cells, gdim, num_total_vertices,
-               value_rank, padded_value_size,
+    output_xml(time_step, vertex_data, tdim, num_global_cells, gdim,
+               num_total_vertices, value_rank, padded_value_size,
                u.name(), dataset_name);
   }
 
@@ -287,35 +284,48 @@ void XDMFFile::operator<< (const std::pair<const Function*, double> ut)
 //----------------------------------------------------------------------------
 void XDMFFile::operator>> (Mesh& mesh)
 {
-  if(hdf5_filemode != "r")
+  // Prepare HDF5 file
+  if (hdf5_filemode != "r")
   {
     hdf5_file.reset(new HDF5File(hdf5_filename, "r"));
     hdf5_filemode = "r";
   }
-
   dolfin_assert(hdf5_file);
 
+  // Prepare XML file
   pugi::xml_document xml_doc;
   pugi::xml_parse_result result = xml_doc.load_file(_filename.c_str());
   if (!result)
   {
     dolfin_error("XDMFFile.cpp",
                  "read mesh from XDMF/H5 files",
-                 "XML parsing error when reading from file");
+                 "XML parsing error. XDMF file should contain only one mesh/dataset");
   }
 
   // Topology - check format and get dataset name
-  pugi::xml_node xdmf_topology = xml_doc.child("Xdmf").child("Domain").child("Grid").child("Topology").child("DataItem");
-  dolfin_assert(xdmf_topology);
+  pugi::xml_node xdmf_topology
+    = xml_doc.child("Xdmf").child("Domain").child("Grid").child("Topology").child("DataItem");
+  if (!xdmf_topology)
+  {
+    dolfin_error("XDMFFile.cpp",
+                 "read mesh from XDMF/H5 files",
+                 "XML parsing error. XDMF file should contain only one mesh/dataset");
+  }
 
-  const std::string topo_fmt(xdmf_topology.attribute("Format").value());
-  dolfin_assert(topo_fmt == "HDF");
+  const std::string
+    topological_data_format(xdmf_topology.attribute("Format").value());
+  if (topological_data_format != "HDF")
+  {
+    dolfin_error("XDMFFile.cpp",
+                 "read mesh from XDMF/H5 files",
+                 "XML parsing error. Wrong dataset format (not HDF5)");
+  }
 
   const std::string topo_ref(xdmf_topology.first_child().value());
   std::vector<std::string> topo_bits;
   boost::split(topo_bits, topo_ref, boost::is_any_of(":/"));
 
-  // Should have 5 elements "filename.h5", "", "Mesh", "meshname", "topology" 
+  // Should have 5 elements "filename.h5", "", "Mesh", "meshname", "topology"
   dolfin_assert(topo_bits.size() == 5);
   // FIXME: get path() from filename to check
   //  dolfin_assert(topo_bits[0] == hdf5_filename);
@@ -323,7 +333,8 @@ void XDMFFile::operator>> (Mesh& mesh)
   dolfin_assert(topo_bits[4] == "topology");
 
   // Geometry - check format and get dataset name
-  pugi::xml_node xdmf_geometry = xml_doc.child("Xdmf").child("Domain").child("Grid").child("Geometry").child("DataItem");
+  pugi::xml_node xdmf_geometry =
+    xml_doc.child("Xdmf").child("Domain").child("Grid").child("Geometry").child("DataItem");
   dolfin_assert(xdmf_geometry);
 
   const std::string geom_fmt(xdmf_geometry.attribute("Format").value());
@@ -333,7 +344,8 @@ void XDMFFile::operator>> (Mesh& mesh)
   std::vector<std::string> geom_bits;
   boost::split(geom_bits, geom_ref, boost::is_any_of(":/"));
 
-  // Should have 5 elements "filename.h5", "", "Mesh", "meshname", "coordinates" 
+  // Should have 5 elements "filename.h5", "", "Mesh", "meshname",
+  // "coordinates"
   dolfin_assert(geom_bits.size() == 5);
   //  dolfin_assert(geom_bits[0] == hdf5_filename);
   dolfin_assert(geom_bits[2] == "Mesh");
@@ -341,16 +353,14 @@ void XDMFFile::operator>> (Mesh& mesh)
   dolfin_assert(geom_bits[4] == "coordinates");
 
   // Try to read the mesh from the associated HDF5 file
-  hdf5_file->read(mesh, geom_bits[3]);
-
+  hdf5_file->read(mesh, "/Mesh/" + geom_bits[3]);
 }
 //----------------------------------------------------------------------------
-  
 void XDMFFile::operator<< (const Mesh& mesh)
 {
   // Write Mesh to HDF5 file
 
-  if(hdf5_filemode != "w")
+  if (hdf5_filemode != "w")
   {
     // Create HDF5 file (truncate)
     hdf5_file.reset(new HDF5File(hdf5_filename, "w"));
@@ -374,12 +384,13 @@ void XDMFFile::operator<< (const Mesh& mesh)
   // Write mesh to HDF5 file
   // The XML below will obliterate any existing XDMF file
 
-  hdf5_file->write(mesh, cell_dim, name);
+  const std::string group_name = "/Mesh/" + name;
+  hdf5_file->write(mesh, cell_dim, group_name);
 
   // FIXME: Names should be returned by HDF5::write_mesh
   // Mesh data set names
-  const std::string mesh_topology_name = "/Mesh/" + name + "/topology";
-  const std::string mesh_coords_name = "/Mesh/" + name + "/coordinates";
+  const std::string mesh_topology_name = group_name + "/topology";
+  const std::string mesh_coords_name = group_name + "/coordinates";
 
   // Write the XML meta description on process zero
   if (MPI::process_number() == 0)
@@ -409,21 +420,11 @@ void XDMFFile::operator<< (const Mesh& mesh)
 
     xml_doc.save_file(_filename.c_str(), "  ");
   }
-
 }
 //----------------------------------------------------------------------------
 void XDMFFile::operator<< (const MeshFunction<bool>& meshfunction)
 {
-  const Mesh& mesh = meshfunction.mesh();
-  const std::size_t cell_dim = meshfunction.dim();
-
-  // HDF5 does not support a boolean type,
-  // so copy to a std::size_t with values 1 and 0
-  MeshFunction<std::size_t> mf(mesh, cell_dim);
-  for (MeshEntityIterator cell(mesh, cell_dim); !cell.end(); ++cell)
-    mf[cell->index()] = (meshfunction[cell->index()] ? 1 : 0);
-
-  write_mesh_function(mf);
+  write_mesh_function(meshfunction);
 }
 //----------------------------------------------------------------------------
 void XDMFFile::operator<< (const MeshFunction<int>& meshfunction)
@@ -444,8 +445,7 @@ void XDMFFile::operator<< (const MeshFunction<double>& meshfunction)
 template<typename T>
 void XDMFFile::write_mesh_function(const MeshFunction<T>& meshfunction)
 {
-
-  if(hdf5_filemode != "w")
+  if (hdf5_filemode != "w")
   {
     // Create HDF5 file (truncate)
     hdf5_file.reset(new HDF5File(hdf5_filename, "w"));
@@ -460,19 +460,20 @@ void XDMFFile::write_mesh_function(const MeshFunction<T>& meshfunction)
   }
 
   // Get mesh
-  const Mesh& mesh = meshfunction.mesh();
+  const Mesh& mesh = *meshfunction.mesh();
 
   const std::size_t cell_dim = meshfunction.dim();
   dolfin_assert(cell_dim <= mesh.topology().dim());
 
   // Use HDF5 function to output MeshFunction
-  current_mesh_name = boost::lexical_cast<std::string>(counter);
-  hdf5_file->write_mesh_function(meshfunction, current_mesh_name);
+  current_mesh_name = "/Mesh/" + boost::lexical_cast<std::string>(counter);
+  hdf5_file->write(meshfunction, current_mesh_name);
 
   // Saved MeshFunction values are in the /Mesh group
-  const std::string dataset_name = "/Mesh/" + current_mesh_name + "/values";
+  const std::string dataset_name =  current_mesh_name + "/values";
 
-  // Write the XML meta description (see http://www.xdmf.org) on process zero
+  // Write the XML meta description (see http://www.xdmf.org) on
+  // process zero
   if (MPI::process_number() == 0)
   {
     output_xml((double)counter, false,
@@ -486,7 +487,7 @@ void XDMFFile::write_mesh_function(const MeshFunction<T>& meshfunction)
 //----------------------------------------------------------------------------
 void XDMFFile::operator>> (MeshFunction<bool>& meshfunction)
 {
-  const Mesh& mesh = meshfunction.mesh();
+  const Mesh& mesh = *meshfunction.mesh();
   const std::size_t cell_dim = meshfunction.dim();
 
   MeshFunction<std::size_t> mf(mesh, cell_dim);
@@ -494,7 +495,6 @@ void XDMFFile::operator>> (MeshFunction<bool>& meshfunction)
 
   for (MeshEntityIterator cell(mesh, cell_dim); !cell.end(); ++cell)
     meshfunction[cell->index()] = (mf[cell->index()] == 1);
-
 }
 //----------------------------------------------------------------------------
 void XDMFFile::operator>> (MeshFunction<int>& meshfunction)
@@ -515,7 +515,7 @@ void XDMFFile::operator>> (MeshFunction<double>& meshfunction)
 template<typename T>
 void XDMFFile::read_mesh_function(MeshFunction<T>& meshfunction)
 {
-  if(hdf5_filemode != "r")
+  if (hdf5_filemode != "r")
   {
     hdf5_file.reset(new HDF5File(hdf5_filename, "r"));
     hdf5_filemode = "r";
@@ -544,7 +544,7 @@ void XDMFFile::read_mesh_function(MeshFunction<T>& meshfunction)
   std::vector<std::string> topo_bits;
   boost::split(topo_bits, topo_ref, boost::is_any_of(":/"));
 
-  // Should have 5 elements "filename.h5", "", "Mesh", "meshname", "topology" 
+  // Should have 5 elements "filename.h5", "", "Mesh", "meshname", "topology"
   dolfin_assert(topo_bits.size() == 5);
   //  dolfin_assert(topo_bits[0] == hdf5_filename);
   dolfin_assert(topo_bits[2] == "Mesh");
@@ -562,7 +562,8 @@ void XDMFFile::read_mesh_function(MeshFunction<T>& meshfunction)
   std::vector<std::string> geom_bits;
   boost::split(geom_bits, geom_ref, boost::is_any_of(":/"));
 
-  // Should have 5 elements "filename.h5", "", "Mesh", "meshname", "coordinates" 
+  // Should have 5 elements "filename.h5", "", "Mesh", "meshname",
+  // "coordinates"
   dolfin_assert(geom_bits.size() == 5);
   //  dolfin_assert(geom_bits[0] == hdf5_filename);
   dolfin_assert(geom_bits[2] == "Mesh");
@@ -587,17 +588,16 @@ void XDMFFile::read_mesh_function(MeshFunction<T>& meshfunction)
   dolfin_assert(value_bits[4] == "values");
 
   // Try to read the meshfunction from the associated HDF5 file
-  hdf5_file->read(meshfunction, geom_bits[3]);
-  
+  hdf5_file->read(meshfunction, "/Mesh/" + geom_bits[3]);
 }
-
 //----------------------------------------------------------------------------
 void XDMFFile::xml_mesh_topology(pugi::xml_node &xdmf_topology,
                                  const std::size_t cell_dim,
                                  const std::size_t num_global_cells,
                                  const std::string topology_dataset_name) const
 {
-  xdmf_topology.append_attribute("NumberOfElements") = (unsigned int) num_global_cells;
+  xdmf_topology.append_attribute("NumberOfElements")
+    = (unsigned int) num_global_cells;
 
   // Cell type
   if (cell_dim == 0)
@@ -618,7 +618,8 @@ void XDMFFile::xml_mesh_topology(pugi::xml_node &xdmf_topology,
   // Refer to all cells and dimensions
   pugi::xml_node xdmf_topology_data = xdmf_topology.append_child("DataItem");
   xdmf_topology_data.append_attribute("Format") = "HDF";
-  const std::string cell_dims = boost::lexical_cast<std::string>(num_global_cells)
+  const std::string cell_dims
+    = boost::lexical_cast<std::string>(num_global_cells)
     + " " + boost::lexical_cast<std::string>(cell_dim + 1);
   xdmf_topology_data.append_attribute("Dimensions") = cell_dims.c_str();
 
@@ -626,7 +627,8 @@ void XDMFFile::xml_mesh_topology(pugi::xml_node &xdmf_topology,
   // filenames such as "results/data.xdmf" correctly index h5 files in
   // the same directory
   boost::filesystem::path p(hdf5_filename);
-  std::string topology_reference = p.filename().string() + ":" + topology_dataset_name;
+  std::string topology_reference = p.filename().string() + ":"
+    + topology_dataset_name;
   xdmf_topology_data.append_child(pugi::node_pcdata).set_value(topology_reference.c_str());
 }
 //----------------------------------------------------------------------------
@@ -655,18 +657,22 @@ void XDMFFile::xml_mesh_geometry(pugi::xml_node& xdmf_geometry,
     + " " + boost::lexical_cast<std::string>(gdim);
   xdmf_geom_data.append_attribute("Dimensions") = geom_dim.c_str();
 
-  if(gdim == 1)
+  if (gdim == 1)
   {
     // FIXME: improve this workaround
-    // When gdim==1, XDMF does not support a 1D geometry "X",
-    // so need to provide some dummy Y and Z values.
-    // Using the "X_Y_Z" geometry the Y and Z values can be supplied
-    // as separate datasets, here in plain text (though it could be done in HDF5 too).
-    // Cannot write HDF5 here, as we are only running on rank 0, and will deadlock.
+
+    // When gdim==1, XDMF does not support a 1D geometry "X", so need
+    // to provide some dummy Y and Z values.  Using the "X_Y_Z"
+    // geometry the Y and Z values can be supplied as separate
+    // datasets, here in plain text (though it could be done in HDF5
+    // too).
+
+    // Cannot write HDF5 here, as we are only running on rank 0, and
+    // will deadlock.
 
     std::string dummy_zeros;
     dummy_zeros.reserve(2*num_total_vertices);
-    for(std::size_t i = 0; i < num_total_vertices; ++i)
+    for (std::size_t i = 0; i < num_total_vertices; ++i)
       dummy_zeros += "0 ";
 
     pugi::xml_node xdmf_geom_1 = xdmf_geometry.append_child("DataItem");
@@ -689,10 +695,14 @@ void XDMFFile::xml_mesh_geometry(pugi::xml_node& xdmf_geometry,
 }
 //----------------------------------------------------------------------------
 void XDMFFile::output_xml(const double time_step, const bool vertex_data,
-                          const std::size_t cell_dim, const std::size_t num_global_cells,
-                          const std::size_t gdim, const std::size_t num_total_vertices,
-                          const std::size_t value_rank, const std::size_t padded_value_size,
-                          const std::string name, const std::string dataset_name) const
+                          const std::size_t cell_dim,
+                          const std::size_t num_global_cells,
+                          const std::size_t gdim,
+                          const std::size_t num_total_vertices,
+                          const std::size_t value_rank,
+                          const std::size_t padded_value_size,
+                          const std::string name,
+                          const std::string dataset_name) const
 {
   // Working data structure for formatting XML file
   std::string s;
@@ -759,45 +769,46 @@ void XDMFFile::output_xml(const double time_step, const bool vertex_data,
   // Grid/Topology
   pugi::xml_node xdmf_topology = xdmf_grid.append_child("Topology");
   xml_mesh_topology(xdmf_topology, cell_dim, num_global_cells,
-                    "/Mesh/" + current_mesh_name + "/topology");
+                    current_mesh_name + "/topology");
 
   // Grid/Geometry
   pugi::xml_node xdmf_geometry = xdmf_grid.append_child("Geometry");
   xml_mesh_geometry(xdmf_geometry, num_total_vertices, gdim,
-                    "/Mesh/" + current_mesh_name + "/coordinates");
+                    current_mesh_name + "/coordinates");
 
   // Grid/Attribute (Function value data)
   pugi::xml_node xdmf_values = xdmf_grid.append_child("Attribute");
   xdmf_values.append_attribute("Name") = name.c_str();
+  
+  if (value_rank == 0)
+    xdmf_values.append_attribute("AttributeType") = "Scalar";
+  else if (value_rank == 1)
+    xdmf_values.append_attribute("AttributeType") = "Vector";
+  else if (value_rank == 2)
+    xdmf_values.append_attribute("AttributeType") = "Tensor";
 
-    if (value_rank == 0)
-      xdmf_values.append_attribute("AttributeType") = "Scalar";
-    else if (value_rank == 1)
-      xdmf_values.append_attribute("AttributeType") = "Vector";
-    else if (value_rank == 2)
-      xdmf_values.append_attribute("AttributeType") = "Tensor";
+  if (vertex_data)
+    xdmf_values.append_attribute("Center") = "Node";
+  else
+    xdmf_values.append_attribute("Center") = "Cell";
+  
+  pugi::xml_node xdmf_data = xdmf_values.append_child("DataItem");
+  xdmf_data.append_attribute("Format") = "HDF";
+  
+  const std::size_t num_total_entities 
+    = vertex_data ? num_total_vertices : num_global_cells;
 
-    if (vertex_data)
-      xdmf_values.append_attribute("Center") = "Node";
-    else
-      xdmf_values.append_attribute("Center") = "Cell";
+  s = boost::lexical_cast<std::string>(num_total_entities) + " "
+    + boost::lexical_cast<std::string>(padded_value_size);
 
-    pugi::xml_node xdmf_data = xdmf_values.append_child("DataItem");
-    xdmf_data.append_attribute("Format") = "HDF";
+  xdmf_data.append_attribute("Dimensions") = s.c_str();
 
-    const std::size_t num_total_entities = vertex_data ? num_total_vertices : num_global_cells;
-
-    s = boost::lexical_cast<std::string>(num_total_entities) + " "
-      + boost::lexical_cast<std::string>(padded_value_size);
-
-    xdmf_data.append_attribute("Dimensions") = s.c_str();
-
-    boost::filesystem::path p(hdf5_filename);
-    s = p.filename().string() + ":" + dataset_name;
-    xdmf_data.append_child(pugi::node_pcdata).set_value(s.c_str());
-
-    // Write XML file
-    xml_doc.save_file(_filename.c_str(), "  ");
-  }
+  boost::filesystem::path p(hdf5_filename);
+  s = p.filename().string() + ":" + dataset_name;
+  xdmf_data.append_child(pugi::node_pcdata).set_value(s.c_str());
+  
+  // Write XML file
+  xml_doc.save_file(_filename.c_str(), "  ");
+}
 //----------------------------------------------------------------------------
 #endif
