@@ -26,7 +26,9 @@
 #include <map>
 #include <ostream>
 #include <string>
+#include <vector>
 #include <boost/shared_ptr.hpp>
+#include <dolfin/common/types.h>
 #include "GenericFile.h"
 
 namespace pugi
@@ -47,7 +49,7 @@ namespace dolfin
   template<typename T> class MeshFunction;
   template<typename T> class MeshValueCollection;
 
-  class XMLFile: public GenericFile
+  class XMLFile : public GenericFile
   {
   public:
 
@@ -69,7 +71,7 @@ namespace dolfin
 
     // Vector
     void operator>> (GenericVector& input);
-    void read_vector(Array<double>& input, Array<uint>& indices);
+    void read_vector(std::vector<double>& input, std::vector<dolfin::la_index>& indices);
     void operator<< (const GenericVector& output);
 
     // Parameters
@@ -80,14 +82,10 @@ namespace dolfin
     void operator>>(Function& input);
     void operator<<(const Function& output);
 
-    // FunctionPlotData
-    void operator>> (FunctionPlotData& input);
-    void operator<< (const FunctionPlotData& output);
-
     // MeshFunction (uint)
-    void operator>> (MeshFunction<unsigned int>& input)
+    void operator>> (MeshFunction<std::size_t>& input)
     { read_mesh_function(input, "uint"); }
-    void operator<< (const MeshFunction<unsigned int>& output)
+    void operator<< (const MeshFunction<std::size_t>& output)
     { write_mesh_function(output, "uint"); }
 
     // MeshFunction (int)
@@ -108,10 +106,10 @@ namespace dolfin
     void operator<< (const MeshFunction<bool>& input)
     { write_mesh_function(input, "bool"); }
 
-    // MeshValueCollection (uint)
-    void operator>> (MeshValueCollection<unsigned int>& input)
+    // MeshValueCollection (std::size_t)
+    void operator>> (MeshValueCollection<std::size_t>& input)
     { read_mesh_value_collection(input, "uint"); }
-    void operator<< (const MeshValueCollection<unsigned int>& output)
+    void operator<< (const MeshValueCollection<std::size_t>& output)
     { write_mesh_value_collection(output, "uint"); }
 
     // MeshValueCollection (int)
