@@ -46,11 +46,13 @@ namespace dolfin
 
   private:
 
-    static void build_global_to_cell_dof(std::vector<std::vector<std::pair<dolfin::la_index, dolfin::la_index> > >& global_dof_to_cell_dof,
-                                         const FunctionSpace& V);
+    static void build_global_to_cell_dof(std::vector<std::vector<
+     std::pair<dolfin::la_index, dolfin::la_index> > >& global_dof_to_cell_dof,
+     const FunctionSpace& V);
 
-    static void build_dof_map(std::vector<std::vector<dolfin::la_index> >& global_dof_to_cell_dof,
-                         const FunctionSpace& V);
+    static void build_dof_map(std::vector<std::vector<dolfin::la_index>
+                              >& global_dof_to_cell_dof,
+                              const FunctionSpace& V);
 
   };
 
