@@ -1,4 +1,4 @@
-// Copyright (C) 2011 Garth N. Wells
+// Copyright (C) 2011-2013 Garth N. Wells
 //
 // This file is part of DOLFIN.
 //
@@ -18,7 +18,7 @@
 // Modified by Anders Logg 2011
 //
 // First added:  2002-12-06
-// Last changed: 2011-11-14
+// Last changed: 2013-05-25
 
 #include <map>
 #include <iomanip>
@@ -31,15 +31,15 @@
 
 #include "pugixml.hpp"
 
-#include "dolfin/common/Array.h"
 #include "dolfin/common/MPI.h"
+#include "dolfin/common/NoDeleter.h"
+#include "dolfin/geometry/Point.h"
 #include "dolfin/la/GenericVector.h"
 #include "dolfin/mesh/Cell.h"
 #include "dolfin/mesh/CellType.h"
 #include "dolfin/mesh/Mesh.h"
 #include "dolfin/mesh/MeshData.h"
 #include "dolfin/mesh/MeshEditor.h"
-#include "dolfin/mesh/Point.h"
 #include "dolfin/mesh/Vertex.h"
 #include "dolfin/mesh/MeshFunction.h"
 #include "XMLMeshFunction.h"
@@ -64,10 +64,10 @@ void XMLMesh::read(Mesh& mesh, const pugi::xml_node xml_dolfin)
   read_mesh(mesh, mesh_node);
 
   // Read mesh data (if any)
-  read_data(mesh.data(), mesh_node);
+  read_data(mesh.data(), mesh, mesh_node);
 
   // Read mesh domains (if any)
-  read_domains(mesh.domains(), mesh_node);
+  read_domains(mesh.domains(), mesh, mesh_node);
 }
 //-----------------------------------------------------------------------------
 void XMLMesh::write(const Mesh& mesh, pugi::xml_node xml_node)
@@ -79,10 +79,10 @@ void XMLMesh::write(const Mesh& mesh, pugi::xml_node xml_node)
   write_mesh(mesh, mesh_node);
 
   // Write mesh data (if any)
-  write_data(mesh.data(), mesh_node);
+  write_data(mesh, mesh.data(), mesh_node);
 
   // Write mesh markers (if any)
-  write_domains(mesh.domains(), mesh_node);
+  write_domains(mesh, mesh.domains(), mesh_node);
 }
 //-----------------------------------------------------------------------------
 void XMLMesh::read_mesh(Mesh& mesh, const pugi::xml_node mesh_node)
@@ -135,7 +135,8 @@ void XMLMesh::read_mesh(Mesh& mesh, const pugi::xml_node mesh_node)
 
   // Iterate over cells and add to mesh
   std::vector<std::size_t> v(num_vertices_per_cell);
-  for (pugi::xml_node_iterator it = xml_cells.begin(); it != xml_cells.end(); ++it)
+  for (pugi::xml_node_iterator it = xml_cells.begin(); it != xml_cells.end();
+       ++it)
   {
     const std::size_t index = it->attribute("index").as_uint();
     for (unsigned int i = 0; i < num_vertices_per_cell; ++i)
@@ -147,7 +148,8 @@ void XMLMesh::read_mesh(Mesh& mesh, const pugi::xml_node mesh_node)
   editor.close();
 }
 //-----------------------------------------------------------------------------
-void XMLMesh::read_data(MeshData& data, const pugi::xml_node mesh_node)
+void XMLMesh::read_data(MeshData& data, const Mesh& mesh,
+                        const pugi::xml_node mesh_node)
 {
   // Check if we have any mesh data
   const pugi::xml_node xml_data = mesh_node.child("data");
@@ -155,85 +157,96 @@ void XMLMesh::read_data(MeshData& data, const pugi::xml_node mesh_node)
     return;
 
   // Iterate over data
-  for (pugi::xml_node_iterator it = xml_data.begin(); it != xml_data.end(); ++it)
+  for (pugi::xml_node_iterator it = xml_data.begin();
+       it != xml_data.end(); ++it)
   {
-    // Check that node is <data_entry>
+    // Get node name
     const std::string node_name = it->name();
-    if (node_name != "data_entry")
+
+    // Read data stored as a MeshFunction (new style)
+    if (node_name == "mesh_function")
+    {
+      // Create MeshFunction to read data into
+      MeshFunction<std::size_t> mf(mesh);
+
+      // Read  MeshFunction
+      //const std::string data_type = it->attribute("type").value();
+      XMLMeshFunction::read(mf, "uint", *it);
+
+      // Create mesh domain array
+      std::vector<std::size_t>& _data
+        = data.create_array(mf.name(), mf.dim());
+      _data.resize(mf.size());
+
+      // Copy MeshFunction into MeshDomain array
+      for (std::size_t i = 0; i < _data.size(); ++i)
+        _data[i] = mf[i];
+    }
+    else if (node_name != "data_entry")
     {
       dolfin_error("XMLMesh.cpp",
                    "read mesh data from XML file",
                    "Expecting XML node <data_entry> but got <%s>",
                    node_name.c_str());
     }
-
-    // Get name of data set
-    const std::string data_set_name = it->attribute("name").value();
-
-    // Check that there is only one data set
-    if (it->first_child().next_sibling())
+    else // Old-style storage
     {
-      dolfin_error("XMLMesh.cpp",
-                   "read mesh data from XML file",
-                   "XML file contains too many data sets");
-    }
+      // Get name of data set
+      const std::string data_set_name = it->attribute("name").value();
 
-    // Get type of data set
-    pugi::xml_node data_set = it->first_child();
-    const std::string data_set_type = data_set.name();
-    if (data_set_type == "array")
-    {
-      // Get type
-      const std::string data_type = data_set.attribute("type").value();
-      if (data_type == "uint")
+      // Check that there is only one data set
+      if (it->first_child().next_sibling())
       {
-        // Get vector from MeshData
-        boost::shared_ptr<std::vector<std::size_t> >
-          array = data.array(data_set_name);
-        if (!array)
-          array = data.create_array(data_set_name);
-        dolfin_assert(array);
+        dolfin_error("XMLMesh.cpp",
+                     "read mesh data from XML file",
+                     "XML file contains too many data sets");
+      }
 
-        // Read vector
-        read_array_uint(*array, data_set);
+      // Get type of data set
+      pugi::xml_node data_set = it->first_child();
+      const std::string data_set_type = data_set.name();
+      if (data_set_type == "array")
+      {
+        dolfin_error("XMLMesh.cpp",
+                     "read mesh data from XML file",
+                     "Only MeshFunction data can be read");
+      }
+      else if (data_set_type == "mesh_function")
+      {
+        // Create MeshFunction to read data into
+        MeshFunction<std::size_t> mf(mesh);
+
+        // Read  MeshFunction
+        const std::string data_type = data_set.attribute("type").value();
+        XMLMeshFunction::read(mf, data_type, *it);
+
+        // Create mesh domain array
+        std::vector<std::size_t>& _data
+          = data.create_array(data_set_name, mf.dim());
+        _data.resize(mf.size());
+
+        // Copy MeshFunction into MeshDomain array
+        for (std::size_t i = 0; i < _data.size(); ++i)
+          _data[i] = mf[i];
+      }
+      else if (data_set_type == "meshfunction")
+      {
+        dolfin_error("XMLMesh.cpp",
+                     "read mesh data from XML file",
+                     "The XML tag <meshfunction> has been changed to <mesh_function>");
       }
       else
       {
         dolfin_error("XMLMesh.cpp",
                      "read mesh data from XML file",
-                     "Only reading of MeshData uint arrays are supported at present");
+                     "Reading of MeshData \"%s\" is not yet supported",
+                     data_set_type.c_str());
       }
     }
-    else if (data_set_type == "mesh_function")
-    {
-      // Get MeshFunction from MeshData
-      const std::string data_type = data_set.attribute("type").value();
-      boost::shared_ptr<MeshFunction<std::size_t> >
-        mf = data.mesh_function(data_set_name);
-      if (!mf)
-        mf = data.create_mesh_function(data_set_name);
-      dolfin_assert(mf);
-
-      // Read  MeshFunction
-      XMLMeshFunction::read(*mf, data_type, *it);
-    }
-    else if (data_set_type == "meshfunction")
-    {
-      dolfin_error("XMLMesh.cpp",
-                   "read mesh data from XML file",
-                   "The XML tag <meshfunction> has been changed to <mesh_function>");
-    }
-    else
-    {
-      dolfin_error("XMLMesh.cpp",
-                   "read mesh data from XML file",
-                   "Reading of MeshData \"%s\" is not yet supported",
-                   data_set_type.c_str());
-    }
   }
 }
 //-----------------------------------------------------------------------------
-void XMLMesh::read_domains(MeshDomains& domains,
+void XMLMesh::read_domains(MeshDomains& domains, const Mesh& mesh,
                            const pugi::xml_node mesh_node)
 {
   // Check if we have any domains
@@ -268,9 +281,39 @@ void XMLMesh::read_domains(MeshDomains& domains,
                    type.c_str());
     }
 
-    // Read MeshValueCollection
-    dolfin_assert(domains.markers(dim));
-    XMLMeshValueCollection::read(*(domains.markers(dim)), type, *it);
+    // Initialise mesh entities
+    mesh.init(dim);
+
+    // Read data into a mesh value collection
+    boost::shared_ptr<const Mesh> _mesh = reference_to_no_delete_pointer(mesh);
+    MeshValueCollection<std::size_t> mvc(_mesh);
+    XMLMeshValueCollection::read(mvc, type, *it);
+
+    // Get mesh value collection data
+    const std::map<std::pair<std::size_t, std::size_t>, std::size_t>&
+      values = mvc.values();
+
+    // Get mesh domain data and fill
+    std::map<std::size_t, std::size_t>& markers
+      = domains.markers(dim);
+    std::map<std::pair<std::size_t, std::size_t>,
+             std::size_t>::const_iterator entry;
+    if (dim != mesh.topology().dim())
+    {
+      for (entry = values.begin(); entry != values.end(); ++entry)
+      {
+        const Cell cell(mesh, entry->first.first);
+        const std::size_t entity_index
+          = cell.entities(dim)[entry->first.second];
+        markers[entity_index] = entry->second;
+      }
+    }
+    else
+    {
+      // Special case for cells
+      for (entry = values.begin(); entry != values.end(); ++entry)
+        markers[entry->first.first] = entry->second;
+    }
   }
 }
 //-----------------------------------------------------------------------------
@@ -300,7 +343,8 @@ void XMLMesh::read_array_uint(std::vector<std::size_t>& array,
   array.resize(size);
 
   // Iterate over array entries
-  for (pugi::xml_node_iterator it = xml_array.begin(); it !=xml_array.end(); ++it)
+  for (pugi::xml_node_iterator it = xml_array.begin(); it !=xml_array.end();
+       ++it)
   {
     const std::size_t index = it->attribute("index").as_uint();
     const double value = it->attribute("value").as_uint();
@@ -393,69 +437,51 @@ void XMLMesh::write_mesh(const Mesh& mesh, pugi::xml_node mesh_node)
   }
 }
 //-----------------------------------------------------------------------------
-void XMLMesh::write_data(const MeshData& data, pugi::xml_node mesh_node)
+void XMLMesh::write_data(const Mesh& mesh, const MeshData& data,
+                         pugi::xml_node mesh_node)
 {
   // Check if there is any data to write
-  if (data.mesh_functions.size() + data.arrays.empty())
+  if (data._arrays.empty())
     return;
 
   // Add mesh data node
   pugi::xml_node mesh_data_node = mesh_node.append_child("data");
 
-  // Write mesh functions
-  typedef std::map<std::string,
-                   boost::shared_ptr<MeshFunction<std::size_t> > >
-    ::const_iterator mf_iterator;
-  for (mf_iterator it = data.mesh_functions.begin();
-       it != data.mesh_functions.end(); ++it)
-  {
-    std::string name = it->first;
-    boost::shared_ptr<MeshFunction<std::size_t> > mf = it->second;
-    dolfin_assert(mf);
-
-    pugi::xml_node data_entry_node = mesh_data_node.append_child("data_entry");
-    data_entry_node.append_attribute("name") = name.c_str();
-
-    pugi::xml_node mf_node = data_entry_node.append_child("mesh_function");
-    mf_node.append_attribute("type") = "uint";
-    mf_node.append_attribute("dim") = (unsigned int) mf->dim();
-    mf_node.append_attribute("size") = (unsigned int) mf->size();
-
-    for (std::size_t i = 0; i < mf->size(); i++)
-    {
-      pugi::xml_node entity_node = mf_node.append_child("entity");
-      entity_node.append_attribute("index") = (unsigned int) i;
-      entity_node.append_attribute("value") = (unsigned int) (*mf)[i];
-    }
-  }
-
   // Write arrays
+  typedef std::vector<std::map<std::string,
+                               std::vector<std::size_t> > >::const_iterator array_iterator_d;
   typedef std::map<std::string,
-                   boost::shared_ptr<std::vector<std::size_t> > >
-    ::const_iterator array_iterator;
-  for (array_iterator it = data.arrays.begin(); it != data.arrays.end(); ++it)
+                   std::vector<std::size_t> >::const_iterator array_iterator;
+  for (array_iterator_d it_d = data._arrays.begin(); it_d != data._arrays.end(); ++it_d)
   {
-    std::string name = it->first;
-    boost::shared_ptr<std::vector<std::size_t> > array = it->second;
-    dolfin_assert(array);
-
-    pugi::xml_node data_entry_node = mesh_data_node.append_child("data_entry");
-    data_entry_node.append_attribute("name") = name.c_str();
-
-    pugi::xml_node array_node = data_entry_node.append_child("array");
-    array_node.append_attribute("type") = "uint";
-    array_node.append_attribute("size") = static_cast<unsigned int>(array->size());
-
-    for (std::size_t i = 0; i < array->size(); i++)
+    const std::size_t dim =  it_d - data._arrays.begin();
+    for (array_iterator it = it_d->begin(); it != it_d->end(); ++it)
     {
-      pugi::xml_node element_node = array_node.append_child("element");
-      element_node.append_attribute("index") = (unsigned int) i;
-      element_node.append_attribute("value") = (unsigned int) (*array)[i];
+      // Data set name and array
+      std::string name = it->first;
+      const std::vector<std::size_t>& array = it->second;
+
+      // Check data lenght
+      if (array.size() != mesh.num_entities(dim))
+      {
+        dolfin_error("XMLMesh.cpp",
+                     "write mesh data to XML file",
+                     "Data array length does not match number of mesh entities");
+      }
+
+      // Copy data into MeshFunction
+      MeshFunction<std::size_t> mf(mesh, dim);
+      mf.rename(name, name);
+      for (std::size_t i = 0; i < mf.size(); ++i)
+        mf[i] = array[i];
+
+      // Write MeshFunction
+      XMLMeshFunction::write(mf, "uint", mesh_data_node, false);
     }
   }
 }
 //-----------------------------------------------------------------------------
-void XMLMesh::write_domains(const MeshDomains& domains,
+void XMLMesh::write_domains(const Mesh& mesh, const MeshDomains& domains,
                             pugi::xml_node mesh_node)
 {
   // Check if there is any data to write
@@ -468,9 +494,16 @@ void XMLMesh::write_domains(const MeshDomains& domains,
   // Write mesh markers
   for (std::size_t d = 0; d <= domains.max_dim(); d++)
   {
-    dolfin_assert(domains.markers(d));
-    if (!domains.markers(d)->empty())
-      XMLMeshValueCollection::write(*(domains.markers(d)), "uint", domains_node);
+    if (!domains.markers(d).empty())
+    {
+      const std::map<std::size_t, std::size_t>& domain = domains.markers(d);
+
+      MeshValueCollection<std::size_t> collection(mesh, d);
+      std::map<std::size_t, std::size_t>::const_iterator it;
+      for (it = domain.begin(); it != domain.end(); ++it)
+        collection.set_value(it->first, it->second);
+      XMLMeshValueCollection::write(collection, "uint", domains_node);
+    }
   }
 }
 //-----------------------------------------------------------------------------
