@@ -22,6 +22,7 @@
 #define __XMLVECTOR_H
 
 #include <ostream>
+#include <vector>
 
 namespace pugi
 {
@@ -42,11 +43,11 @@ namespace dolfin
     static void read(GenericVector& x, const pugi::xml_node xml_dolfin);
 
     // Read XML vector in Array
-    static void read(Array<double>& x, Array<uint>& indices,
+    static void read(std::vector<double>& x, std::vector<dolfin::la_index>& indices,
                      const pugi::xml_node xml_dolfin);
 
     // Read XML vector size
-    static uint read_size(const pugi::xml_node xml_dolfin);
+    static std::size_t read_size(const pugi::xml_node xml_dolfin);
 
     /// Write the XML file
     static void write(const GenericVector& vector, pugi::xml_node xml_node,
