@@ -25,8 +25,10 @@
 #ifndef __BLOCKVECTOR_H
 #define __BLOCKVECTOR_H
 
+#include <string>
 #include <vector>
 #include <boost/shared_ptr.hpp>
+#include <dolfin/common/types.h>
 
 namespace dolfin
 {
@@ -39,7 +41,7 @@ namespace dolfin
   public:
 
     /// Constructor
-    BlockVector(uint n = 0);
+    BlockVector(std::size_t n = 0);
 
     /// Destructor
     virtual ~BlockVector();
@@ -48,13 +50,13 @@ namespace dolfin
     virtual BlockVector* copy() const;
 
     /// Set function
-    void set_block(uint i, boost::shared_ptr<GenericVector> v);
+    void set_block(std::size_t i, boost::shared_ptr<GenericVector> v);
 
     /// Get sub-vector (const)
-    const boost::shared_ptr<GenericVector> get_block(uint i) const;
+    const boost::shared_ptr<GenericVector> get_block(std::size_t i) const;
 
     /// Get sub-vector (non-const)
-    boost::shared_ptr<GenericVector> get_block(uint);
+    boost::shared_ptr<GenericVector> get_block(std::size_t);
 
     /// Add multiple of given vector (AXPY operation)
     void axpy(double a, const BlockVector& x);
@@ -89,8 +91,11 @@ namespace dolfin
     /// Assignment operator
     const BlockVector& operator= (double a);
 
+    /// Return true if empty
+    virtual bool empty() const;
+
     /// Number of vectors
-    uint size() const;
+    std::size_t size() const;
 
     /// Return informal string representation (pretty-print)
     std::string str(bool verbose) const;
