@@ -22,12 +22,13 @@
 
 #ifdef HAS_TRILINOS
 
+#include "dolfin/common/MPI.h"
+
 #include <Epetra_MpiComm.h>
 #include <Epetra_SerialComm.h>
 
 #include "dolfin/common/MPI.h"
 #include "dolfin/common/SubSystemsManager.h"
-#include "EpetraSparsityPattern.h"
 #include "SparsityPattern.h"
 #include "EpetraLUSolver.h"
 #include "EpetraMatrix.h"
@@ -52,39 +53,54 @@ EpetraFactory::~EpetraFactory()
   // Do nothing
 }
 //-----------------------------------------------------------------------------
-EpetraMatrix* EpetraFactory::create_matrix() const
+boost::shared_ptr<GenericMatrix> EpetraFactory::create_matrix() const
 {
-  return new EpetraMatrix();
+  boost::shared_ptr<GenericMatrix> A(new EpetraMatrix);
+  return A;
 }
 //-----------------------------------------------------------------------------
-EpetraVector* EpetraFactory::create_vector() const
+boost::shared_ptr<GenericVector> EpetraFactory::create_vector() const
 {
-  return new EpetraVector("global");
+  boost::shared_ptr<GenericVector> x(new EpetraVector("global"));
+  return x;
 }
 //-----------------------------------------------------------------------------
-EpetraVector* EpetraFactory::create_local_vector() const
+boost::shared_ptr<GenericVector> EpetraFactory::create_local_vector() const
 {
-  return new EpetraVector("local");
+  boost::shared_ptr<GenericVector> x(new EpetraVector("local"));
+  return x;
 }
 //-----------------------------------------------------------------------------
-SparsityPattern* EpetraFactory::create_pattern() const
+boost::shared_ptr<TensorLayout> EpetraFactory::create_layout(std::size_t rank) const
 {
-  return new SparsityPattern;
+  bool sparsity = false;
+  if (rank > 1)
+    sparsity = true;
+  boost::shared_ptr<TensorLayout> pattern(new TensorLayout(0, sparsity));
+  return pattern;
 }
 //-----------------------------------------------------------------------------
-EpetraLUSolver* EpetraFactory::create_lu_solver(std::string method) const
+boost::shared_ptr<GenericLinearOperator> EpetraFactory::create_linear_operator() const
 {
-  return new EpetraLUSolver(method);
+  boost::shared_ptr<GenericLinearOperator> A(new NotImplementedLinearOperator);
+  return A;
 }
 //-----------------------------------------------------------------------------
-EpetraKrylovSolver* EpetraFactory::create_krylov_solver(std::string method,
+boost::shared_ptr<GenericLUSolver> EpetraFactory::create_lu_solver(std::string method) const
+{
+  boost::shared_ptr<GenericLUSolver> solver(new EpetraLUSolver(method));
+  return solver;
+}
+//-----------------------------------------------------------------------------
+boost::shared_ptr<GenericLinearSolver> EpetraFactory::create_krylov_solver(std::string method,
                                               std::string preconditioner) const
 {
-  return new EpetraKrylovSolver(method, preconditioner);
+  boost::shared_ptr<GenericLinearSolver> solver(new EpetraKrylovSolver(method, preconditioner));
+  return solver;
 }
 //-----------------------------------------------------------------------------
 std::vector<std::pair<std::string, std::string> >
-EpetraFactory::lu_solver_methods() const
+  EpetraFactory::lu_solver_methods() const
 {
   return EpetraLUSolver::methods();
 }
@@ -96,7 +112,7 @@ EpetraFactory::krylov_solver_methods() const
 }
 //-----------------------------------------------------------------------------
 std::vector<std::pair<std::string, std::string> >
-EpetraFactory::krylov_solver_preconditioners() const
+  EpetraFactory::krylov_solver_preconditioners() const
 {
   return EpetraKrylovSolver::preconditioners();
 }
