@@ -36,6 +36,7 @@
 
 #include <dolfin/common/MPI.h>
 #include <dolfin/common/NoDeleter.h>
+#include <dolfin/common/Timer.h>
 #include "GenericLinearOperator.h"
 #include "GenericVector.h"
 #include "EpetraMatrix.h"
@@ -51,10 +52,10 @@ EpetraLUSolver::methods()
 {
   static std::vector<std::pair<std::string, std::string> > m;
 
-  m.push_back(std::make_pair("default",      "default LU solver"));
-  m.push_back(std::make_pair("umfpack",      "UMFPACK (Unsymmetric MultiFrontal sparse LU factorization)"));
-  m.push_back(std::make_pair("mumps",        "MUMPS (MUltifrontal Massively Parallel Sparse direct Solver)"));
-  m.push_back(std::make_pair("klu",          "Trilinos KLU"));
+  m.push_back(std::make_pair("default", "default LU solver"));
+  m.push_back(std::make_pair("umfpack", "UMFPACK (Unsymmetric MultiFrontal sparse LU factorization)"));
+  m.push_back(std::make_pair("mumps", "MUMPS (MUltifrontal Massively Parallel Sparse direct Solver)"));
+  m.push_back(std::make_pair("klu", "Trilinos KLU"));
 
   return m;
 }
@@ -187,6 +188,8 @@ const GenericLinearOperator& EpetraLUSolver::get_operator() const
 //-----------------------------------------------------------------------------
 std::size_t EpetraLUSolver::solve(GenericVector& x, const GenericVector& b)
 {
+  Timer timer("Epetra LU solver");
+
   dolfin_assert(linear_problem);
   dolfin_assert(solver);
 
@@ -273,8 +276,8 @@ std::size_t EpetraLUSolver::solve(GenericVector& x, const GenericVector& b)
 }
 //-----------------------------------------------------------------------------
 std::size_t EpetraLUSolver::solve(const GenericLinearOperator& A,
-                                   GenericVector& x,
-                                   const GenericVector& b)
+                                  GenericVector& x,
+                                  const GenericVector& b)
 {
   return solve(as_type<const EpetraMatrix>(require_matrix(A)),
                as_type<EpetraVector>(x),
@@ -282,14 +285,15 @@ std::size_t EpetraLUSolver::solve(const GenericLinearOperator& A,
 }
 //-----------------------------------------------------------------------------
 std::size_t EpetraLUSolver::solve(const EpetraMatrix& A, EpetraVector& x,
-                                   const EpetraVector& b)
+                                  const EpetraVector& b)
 {
   boost::shared_ptr<const EpetraMatrix> Atmp(&A, NoDeleter());
   set_operator(Atmp);
   return solve(x, b);
 }
 //-----------------------------------------------------------------------------
-std::size_t EpetraLUSolver::solve_transpose(GenericVector& x, const GenericVector& b)
+std::size_t EpetraLUSolver::solve_transpose(GenericVector& x,
+                                            const GenericVector& b)
 {
   dolfin_assert(solver);
   solver->SetUseTranspose(true);
@@ -299,8 +303,8 @@ std::size_t EpetraLUSolver::solve_transpose(GenericVector& x, const GenericVecto
 }
 //-----------------------------------------------------------------------------
 std::size_t EpetraLUSolver::solve_transpose(const GenericLinearOperator& A,
-                                   GenericVector& x,
-                                   const GenericVector& b)
+                                            GenericVector& x,
+                                            const GenericVector& b)
 {
   dolfin_assert(solver);
   solver->SetUseTranspose(true);
@@ -309,8 +313,9 @@ std::size_t EpetraLUSolver::solve_transpose(const GenericLinearOperator& A,
   return out;
 }
 //-----------------------------------------------------------------------------
-std::size_t EpetraLUSolver::solve_transpose(const EpetraMatrix& A, EpetraVector& x,
-                                   const EpetraVector& b)
+std::size_t EpetraLUSolver::solve_transpose(const EpetraMatrix& A,
+                                            EpetraVector& x,
+                                            const EpetraVector& b)
 {
   dolfin_assert(solver);
   solver->SetUseTranspose(true);
