@@ -59,7 +59,8 @@ namespace dolfin
     virtual std::size_t size(std::size_t dim) const = 0;
 
     /// Return local ownership range
-    virtual std::pair<std::size_t, std::size_t> local_range(std::size_t dim) const = 0;
+    virtual std::pair<std::size_t, std::size_t>
+      local_range(std::size_t dim) const = 0;
 
     /// Get block of values
     virtual void get(double* block, const dolfin::la_index* num_rows,
@@ -70,12 +71,14 @@ namespace dolfin
                      const dolfin::la_index * const * rows) = 0;
 
     /// Add block of values
-    virtual void add(const double* block,
-                     const std::vector<const std::vector<dolfin::la_index>* >& rows) = 0;
+    virtual
+      void add(const double* block,
+           const std::vector<const std::vector<dolfin::la_index>* >& rows) = 0;
 
     /// Add block of values
-    virtual void add(const double* block,
-                     const std::vector<std::vector<dolfin::la_index> >& rows) = 0;
+    virtual
+      void add(const double* block,
+               const std::vector<std::vector<dolfin::la_index> >& rows) = 0;
 
     /// Add block of values
     virtual void add(const double* block, const dolfin::la_index* num_rows,
