@@ -19,7 +19,7 @@
 // Modified by Anders Logg, 2008.
 //
 // First added:  2007-07-03
-// Last changed: 2011-10-19
+// Last changed: 2013-11-25
 
 #ifndef __KRYLOV_SOLVER_H
 #define __KRYLOV_SOLVER_H
@@ -27,6 +27,7 @@
 #include <string>
 #include <vector>
 #include <boost/shared_ptr.hpp>
+#include <boost/scoped_ptr.hpp>
 #include "GenericLinearSolver.h"
 
 namespace dolfin
@@ -34,9 +35,11 @@ namespace dolfin
 
   class GenericLinearOperator;
   class GenericVector;
+  class VectorSpaceBasis;
 
-  /// This class defines an interface for a Krylov solver. The approproiate solver
-  /// is chosen on the basis of the matrix/vector type.
+  /// This class defines an interface for a Krylov solver. The
+  /// approproiate solver is chosen on the basis of the matrix/vector
+  /// type.
 
   class KrylovSolver : public GenericLinearSolver
   {
@@ -63,18 +66,25 @@ namespace dolfin
 
     /// Set null space of the operator (matrix). This is used to solve
     /// singular systems
-    void set_nullspace(const std::vector<const GenericVector*> nullspace);
+    void set_nullspace(const VectorSpaceBasis& nullspace);
 
     /// Solve linear system Ax = b
     std::size_t solve(GenericVector& x, const GenericVector& b);
 
     /// Solve linear system Ax = b
     std::size_t solve(const GenericLinearOperator& A,
-               GenericVector& x, const GenericVector& b);
+                      GenericVector& x, const GenericVector& b);
 
     /// Default parameter values
     static Parameters default_parameters();
 
+    /// Update solver parameters (pass parameters down to wrapped implementation)
+    virtual void update_parameters(const Parameters& parameters)
+    {
+      this->parameters.update(parameters);
+      solver->parameters.update(parameters);
+    }
+
   private:
 
     // Initialize solver
