@@ -15,27 +15,30 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
-// Modified by Anders Logg 2011
+// Modified by Anders Logg 2011-2012
 //
 // First added:  2007-11-30
-// Last changed: 2011-10-19
+// Last changed: 2012-08-20
 
 #ifdef HAS_PETSC
 
 #ifndef __PETSC_FACTORY_H
 #define __PETSC_FACTORY_H
 
+#include <string>
+#include <boost/shared_ptr.hpp>
+#include <dolfin/common/types.h>
 #include "PETScKrylovSolver.h"
 #include "PETScLUSolver.h"
 #include "PETScMatrix.h"
 #include "PETScVector.h"
-#include "SparsityPattern.h"
-#include "LinearAlgebraFactory.h"
+#include "TensorLayout.h"
+#include "GenericLinearAlgebraFactory.h"
 
 namespace dolfin
 {
 
-  class PETScFactory : public LinearAlgebraFactory
+  class PETScFactory : public GenericLinearAlgebraFactory
   {
   public:
 
@@ -43,35 +46,38 @@ namespace dolfin
     virtual ~PETScFactory() {}
 
     /// Create empty matrix
-    PETScMatrix* create_matrix() const;
+    boost::shared_ptr<GenericMatrix> create_matrix() const;
 
     /// Create empty vector (global)
-    PETScVector* create_vector() const;
+    boost::shared_ptr<GenericVector> create_vector() const;
 
     /// Create empty vector (local)
-    PETScVector* create_local_vector() const;
+    boost::shared_ptr<GenericVector> create_local_vector() const;
 
-    /// Create empty sparsity pattern
-    SparsityPattern* create_pattern() const;
+    /// Create empty tensor layout
+    boost::shared_ptr<TensorLayout> create_layout(std::size_t rank) const;
+
+    /// Create empty linear operator
+    boost::shared_ptr<GenericLinearOperator> create_linear_operator() const;
 
     /// Create LU solver
-    PETScLUSolver* create_lu_solver(std::string method) const;
+    boost::shared_ptr<GenericLUSolver> create_lu_solver(std::string method) const;
 
     /// Create Krylov solver
-    PETScKrylovSolver* create_krylov_solver(std::string method,
+    boost::shared_ptr<GenericLinearSolver> create_krylov_solver(std::string method,
                                             std::string preconditioner) const;
 
     /// Return a list of available LU solver methods
     std::vector<std::pair<std::string, std::string> >
-    lu_solver_methods() const;
+      lu_solver_methods() const;
 
     /// Return a list of available Krylov solver methods
     std::vector<std::pair<std::string, std::string> >
-    krylov_solver_methods() const;
+      krylov_solver_methods() const;
 
     /// Return a list of available preconditioners
     std::vector<std::pair<std::string, std::string> >
-    krylov_solver_preconditioners() const;
+      krylov_solver_preconditioners() const;
 
     /// Return singleton instance
     static PETScFactory& instance()
