@@ -73,22 +73,27 @@ namespace dolfin
     std::size_t solve(GenericVector& x, const GenericVector& b);
 
     /// Solve linear system Ax = b
-    std::size_t solve(GenericVector& x, const GenericVector& b, bool transpose);
+    std::size_t solve(GenericVector& x, const GenericVector& b,
+                      bool transpose);
 
     /// Solve linear system Ax = b
-    std::size_t solve(const GenericLinearOperator& A, GenericVector& x, const GenericVector& b);
+    std::size_t solve(const GenericLinearOperator& A, GenericVector& x,
+                      const GenericVector& b);
 
     /// Solve linear system Ax = b
-    std::size_t solve(const PETScMatrix& A, PETScVector& x, const PETScVector& b);
+    std::size_t solve(const PETScMatrix& A, PETScVector& x,
+                      const PETScVector& b);
 
     /// Solve linear system A^Tx = b
     std::size_t solve_transpose(GenericVector& x, const GenericVector& b);
 
     /// Solve linear system A^Tx = b
-    std::size_t solve_transpose(const GenericLinearOperator& A, GenericVector& x, const GenericVector& b);
+    std::size_t solve_transpose(const GenericLinearOperator& A,
+                                GenericVector& x, const GenericVector& b);
 
     /// Solve linear system A^Tx = b
-    std::size_t solve_transpose(const PETScMatrix& A, PETScVector& x, const PETScVector& b);
+    std::size_t solve_transpose(const PETScMatrix& A, PETScVector& x,
+                                const PETScVector& b);
 
     /// Return informal string representation (pretty-print)
     std::string str(bool verbose) const;
@@ -106,18 +111,30 @@ namespace dolfin
 
   private:
 
+    const MatSolverPackage _solver_package;
+
     // Available LU solvers
     static const std::map<std::string, const MatSolverPackage> _methods;
 
+    // Whether those solvers support Cholesky
+    static const std::map<const MatSolverPackage, const bool> _methods_cholesky;
+
     // Available LU solvers descriptions
-    static const std::vector<std::pair<std::string, std::string> > _methods_descr;
+    static const std::vector<std::pair<std::string, std::string> >
+      _methods_descr;
 
     // Select LU solver type
     const MatSolverPackage select_solver(std::string& method) const;
 
+    // Does an LU solver support Cholesky?
+    bool solver_has_cholesky(const MatSolverPackage package) const;
+
     // Initialise solver
     void init_solver(std::string& method);
 
+    // Configure PETSc options
+    void configure_ksp(const MatSolverPackage solver_package);
+
     // Set PETSc operators
     void set_petsc_operators();
 
