@@ -85,9 +85,9 @@ namespace dolfin
     /// Finalize assembly of tensor. The following values are recognized
     /// for the mode parameter:
     ///
-    ///   add    - corresponding to PETSc MatAssemblyBegin+End(MAT_FINAL_ASSEMBLY)
-    ///   insert - corresponding to PETSc MatAssemblyBegin+End(MAT_FINAL_ASSEMBLY)
-    ///   flush  - corresponding to PETSc MatAssemblyBegin+End(MAT_FLUSH_ASSEMBLY)
+    ///   add    - corresponds to PETSc MatAssemblyBegin+End(MAT_FINAL_ASSEMBLY)
+    ///   insert - corresponds to PETSc MatAssemblyBegin+End(MAT_FINAL_ASSEMBLY)
+    ///   flush  - corresponds to PETSc MatAssemblyBegin+End(MAT_FLUSH_ASSEMBLY)
     virtual void apply(std::string mode);
 
     /// Return informal string representation (pretty-print)
@@ -112,19 +112,23 @@ namespace dolfin
     { PETScBaseMatrix::resize(z, dim); }
 
     /// Get block of values
-    virtual void get(double* block, std::size_t m, const dolfin::la_index* rows, std::size_t n,
-                     const dolfin::la_index* cols) const;
+    virtual void get(double* block,
+                     std::size_t m, const dolfin::la_index* rows,
+                     std::size_t n, const dolfin::la_index* cols) const;
 
     /// Set block of values
-    virtual void set(const double* block, std::size_t m, const dolfin::la_index* rows, std::size_t n,
-                     const dolfin::la_index* cols);
+    virtual void set(const double* block,
+                     std::size_t m, const dolfin::la_index* rows,
+                     std::size_t n, const dolfin::la_index* cols);
 
     /// Add block of values
-    virtual void add(const double* block, std::size_t m, const dolfin::la_index* rows, std::size_t n,
-                     const dolfin::la_index* cols);
+    virtual void add(const double* block,
+                     std::size_t m, const dolfin::la_index* rows,
+                     std::size_t n, const dolfin::la_index* cols);
 
     /// Add multiple of given matrix (AXPY operation)
-    virtual void axpy(double a, const GenericMatrix& A, bool same_nonzero_pattern);
+    virtual void axpy(double a, const GenericMatrix& A,
+                      bool same_nonzero_pattern);
 
     /// Get non-zero values of given row
     virtual void getrow(std::size_t row,
