@@ -35,6 +35,8 @@
 #include "TensorLayout.h"
 #include "GenericMatrix.h"
 
+#include <dolfin/log/dolfin_log.h>
+
 namespace dolfin
 {
 
@@ -56,7 +58,7 @@ namespace dolfin
 
     /// Create empty matrix
     STLMatrix(std::size_t primary_dim=0) : _primary_dim(primary_dim),
-      _local_range(0, 0), num_codim_entities(0) {}
+      _block_size(1), _local_range(0, 0), num_codim_entities(0) {}
 
     /// Destructor
     virtual ~STLMatrix() {}
@@ -70,7 +72,8 @@ namespace dolfin
     virtual std::size_t size(std::size_t dim) const;
 
     /// Return local ownership range
-    virtual std::pair<std::size_t, std::size_t> local_range(std::size_t dim) const;
+    virtual std::pair<std::size_t, std::size_t>
+      local_range(std::size_t dim) const;
 
     /// Set all entries to zero and keep any sparse structure
     virtual void zero();
@@ -101,17 +104,20 @@ namespace dolfin
     { dolfin_not_implemented(); }
 
     /// Get block of values
-    virtual void get(double* block, std::size_t m, const dolfin::la_index* rows, std::size_t n,
+    virtual void get(double* block, std::size_t m,
+                     const dolfin::la_index* rows, std::size_t n,
                      const dolfin::la_index* cols) const
     { dolfin_not_implemented(); }
 
     /// Set block of values
-    virtual void set(const double* block, std::size_t m, const dolfin::la_index* rows, std::size_t n,
+    virtual void set(const double* block, std::size_t m,
+                     const dolfin::la_index* rows, std::size_t n,
                      const dolfin::la_index* cols)
     { dolfin_not_implemented(); }
 
     /// Add block of values
-    virtual void add(const double* block, std::size_t m, const dolfin::la_index* rows, std::size_t n,
+    virtual void add(const double* block, std::size_t m,
+                     const dolfin::la_index* rows, std::size_t n,
                      const dolfin::la_index* cols);
 
     /// Add multiple of given matrix (AXPY operation)
@@ -127,7 +133,8 @@ namespace dolfin
                         std::vector<double>& values) const;
 
     /// Set values for given row
-    virtual void setrow(std::size_t row, const std::vector<std::size_t>& columns,
+    virtual void setrow(std::size_t row,
+                        const std::vector<std::size_t>& columns,
                         const std::vector<double>& values)
     { dolfin_not_implemented(); }
 
@@ -163,6 +170,10 @@ namespace dolfin
 
     ///--- STLMatrix interface ---
 
+    /// Return matrix block size
+    std::size_t block_size() const
+    { return _block_size; }
+
     /// Clear matrix. Destroys data and sparse layout
     void clear()
     {
@@ -184,6 +195,7 @@ namespace dolfin
     void csr(std::vector<double>& vals, std::vector<T>& cols,
              std::vector<T>& row_ptr,
              std::vector<T>& local_to_global_row,
+             bool block,
              bool symmetric) const;
 
     /// Return matrix in CSC format
@@ -191,6 +203,7 @@ namespace dolfin
     void csc(std::vector<double>& vals, std::vector<T>& rows,
              std::vector<T>& col_ptr,
              std::vector<T>& local_to_global_col,
+             bool block,
              bool symmetric) const;
 
     /// Return number of global non-zero entries
@@ -207,11 +220,15 @@ namespace dolfin
                             std::vector<T>& rows,
                             std::vector<T>& col_ptr,
                             std::vector<T>& local_to_global_col,
+                            bool block,
                             bool symmetric) const;
 
     // Primary dimension (0=row-wise storage, 1=column-wise storage)
     const std::size_t _primary_dim;
 
+    // Block size, e.g. 3 for 3D elasticity with appropriate dof ordering
+    std::size_t _block_size;
+
     // Local ownership range (row range for row-wise storage, column
     // range for column-wise storage)
     std::pair<std::size_t, std::size_t> _local_range;
@@ -224,7 +241,8 @@ namespace dolfin
     std::vector<std::vector<std::pair<std::size_t, double> > > _values;
 
     // Off-process data ([i, j], value)
-    boost::unordered_map<std::pair<std::size_t, std::size_t>, double> off_processs_data;
+    boost::unordered_map<std::pair<std::size_t, std::size_t>, double>
+      off_processs_data;
 
   };
 
@@ -235,6 +253,7 @@ namespace dolfin
   void STLMatrix::csr(std::vector<double>& vals, std::vector<T>& cols,
                       std::vector<T>& row_ptr,
                       std::vector<T>& local_to_global_row,
+                      bool block,
                       bool symmetric) const
   {
     if (_primary_dim != 0)
@@ -243,13 +262,15 @@ namespace dolfin
                    "creating compressed row storage data",
                    "Cannot create CSR matrix from STLMatrix with column-wise storage.");
     }
-    compressed_storage(vals, cols, row_ptr, local_to_global_row, symmetric);
+    compressed_storage(vals, cols, row_ptr, local_to_global_row, block,
+                       symmetric);
   }
-  //-----------------------------------------------------------------------------
+  //---------------------------------------------------------------------------
   template<typename T>
   void STLMatrix::csc(std::vector<double>& vals, std::vector<T>& rows,
                       std::vector<T>& col_ptr,
                       std::vector<T>& local_to_global_col,
+                      bool block,
                       bool symmetric) const
   {
     if (_primary_dim != 1)
@@ -258,14 +279,16 @@ namespace dolfin
                    "creating compressed column storage data",
                    "Cannot create CSC matrix from STLMatrix with row-wise storage.");
     }
-    compressed_storage(vals, rows, col_ptr, local_to_global_col, symmetric);
+    compressed_storage(vals, rows, col_ptr, local_to_global_col, block,
+                       symmetric);
   }
-  //-----------------------------------------------------------------------------
+  //---------------------------------------------------------------------------
   template<typename T>
   void STLMatrix::compressed_storage(std::vector<double>& vals,
                                      std::vector<T>& cols,
                                      std::vector<T>& row_ptr,
                                      std::vector<T>& local_to_global_row,
+                                     bool block,
                                      bool symmetric) const
   {
     // Reset data structures
@@ -294,16 +317,20 @@ namespace dolfin
       cols.reserve(_local_nnz);
 
       // Build data structures
-      for (std::size_t local_row = 0; local_row < num_local_rows; ++local_row)
+      for (std::size_t local_row = 0; local_row < num_local_rows;
+           local_row += _block_size)
       {
-        for (std::size_t column = 0; column < _values[local_row].size(); ++column)
+        for (std::size_t column = 0; column < _values[local_row].size();
+             column += _block_size)
         {
-          cols.push_back(_values[local_row][column].first);
-          vals.push_back(_values[local_row][column].second);
-
+          cols.push_back(_values[local_row][column].first/_block_size);
+          for (std::size_t b0 = 0; b0 < _block_size; ++b0)
+            for (std::size_t b1 = 0; b1 < _block_size; ++b1)
+              vals.push_back(_values[local_row + b0][column + b1].second);
         }
-        local_to_global_row.push_back(_local_range.first + local_row);
-        row_ptr.push_back(row_ptr.back() + _values[local_row].size());
+        local_to_global_row.push_back((_local_range.first
+                                       + local_row)/_block_size);
+        row_ptr.push_back(row_ptr.back()+_values[local_row].size()/_block_size);
       }
     }
     else
@@ -313,17 +340,23 @@ namespace dolfin
       cols.reserve((_local_nnz - num_local_rows)/2 + num_local_rows);
 
       // Build data structures
-      for (std::size_t local_row = 0; local_row < _values.size(); ++local_row)
+      for (std::size_t local_row = 0; local_row < _values.size();
+           local_row += _block_size)
       {
-        const std::size_t global_row_index = local_row + _local_range.first;
+        const std::size_t global_row_index
+          = (local_row + _local_range.first)/_block_size;
         std::size_t counter = 0;
-        for (std::size_t i = 0; i < _values[local_row].size(); ++i)
+        for (std::size_t column = 0; column < _values[local_row].size();
+             column += _block_size)
         {
-          const std::size_t index = _values[local_row][i].first;
+          const std::size_t index
+            = _values[local_row][column].first/_block_size;
           if (index >= global_row_index)
           {
             cols.push_back(index);
-            vals.push_back(_values[local_row][i].second);
+            for (std::size_t b0 = 0; b0 < _block_size; ++b0)
+              for (std::size_t b1 = 0; b1 < _block_size; ++b1)
+                vals.push_back(_values[local_row + b0][column + b1].second);
             ++counter;
           }
         }
