@@ -27,13 +27,14 @@
 #include <string>
 #include <vector>
 #include <dolfin/common/MPI.h>
+#include <dolfin/common/types.h>
 #include "DefaultFactory.h"
 #include "GenericTensor.h"
 
 namespace dolfin
 {
 
-  class GenericSparsityPattern;
+  class TensorLayout;
 
   /// This class represents a real-valued scalar quantity and
   /// implements the GenericTensor interface for scalars.
@@ -43,40 +44,27 @@ namespace dolfin
   public:
 
     /// Create zero scalar
-    Scalar() : GenericTensor(), value(0.0) {}
+    Scalar() : GenericTensor(), _value(0.0) {}
 
     /// Destructor
     virtual ~Scalar() {}
 
     //--- Implementation of the GenericTensor interface ---
 
-    /// Return true if tensor is distributed
-    virtual bool distributed() const
-    {
-      if (MPI::num_processes() > 1)
-        return true;
-      else
-        return false;
-    }
-
     /// Resize tensor to given dimensions
-    virtual void resize(uint rank, const uint* dims)
-    { dolfin_assert(rank == 0); value = 0.0; }
+    virtual void resize(std::size_t rank, const std::size_t* dims)
+    { dolfin_assert(rank == 0); _value = 0.0; }
 
     /// Initialize zero tensor using sparsity pattern
-    void init(const GenericSparsityPattern& sparsity_pattern)
-    { value = 0.0; }
-
-    /// Return copy of tensor
-    virtual Scalar* copy() const
-    { Scalar* s = new Scalar(); s->value = value; return s; }
+    void init(const TensorLayout& tensor_layout)
+    { _value = 0.0; }
 
     /// Return tensor rank (number of dimensions)
-    uint rank() const
+    std::size_t rank() const
     { return 0; }
 
     /// Return size of given dimension
-    uint size(uint dim) const
+    std::size_t size(std::size_t dim) const
     {
       dolfin_error("Scalar.h",
                    "get size of scalar",
@@ -85,7 +73,7 @@ namespace dolfin
     }
 
     /// Return local ownership range
-    virtual std::pair<uint, uint> local_range(uint dim) const
+    virtual std::pair<std::size_t, std::size_t> local_range(std::size_t dim) const
     {
       dolfin_error("Scalar.h",
                    "get local range of scalar",
@@ -94,64 +82,72 @@ namespace dolfin
     }
 
     /// Get block of values
-    void get(double* block, const uint* num_rows, const uint * const * rows) const
-    { block[0] = value; }
+    void get(double* block, const dolfin::la_index* num_rows, const dolfin::la_index * const * rows) const
+    { block[0] = _value; }
 
     /// Set block of values
-    void set(const double* block, const uint* num_rows, const uint * const * rows)
-    { value = block[0]; }
+    void set(const double* block, const dolfin::la_index* num_rows, const dolfin::la_index * const * rows)
+    { _value = block[0]; }
 
     /// Add block of values
-    void add(const double* block, const uint* num_rows, const uint * const * rows)
+    void add(const double* block, const dolfin::la_index* num_rows, const dolfin::la_index * const * rows)
     {
       dolfin_assert(block);
-      value += block[0];
+      _value += block[0];
     }
 
     /// Add block of values
-    void add(const double* block, const std::vector<const std::vector<uint>* >& rows)
+    void add(const double* block, const std::vector<const std::vector<dolfin::la_index>* >& rows)
     {
       dolfin_assert(block);
-      value += block[0];
+      _value += block[0];
     }
 
     /// Add block of values
-    void add(const double* block, const std::vector<std::vector<uint> >& rows)
+    void add(const double* block, const std::vector<std::vector<dolfin::la_index> >& rows)
     {
       dolfin_assert(block);
-      value += block[0];
+      _value += block[0];
     }
 
     /// Set all entries to zero and keep any sparse structure
     void zero()
-    { value = 0.0; }
+    { _value = 0.0; }
 
     /// Finalize assembly of tensor
     void apply(std::string mode)
-    { value = MPI::sum(value); }
+    { _value = MPI::sum(_value); }
 
     /// Return informal string representation (pretty-print)
     std::string str(bool verbose) const
     {
       std::stringstream s;
-      s << "<Scalar value " << value << ">";
+      s << "<Scalar value " << _value << ">";
       return s.str();
     }
 
     //--- Scalar interface ---
 
+    /// Return copy of scalar
+    virtual boost::shared_ptr<Scalar> copy() const
+    {
+      boost::shared_ptr<Scalar> s(new Scalar);
+      s->_value = _value;
+      return s;
+    }
+
     /// Cast to double
     operator double() const
-    { return value; }
+    { return _value; }
 
     /// Assignment from double
     const Scalar& operator= (double value)
-    { this->value = value; return *this; }
+    { _value = value; return *this; }
 
     //--- Special functions
 
     /// Return a factory for the default linear algebra backend
-    LinearAlgebraFactory& factory() const
+    GenericLinearAlgebraFactory& factory() const
     {
       DefaultFactory f;
       return f.factory();
@@ -160,12 +156,12 @@ namespace dolfin
 
     /// Get value
     double getval() const
-    { return value; }
+    { return _value; }
 
   private:
 
     // Value of scalar
-    double value;
+    double _value;
 
   };
 
