@@ -27,17 +27,20 @@ using namespace dolfin;
 
 //-----------------------------------------------------------------------------
 TensorLayout::TensorLayout(std::size_t pdim, bool sparsity_pattern)
-    : primary_dim(pdim)
+  : primary_dim(pdim), block_size(0)
 {
   // Create empty sparsity pattern
   if (sparsity_pattern)
     _sparsity_pattern.reset(new SparsityPattern(primary_dim));
 }
 //-----------------------------------------------------------------------------
-TensorLayout::TensorLayout(const std::vector<std::size_t>& dims, std::size_t pdim,
-  const std::vector<std::pair<std::size_t, std::size_t> >& ownership_range,
-  bool sparsity_pattern)
-  : primary_dim(pdim), _shape(dims), _ownership_range(ownership_range)
+TensorLayout::TensorLayout(const std::vector<std::size_t>& dims,
+                           std::size_t pdim, std::size_t bs,
+                           const std::vector<std::pair<std::size_t,
+                                     std::size_t> >& ownership_range,
+                           bool sparsity_pattern)
+  : primary_dim(pdim), block_size(bs), _shape(dims),
+    _ownership_range(ownership_range)
 {
   // Only rank 2 sparsity patterns are supported
   dolfin_assert(!(sparsity_pattern && dims.size() != 2));
@@ -50,7 +53,7 @@ TensorLayout::TensorLayout(const std::vector<std::size_t>& dims, std::size_t pdi
     _sparsity_pattern.reset(new SparsityPattern(primary_dim));
 }
 //-----------------------------------------------------------------------------
-void TensorLayout::init(const std::vector<std::size_t>& dims,
+void TensorLayout::init(const std::vector<std::size_t>& dims, std::size_t bs,
   const std::vector<std::pair<std::size_t, std::size_t> >& ownership_range)
 {
   // Only rank 2 sparsity patterns are supported
@@ -62,6 +65,9 @@ void TensorLayout::init(const std::vector<std::size_t>& dims,
   // Store dimensions
   _shape = dims;
 
+  // Store block size
+  block_size = bs;
+
   // Store ownership range
   _ownership_range = ownership_range;
 }
@@ -77,7 +83,8 @@ std::size_t TensorLayout::size(std::size_t i) const
   return _shape[i];
 }
 //-----------------------------------------------------------------------------
-std::pair<std::size_t, std::size_t> TensorLayout::local_range(std::size_t dim) const
+std::pair<std::size_t, std::size_t>
+TensorLayout::local_range(std::size_t dim) const
 {
   dolfin_assert(dim < 2);
   return _ownership_range[dim];
