@@ -14,10 +14,12 @@
 #include <dolfin/la/GenericMatrix.h>
 #include <dolfin/la/GenericSparsityPattern.h>
 #include <dolfin/la/GenericVector.h>
+#include <dolfin/la/VectorSpaceBasis.h>
 #include <dolfin/la/GenericLinearSolver.h>
 #include <dolfin/la/GenericLUSolver.h>
 #include <dolfin/la/GenericPreconditioner.h>
 
+#include <dolfin/la/PETScOptions.h>
 #include <dolfin/la/PETScObject.h>
 #include <dolfin/la/PETScBaseMatrix.h>
 #include <dolfin/la/uBLASFactory.h>
