@@ -16,22 +16,23 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells 2008
-// Modified by Anders Logg 2011
+// Modified by Anders Logg 2011-2012
 //
 // First added:  2007-12-06
-// Last changed: 2011-10-19
+// Last changed: 2012-08-20
 
 #ifndef __UBLAS_FACTORY_H
 #define __UBLAS_FACTORY_H
 
 #include <string>
+#include <boost/shared_ptr.hpp>
 
 #include "uBLASKrylovSolver.h"
 #include "uBLASMatrix.h"
 #include "uBLASVector.h"
-#include "SparsityPattern.h"
+#include "TensorLayout.h"
 #include "UmfpackLUSolver.h"
-#include "LinearAlgebraFactory.h"
+#include "GenericLinearAlgebraFactory.h"
 
 namespace dolfin
 {
@@ -39,7 +40,7 @@ namespace dolfin
   class GenericLinearSolver;
 
   template<typename Mat = ublas_sparse_matrix>
-  class uBLASFactory : public LinearAlgebraFactory
+  class uBLASFactory : public GenericLinearAlgebraFactory
   {
   public:
 
@@ -47,33 +48,62 @@ namespace dolfin
     virtual ~uBLASFactory() {}
 
     /// Create empty matrix
-    uBLASMatrix<Mat>* create_matrix() const
-    { return new uBLASMatrix<Mat>(); }
+    boost::shared_ptr<GenericMatrix> create_matrix() const
+    {
+      boost::shared_ptr<GenericMatrix> A(new uBLASMatrix<Mat>);
+      return A;
+    }
 
     /// Create empty vector
-    uBLASVector* create_vector() const
-    { return new uBLASVector(); }
+    boost::shared_ptr<GenericVector> create_vector() const
+    {
+      boost::shared_ptr<GenericVector> x(new uBLASVector);
+      return x;
+    }
 
     /// Create empty vector (local)
-    uBLASVector* create_local_vector() const
-    { return new uBLASVector(); }
+    boost::shared_ptr<GenericVector> create_local_vector() const
+    {
+      boost::shared_ptr<GenericVector> x(new uBLASVector);
+      return x;
+    }
 
-    /// Create empty sparsity pattern
-    SparsityPattern* create_pattern() const
-    { return new SparsityPattern(); }
+    /// Create empty tensor layout
+    boost::shared_ptr<TensorLayout> create_layout(std::size_t rank) const
+    {
+      bool sparsity = false;
+      if (rank > 1)
+        sparsity = true;
+      boost::shared_ptr<TensorLayout> pattern(new TensorLayout(0, sparsity));
+      return pattern;
+    }
+
+    /// Create empty linear operator
+    boost::shared_ptr<GenericLinearOperator> create_linear_operator() const
+    {
+      boost::shared_ptr<GenericLinearOperator> A(new uBLASLinearOperator);
+      return A;
+    }
 
     /// Create LU solver
-    UmfpackLUSolver* create_lu_solver(std::string method) const
-    { return new UmfpackLUSolver(); }
+    boost::shared_ptr<GenericLUSolver> create_lu_solver(std::string method) const
+    {
+      boost::shared_ptr<GenericLUSolver> solver(new UmfpackLUSolver);
+      return solver;
+    }
 
     /// Create Krylov solver
-    GenericLinearSolver* create_krylov_solver(std::string method,
+    boost::shared_ptr<GenericLinearSolver> create_krylov_solver(std::string method,
                                               std::string preconditioner) const
-    { return new uBLASKrylovSolver(method, preconditioner); }
+    {
+      boost::shared_ptr<GenericLinearSolver>
+        solver(new uBLASKrylovSolver(method, preconditioner));
+      return solver;
+    }
 
     /// Return a list of available LU solver methods
     std::vector<std::pair<std::string, std::string> >
-    lu_solver_methods() const
+      lu_solver_methods() const
     {
       std::vector<std::pair<std::string, std::string> > methods;
       methods.push_back(std::make_pair("default",
@@ -85,14 +115,14 @@ namespace dolfin
 
     /// Return a list of available Krylov solver methods
     std::vector<std::pair<std::string, std::string> >
-    krylov_solver_methods() const
+      krylov_solver_methods() const
     {
       return uBLASKrylovSolver::methods();
     }
 
     /// Return a list of available preconditioners
     std::vector<std::pair<std::string, std::string> >
-    krylov_solver_preconditioners() const
+      krylov_solver_preconditioners() const
     {
       return uBLASKrylovSolver::preconditioners();
     }
