@@ -15,10 +15,10 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
-// Modified by Anders Logg 2006-2011
+// Modified by Anders Logg 2006-2012
 //
 // First added:  2006-05-31
-// Last changed: 2011-11-11
+// Last changed: 2012-08-20
 
 #ifndef __UBLAS_KRYLOV_SOLVER_H
 #define __UBLAS_KRYLOV_SOLVER_H
@@ -29,7 +29,7 @@
 #include <dolfin/common/types.h>
 #include "ublas.h"
 #include "GenericLinearSolver.h"
-#include "uBLASKrylovMatrix.h"
+#include "uBLASLinearOperator.h"
 #include "uBLASMatrix.h"
 #include "uBLASVector.h"
 #include "uBLASPreconditioner.h"
@@ -37,7 +37,7 @@
 namespace dolfin
 {
 
-  class GenericMatrix;
+  class GenericLinearOperator;
   class GenericVector;
 
   /// This class implements Krylov methods for linear systems
@@ -62,35 +62,33 @@ namespace dolfin
     ~uBLASKrylovSolver();
 
     /// Solve the operator (matrix)
-    void set_operator(const boost::shared_ptr<const GenericMatrix> A)
+    void set_operator(const boost::shared_ptr<const GenericLinearOperator> A)
     { set_operators(A, A); }
 
     /// Set operator (matrix) and preconditioner matrix
-    void set_operators(const boost::shared_ptr<const GenericMatrix> A,
-                       const boost::shared_ptr<const GenericMatrix> P)
-    { this->A = A; this->P = P; }
+    void set_operators(const boost::shared_ptr<const GenericLinearOperator> A,
+                       const boost::shared_ptr<const GenericLinearOperator> P)
+    { _A = A; _P = P; }
 
 
     /// Return the operator (matrix)
-    const GenericMatrix& get_operator() const
+    const GenericLinearOperator& get_operator() const
     {
-      if (!A)
+      if (!_A)
       {
         dolfin_error("uBLASKrylovSolver.cpp",
                      "access operator for uBLAS Krylov solver",
                      "Operator has not been set");
       }
-      return *A;
+      return *_A;
     }
 
     /// Solve linear system Ax = b and return number of iterations
-    uint solve(GenericVector& x, const GenericVector& b);
+    std::size_t solve(GenericVector& x, const GenericVector& b);
 
     /// Solve linear system Ax = b and return number of iterations
-    uint solve(const GenericMatrix& A, GenericVector& x, const GenericVector& b);
-
-    /// Solve linear system Ax = b and return number of iterations (virtual matrix)
-    uint solve(const uBLASKrylovMatrix& A, uBLASVector& x, const uBLASVector& b);
+    std::size_t solve(const GenericLinearOperator& A, GenericVector& x,
+                      const GenericVector& b);
 
     /// Return a list of available solver methods
     static std::vector<std::pair<std::string, std::string> > methods();
@@ -104,23 +102,25 @@ namespace dolfin
   private:
 
     /// Select solver and solve linear system Ax = b and return number of iterations
-    template<typename Mat>
-    uint solve_krylov(const Mat& A, uBLASVector& x, const uBLASVector& b,
-                      const Mat& P);
+    template<typename MatA, typename MatP>
+    std::size_t solve_krylov(const MatA& A,
+                      uBLASVector& x,
+                      const uBLASVector& b,
+                      const MatP& P);
 
     /// Solve linear system Ax = b using CG
     template<typename Mat>
-    uint solveCG(const Mat& A, uBLASVector& x, const uBLASVector& b,
+    std::size_t solveCG(const Mat& A, uBLASVector& x, const uBLASVector& b,
                  bool& converged) const;
 
     /// Solve linear system Ax = b using restarted GMRES
     template<typename Mat>
-    uint solveGMRES(const Mat& A, uBLASVector& x, const uBLASVector& b,
+    std::size_t solveGMRES(const Mat& A, uBLASVector& x, const uBLASVector& b,
                         bool& converged) const;
 
     /// Solve linear system Ax = b using BiCGStab
     template<typename Mat>
-    uint solveBiCGStab(const Mat& A, uBLASVector& x, const uBLASVector& b,
+    std::size_t solveBiCGStab(const Mat& A, uBLASVector& x, const uBLASVector& b,
                         bool& converged) const;
 
     /// Select and create named preconditioner
@@ -130,35 +130,35 @@ namespace dolfin
     void read_parameters();
 
     /// Krylov method
-    std::string method;
+    std::string _method;
 
     /// Preconditioner
-    boost::shared_ptr<uBLASPreconditioner> pc;
+    boost::shared_ptr<uBLASPreconditioner> _pc;
 
     /// Solver parameters
     double rtol, atol, div_tol;
-    uint max_it, restart;
+    std::size_t max_it, restart;
     bool report;
 
     /// Operator (the matrix)
-    boost::shared_ptr<const GenericMatrix> A;
+    boost::shared_ptr<const GenericLinearOperator> _A;
 
     /// Matrix used to construct the preconditoner
-    boost::shared_ptr<const GenericMatrix> P;
+    boost::shared_ptr<const GenericLinearOperator> _P;
 
   };
   //---------------------------------------------------------------------------
   // Implementation of template functions
   //---------------------------------------------------------------------------
-  template<typename Mat>
-  dolfin::uint uBLASKrylovSolver::solve_krylov(const Mat& A,
+  template<typename MatA, typename MatP>
+  std::size_t uBLASKrylovSolver::solve_krylov(const MatA& A,
                                                uBLASVector& x,
                                                const uBLASVector& b,
-                                               const Mat& P)
+                                               const MatP& P)
   {
     // Check dimensions
-    uint M = A.size(0);
-    uint N = A.size(1);
+    std::size_t M = A.size(0);
+    std::size_t N = A.size(1);
     if ( N != b.size() )
     {
       dolfin_error("uBLASKrylovSolver.h",
@@ -181,24 +181,24 @@ namespace dolfin
       info("Solving linear system of size %d x %d (uBLAS Krylov solver).", M, N);
 
     // Initialise preconditioner if necessary
-    pc->init(P);
+    _pc->init(P);
 
     // Choose solver and solve
     bool converged = false;
-    uint iterations = 0;
-    if (method == "cg")
+    std::size_t iterations = 0;
+    if (_method == "cg")
       iterations = solveCG(A, x, b, converged);
-    else if (method == "gmres")
+    else if (_method == "gmres")
       iterations = solveGMRES(A, x, b, converged);
-    else if (method == "bicgstab")
+    else if (_method == "bicgstab")
       iterations = solveBiCGStab(A, x, b, converged);
-    else if (method == "default")
+    else if (_method == "default")
       iterations = solveBiCGStab(A, x, b, converged);
     else
     {
       dolfin_error("uBLASKrylovSolver.h",
                    "solve linear system using uBLAS Krylov solver",
-                   "Requested Krylov method (\"%s\") is unknown", method.c_str());
+                   "Requested Krylov method (\"%s\") is unknown", _method.c_str());
     }
 
     // Check for convergence
@@ -221,7 +221,7 @@ namespace dolfin
   }
   //-----------------------------------------------------------------------------
   template<typename Mat>
-  dolfin::uint uBLASKrylovSolver::solveCG(const Mat& A,
+  std::size_t uBLASKrylovSolver::solveCG(const Mat& A,
                                           uBLASVector& x,
                                           const uBLASVector& b,
                                           bool& converged) const
@@ -231,7 +231,7 @@ namespace dolfin
   }
   //-----------------------------------------------------------------------------
   template<typename Mat>
-  dolfin::uint uBLASKrylovSolver::solveGMRES(const Mat& A, uBLASVector& x,
+  std::size_t uBLASKrylovSolver::solveGMRES(const Mat& A, uBLASVector& x,
                                              const uBLASVector& b,
                                              bool& converged) const
   {
@@ -240,7 +240,7 @@ namespace dolfin
     const ublas_vector& _b = b.vec();
 
     // Get size of system
-    const uint size = A.size(0);
+    const std::size_t size = A.size(0);
 
     // Create residual vector
     uBLASVector r(size);
@@ -267,7 +267,7 @@ namespace dolfin
     double nu, temp1, temp2, r_norm = 0.0, beta0 = 0;
 
     converged = false;
-    uint iteration = 0;
+    std::size_t iteration = 0;
     while (iteration < max_it && !converged)
     {
       // Compute residual r = b -A*x
@@ -279,7 +279,7 @@ namespace dolfin
 
       // Apply preconditioner (use w for temporary storage)
       _w.assign(_r);
-      pc->solve(r, w);
+      _pc->solve(r, w);
 
       // L2 norm of residual (for most recent restart)
       const double beta = norm_2(_r);
@@ -302,8 +302,8 @@ namespace dolfin
       noalias(column(V, 0)) = _r/beta;
 
       // Modified Gram-Schmidt procedure
-      uint subiteration = 0;
-      uint j = 0;
+      std::size_t subiteration = 0;
+      std::size_t j = 0;
       while (subiteration < restart && iteration < max_it && !converged && r_norm/beta < div_tol)
       {
         // Compute product w = A*V_j (use r for temporary storage)
@@ -313,9 +313,9 @@ namespace dolfin
 
         // Apply preconditioner (use r for temporary storage)
         _r.assign(_w);
-        pc->solve(w, r);
+        _pc->solve(w, r);
 
-        for (uint i=0; i <= j; ++i)
+        for (std::size_t i=0; i <= j; ++i)
         {
           _h(i)= inner_prod(_w, column(V,i));
           noalias(_w) -= _h(i)*column(V,i);
@@ -328,7 +328,7 @@ namespace dolfin
         // Apply previous Givens rotations to the "new" column
         // (this could be improved? - use more uBLAS functions.
         //  The below has been taken from old DOLFIN code.)
-        for(uint i=0; i<j; ++i)
+        for(std::size_t i=0; i<j; ++i)
         {
           temp1 = _h(i);
           temp2 = _h(i+1);
@@ -361,7 +361,7 @@ namespace dolfin
         //   noalias(column(H, j)) = subrange(h, 0, restart);
         // but this gives an error when uBLAS debugging is turned onand H
         // is a triangular matrix
-        for(uint i=0; i<j+1; ++i)
+        for(std::size_t i=0; i<j+1; ++i)
           H(i,j) = _h(i);
 
         // Check for convergence
@@ -388,7 +388,8 @@ namespace dolfin
   }
   //-----------------------------------------------------------------------------
   template<typename Mat>
-  dolfin::uint uBLASKrylovSolver::solveBiCGStab(const Mat& A, uBLASVector& x,
+  std::size_t uBLASKrylovSolver::solveBiCGStab(const Mat& A,
+                                                uBLASVector& x,
                                                 const uBLASVector& b,
                                                 bool& converged) const
   {
@@ -397,7 +398,7 @@ namespace dolfin
     const ublas_vector& _b = b.vec();
 
    // Get size of system
-    const uint size = A.size(0);
+    const std::size_t size = A.size(0);
 
     // Allocate vectors
     uBLASVector r(size), rstar(size), p(size), s(size), v(size), t(size), y(size), z(size);
@@ -435,13 +436,13 @@ namespace dolfin
     // Apply preconditioner to r^start. This is a trick to avoid problems in which
     // (r^start, r) = 0  after the first iteration (such as PDE's with homogeneous
     // Neumann bc's and no forcing/source term.
-    pc->solve(rstar, r);
+    _pc->solve(rstar, r);
 
     // Right-preconditioned Bi-CGSTAB
 
     // Start iterations
     converged = false;
-    uint iteration = 0;
+    std::size_t iteration = 0;
     while (iteration < max_it && !converged && r_norm/r0_norm < div_tol)
     {
       // Set rho_n = rho_n+1
@@ -463,7 +464,7 @@ namespace dolfin
       noalias(_p) += _r - beta*omega*_v;
 
       // My = p
-      pc->solve(y, p);
+      _pc->solve(y, p);
 
       // v = A*y
       //axpy_prod(A, y, v, true);
@@ -476,7 +477,7 @@ namespace dolfin
       noalias(_s) = _r - alpha*_v;
 
       // Mz = s
-      pc->solve(z, s);
+      _pc->solve(z, s);
 
       // t = A*z
       //axpy_prod(A, z, t, true);
