@@ -9,11 +9,11 @@
 //
 // DOLFIN is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // Thanks to Jim Tilander for many helpful hints.
 //
@@ -28,6 +28,14 @@
 namespace dolfin
 {
 
+  /* FIXME: logging in destructors may fail at exit because the logger instance
+     may already be destroyed ("static initialization order fiasco"). The same
+     may happen at startup, if logging from constructors of static objects. The
+     logger instance should be converted to a heap-allocated (and never
+     deleted) object, with an accessor function. Like in SubSystemsManager, but
+     maybe with a static pointer rather than a static object in the accessor
+     function. */
+
   class LogManager
   {
   public:
