@@ -19,7 +19,7 @@
 // Modified by Garth N. Wells, 2011.
 //
 // First added:  2003-03-13
-// Last changed: 2011-11-15
+// Last changed: 2013-11-15
 
 #include <unistd.h>
 #include <iomanip>
@@ -39,6 +39,7 @@
 #endif
 
 #include <dolfin/common/constants.h>
+#include <dolfin/common/defines.h>
 #include <dolfin/common/MPI.h>
 #include <dolfin/parameter/GlobalParameters.h>
 #include "LogLevel.h"
@@ -155,7 +156,7 @@ void Logger::dolfin_error(std::string location,
     << "*** using the information listed below, you can ask for help at"
     << std::endl
     << "***" << std::endl
-    << "***     https://answers.launchpad.net/dolfin"
+    << "***     fenics@fenicsproject.org"
     << std::endl
     << "***" << std::endl
     << "*** Remember to include the error message listed below and, if possible,"
@@ -171,6 +172,9 @@ void Logger::dolfin_error(std::string location,
     << "*** " << "Where:   This error was encountered inside " << location << "."
     << std::endl
     << "*** " << "Process: " << MPI::process_number() << std::endl
+    << "*** " << std::endl
+    << "*** " << "DOLFIN version: " << dolfin_version()  << std::endl
+    << "*** " << "Git changeset:  " << git_commit_hash() << std::endl
     << "*** "
     << "-------------------------------------------------------------------------"
     << std::endl;
@@ -373,7 +377,7 @@ void Logger::_report_memory_usage(size_t num_mb)
 //-----------------------------------------------------------------------------
 void Logger::__debug(std::string msg) const
 {
-  std::string s = std::string("Debug: ") + msg;
+  std::string s = std::string("DEBUG: ") + msg;
   write(DBG, s);
 }
 //-----------------------------------------------------------------------------
