@@ -1,4 +1,4 @@
-// Copyright (C) 2003-2011 Anders Logg
+// Copyright (C) 2003-2013 Anders Logg
 //
 // This file is part of DOLFIN.
 //
@@ -20,7 +20,7 @@
 // Modified by Ola Skavhaug 2007, 2009
 //
 // First added:  2003-03-13
-// Last changed: 2011-11-17
+// Last changed: 2013-01-07
 
 #ifndef __LOGGER_H
 #define __LOGGER_H
@@ -28,11 +28,16 @@
 #include <map>
 #include <ostream>
 #include <string>
-#include <dolfin/common/types.h>
+#include <boost/scoped_ptr.hpp>
+#include "Table.h"
 #include "LogLevel.h"
 
+// Forward declarations
+namespace boost { class thread; }
+
 namespace dolfin
 {
+
   class Logger
   {
   public:
@@ -60,6 +65,11 @@ namespace dolfin
                       std::string task,
                       std::string reason) const;
 
+    /// Issue deprecation warning for removed feature
+    void deprecation(std::string feature,
+                     std::string version,
+                     std::string message) const;
+
     /// Begin task (increase indentation level)
     void begin(std::string msg, int log_level=INFO);
 
@@ -79,23 +89,34 @@ namespace dolfin
     void set_log_active(bool active);
 
     /// Return true iff logging is active
-    inline bool is_active() { return active; }
+    inline bool is_active() { return _active; }
 
     /// Set log level
     void set_log_level(int log_level);
 
     /// Get log level
-    inline int get_log_level() const { return log_level; }
+    inline int get_log_level() const { return _log_level; }
 
     /// Register timing (for later summary)
     void register_timing(std::string task, double elapsed_time);
 
+    /// Return a summary of timings and tasks as a Table, optionally clearing
+    /// stored timings
+    Table timings(bool reset=false);
+
     /// Print summary of timings and tasks, optionally clearing stored timings
-    void summary(bool reset=false);
+    void list_timings(bool reset=false);
 
     /// Return timing (average) for given task, optionally clearing timing for task
     double timing(std::string task, bool reset=false);
 
+    /// Monitor memory usage. Call this function at the start of a
+    /// program to continuously monitor the memory usage of the process.
+    void monitor_memory_usage();
+
+    /// Helper function for reporting memory usage
+    void _report_memory_usage(size_t num_mb);
+
     /// Helper function for dolfin_debug macro
     void __debug(std::string msg) const;
 
@@ -109,10 +130,10 @@ namespace dolfin
     void write(int log_level, std::string msg) const;
 
     // True iff logging is active
-    bool active;
+    bool _active;
 
     // Current log level
-    int log_level;
+    int _log_level;
 
     // Current indentation level
     int indentation_level;
@@ -121,11 +142,17 @@ namespace dolfin
     std::ostream* logstream;
 
     // List of timings for tasks, map from string to (num_timings, total_time)
-    std::map<std::string, std::pair<uint, double> > timings;
+    std::map<std::string, std::pair<std::size_t, double> > _timings;
 
     // MPI data (initialized to 0)
-    mutable uint num_processes;
-    mutable uint process_number;
+    mutable std::size_t num_processes;
+    mutable std::size_t process_number;
+
+    // Thread used for monitoring memory usage
+    boost::scoped_ptr<boost::thread> _thread_monitor_memory_usage;
+
+    // Maximum memory usage so far
+    long int _maximum_memory_usage;
 
   };
 
