@@ -22,7 +22,6 @@
 #define __PROGRESS_H
 
 #include <string>
-#include <dolfin/common/types.h>
 
 namespace dolfin
 {
@@ -96,28 +95,25 @@ namespace dolfin
     void update(double p);
 
     // Title of progress bar
-    std::string title;
+    std::string _title;
 
     // Number of steps
-    uint n;
+    std::size_t _n;
 
     // Current position
-    uint i;
-
-    // Minimum progress increment
-    double p_step;
+    std::size_t i;
 
     // Minimum time increment
     double t_step;
 
     // Minimum counter increment
-    uint c_step;
+    std::size_t c_step;
 
     // Current progress
-    double p;
+    double _p;
 
     // Time for latest update
-    double t;
+    double _t;
 
     // Time for last checking the time
     double tc;
@@ -132,7 +128,7 @@ namespace dolfin
     bool displayed;
 
     // Counter for updates
-    uint counter;
+    std::size_t counter;
 
   };
 
