@@ -1,4 +1,4 @@
-// Copyright (C) 2008-2009 Anders Logg
+// Copyright (C) 2008-2011 Anders Logg
 //
 // This file is part of DOLFIN.
 //
@@ -9,14 +9,14 @@
 //
 // DOLFIN is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2008-07-19
-// Last changed: 2010-11-11
+// Last changed: 2011-10-07
 
 #ifndef __TABLE_H
 #define __TABLE_H
@@ -24,7 +24,6 @@
 #include <map>
 #include <set>
 #include <vector>
-#include <dolfin/common/types.h>
 #include <dolfin/common/Variable.h>
 
 namespace dolfin
@@ -51,7 +50,7 @@ namespace dolfin
   public:
 
     /// Create empty table
-    Table(std::string title="");
+    Table(std::string title="", bool right_justify=true);
 
     /// Destructor
     ~Table();
@@ -63,7 +62,7 @@ namespace dolfin
     void set(std::string row, std::string col, int value);
 
     /// Set value of table entry
-    void set(std::string row, std::string col, uint value);
+    void set(std::string row, std::string col, std::size_t value);
 
     /// Set value of table entry
     void set(std::string row, std::string col, double value);
@@ -108,6 +107,9 @@ namespace dolfin
     // Table values as doubles
     std::map<std::pair<std::string, std::string>, double> dvalues;
 
+    // True if we should right-justify the table entries
+    bool _right_justify;
+
   };
 
   /// This class represents an entry in a Table
@@ -123,7 +125,7 @@ namespace dolfin
     ~TableEntry();
 
     /// Assign value to table entry
-    const TableEntry& operator= (uint value);
+    const TableEntry& operator= (std::size_t value);
 
     /// Assign value to table entry
     const TableEntry& operator= (int value);
@@ -140,13 +142,13 @@ namespace dolfin
   private:
 
     // Row
-    std::string row;
+    std::string _row;
 
     // Column
-    std::string col;
+    std::string _col;
 
     // Table
-    Table& table;
+    Table& _table;
 
   };
 
