@@ -23,6 +23,8 @@
 #ifndef __FACE_H
 #define __FACE_H
 
+#include <boost/shared_ptr.hpp>
+
 #include "MeshEntity.h"
 #include "MeshEntityIteratorBase.h"
 #include "MeshFunction.h"
@@ -66,9 +68,15 @@ namespace dolfin
 
     FaceFunction(const Mesh& mesh) : MeshFunction<T>(mesh, 2) {}
 
+    FaceFunction(boost::shared_ptr<const Mesh> mesh)
+      : MeshFunction<T>(mesh, 2) {}
+
     FaceFunction(const Mesh& mesh, const T& value)
       : MeshFunction<T>(mesh, 2, value) {}
 
+    FaceFunction(boost::shared_ptr<const Mesh> mesh, const T& value)
+      : MeshFunction<T>(mesh, 2, value) {}
+
   };
 
 }
