@@ -1,4 +1,4 @@
-// Copyright (C) 2006-2008 Anders Logg
+// Copyright (C) 2006-2013 Anders Logg
 //
 // This file is part of DOLFIN.
 //
@@ -15,10 +15,10 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
-// Modified by Kristoffer Selim, 2008.
+// Modified by Kristoffer Selim 2008
 //
 // First added:  2006-06-05
-// Last changed: 2010-01-15
+// Last changed: 2013-08-26
 
 #ifndef __INTERVAL_CELL_H
 #define __INTERVAL_CELL_H
@@ -69,6 +69,9 @@ namespace dolfin
     /// Compute diameter of interval
     double diameter(const MeshEntity& interval) const;
 
+    /// Compute squared distance to given point
+    double squared_distance(const Cell& cell, const Point& point) const;
+
     /// Compute component i of normal of given facet with respect to the cell
     double normal(const Cell& cell, std::size_t facet, std::size_t i) const;
 
@@ -85,6 +88,12 @@ namespace dolfin
     void order(Cell& cell,
                const std::vector<std::size_t>& local_to_global_vertex_indices) const;
 
+    /// Check whether given point collides with cell
+    bool collides(const Cell& cell, const Point& point) const;
+
+    /// Check whether given entity collides with cell
+    bool collides(const Cell& cell, const MeshEntity& entity) const;
+
     /// Return description of cell type
     std::string description(bool plural) const;
 
