@@ -47,7 +47,8 @@ namespace dolfin
   public:
 
     /// Create local mesh data for given LocalMeshValueCollection
-    LocalMeshValueCollection(const MeshValueCollection<T>& values, std::size_t dim);
+    LocalMeshValueCollection(const MeshValueCollection<T>& values,
+                             std::size_t dim);
 
     /// Destructor
     ~LocalMeshValueCollection() {}
@@ -57,7 +58,8 @@ namespace dolfin
     { return _dim; }
 
     /// Return data
-    const std::vector<std::pair<std::pair<std::size_t, std::size_t>, T> >& values() const
+    const std::vector<std::pair<std::pair<std::size_t,
+      std::size_t>, T> >& values() const
     { return _values; }
 
   private:
@@ -75,7 +77,8 @@ namespace dolfin
   //---------------------------------------------------------------------------
   template <typename T>
   LocalMeshValueCollection<T>::LocalMeshValueCollection(const MeshValueCollection<T>& values,
-                                                        std::size_t dim) : _dim(dim)
+                                                        std::size_t dim)
+    : _dim(dim)
   {
     // Prepare data
     std::vector<std::vector<std::size_t> > send_indices;
@@ -89,11 +92,14 @@ namespace dolfin
       send_indices.resize(num_processes);
       send_v.resize(num_processes);
 
-      const std::map<std::pair<std::size_t, std::size_t>, T>& vals = values.values();
+      const std::map<std::pair<std::size_t, std::size_t>, T>& vals
+        = values.values();
       for (std::size_t p = 0; p < num_processes; p++)
       {
-        const std::pair<std::size_t, std::size_t> local_range = MPI::local_range(p, vals.size());
-        typename std::map<std::pair<std::size_t, std::size_t>, T>::const_iterator it = vals.begin();
+        const std::pair<std::size_t, std::size_t> local_range
+          = MPI::local_range(p, vals.size());
+        typename std::map<std::pair<std::size_t,
+          std::size_t>, T>::const_iterator it = vals.begin();
         std::advance(it, local_range.first);
         for (std::size_t i = local_range.first; i < local_range.second; ++i)
         {
@@ -119,7 +125,9 @@ namespace dolfin
       const std::size_t local_entity_index = indices[2*i + 1];
       const T value = v[i];
 
-      _values.push_back( std::make_pair( std::make_pair(cell_index, local_entity_index) , value) );
+      _values.push_back(std::make_pair(std::make_pair(cell_index,
+                                                      local_entity_index),
+                                       value));
     }
   }
   //---------------------------------------------------------------------------
