@@ -26,10 +26,8 @@
 
 #include <map>
 #include <string>
-#include <utility>
 #include <vector>
 #include <boost/shared_ptr.hpp>
-
 #include <dolfin/common/Variable.h>
 
 namespace dolfin
@@ -39,10 +37,9 @@ namespace dolfin
   template <typename T> class MeshFunction;
 
   /// The class MeshData is a container for auxiliary mesh data,
-  /// represented either as _MeshFunction_ over topological mesh
-  /// entities, arrays or maps. Each dataset is identified by a unique
-  /// user-specified string. Only std::size_t-valued data are currently
-  /// supported.
+  /// represented either as arrays or maps. Each dataset is identified
+  /// by a unique user-specified string. Only std::size_t-valued data
+  /// are currently supported.
   ///
   /// Auxiliary mesh data may be attached to a mesh by users as a
   /// convenient way to store data associated with a mesh. It is also
@@ -51,11 +48,11 @@ namespace dolfin
   ///
   /// Facet orientation (used for assembly over interior facets)
   ///
-  ///   * "facet_orientation"     - _MeshFunction_ <std::size_t> of dimension D - 1
+  ///   * "facet_orientation"  - _std:vector_ <std::size_t> of dimension D - 1
   ///
   /// Sub meshes (used by the class SubMesh)
   ///
-  ///   * "parent_vertex_indices" - _MeshFunction_ <std::size_t> of dimension 0
+  ///   * "parent_vertex_indices" - _std::vector_ <std::size_t> of dimension 0
   ///
   /// Note to developers: use underscore in names in place of spaces.
 
@@ -64,7 +61,7 @@ namespace dolfin
   public:
 
     /// Constructor
-    MeshData(Mesh& mesh);
+    MeshData();
 
     /// Destructor
     ~MeshData();
@@ -79,33 +76,32 @@ namespace dolfin
     /// Clear all data
     void clear();
 
-    //--- Creation of data ---
+    //--- Query of data ---
 
-    /// Create MeshFunction with given name (uninitialized)
+    /// Check is array exists
     ///
     /// *Arguments*
     ///     name (std::string)
-    ///         The name of the mesh function.
+    ///         The name of the array.
     ///
     /// *Returns*
-    ///     _MeshFunction_ <std::size_t>
-    ///         The mesh function.
+    ///     bool
+    ///         True is array exists, false otherwise.
+    bool exists(std::string name, std::size_t dim) const;
+
+    //--- Creation of data ---
+
+    /// This function is no longer supported. It is retained to print
+    /// an informative error message. It will be removed in the
+    /// future.
     boost::shared_ptr<MeshFunction<std::size_t> >
       create_mesh_function(std::string name);
 
-    /// Create MeshFunction with given name and dimension
-    ///
-    /// *Arguments*
-    ///     name (std::string)
-    ///         The name of the mesh function.
-    ///     dim (std::size_t)
-    ///         The dimension of the mesh function.
-    ///
-    /// *Returns*
-    ///     _MeshFunction_ <std::size_t>
-    ///         The mesh function.
+    /// This function is no longer supported. It is retained to print
+    /// an informative error message. It will be removed in the
+    /// future.
     boost::shared_ptr<MeshFunction<std::size_t> >
-    create_mesh_function(std::string name, std::size_t dim);
+      create_mesh_function(std::string name, std::size_t dim);
 
     /// Create empty array (vector) with given name
     ///
@@ -116,7 +112,7 @@ namespace dolfin
     /// *Returns*
     ///     std::vector<std::size_t>
     ///         The array.
-    boost::shared_ptr<std::vector<std::size_t> > create_array(std::string name);
+    //std::vector<std::size_t>& create_array(std::string name);
 
     /// Create array (vector) with given name and size
     ///
@@ -129,21 +125,17 @@ namespace dolfin
     /// *Returns*
     ///     std::vector<std::size_t>
     ///         The array.
-    boost::shared_ptr<std::vector<std::size_t> > create_array(std::string name, std::size_t size);
+    //private:
+    std::vector<std::size_t>& create_array(std::string name, std::size_t dim);
 
+    //public:
     //--- Retrieval of data ---
 
-    /// Return MeshFunction with given name (returning zero if data is
-    /// not available)
-    ///
-    /// *Arguments*
-    ///     name (std::string)
-    ///         The name of the MeshFunction.
-    ///
-    /// *Returns*
-    ///     _MeshFunction_ <std::size_t>
-    ///         The mesh function with given name
-    boost::shared_ptr<MeshFunction<std::size_t> > mesh_function(const std::string name) const;
+    /// This function is no longer supported. It is retained to print
+    /// an informative error message. It will be removed in the
+    /// future.
+    boost::shared_ptr<MeshFunction<std::size_t> >
+      mesh_function(const std::string name) const;
 
     /// Return array with given name (returning zero if data is not
     /// available)
@@ -155,23 +147,29 @@ namespace dolfin
     /// *Returns*
     ///     std::vector<std::size_t>
     ///         The array.
-    boost::shared_ptr<std::vector<std::size_t> > array(const std::string name) const;
+    std::vector<std::size_t>& array(std::string name, std::size_t dim);
 
-    //--- Removal of data ---
-
-    /// Erase MeshFunction with given name
+    /// Return array with given name (returning zero if data is not
+    /// available)
     ///
     /// *Arguments*
     ///     name (std::string)
-    ///         The name of the mesh function
-    void erase_mesh_function(const std::string name);
+    ///         The name of the array.
+    ///
+    /// *Returns*
+    ///     std::vector<std::size_t>
+    ///         The array.
+    const std::vector<std::size_t>& array(std::string name,
+                                          std::size_t dim) const;
+
+    //--- Removal of data ---
 
     /// Erase array with given name
     ///
     /// *Arguments*
     ///     name (std::string)
     ///         The name of the array.
-    void erase_array(const std::string name);
+    void erase_array(const std::string name, std::size_t dim);
 
     //--- Misc ---
 
@@ -188,21 +186,14 @@ namespace dolfin
 
     /// Friends
     friend class XMLMesh;
-    friend class MeshPartitioning;
 
   private:
 
     // Check if name is deprecated
     void check_deprecated(std::string name) const;
 
-    // The mesh
-    Mesh& _mesh;
-
-    // A map from named mesh data to MeshFunctions
-    std::map<std::string, boost::shared_ptr<MeshFunction<std::size_t> > > mesh_functions;
-
-    // A map from named mesh data to vector
-    std::map<std::string, boost::shared_ptr<std::vector<std::size_t> > > arrays;
+    // A map from named mesh array data to vector for dim
+    std::vector<std::map<std::string, std::vector<std::size_t> > > _arrays;
 
     // List of depcrecated named data
     std::vector<std::string> _deprecated_names;
