@@ -1,4 +1,4 @@
-// Copyright (C) 2006-2009 Anders Logg
+// Copyright (C) 2006-2012 Anders Logg
 //
 // This file is part of DOLFIN.
 //
@@ -16,13 +16,12 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2006-05-16
-// Last changed: 2011-07-18
+// Last changed: 2012-09-27
 
 #ifndef __MESH_EDITOR_H
 #define __MESH_EDITOR_H
 
 #include <vector>
-#include <dolfin/common/types.h>
 #include "CellType.h"
 
 namespace dolfin
@@ -50,9 +49,9 @@ namespace dolfin
     /// *Arguments*
     ///     mesh (_Mesh_)
     ///         The mesh to open.
-    ///     tdim (uint)
+    ///     tdim (std::size_t)
     ///         The topological dimension.
-    ///     gdim (uint)
+    ///     gdim (std::size_t)
     ///         The geometrical dimension.
     ///
     /// *Example*
@@ -62,7 +61,7 @@ namespace dolfin
     ///         MeshEditor editor;
     ///         editor.open(mesh, 2, 2);
     ///
-    void open(Mesh& mesh, uint tdim, uint gdim);
+    void open(Mesh& mesh, std::size_t tdim, std::size_t gdim);
 
     /// Open mesh of given cell type, topological and geometrical dimension
     ///
@@ -71,11 +70,11 @@ namespace dolfin
     ///         The mesh to open.
     ///     type (CellType::Type)
     ///         Cell type.
-    ///     tdim (uint)
+    ///     tdim (std::size_t)
     ///         The topological dimension.
-    ///     gdim (uint)
+    ///     gdim (std::size_t)
     ///         The geometrical dimension.
-    void open(Mesh& mesh, CellType::Type type, uint tdim, uint gdim);
+    void open(Mesh& mesh, CellType::Type type, std::size_t tdim, std::size_t gdim);
 
     /// Open mesh of given cell type, topological and geometrical dimension
     ///
@@ -84,16 +83,16 @@ namespace dolfin
     ///         The mesh to open.
     ///     type (std::string)
     ///         Cell type.
-    ///     tdim (uint)
+    ///     tdim (std::size_t)
     ///         The topological dimension.
-    ///     gdim (uint)
+    ///     gdim (std::size_t)
     ///         The geometrical dimension.
-    void open(Mesh& mesh, std::string type, uint tdim, uint gdim);
+    void open(Mesh& mesh, std::string type, std::size_t tdim, std::size_t gdim);
 
     /// Specify number of vertices
     ///
     /// *Arguments*
-    ///     num_vertices (uint)
+    ///     num_vertices (std::size_t)
     ///         The number of vertices.
     ///
     /// *Example*
@@ -104,19 +103,12 @@ namespace dolfin
     ///         editor.open(mesh, 2, 2);
     ///         editor.init_vertices(4);
     ///
-    void init_vertices(uint num_vertices);
-
-    /// Specify number of vertices
-    ///
-    /// *Arguments*
-    ///     num_higher_order_vertices (uint)
-    ///         The number of higher order vertices.
-    void init_higher_order_vertices(uint num_higher_order_vertices);
+    void init_vertices(std::size_t num_vertices);
 
     /// Specify number of cells
     ///
     /// *Arguments*
-    ///     num_cells (uint)
+    ///     num_cells (std::size_t)
     ///         The number of cells.
     ///
     /// *Example*
@@ -127,60 +119,50 @@ namespace dolfin
     ///         editor.open(mesh, 2, 2);
     ///         editor.init_cells(2);
     ///
-    void init_cells(uint num_cells);
-
-    /// Specify number of cells
-    ///
-    /// *Arguments*
-    ///     num_higher_order_cells (uint)
-    ///         The number of higher order cells.
-    ///     num_higher_order_cell_dof (uint)
-    ///         The number of cell dofs.
-    void init_higher_order_cells(uint num_higher_order_cells, uint num_higher_order_cell_dof);
-
-    /// Set boolean indicator inside MeshGeometry
-    void set_affine_cell_indicator(uint c, const std::string affine_str);
+    void init_cells(std::size_t num_cells);
 
     /// Add vertex v at given point p
     ///
     /// *Arguments*
-    ///     v (uint)
+    ///     index (std::size_t)
     ///         The vertex (index).
     ///     p (_Point_)
     ///         The point.
-    void add_vertex(uint v, const Point& p);
+    void add_vertex(std::size_t index, const Point& p);
 
     /// Add vertex v at given coordinate x
     ///
     /// *Arguments*
-    ///     v (uint)
+    ///     index (std::size_t)
+    ///         The vertex (index).
+    ///     x (std::vector<double>)
+    ///         The x-coordinates.
+    void add_vertex(std::size_t index, const std::vector<double>& x);
+
+    /// Add vertex v at given point x (for a 1D mesh)
+    ///
+    /// *Arguments*
+    ///     index (std::size_t)
     ///         The vertex (index).
     ///     x (double)
     ///         The x-coordinate.
-    void add_vertex(uint v, double x);
+    void add_vertex(std::size_t index, double x);
 
-    /// Add vertex v at given coordinate (x, y)
+    /// Add vertex v at given point (x, y) (for a 2D mesh)
     ///
     /// *Arguments*
-    ///     v (uint)
+    ///     index (std::size_t)
     ///         The vertex (index).
     ///     x (double)
     ///         The x-coordinate.
     ///     y (double)
     ///         The y-coordinate.
-    ///
-    /// *Example*
-    ///     .. code-block:: c++
-    ///
-    ///         MeshEditor editor;
-    ///         editor.add_vertex(0, 0.0, 0.0);
-    ///
-    void add_vertex(uint v, double x, double y);
+    void add_vertex(std::size_t index, double x, double y);
 
-    /// Add vertex v at given coordinate (x, y, z)
+    /// Add vertex v at given point (x, y, z) (for a 3D mesh)
     ///
     /// *Arguments*
-    ///     v (uint)
+    ///     index (std::size_t)
     ///         The vertex (index).
     ///     x (double)
     ///         The x-coordinate.
@@ -188,123 +170,92 @@ namespace dolfin
     ///         The y-coordinate.
     ///     z (double)
     ///         The z-coordinate.
-    void add_vertex(uint v, double x, double y, double z);
+    void add_vertex(std::size_t index, double x, double y, double z);
 
     /// Add vertex v at given point p
     ///
     /// *Arguments*
-    ///     v (uint)
-    ///         The vertex (index).
+    ///     local_index (std::size_t)
+    ///         The vertex (local index).
+    ///     global_index (std::size_t)
+    ///         The vertex (global_index).
     ///     p (_Point_)
     ///         The point.
-    void add_higher_order_vertex(uint v, const Point& p);
+    void add_vertex_global(std::size_t local_index, std::size_t global_index,
+                           const Point& p);
 
     /// Add vertex v at given coordinate x
     ///
     /// *Arguments*
-    ///     v (uint)
-    ///         The vertex (index).
-    ///     x (double)
-    ///         The x-coordinate.
-    void add_higher_order_vertex(uint v, double x);
+    ///     local_index (std::size_t)
+    ///         The vertex (local index).
+    ///     global_index (std::size_t)
+    ///         The vertex (global_index).
+    ///     x (std::vector<double>)
+    ///         The x-coordinates.
+    void add_vertex_global(std::size_t local_index, std::size_t global_index,
+                           const std::vector<double>& x);
 
-    /// Add vertex v at given coordinate (x, y)
+    /// Add cell with given vertices (1D)
     ///
     /// *Arguments*
-    ///     v (uint)
-    ///         The vertex (index).
-    ///     x (double)
-    ///         The x-coordinate.
-    ///     y (double)
-    ///         The y-coordinate.
-    void add_higher_order_vertex(uint v, double x, double y);
+    ///     c (std::size_t)
+    ///         The cell (index).
+    ///     v0 (std::vector<std::size_t>)
+    ///         The first vertex (local index).
+    ///     v1 (std::vector<std::size_t>)
+    ///         The second vertex (local index).
+    void add_cell(std::size_t c, std::size_t v0, std::size_t v1);
 
-    /// Add vertex v at given coordinate (x, y, z)
+    /// Add cell with given vertices (2D)
     ///
     /// *Arguments*
-    ///     v (uint)
-    ///         The vertex (index).
-    ///     x (double)
-    ///         The x-coordinate.
-    ///     y (double)
-    ///         The y-coordinate.
-    ///     z (double)
-    ///         The z-coordinate.
-    void add_higher_order_vertex(uint v, double x, double y, double z);
+    ///     c (std::size_t)
+    ///         The cell (index).
+    ///     v0 (std::vector<std::size_t>)
+    ///         The first vertex (local index).
+    ///     v1 (std::vector<std::size_t>)
+    ///         The second vertex (local index).
+    ///     v2 (std::vector<std::size_t>)
+    ///         The third vertex (local index).
+    void add_cell(std::size_t c, std::size_t v0, std::size_t v1, std::size_t v2);
+
+    /// Add cell with given vertices (3D)
+    ///
+    /// *Arguments*
+    ///     c (std::size_t)
+    ///         The cell (index).
+    ///     v0 (std::vector<std::size_t>)
+    ///         The first vertex (local index).
+    ///     v1 (std::vector<std::size_t>)
+    ///         The second vertex (local index).
+    ///     v2 (std::vector<std::size_t>)
+    ///         The third vertex (local index).
+    ///     v3 (std::vector<std::size_t>)
+    ///         The fourth vertex (local index).
+    void add_cell(std::size_t c, std::size_t v0, std::size_t v1,
+                  std::size_t v2, std::size_t v3);
 
     /// Add cell with given vertices
     ///
     /// *Arguments*
-    ///     c (uint)
+    ///     c (std::size_t)
     ///         The cell (index).
-    ///     v (std::vector<uint>)
-    ///         The vertex indices
-    void add_cell(uint c, const std::vector<uint>& v);
+    ///     v (std::vector<std::size_t>)
+    ///         The vertex indices (local indices)
+    void add_cell(std::size_t c, const std::vector<std::size_t>& v);
 
-    /// Add cell (interval) with given vertices
+    /// Add cell with given vertices
     ///
     /// *Arguments*
-    ///     c (uint)
+    ///     local_index (std::size_t)
     ///         The cell (index).
-    ///     v0 (uint)
-    ///         Index of the first vertex.
-    ///     v1 (uint)
-    ///         Index of the second vertex.
-    void add_cell(uint c, uint v0, uint v1);
-
-    /// Add cell (triangle) with given vertices
-    ///
-    /// *Arguments*
-    ///     c (uint)
-    ///         The cell (index).
-    ///     v0 (uint)
-    ///         Index of the first vertex.
-    ///     v1 (uint)
-    ///         Index of the second vertex.
-    ///     v2 (uint)
-    ///         Index of the third vertex.
-    ///
-    /// *Example*
-    ///     .. code-block:: c++
-    ///
-    ///         MeshEditor editor;
-    ///         editor.add_cell(0, 0, 1, 2);
-    ///
-    void add_cell(uint c, uint v0, uint v1, uint v2);
-
-    /// Add cell (tetrahedron) with given vertices
-    ///
-    /// *Arguments*
-    ///     c (uint)
-    ///         The cell (index).
-    ///     v0 (uint)
-    ///         Index of the first vertex.
-    ///     v1 (uint)
-    ///         Index of the second vertex.
-    ///     v2 (uint)
-    ///         Index of the third vertex.
-    ///     v3 (uint)
-    ///         Index of the fourth vertex.
-    void add_cell(uint c, uint v0, uint v1, uint v2, uint v3);
-
-    /// Add higher order cell data (assume P2 triangle for now)
-    ///
-    /// *Arguments*
-    ///     c (uint)
-    ///         The cell (index).
-    ///     v0 (uint)
-    ///         Index of the first vertex.
-    ///     v1 (uint)
-    ///         Index of the second vertex.
-    ///     v2 (uint)
-    ///         Index of the third vertex.
-    ///     v3 (uint)
-    ///         Index of the fourth vertex.
-    ///     v4 (uint)
-    ///         Index of the fifth vertex.
-    ///     v5 (uint)
-    ///         Index of the sixth vertex.
-    void add_higher_order_cell_data(uint c, uint v0, uint v1, uint v2, uint v3, uint v4, uint v5);
+    ///     global_index (std::size_t)
+    ///         The global (user) cell index.
+    ///     v (std::vector<std::size_t>)
+    ///         The vertex indices (local indices)
+    void add_cell(std::size_t local_index, std::size_t global_index,
+                  const std::vector<std::size_t>& v);
 
     /// Close mesh, finish editing, and order entities locally
     ///
@@ -328,16 +279,10 @@ namespace dolfin
     friend class TetrahedronCell;
 
     // Add vertex, common part
-    void add_vertex_common(uint v, uint dim);
-
-    // Add higher order vertex, common part
-    void add_higher_order_vertex_common(uint v, uint dim);
+    void add_vertex_common(std::size_t v, std::size_t dim);
 
     // Add cell, common part
-    void add_cell_common(uint v, uint dim);
-
-    // Add higher order cell, common part
-    void add_higher_order_cell_common(uint v, uint dim);
+    void add_cell_common(std::size_t v, std::size_t dim);
 
     // Compute boundary indicators (exterior facets)
     void compute_boundary_indicators();
@@ -345,49 +290,32 @@ namespace dolfin
     // Clear all data
     void clear();
 
-    // Check that vertex is in range
-    void check_vertex(uint v);
+    // Check that vertices are in range
+    void check_vertices(const std::vector<std::size_t>& v) const;
 
     // The mesh
-    Mesh* mesh;
+    Mesh* _mesh;
 
     // Topological dimension
-    uint tdim;
+    std::size_t _tdim;
 
     // Geometrical (Euclidean) dimension
-    uint gdim;
+    std::size_t _gdim;
 
     // Number of vertices
-    uint num_vertices;
+    std::size_t _num_vertices;
 
     // Number of cells
-    uint num_cells;
+    std::size_t _num_cells;
 
     // Next available vertex
-    uint next_vertex;
+    std::size_t next_vertex;
 
     // Next available cell
-    uint next_cell;
+    std::size_t next_cell;
 
     // Temporary storage for local cell data
-    std::vector<uint> vertices;
-
-    // NEW HIGHER ORDER MESH STUFF
-
-    // Number of higher order vertices
-    uint num_higher_order_vertices;
-
-    // Number of higher order cells <--- should be the same as num_cells!  good for error checking
-    uint num_higher_order_cells;
-
-    // Next available higher order vertex
-    uint next_higher_order_vertex;
-
-    // Next available higher order cell
-    uint next_higher_order_cell;
-
-    // Temporary storage for local higher order cell data
-    std::vector<uint> higher_order_cell_data;
+    std::vector<std::size_t> _vertices;
 
   };
 
