@@ -16,27 +16,31 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Johan Hoffman, 2007.
-// Modified by Garth N. Wells, 2010.
+// Modified by Garth N. Wells, 2010-2013
 //
 // First added:  2006-05-22
-// Last changed: 2011-03-12
+// Last changed: 2013-05-10
 
 #ifndef __MESH_FUNCTION_H
 #define __MESH_FUNCTION_H
 
+#include <map>
 #include <vector>
+
 #include <boost/scoped_array.hpp>
+#include <boost/shared_ptr.hpp>
 #include <boost/unordered_set.hpp>
 #include <dolfin/common/Hierarchical.h>
 #include <dolfin/common/MPI.h>
+#include <dolfin/common/NoDeleter.h>
 #include <dolfin/common/Variable.h>
 #include <dolfin/log/log.h>
 #include <dolfin/io/File.h>
 #include "LocalMeshValueCollection.h"
+#include "MeshDomains.h"
 #include "MeshEntity.h"
 #include "Mesh.h"
 #include "MeshConnectivity.h"
-#include "MeshPartitioning.h"
 
 namespace dolfin
 {
@@ -65,6 +69,13 @@ namespace dolfin
     ///         The mesh to create mesh function on.
     explicit MeshFunction(const Mesh& mesh);
 
+    /// Create empty mesh function on given mesh (shared_ptr version)
+    ///
+    /// *Arguments*
+    ///     mesh (_Mesh_)
+    ///         The mesh to create mesh function on.
+    explicit MeshFunction(boost::shared_ptr<const Mesh> mesh);
+
     /// Create mesh function of given dimension on given mesh
     ///
     /// *Arguments*
@@ -74,6 +85,16 @@ namespace dolfin
     ///         The mesh entity dimension for the mesh function.
     MeshFunction(const Mesh& mesh, std::size_t dim);
 
+    /// Create mesh function of given dimension on given mesh
+    /// (shared_ptr version)
+    ///
+    /// *Arguments*
+    ///     mesh (_Mesh_)
+    ///         The mesh to create mesh function on.
+    ///     dim (std::size_t)
+    ///         The mesh entity dimension for the mesh function.
+    MeshFunction(boost::shared_ptr<const Mesh> mesh, std::size_t dim);
+
     /// Create mesh of given dimension on given mesh and initialize
     /// to a value
     ///
@@ -86,6 +107,19 @@ namespace dolfin
     ///         The value.
     MeshFunction(const Mesh& mesh, std::size_t dim, const T& value);
 
+    /// Create mesh of given dimension on given mesh and initialize
+    /// to a value (shared_ptr version)
+    ///
+    /// *Arguments*
+    ///     mesh (_Mesh_)
+    ///         The mesh to create mesh function on.
+    ///     dim (std::size_t)
+    ///         The mesh entity dimension.
+    ///     value (T)
+    ///         The value.
+    MeshFunction(boost::shared_ptr<const Mesh> mesh, std::size_t dim,
+                 const T& value);
+
     /// Create function from data file
     ///
     /// *Arguments*
@@ -95,6 +129,16 @@ namespace dolfin
     ///         The filename to create mesh function from.
     MeshFunction(const Mesh& mesh, const std::string filename);
 
+    /// Create function from data file (shared_ptr version)
+    ///
+    /// *Arguments*
+    ///     mesh (_Mesh_)
+    ///         The mesh to create mesh function on.
+    ///     filename (std::string)
+    ///         The filename to create mesh function from.
+    MeshFunction(boost::shared_ptr<const Mesh> mesh,
+                 const std::string filename);
+
     /// Create function from a MeshValueCollecion
     ///
     /// *Arguments*
@@ -105,6 +149,28 @@ namespace dolfin
     MeshFunction(const Mesh& mesh,
                  const MeshValueCollection<T>& value_collection);
 
+    /// Create function from a MeshValueCollecion (shared_ptr version)
+    ///
+    /// *Arguments*
+    ///     mesh (_Mesh_)
+    ///         The mesh to create mesh function on.
+    ///     value_collection (_MeshValueCollection_ <T>)
+    ///         The mesh value collection for the mesh function data.
+    MeshFunction(boost::shared_ptr<const Mesh> mesh,
+                 const MeshValueCollection<T>& value_collection);
+
+    /// Create function from MeshDomains
+    ///
+    /// *Arguments*
+    ///     mesh (_Mesh_)
+    ///         The mesh to create mesh function on.
+    ///     dim (std::size_t)
+    ///         The dimension of the MeshFunction
+    ///     domains (_MeshDomains)
+    ///         The domains from which to extratc the domain markers
+    MeshFunction(boost::shared_ptr<const Mesh> mesh,
+                 std::size_t dim, const MeshDomains& domains);
+
     /// Copy constructor
     ///
     /// *Arguments*
@@ -135,7 +201,7 @@ namespace dolfin
     /// *Returns*
     ///     _Mesh_
     ///         The mesh.
-    const Mesh& mesh() const;
+    boost::shared_ptr<const Mesh> mesh() const;
 
     /// Return topological dimension
     ///
@@ -245,6 +311,16 @@ namespace dolfin
     ///         The dimension.
     void init(const Mesh& mesh, std::size_t dim);
 
+    /// Initialize mesh function for given topological dimension
+    /// (shared_ptr version)
+    ///
+    /// *Arguments*
+    ///     mesh (_Mesh_)
+    ///         The mesh.
+    ///     dim (std::size_t)
+    ///         The dimension.
+    void init(boost::shared_ptr<const Mesh> mesh, std::size_t dim);
+
     /// Initialize mesh function for given topological dimension of
     /// given size
     ///
@@ -257,6 +333,19 @@ namespace dolfin
     ///         The size.
     void init(const Mesh& mesh, std::size_t dim, std::size_t size);
 
+    /// Initialize mesh function for given topological dimension of
+    /// given size (shared_ptr version)
+    ///
+    /// *Arguments*
+    ///     mesh (_Mesh_)
+    ///         The mesh.
+    ///     dim (std::size_t)
+    ///         The dimension.
+    ///     size (std::size_t)
+    ///         The size.
+    void init(boost::shared_ptr<const Mesh> mesh, std::size_t dim,
+              std::size_t size);
+
     /// Set value at given index
     ///
     /// *Arguments*
@@ -302,7 +391,7 @@ namespace dolfin
     boost::scoped_array<T> _values;
 
     // The mesh
-    const Mesh* _mesh;
+    boost::shared_ptr<const Mesh> _mesh;
 
     // Topological dimension
     std::size_t _dim;
@@ -318,43 +407,84 @@ namespace dolfin
   // Implementation of MeshFunction
   //---------------------------------------------------------------------------
   template <typename T>
-  MeshFunction<T>::MeshFunction() : Variable("f", "unnamed MeshFunction"),
-    Hierarchical<MeshFunction<T> >(*this), _values(0), _mesh(0), _dim(0),
+    MeshFunction<T>::MeshFunction() : Variable("f", "unnamed MeshFunction"),
+    Hierarchical<MeshFunction<T> >(*this), _values(0), _dim(0),
     _size(0)
   {
     // Do nothing
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  MeshFunction<T>::MeshFunction(const Mesh& mesh) :
-    Variable("f", "unnamed MeshFunction"),
-    Hierarchical<MeshFunction<T> >(*this), _mesh(&mesh), _dim(0), _size(0)
+    MeshFunction<T>::MeshFunction(const Mesh& mesh)
+    : Variable("f", "unnamed MeshFunction"),
+    Hierarchical<MeshFunction<T> >(*this),
+    _mesh(reference_to_no_delete_pointer(mesh)), _dim(0), _size(0)
   {
     // Do nothing
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  MeshFunction<T>::MeshFunction(const Mesh& mesh, std::size_t dim) :
-    Variable("f", "unnamed MeshFunction"),
-    Hierarchical<MeshFunction<T> >(*this), _mesh(&mesh), _dim(0), _size(0)
+    MeshFunction<T>::MeshFunction(boost::shared_ptr<const Mesh> mesh)
+    : Variable("f", "unnamed MeshFunction"),
+    Hierarchical<MeshFunction<T> >(*this), _mesh(mesh), _dim(0), _size(0)
+  {
+    // Do nothing
+  }
+  //---------------------------------------------------------------------------
+  template <typename T>
+  MeshFunction<T>::MeshFunction(const Mesh& mesh, std::size_t dim)
+    : Variable("f", "unnamed MeshFunction"),
+    Hierarchical<MeshFunction<T> >(*this),
+    _mesh(reference_to_no_delete_pointer(mesh)) , _dim(0), _size(0)
   {
     init(dim);
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  MeshFunction<T>::MeshFunction(const Mesh& mesh, std::size_t dim, const T& value) :
-      Variable("f", "unnamed MeshFunction"),
-      Hierarchical<MeshFunction<T> >(*this),
-      _mesh(&mesh), _dim(0), _size(0)
+    MeshFunction<T>::MeshFunction(boost::shared_ptr<const Mesh> mesh,
+                                  std::size_t dim)
+    : Variable("f", "unnamed MeshFunction"),
+    Hierarchical<MeshFunction<T> >(*this), _mesh(mesh), _dim(0), _size(0)
+  {
+    init(dim);
+  }
+  //---------------------------------------------------------------------------
+  template <typename T>
+  MeshFunction<T>::MeshFunction(const Mesh& mesh, std::size_t dim,
+                                const T& value)
+    : Variable("f", "unnamed MeshFunction"),
+    Hierarchical<MeshFunction<T> >(*this),
+    _mesh(reference_to_no_delete_pointer(mesh)), _dim(0), _size(0)
   {
     init(dim);
     set_all(value);
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  MeshFunction<T>::MeshFunction(const Mesh& mesh, const std::string filename) :
-    Variable("f", "unnamed MeshFunction"),
-    Hierarchical<MeshFunction<T> >(*this), _mesh(&mesh), _dim(0), _size(0)
+    MeshFunction<T>::MeshFunction(boost::shared_ptr<const Mesh> mesh,
+                                   std::size_t dim, const T& value)
+  : Variable("f", "unnamed MeshFunction"),
+    Hierarchical<MeshFunction<T> >(*this), _mesh(mesh), _dim(0), _size(0)
+  {
+    init(dim);
+    set_all(value);
+  }
+  //---------------------------------------------------------------------------
+  template <typename T>
+  MeshFunction<T>::MeshFunction(const Mesh& mesh, const std::string filename)
+    : Variable("f", "unnamed MeshFunction"),
+    Hierarchical<MeshFunction<T> >(*this),
+    _mesh(reference_to_no_delete_pointer(mesh)), _dim(0), _size(0)
+  {
+    File file(filename);
+    file >> *this;
+  }
+  //---------------------------------------------------------------------------
+  template <typename T>
+    MeshFunction<T>::MeshFunction(boost::shared_ptr<const Mesh> mesh,
+                                  const std::string filename)
+    : Variable("f", "unnamed MeshFunction"),
+    Hierarchical<MeshFunction<T> >(*this), _mesh(mesh), _dim(0), _size(0)
   {
     File file(filename);
     file >> *this;
@@ -364,16 +494,64 @@ namespace dolfin
   MeshFunction<T>::MeshFunction(const Mesh& mesh,
     const MeshValueCollection<T>& value_collection) :
     Variable("f", "unnamed MeshFunction"),
-    Hierarchical<MeshFunction<T> >(*this), _mesh(&mesh),
-    _dim(value_collection.dim()), _size(0)
+      Hierarchical<MeshFunction<T> >(*this),
+      _mesh(reference_to_no_delete_pointer(mesh)),
+      _dim(value_collection.dim()), _size(0)
   {
     *this = value_collection;
   }
   //---------------------------------------------------------------------------
+  template <typename T>
+    MeshFunction<T>::MeshFunction(boost::shared_ptr<const Mesh> mesh,
+                                  const MeshValueCollection<T>& value_collection)
+    : Variable("f", "unnamed MeshFunction"),
+      Hierarchical<MeshFunction<T> >(*this), _mesh(mesh),
+      _dim(value_collection.dim()), _size(0)
+  {
+    *this = value_collection;
+  }
+  //---------------------------------------------------------------------------
+  template <typename T>
+    MeshFunction<T>::MeshFunction(boost::shared_ptr<const Mesh> mesh,
+                                  std::size_t dim, const MeshDomains& domains)
+    : Variable("f", "unnamed MeshFunction"),
+      Hierarchical<MeshFunction<T> >(*this), _mesh(mesh), _dim(0), _size(0)
+  {
+    dolfin_assert(_mesh);
+
+    // Initialise MeshFunction
+    init(dim);
+
+    // Initialise mesh
+    mesh->init(dim);
+
+    // Set MeshFunction with default value
+    set_all(std::numeric_limits<T>::max());
+
+    // Get mesh dimension
+    const std::size_t D = _mesh->topology().dim();
+    dolfin_assert(dim <= D);
+
+    // Get domain data
+    const std::map<std::size_t, std::size_t>& data = domains.markers(dim);
+
+    // Iterate over all values and copy into MeshFunctions
+    std::map<std::size_t, std::size_t>::const_iterator it;
+    for (it = data.begin(); it != data.end(); ++it)
+    {
+      // Get value collection entry data
+      const std::size_t entity_index = it->first;
+      const T value = it->second;
+
+      dolfin_assert(entity_index < _size);
+      _values[entity_index] = value;
+    }
+  }
+  //---------------------------------------------------------------------------
   template <typename T>
   MeshFunction<T>::MeshFunction(const MeshFunction<T>& f) :
     Variable("f", "unnamed MeshFunction"),
-    Hierarchical<MeshFunction<T> >(*this), _mesh(0), _dim(0), _size(0)
+    Hierarchical<MeshFunction<T> >(*this), _dim(0), _size(0)
   {
     *this = f;
   }
@@ -410,10 +588,14 @@ namespace dolfin
     const MeshConnectivity& connectivity = _mesh->topology()(D, d);
     dolfin_assert(!connectivity.empty());
 
+    // Set MeshFunction with default value
+    set_all(std::numeric_limits<T>::max());
+
     // Iterate over all values
     boost::unordered_set<std::size_t> entities_values_set;
     typename std::map<std::pair<std::size_t, std::size_t>, T>::const_iterator it;
-    const std::map<std::pair<std::size_t, std::size_t>, T>& values = mesh_value_collection.values();
+    const std::map<std::pair<std::size_t, std::size_t>, T>& values
+      = mesh_value_collection.values();
     for (it = values.begin(); it != values.end(); ++it)
     {
       // Get value collection entry data
@@ -442,76 +624,72 @@ namespace dolfin
       entities_values_set.insert(entity_index);
     }
 
-    // Check that all values have been set
+    // Check that all values have been set, if not issue a debug message
     if (entities_values_set.size() != _size)
-    {
-      dolfin_error("MeshFunction.h",
-                   "assign mesh value collection to mesh function",
-                   "Mesh value collection does not contain all values for all entities");
-    }
+      dolfin_debug("Mesh value collection does not contain all values for all entities");
 
     return *this;
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  const Mesh& MeshFunction<T>::mesh() const
+    boost::shared_ptr<const Mesh> MeshFunction<T>::mesh() const
   {
     dolfin_assert(_mesh);
-    return *_mesh;
+    return _mesh;
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  std::size_t MeshFunction<T>::dim() const
+    std::size_t MeshFunction<T>::dim() const
   {
     return _dim;
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  bool MeshFunction<T>::empty() const
+    bool MeshFunction<T>::empty() const
   {
     return _size == 0;
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  std::size_t MeshFunction<T>::size() const
+    std::size_t MeshFunction<T>::size() const
   {
     return _size;
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  const T* MeshFunction<T>::values() const
+    const T* MeshFunction<T>::values() const
   {
     return _values.get();
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  T* MeshFunction<T>::values()
+    T* MeshFunction<T>::values()
   {
     return _values.get();
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  T& MeshFunction<T>::operator[] (const MeshEntity& entity)
+    T& MeshFunction<T>::operator[] (const MeshEntity& entity)
   {
     dolfin_assert(_values);
-    dolfin_assert(&entity.mesh() == _mesh);
+    dolfin_assert(&entity.mesh() == _mesh.get());
     dolfin_assert(entity.dim() == _dim);
     dolfin_assert(entity.index() < _size);
     return _values[entity.index()];
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  const T& MeshFunction<T>::operator[] (const MeshEntity& entity) const
+    const T& MeshFunction<T>::operator[] (const MeshEntity& entity) const
   {
     dolfin_assert(_values);
-    dolfin_assert(&entity.mesh() == _mesh);
+    dolfin_assert(&entity.mesh() == _mesh.get());
     dolfin_assert(entity.dim() == _dim);
     dolfin_assert(entity.index() < _size);
     return _values[entity.index()];
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  T& MeshFunction<T>::operator[] (std::size_t index)
+    T& MeshFunction<T>::operator[] (std::size_t index)
   {
     dolfin_assert(_values);
     dolfin_assert(index < _size);
@@ -519,7 +697,7 @@ namespace dolfin
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  const T& MeshFunction<T>::operator[] (std::size_t index) const
+    const T& MeshFunction<T>::operator[] (std::size_t index) const
   {
     dolfin_assert(_values);
     dolfin_assert(index < _size);
@@ -527,7 +705,7 @@ namespace dolfin
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  const MeshFunction<T>& MeshFunction<T>::operator= (const T& value)
+    const MeshFunction<T>& MeshFunction<T>::operator= (const T& value)
   {
     set_all(value);
     //Hierarchical<MeshFunction<T> >::operator=(value);
@@ -535,7 +713,7 @@ namespace dolfin
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  void MeshFunction<T>::init(std::size_t dim)
+    void MeshFunction<T>::init(std::size_t dim)
   {
     if (!_mesh)
     {
@@ -545,11 +723,11 @@ namespace dolfin
 
     }
     _mesh->init(dim);
-    init(*_mesh, dim, _mesh->size(dim));
+    init(_mesh, dim, _mesh->size(dim));
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  void MeshFunction<T>::init(std::size_t dim, std::size_t size)
+    void MeshFunction<T>::init(std::size_t dim, std::size_t size)
   {
     if (!_mesh)
     {
@@ -558,18 +736,28 @@ namespace dolfin
                    "Mesh has not been specified for mesh function");
     }
     _mesh->init(dim);
-    init(*_mesh, dim, size);
+    init(_mesh, dim, size);
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  void MeshFunction<T>::init(const Mesh& mesh, std::size_t dim)
+    void MeshFunction<T>::init(const Mesh& mesh, std::size_t dim)
   {
     mesh.init(dim);
     init(mesh, dim, mesh.size(dim));
   }
   //---------------------------------------------------------------------------
   template <typename T>
-  void MeshFunction<T>::init(const Mesh& mesh, std::size_t dim, std::size_t size)
+    void MeshFunction<T>::init(boost::shared_ptr<const Mesh> mesh,
+                               std::size_t dim)
+  {
+    dolfin_assert(mesh);
+    mesh->init(dim);
+    init(mesh, dim, mesh->size(dim));
+  }
+  //---------------------------------------------------------------------------
+  template <typename T>
+    void MeshFunction<T>::init(const Mesh& mesh, std::size_t dim,
+                               std::size_t size)
   {
     // Initialize mesh for entities of given dimension
     mesh.init(dim);
@@ -578,7 +766,25 @@ namespace dolfin
     // Initialize data
     if (_size != size)
       _values.reset(new T[size]);
-    _mesh = &mesh;
+    _mesh = reference_to_no_delete_pointer(mesh);
+    _dim = dim;
+    _size = size;
+  }
+  //---------------------------------------------------------------------------
+  template <typename T>
+    void MeshFunction<T>::init(boost::shared_ptr<const Mesh> mesh,
+                               std::size_t dim, std::size_t size)
+  {
+    dolfin_assert(mesh);
+
+    // Initialize mesh for entities of given dimension
+    mesh->init(dim);
+    dolfin_assert(mesh->size(dim) == size);
+
+    // Initialize data
+    if (_size != size)
+      _values.reset(new T[size]);
+    _mesh = mesh;
     _dim = dim;
     _size = size;
   }
