@@ -24,8 +24,8 @@
 #define __MESH_GEOMETRY_H
 
 #include <string>
+#include <dolfin/geometry/Point.h>
 #include <dolfin/log/log.h>
-#include "Point.h"
 
 namespace dolfin
 {
