@@ -1,4 +1,4 @@
-// Copyright (C) 2007-2009 Anders Logg
+// Copyright (C) 2007-2012 Anders Logg
 //
 // This file is part of DOLFIN.
 //
@@ -16,14 +16,14 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2007-01-30
-// Last changed: 2011-03-17
+// Last changed: 2012-06-25
 
+#include <vector>
 #include <boost/shared_ptr.hpp>
 #include <dolfin/common/NoDeleter.h>
 #include <dolfin/log/log.h>
 #include "Cell.h"
 #include "Mesh.h"
-#include "ParallelData.h"
 #include "MeshOrdering.h"
 
 using namespace dolfin;
@@ -37,16 +37,20 @@ void MeshOrdering::order(Mesh& mesh)
   if (mesh.num_cells() == 0)
     return;
 
-  // Get global vertex numbering (important when running in parallel)
-  const MeshFunction<unsigned int>* global_vertex_indices = 0;
-  if (mesh.parallel_data().have_global_entity_indices(0))
-    global_vertex_indices = &(mesh.parallel_data().global_entity_indices(0));
+  // Get global vertex numbering
+  dolfin_assert(mesh.topology().have_global_indices(0));
+  const std::vector<std::size_t>& local_to_global_vertex_indices
+    = mesh.topology().global_indices(0);
+
+  // Skip ordering for dimension 0
+  if (mesh.topology().dim() == 0)
+    return;
 
   // Iterate over all cells and order the mesh entities locally
   Progress p("Ordering mesh", mesh.num_cells());
   for (CellIterator cell(mesh); !cell.end(); ++cell)
   {
-    cell->order(global_vertex_indices);
+    cell->order(local_to_global_vertex_indices);
     p++;
   }
 }
@@ -57,16 +61,16 @@ bool MeshOrdering::ordered(const Mesh& mesh)
   if (mesh.num_cells() == 0)
     return true;
 
-  // Get global vertex numbering (important when running in parallel)
-  const MeshFunction<unsigned int>* global_vertex_indices = 0;
-  if (mesh.parallel_data().have_global_entity_indices(0))
-    global_vertex_indices = &(mesh.parallel_data().global_entity_indices(0));
+  // Get global vertex numbering
+  dolfin_assert(mesh.topology().have_global_indices(0));
+  const std::vector<std::size_t>& local_to_global_vertex_indices
+    = mesh.topology().global_indices(0);
 
   // Check if all cells are ordered
   Progress p("Checking mesh ordering", mesh.num_cells());
   for (CellIterator cell(mesh); !cell.end(); ++cell)
   {
-    if (!cell->ordered(global_vertex_indices))
+    if (!cell->ordered(local_to_global_vertex_indices))
       return false;
     p++;
   }
