@@ -38,8 +38,13 @@ MeshTopology::MeshTopology()
 }
 //-----------------------------------------------------------------------------
 MeshTopology::MeshTopology(const MeshTopology& topology)
+  : coloring(topology.coloring), num_entities(topology.num_entities),
+    global_num_entities(topology.global_num_entities), 
+    _global_indices(topology._global_indices),
+    _shared_entities(topology._shared_entities),
+    connectivity(topology.connectivity)
 {
-  *this = topology;
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
 MeshTopology::~MeshTopology()
@@ -47,17 +52,22 @@ MeshTopology::~MeshTopology()
   clear();
 }
 //-----------------------------------------------------------------------------
-const MeshTopology& MeshTopology::operator= (const MeshTopology& topology)
+MeshTopology& MeshTopology::operator= (const MeshTopology& topology)
 {
   // Clear old data if any
   clear();
 
   // Copy data
+
+  // Public data
+  coloring = topology.coloring;
+
+  // Private data
   num_entities = topology.num_entities;
   global_num_entities = topology.global_num_entities;
-  connectivity = topology.connectivity;
   _global_indices = topology._global_indices;
-  coloring = topology.coloring;
+  _shared_entities = topology._shared_entities;
+  connectivity = topology.connectivity;
 
   return *this;
 }
