@@ -15,11 +15,11 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
-// Modified by Anders Logg, 2008.
-// Modified by Kristoffer Selim, 2008.
+// Modified by Anders Logg 2008-2013
+// Modified by Kristoffer Selim 2008
 //
 // First added:  2007-12-12
-// Last changed: 2010-01-15
+// Last changed: 2013-08-26
 
 #ifndef __POINT_CELL_H
 #define __POINT_CELL_H
@@ -67,6 +67,9 @@ namespace dolfin
     /// Compute diameter of triangle
     double diameter(const MeshEntity& triangle) const;
 
+    /// Compute squared distance to given point
+    double squared_distance(const Cell& cell, const Point& point) const;
+
     /// Compute component i of normal of given facet with respect to the cell
     double normal(const Cell& cell, std::size_t facet, std::size_t i) const;
 
@@ -82,6 +85,12 @@ namespace dolfin
     /// Order entities locally
     void order(Cell& cell) const;
 
+    /// Check whether given point is contained in cell
+    bool collides(const Cell& cell, const Point& point) const;
+
+    /// Check whether given entity collides with cell
+    bool collides(const Cell& cell, const MeshEntity& entity) const;
+
     /// Return description of cell type
     std::string description(bool plural) const;
 
