@@ -1,4 +1,4 @@
-// Copyright (C) 2006-2011 Anders Logg
+// Copyright (C) 2006-2013 Anders Logg
 //
 // This file is part of DOLFIN.
 //
@@ -22,7 +22,7 @@
 // Modified by Jan Blechta 2013
 //
 // First added:  2006-06-05
-// Last changed: 2013-02-21
+// Last changed: 2013-12-09
 
 #include <algorithm>
 #include <dolfin/log/log.h>
@@ -214,7 +214,92 @@ double TriangleCell::diameter(const MeshEntity& triangle) const
   const double c  = p0.distance(p1);
 
   // Formula for diameter (2*circumradius) from http://mathworld.wolfram.com
-  return 0.5*a*b*c/volume(triangle);
+  return 0.5*a*b*c / volume(triangle);
+}
+//-----------------------------------------------------------------------------
+double TriangleCell::squared_distance(const Cell& cell, const Point& point) const
+{
+  // Get the vertices as points
+  const MeshGeometry& geometry = cell.mesh().geometry();
+  const unsigned int* vertices = cell.entities(0);
+  const Point a = geometry.point(vertices[0]);
+  const Point b = geometry.point(vertices[1]);
+  const Point c = geometry.point(vertices[2]);
+
+  // Call function to compute squared distance
+  return squared_distance(point, a, b, c);
+}
+//-----------------------------------------------------------------------------
+double TriangleCell::squared_distance(const Point& point,
+                                      const Point& a,
+                                      const Point& b,
+                                      const Point& c)
+{
+  // Algorithm from Real-time collision detection by Christer Ericson:
+  // ClosestPtPointTriangle on page 141, Section 5.1.5.
+  //
+  // Algorithm modified to handle triangles embedded in 3D.
+  //
+  // Note: This algorithm actually computes the closest point but we
+  // only return the distance to that point.
+
+  // Compute normal to plane defined by triangle
+  const Point ab = b - a;
+  const Point ac = c - a;
+  Point n = ab.cross(ac);
+  n /= n.norm();
+
+  // Subtract projection onto plane
+  const double pn = (point - a).dot(n);
+  const Point p = point - pn*n;
+
+  // Check if point is in vertex region outside A
+  const Point ap = p - a;
+  const double d1 = ab.dot(ap);
+  const double d2 = ac.dot(ap);
+  if (d1 <= 0.0 && d2 <= 0.0)
+    return p.squared_distance(a) + pn*pn;
+
+  // Check if point is in vertex region outside B
+  const Point bp = p - b;
+  const double d3 = ab.dot(bp);
+  const double d4 = ac.dot(bp);
+  if (d3 >= 0.0 && d4 <= d3)
+    return p.squared_distance(b) + pn*pn;
+
+  // Check if point is in edge region of AB and if so compute projection
+  const double vc = d1*d4 - d3*d2;
+  if (vc <= 0.0 && d1 >= 0.0 && d3 <= 0.0)
+  {
+    const double v = d1 / (d1 - d3);
+    return p.squared_distance(a + v*ab) + pn*pn;
+  }
+
+  // Check if point is in vertex region outside C
+  const Point cp = p - c;
+  const double d5 = ab.dot(cp);
+  const double d6 = ac.dot(cp);
+  if (d6 >= 0.0 && d5 <= d6)
+    return p.squared_distance(c) + pn*pn;
+
+  // Check if point is in edge region of AC and if so compute projection
+  const double vb = d5*d2 - d1*d6;
+  if (vb <= 0.0 && d2 >= 0.0 && d6 <= 0.0)
+  {
+    const double w = d2 / (d2 - d6);
+    return p.squared_distance(a + w*ac) + pn*pn;
+  }
+
+  // Check if point is in edge region of BC and if so compute projection
+  const double va = d3*d6 - d5*d4;
+  if (va <= 0.0 && (d4 - d3) >= 0.0 && (d5 - d6) >= 0.0)
+  {
+    const double w = (d4 - d3) / ((d4 - d3) + (d5 - d6));
+    return p.squared_distance(b + w*(c - b)) + pn*pn;
+  }
+
+  // Point is inside triangle so return distance to plane
+  return pn*pn;
 }
 //-----------------------------------------------------------------------------
 double TriangleCell::normal(const Cell& cell, std::size_t facet, std::size_t i) const
@@ -279,13 +364,13 @@ Point TriangleCell::cell_normal(const Cell& cell) const
 
   // Get the three vertices as points
   const unsigned int* vertices = cell.entities(0);
-  Point p0 = geometry.point(vertices[0]);
-  Point p1 = geometry.point(vertices[1]);
-  Point p2 = geometry.point(vertices[2]);
+  const Point p0 = geometry.point(vertices[0]);
+  const Point p1 = geometry.point(vertices[1]);
+  const Point p2 = geometry.point(vertices[2]);
 
   // Defined cell normal via cross product of first two edges:
-  Point v01 = p1 - p0;
-  Point v02 = p2 - p0;
+  const Point v01 = p1 - p0;
+  const Point v02 = p2 - p0;
   Point n = v01.cross(v02);
 
   // Normalize
@@ -383,6 +468,95 @@ void TriangleCell::order(Cell& cell,
   }
 }
 //-----------------------------------------------------------------------------
+bool TriangleCell::collides(const Cell& cell, const Point& point) const
+{
+  // Algorithm from http://www.blackpawn.com/texts/pointinpoly/
+  // See also "Real-Time Collision Detection" by Christer Ericson.
+  //
+  // We express AP as a linear combination of the vectors AB and
+  // AC. Point is inside triangle iff AP is a convex combination.
+  //
+  // Note: This function may be optimized to take into account that
+  // only 2D vectors and inner products need to be computed.
+
+  // Get the vertices as points
+  const MeshGeometry& geometry = cell.mesh().geometry();
+  const unsigned int* vertices = cell.entities(0);
+  const Point p0 = geometry.point(vertices[0]);
+  const Point p1 = geometry.point(vertices[1]);
+  const Point p2 = geometry.point(vertices[2]);
+
+  // Compute vectors
+  const Point v1 = p1 - p0;
+  const Point v2 = p2 - p0;
+  const Point v = point - p0;
+
+  // Compute entries of linear system
+  const double a11 = v1.dot(v1);
+  const double a12 = v1.dot(v2);
+  const double a22 = v2.dot(v2);
+  const double b1 = v.dot(v1);
+  const double b2 = v.dot(v2);
+
+  // Solve linear system
+  const double inv_det = 1.0 / (a11*a22 - a12*a12);
+  const double x1 = inv_det*( a22*b1 - a12*b2);
+  const double x2 = inv_det*(-a12*b1 + a11*b2);
+
+  // Tolerance for numeric test (using vector v1)
+  const double dx = std::abs(v1.x());
+  const double dy = std::abs(v1.y());
+  const double eps = std::max(DOLFIN_EPS_LARGE, DOLFIN_EPS_LARGE*std::max(dx, dy));
+
+  // Check if point is inside
+  return x1 >= -eps && x2 >= -eps && x1 + x2 <= 1.0 + eps;
+}
+//-----------------------------------------------------------------------------
+bool TriangleCell::collides(const Cell& cell, const MeshEntity& entity) const
+{
+  // This is only implemented for triangle-triangle collisions at this point
+  if (entity.dim() != 2)
+  {
+    dolfin_error("TriangleCell.cpp",
+                 "compute collision with entity",
+                 "Only know how to compute triangle-triangle collisions");
+  }
+
+  // Get the vertices as points
+  const MeshGeometry& geometry_p = cell.mesh().geometry();
+  const unsigned int* vertices_p = cell.entities(0);
+  const Point p0 = geometry_p.point(vertices_p[0]);
+  const Point p1 = geometry_p.point(vertices_p[1]);
+  const Point p2 = geometry_p.point(vertices_p[2]);
+
+  // Get the vertices as points
+  const MeshGeometry& geometry_q = entity.mesh().geometry();
+  const unsigned int* vertices_q = entity.entities(0);
+  const Point q0 = geometry_q.point(vertices_q[0]);
+  const Point q1 = geometry_q.point(vertices_q[1]);
+  const Point q2 = geometry_q.point(vertices_q[2]);
+
+  // First check if triangles are completely overlapping (necessary
+  // since tests below will fail for collinear edges). Note that this
+  // test will also cover a few other cases with coinciding midpoints.
+  const double eps2 = DOLFIN_EPS_LARGE*DOLFIN_EPS_LARGE*p0.squared_distance(p1);
+  if (cell.midpoint().squared_distance(entity.midpoint()) < eps2)
+    return true;
+
+  // Check for pairwise collisions between the edges
+  if (collides(p0, p1, q0, q1)) return true;
+  if (collides(p0, p1, q1, q2)) return true;
+  if (collides(p0, p1, q2, q0)) return true;
+  if (collides(p1, p2, q0, q1)) return true;
+  if (collides(p1, p2, q1, q2)) return true;
+  if (collides(p1, p2, q2, q0)) return true;
+  if (collides(p2, p0, q0, q1)) return true;
+  if (collides(p2, p0, q1, q2)) return true;
+  //if (collides(p2, p0, q2, q0)) return true; // optimization, not needed
+
+  return false;
+}
+//-----------------------------------------------------------------------------
 std::string TriangleCell::description(bool plural) const
 {
   if (plural)
@@ -414,20 +588,24 @@ std::size_t TriangleCell::find_edge(std::size_t i, const Cell& cell) const
   return 0;
 }
 //-----------------------------------------------------------------------------
-double TriangleCell::radius_ratio(const Cell& triangle) const
+bool TriangleCell::collides(const Point& a, const Point& b,
+                            const Point& c, const Point& d) const
 {
-  // See Jonathan Richard Shewchuk: What Is a Good Linear Finite Element?,
-  // online: http://www.cs.berkeley.edu/~jrs/papers/elemj.pdf
-  
-  const double S = volume(triangle);
-  
-  // Handle degenerate case
-  if (S == 0.0) {return 0.0;}
-  
-  const double a = facet_area(triangle, 0);
-  const double b = facet_area(triangle, 1);
-  const double c = facet_area(triangle, 2);
-  
-  return 16.0*S*S/(a*b*c*(a+b+c));
+  // Algorithm from Real-time collision detection by Christer Ericson:
+  // Test2DSegmentSegment on page 152, Section 5.1.9.
+
+  // Compute signed areas of abd and abc
+  double abd = signed_area(a, b, d);
+  double abc = signed_area(a, b, c);
+
+  // Return false if not intersecting (or collinear)
+  if (abd*abc >= 0.0)
+    return false;
+
+  // Compute signed area of cda
+  double cda = signed_area(c, d, a);
+
+  // Check whether segments collide
+  return cda*(cda + abc - abd) < 0.0;
 }
 //-----------------------------------------------------------------------------
