@@ -1,4 +1,4 @@
-// Copyright (C) 2006-2008 Anders Logg
+// Copyright (C) 2006-2013 Anders Logg
 //
 // This file is part of DOLFIN.
 //
@@ -19,7 +19,7 @@
 // Modified by Jan Blechta 2013
 //
 // First added:  2006-06-05
-// Last changed: 2013-02-21
+// Last changed: 2013-08-26
 
 #ifndef __TRIANGLE_CELL_H
 #define __TRIANGLE_CELL_H
@@ -52,11 +52,13 @@ namespace dolfin
     std::size_t orientation(const Cell& cell) const;
 
     /// Create entities e of given topological dimension from vertices v
-    void create_entities(std::vector<std::vector<std::size_t> >& e, std::size_t dim,
+    void create_entities(std::vector<std::vector<std::size_t> >& e,
+                         std::size_t dim,
                          const unsigned int* v) const;
 
     /// Refine cell uniformly
-    void refine_cell(Cell& cell, MeshEditor& editor, std::size_t& current_cell) const;
+    void refine_cell(Cell& cell, MeshEditor& editor,
+                     std::size_t& current_cell) const;
 
     /// Compute (generalized) volume (area) of triangle
     double volume(const MeshEntity& triangle) const;
@@ -64,8 +66,17 @@ namespace dolfin
     /// Compute diameter of triangle
     double diameter(const MeshEntity& triangle) const;
 
-    /// Compute 2.*inradius/circumradius for given triangle
-    virtual double radius_ratio(const Cell& triangle) const;
+    /// Compute squared distance to given point
+    double squared_distance(const Cell& cell, const Point& point) const;
+
+    /// Compute squared distance to given point. This version takes
+    /// the three vertex coordinates as 3D points. This makes it
+    /// possible to reuse this function for computing the (squared)
+    /// distance to a tetrahedron.
+    static double squared_distance(const Point& point,
+                                   const Point& a,
+                                   const Point& b,
+                                   const Point& c);
 
     /// Compute component i of normal of given facet with respect to the cell
     double normal(const Cell& cell, std::size_t facet, std::size_t i) const;
@@ -83,6 +94,12 @@ namespace dolfin
     void order(Cell& cell,
                const std::vector<std::size_t>& local_to_global_vertex_indices) const;
 
+    /// Check whether given point collides with cell
+    bool collides(const Cell& cell, const Point& point) const;
+
+    /// Check whether given entity collides with cell
+    bool collides(const Cell& cell, const MeshEntity& entity) const;
+
     /// Return description of cell type
     std::string description(bool plural) const;
 
@@ -91,6 +108,14 @@ namespace dolfin
     // Find local index of edge i according to ordering convention
     std::size_t find_edge(std::size_t i, const Cell& cell) const;
 
+    // Compute signed area of triangle abc
+    double signed_area(const Point& a, const Point& b, const Point c) const
+    { return (a.x() - c.x())*(b.y() - c.y()) - (a.y() - c.y())*(b.x() - c.x()); }
+
+    // Check whether edges ab and cd collide
+    bool collides(const Point& a, const Point& b,
+                  const Point& c, const Point& d) const;
+
   };
 
 }
