@@ -19,7 +19,7 @@
 // Modified by Anders E. Johansen 2011
 //
 // First added:  2005-10-23
-// Last changed: 2011-07-11
+// Last changed: 2013-11-20
 
 #ifndef __NEWTON_SOLVER_H
 #define __NEWTON_SOLVER_H
@@ -45,13 +45,10 @@ namespace dolfin
   {
   public:
 
-    /// Create nonlinear solver with default linear solver and default
-    /// linear algebra backend
-    NewtonSolver(std::string solver_type="lu",
-                 std::string pc_type="default");
+    /// Create nonlinear solver
+    NewtonSolver();
 
-    /// Create nonlinear solver using provided linear solver and linear algebra
-    /// backend determined by factory
+    /// Create nonlinear solver using provided linear solver
     ///
     /// *Arguments*
     ///     solver (_GenericLinearSolver_)
@@ -78,7 +75,7 @@ namespace dolfin
     ///         Pair of number of Newton iterations, and whether
     ///         iteration converged)
     std::pair<std::size_t, bool> solve(NonlinearProblem& nonlinear_function,
-                                GenericVector& x);
+                                       GenericVector& x);
 
     /// Return Newton iteration number
     ///
@@ -118,14 +115,15 @@ namespace dolfin
   private:
 
     /// Convergence test
-    virtual bool converged(const GenericVector& b, const GenericVector& dx,
-                           const NonlinearProblem& nonlinear_problem);
+    virtual bool converged(const GenericVector& r,
+                           const NonlinearProblem& nonlinear_problem,
+                           std::size_t iteration);
 
     /// Current number of Newton iterations
-    std::size_t newton_iteration;
+    std::size_t _newton_iteration;
 
     /// Most recent residual and intitial residual
-    double _residual, residual0;
+    double _residual, _residual0;
 
     /// Solver
     boost::shared_ptr<GenericLinearSolver> _solver;
