@@ -18,7 +18,7 @@
 // Modified by Fredrik Valdmanis, 2011
 //
 // First added:  2009-07-02
-// Last changed: 2013-02-18
+// Last changed: 2013-06-21
 
 #ifndef __GLOBAL_PARAMETERS_H
 #define __GLOBAL_PARAMETERS_H
@@ -51,30 +51,54 @@ namespace dolfin
       Parameters p("dolfin");
 
       // General
-      p.add("timer_prefix", "");                             // Prefix for timer tasks
-      p.add("allow_extrapolation", false);                   // Allow extrapolation in function interpolation
-      p.add("exact_interpolation", true);                    // Use exact or linear interpolation in ODESolution::eval()
+
+      // Prefix for timer tasks
+      p.add("timer_prefix", "");
+
+      // Allow extrapolation in function interpolation
+      p.add("allow_extrapolation", false);
+
+      // Use exact or linear interpolation in ODESolution::eval()
+      p.add("exact_interpolation", true);
 
       // Output
-      p.add("std_out_all_processes", true);                  // Print standard output on all processes
-      p.add("relative_line_width", 0.025);                   // Line width relative to edge length in SVG output
 
-      // Threaded computation
-      p.add("num_threads", 0);                               // Number of threads to run, 0 = run serial version
+      // Print standard output on all processes
+      p.add("std_out_all_processes", true);
+
+      // Line width relative to edge length in SVG output
+      p.add("relative_line_width", 0.025);
+
+      // Number of threads to run, 0 = run serial version
+      p.add("num_threads", 0);
 
       // DOF reordering when running in serial
       p.add("reorder_dofs_serial", true);
 
+      // Allowed dofs ordering libraries and set default
+      std::set<std::string> allowed_dof_ordering_libraries;
+      allowed_dof_ordering_libraries.insert("Boost");
+      allowed_dof_ordering_libraries.insert("random");
+      allowed_dof_ordering_libraries.insert("SCOTCH");
+      std::string default_dof_ordering_library = "Boost";
+      #ifdef HAS_SCOTCH
+      default_dof_ordering_library = "SCOTCH";
+      #endif
+
+      // Add dof ordering library
+      p.add("dof_ordering_library", default_dof_ordering_library,
+            allowed_dof_ordering_libraries);
+
       // Print the level of thread support provided by the MPI library
       p.add("print_mpi_thread_support_level", false);
 
       // Allowed partitioners (not necessarily installed)
       std::set<std::string> allowed_mesh_partitioners;
       allowed_mesh_partitioners.insert("ParMETIS");
-      allowed_mesh_partitioners.insert("ParMETIS_repart");
       allowed_mesh_partitioners.insert("SCOTCH");
       allowed_mesh_partitioners.insert("Zoltan_RCB");
       allowed_mesh_partitioners.insert("Zoltan_PHG");
+      allowed_mesh_partitioners.insert("None");
 
       // Set default graph/mesh partitioner
       std::string default_mesh_partitioner = "SCOTCH";
@@ -85,30 +109,37 @@ namespace dolfin
       #endif
 
       // Add mesh/graph partitioner
-      p.add("mesh_partitioner",
-            default_mesh_partitioner,
+      p.add("mesh_partitioner", default_mesh_partitioner,
             allowed_mesh_partitioners);
-      
+
+      // Approaches to partitioning (following Zoltan syntax)
+      // but applies to both Zoltan PHG and ParMETIS
+      std::set<std::string> allowed_partitioning_approaches;
+      allowed_partitioning_approaches.insert("PARTITION");
+      allowed_partitioning_approaches.insert("REPARTITION");
+      allowed_partitioning_approaches.insert("REFINE");
+
+      p.add("partitioning_approach",
+            "PARTITION",
+            allowed_partitioning_approaches);
+
       #ifdef HAS_PARMETIS
-      // Repartitioning parameter, determines how strongly to hold on to cells
-      // when shifting between processes
+      // Repartitioning parameter, determines how strongly to hold on
+      // to cells when shifting between processes
       p.add("ParMETIS_repartitioning_weight", 1000.0);
       #endif
 
       #ifdef HAS_TRILINOS
-      // Zoltan PHG partitioner methods
-      std::set<std::string> allowed_lb_approach;
-      allowed_lb_approach.insert("PARTITION");
-      allowed_lb_approach.insert("REPARTITION");
-      allowed_lb_approach.insert("REFINE");
-      p.add("Zoltan_PHG_LB_APPROACH", "PARTITION", allowed_lb_approach);
+      // Zoltan PHG partitioner parameters
       p.add("Zoltan_PHG_REPART_MULTIPLIER", 1.0);
       #endif
 
       // Graph coloring
       std::set<std::string> allowed_coloring_libraries;
-      allowed_mesh_partitioners.insert("Boost");
-      allowed_mesh_partitioners.insert("Zoltan");
+      allowed_coloring_libraries.insert("Boost");
+      #ifdef HAS_TRILINOS
+      allowed_coloring_libraries.insert("Zoltan");
+      #endif
       p.add("graph_coloring_library", "Boost", allowed_coloring_libraries);
 
       // Mesh refinement
