@@ -15,8 +15,10 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
+// Modified by Joachim B Haga 2012
+//
 // First added:  2009-05-08
-// Last changed: 2011-07-06
+// Last changed: 2012-09-11
 
 #ifndef __PARAMETER_H
 #define __PARAMETER_H
@@ -24,7 +26,6 @@
 #include <set>
 #include <sstream>
 #include <string>
-#include <dolfin/common/types.h>
 
 namespace dolfin
 {
@@ -36,7 +37,7 @@ namespace dolfin
   public:
 
     /// Create parameter for given key
-    Parameter(std::string key);
+    explicit Parameter(std::string key);
 
     /// Destructor
     virtual ~Parameter();
@@ -50,11 +51,14 @@ namespace dolfin
     /// Return true if parameter is set, return false otherwise
     bool is_set() const;
 
+    /// Reset the parameter to empty, so that is_set() returns false.
+    void reset();
+
     /// Return access count (number of times parameter has been accessed)
-    uint access_count() const;
+    std::size_t access_count() const;
 
     /// Return change count (number of times parameter has been changed)
-    uint change_count() const;
+    std::size_t change_count() const;
 
     /// Set range for int-valued parameter
     virtual void set_range(int min_value, int max_value);
@@ -92,8 +96,8 @@ namespace dolfin
     /// Cast parameter to int
     virtual operator int() const;
 
-    /// Cast parameter to uint
-    virtual operator dolfin::uint() const;
+    /// Cast parameter to std::size_t
+    virtual operator std::size_t() const;
 
     /// Cast parameter to double
     virtual operator double() const;
@@ -122,16 +126,14 @@ namespace dolfin
   protected:
 
     // Access count
-    mutable uint _access_count;
+    mutable std::size_t _access_count;
 
     // Change count
-    uint _change_count;
+    std::size_t _change_count;
 
     // Whether or not parameter has been set
     bool _is_set;
 
-  private:
-
     // Parameter key
     std::string _key;
 
@@ -146,7 +148,7 @@ namespace dolfin
   public:
 
     /// Create unset int-valued
-    IntParameter(std::string key);
+    explicit IntParameter(std::string key);
 
     /// Create int-valued parameter
     IntParameter(std::string key, int value);
@@ -166,8 +168,8 @@ namespace dolfin
     /// Cast parameter to int
     operator int() const;
 
-    /// Cast parameter to uint
-    operator dolfin::uint() const;
+    /// Cast parameter to std::size_t
+    operator std::size_t() const;
 
     /// Return value type string
     std::string type_str() const;
@@ -197,7 +199,7 @@ namespace dolfin
   public:
 
     /// Create unset double-valued parameter
-    DoubleParameter(std::string key);
+    explicit DoubleParameter(std::string key);
 
     /// Create double-valued parameter
     DoubleParameter(std::string key, double value);
@@ -245,7 +247,7 @@ namespace dolfin
   public:
 
     /// Create unset string-valued parameter
-    StringParameter(std::string key);
+    explicit StringParameter(std::string key);
 
     /// Create string-valued parameter
     StringParameter(std::string key, std::string value);
@@ -296,7 +298,7 @@ namespace dolfin
   public:
 
     /// Create unset bool-valued parameter
-    BoolParameter(std::string key);
+    explicit BoolParameter(std::string key);
 
     /// Create bool-valued parameter
     BoolParameter(std::string key, bool value);
