@@ -1,4 +1,4 @@
-// Copyright (C) 2009-2011 Anders Logg
+// Copyright (C) 2009-2012 Anders Logg
 //
 // This file is part of DOLFIN.
 //
@@ -19,7 +19,7 @@
 // Modified by Garth N. Wells, 2009
 //
 // First added:  2009-05-08
-// Last changed: 2011-10-24
+// Last changed: 2012-10-26
 
 #include <sstream>
 #include <stdio.h>
@@ -233,7 +233,7 @@ void Parameters::remove(std::string key)
   delete find_parameter_set(key);
 
   // Remove from maps (safe to remove both)
-  uint num_removed = 0;
+  std::size_t num_removed = 0;
   num_removed += _parameters.erase(key);
   num_removed += _parameter_sets.erase(key);
   dolfin_assert(num_removed == 1);
@@ -263,6 +263,14 @@ void Parameters::update(const Parameters& parameters)
       continue;
     }
 
+    // Skip unset parameters
+    if (!other.is_set())
+    {
+      warning("Ignoring unset parameter \"%s\" in parameter set \"%s\" when updating parameter set \"%s\".",
+              other.key().c_str(), parameters.name().c_str(), name().c_str());
+      continue;
+    }
+
     // Set value (will give an error if the type is wrong)
     if (other.type_str() == "int")
       *self = static_cast<int>(other);
@@ -411,7 +419,7 @@ std::string Parameters::str(bool verbose) const
   {
     s << str(false) << std::endl << std::endl;
 
-    if (_parameters.size() == 0 && _parameter_sets.size() == 0)
+    if (_parameters.empty() && _parameter_sets.empty())
     {
       s << name() << indent("(empty)");
       return s.str();
@@ -423,7 +431,7 @@ std::string Parameters::str(bool verbose) const
     {
       Parameter* p = it->second;
       t(p->key(), "type") = p->type_str();
-      t(p->key(), "value") = p->value_str();
+      t(p->key(), "value") = (p->is_set() ? p->value_str() : "<unset>");
       t(p->key(), "range") = p->range_str();
       t(p->key(), "access") = p->access_count();
       t(p->key(), "change") = p->change_count();
@@ -465,9 +473,11 @@ void Parameters::parse_common(int argc, char* argv[])
   // Collect and report unrecognized options
   const std::vector<std::string> unrecognized_options
     = po::collect_unrecognized(parsed.options, po::include_positional);
-  for (uint i = 0; i < unrecognized_options.size(); i++)
+  for (std::size_t i = 0; i < unrecognized_options.size(); i++)
+  {
     cout << "Skipping unrecognized option for parameter set \""
          << name() << "\": " << unrecognized_options[i] << endl;
+  }
 
   // Show help text
   if (vm.count("help"))
@@ -581,6 +591,6 @@ Parameters* Parameters::find_parameter_set(std::string key) const
 //-----------------------------------------------------------------------------
 namespace dolfin
 {
-  Parameters empty_parameters("empy");
+  Parameters empty_parameters("empty");
 }
 //-----------------------------------------------------------------------------
