@@ -117,6 +117,28 @@ namespace dolfin
                    "Type '%s' is not allowed", key.c_str());
     }
 
+    /// Add an unset parameter of type T with allows parameters. For
+    /// example, to create a unset parameter of type bool, do
+    /// parameters.add<bool>("my_setting")
+    template<typename T>
+    void add(std::string key, T min, T max)
+    {
+      dolfin_error("Parameters.h",
+                   "create parameter of requested type",
+                   "Type '%s' is not allowed", key.c_str());
+    }
+
+    /// Add an unset parameter of type T with allows parameters. For
+    /// example, to create a unset parameter of type bool, do
+    /// parameters.add<bool>("my_setting")
+    template<typename T>
+    void add(std::string key, std::set<T> valid_values)
+    {
+      dolfin_error("Parameters.h",
+                   "create parameter of requested type",
+                   "Type '%s' is not allowed", key.c_str());
+    }
+
     /// Add int-valued parameter
     void add(std::string key, int value);
 
@@ -192,6 +214,13 @@ namespace dolfin
     /// Return informal string representation (pretty-print)
     std::string str(bool verbose) const;
 
+    // Return pointer to parameter for given key and 0 if not found
+    Parameter* find_parameter(std::string key) const;
+
+    // Return pointer to parameter set for given key and 0 if not found
+    Parameters* find_parameter_set(std::string key) const;
+
+
   protected:
 
     /// Parse filtered options (everything except PETSc options)
@@ -212,12 +241,6 @@ namespace dolfin
                  Parameters &parameters,
                  std::string base_name="");
 
-    // Return pointer to parameter for given key and 0 if not found
-    Parameter* find_parameter(std::string key) const;
-
-    // Return pointer to parameter set for given key and 0 if not found
-    Parameters* find_parameter_set(std::string key) const;
-
     // Parameter set key
     std::string _key;
 
@@ -230,18 +253,42 @@ namespace dolfin
   };
 
   // Specialised templated for unset parameters
-  template<> inline void Parameters::add<uint>(std::string key)
+  template<> inline void Parameters::add<std::size_t>(std::string key)
   { _parameters[key] = new IntParameter(key); }
 
+  template<> inline void Parameters::add<std::size_t>(std::string key, std::size_t min, std::size_t max)
+  {
+    _parameters[key] = new IntParameter(key);
+    _parameters[key]->set_range((int) min, (int) max);
+  }
+
   template<> inline void Parameters::add<int>(std::string key)
   { _parameters[key] = new IntParameter(key); }
 
+  template<> inline void Parameters::add<int>(std::string key, int min, int max)
+  {
+    _parameters[key] = new IntParameter(key);
+    _parameters[key]->set_range(min, max);
+  }
+
   template<> inline void Parameters::add<double>(std::string key)
   { _parameters[key] = new DoubleParameter(key); }
 
+  template<> inline void Parameters::add<double>(std::string key, double min, double max)
+  {
+    _parameters[key] = new DoubleParameter(key);
+    _parameters[key]->set_range(min, max);
+  }
+
   template<> inline void Parameters::add<std::string>(std::string key)
   { _parameters[key] = new StringParameter(key); }
 
+  template<> inline void Parameters::add(std::string key, std::set<std::string> valid_values)
+  {
+    _parameters[key] = new StringParameter(key);
+    _parameters[key]->set_range(valid_values);
+  }
+
   template<> inline void Parameters::add<bool>(std::string key)
   { _parameters[key] = new BoolParameter(key); }
 
