@@ -4,6 +4,6 @@
 // DOLFIN plot interface
 
 #include <dolfin/plot/plot.h>
-#include <dolfin/plot/FunctionPlotData.h>
+#include <dolfin/plot/VTKPlotter.h>
 
 #endif
