@@ -16,7 +16,7 @@
 // along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2011-02-07
-// Last changed: 2012-09-27
+// Last changed: 2013-08-02
 
 #include <vector>
 
@@ -68,13 +68,17 @@ void RegularCutRefinement::refine(Mesh& refined_mesh,
   refine_marked(refined_mesh, mesh, refinement_markers, marked_edges);
 }
 //-----------------------------------------------------------------------------
-void RegularCutRefinement::compute_markers(std::vector<int>& refinement_markers,
-                                           IndexSet& marked_edges,
-                                           const Mesh& mesh,
-                                           const MeshFunction<bool>& cell_markers)
+void
+RegularCutRefinement::compute_markers(std::vector<int>& refinement_markers,
+                                      IndexSet& marked_edges,
+                                      const Mesh& mesh,
+                                      const MeshFunction<bool>& cell_markers)
 {
+  // Topological dimension
+  const std::size_t D = mesh.topology().dim();
+
   // Create edge markers and initialize to false
-  const std::size_t edges_per_cell = mesh.topology().dim() + 1;
+  const std::size_t edges_per_cell = D + 1;
   std::vector<std::vector<bool> > edge_markers(mesh.num_cells());
   for (std::size_t i = 0; i < mesh.num_cells(); i++)
   {
@@ -88,8 +92,9 @@ void RegularCutRefinement::compute_markers(std::vector<int>& refinement_markers,
   IndexSet marked_cells(mesh.num_cells());
 
   // Get bisection data
-  boost::shared_ptr<MeshFunction<std::size_t> > bisection_twins
-      = mesh.data().mesh_function("bisection_twins");
+  const std::vector<std::size_t>* bisection_twins = NULL;
+  if (mesh.data().exists("bisection_twins", D))
+    bisection_twins = &(mesh.data().array("bisection_twins", D));
 
   // Iterate until no more cells are marked
   cells.fill();
@@ -218,9 +223,9 @@ void RegularCutRefinement::compute_markers(std::vector<int>& refinement_markers,
 }
 //-----------------------------------------------------------------------------
 void RegularCutRefinement::refine_marked(Mesh& refined_mesh,
-                                         const Mesh& mesh,
-                                         const std::vector<int>& refinement_markers,
-                                         const IndexSet& marked_edges)
+                                  const Mesh& mesh,
+                                  const std::vector<int>& refinement_markers,
+                                  const IndexSet& marked_edges)
 {
   // Count the number of cells in refined mesh
   std::size_t num_cells = 0;
@@ -272,12 +277,16 @@ void RegularCutRefinement::refine_marked(Mesh& refined_mesh,
   }
 
   // Get bisection data for old mesh
-  boost::shared_ptr<const MeshFunction<std::size_t> > bisection_twins
-        = mesh.data().mesh_function("bisection_twins");
+  const std::size_t D = mesh.topology().dim();
+  const std::vector<std::size_t>*  bisection_twins = NULL;
+  if (mesh.data().exists("bisection_twins", D))
+    bisection_twins = &(mesh.data().array("bisection_twins", D));
 
   // Markers for bisected cells pointing to their bisection twins in
   // refined mesh
-  std::vector<std::size_t> refined_bisection_twins(num_cells);
+  std::vector<std::size_t>& refined_bisection_twins
+    = refined_mesh.data().create_array("bisection_twins", D);
+  refined_bisection_twins.resize(num_cells);
   for (std::size_t i = 0; i < num_cells; i++)
     refined_bisection_twins[i] = i;
 
@@ -324,7 +333,6 @@ void RegularCutRefinement::refine_marked(Mesh& refined_mesh,
     else if (marker == regular_refinement)
     {
       // Regular refinement: divide into subsimplicies
-
       dolfin_assert(unrefined_cells[cell->index()] == -1);
 
       // Get vertices and edges
@@ -357,9 +365,7 @@ void RegularCutRefinement::refine_marked(Mesh& refined_mesh,
     }
     else if (marker == backtrack_bisection || marker == backtrack_bisection_refine)
     {
-
       // Special case: backtrack bisected cells
-
       dolfin_assert(unrefined_cells[cell->index()] == -1);
 
       // Get index for bisection twin
@@ -514,13 +520,6 @@ void RegularCutRefinement::refine_marked(Mesh& refined_mesh,
   // Close mesh editor
   dolfin_assert(num_cells == current_cell);
   editor.close();
-
-  // Attach data for bisection twins
-  boost::shared_ptr<MeshFunction<std::size_t> > _refined_bisection_twins
-      = refined_mesh.data().create_mesh_function("bisection_twins");
-  dolfin_assert(_refined_bisection_twins);
-  _refined_bisection_twins->init(refined_mesh.topology().dim());
-  _refined_bisection_twins->set_values(refined_bisection_twins);
 }
 //-----------------------------------------------------------------------------
 std::size_t RegularCutRefinement::count_markers(const std::vector<bool>& markers)
@@ -640,7 +639,7 @@ RegularCutRefinement::find_bisection_edges(const Cell& cell,
       dot_product /= edge_0.length() * edge_1.length();
 
       // Bisection edge found if dot product is small
-      if (std::abs(std::abs(dot_product) - 1.0) < 100.0 * DOLFIN_EPS)
+      if (std::abs(std::abs(dot_product) - 1.0) < DOLFIN_EPS_LARGE)
         return std::make_pair(i, j);
     }
   }
