@@ -19,8 +19,9 @@
 # Modified by Anders Logg, 2008-2010.
 #
 # First added:  2008-03-05
-# Last changed: 2012-09-21
+# Last changed: 2013-05-29
 
+import os
 import dolfin.cpp as cpp
 import ufl
 
@@ -98,6 +99,7 @@ def plot(object, *args, **kwargs):
 
     # Plot element
     if isinstance(object, ufl.FiniteElementBase):
+        if os.environ.get("DOLFIN_NOPLOT", "0") != "0": return
         import ffc
         return ffc.plot(object, *args, **kwargs)
 
