@@ -6,7 +6,7 @@ from dolfin.compilemodules import jit
 
 from compilemodule import compile_extension_module
 from expressions import compile_expressions
-from subdomains import compile_subdomains
+from subdomains import compile_subdomains, CompiledSubDomain
 from jit import jit
 
 # NOTE: The automatic documentation system in DOLFIN requires to _not_ define
@@ -14,4 +14,4 @@ from jit import jit
 # NOTE: purpose.
 
 __all__ = ["compile_extension_module", "compile_expressions", \
-           "compile_subdomains", "jit"]
+           "compile_subdomains", "CompiledSubDomain", "jit"]
