@@ -46,7 +46,7 @@ __all__ = ["compile_extension_module",
 # Bump the interface version if anything changes that invalidates cached
 # modules (not required for change in generated code, swig version or dolfin
 # version)
-_interface_version = 0
+_interface_version = 1
 
 # A list of supported math builtins
 _cpp_math_builtins = [
@@ -140,12 +140,23 @@ import_array();
 %(dolfin_import_statement)s
 
 %%feature("autodoc", "1");
+
+%%inline %%{
+int get_swigversion() { return  SWIGVERSION; }
+%%}
+
+%%pythoncode %%{
+tmp = hex(get_swigversion())
+swigversion = "%%d.%%d.%%d"%%(tuple(map(int, [tmp[-5], tmp[-3], tmp[-2:]])))
+del tmp, get_swigversion
+%%}
+
 """
 
-def expression_to_code_fragments(expr, arguments, constant_members=None):
+def expression_to_code_fragments(expr, arguments, generic_function_members=None):
     "A help function which extract a dict with code snippets from an expression"
 
-    constant_members = constant_members or []
+    generic_function_members = generic_function_members or []
     expr = list(expr)
 
     # Autodetect variables from function strings
@@ -189,14 +200,14 @@ def expression_to_code_fragments(expr, arguments, constant_members=None):
 
     # Generate code for member variables
     members_code = ["  double %s;" % name for name in variables \
-                    if name not in constant_members]
-    members_code.extend("  boost::shared_ptr<dolfin::Constant> shared_%s;" % name \
-                        for name in constant_members)
+                    if name not in generic_function_members]
+    members_code.extend("  boost::shared_ptr<dolfin::GenericFunction> shared_%s;" % name \
+                        for name in generic_function_members)
     members_code = "\n".join(members_code)
 
     # Generate constructor code for initialization of member variables
     constructor_code = "\n".join("    %s = 0;" % name for name in variables\
-                                 if name not in constant_members)
+                                 if name not in generic_function_members)
 
     # Connect the code fragments using the function template code
     fragments = {}
@@ -229,33 +240,22 @@ def expect_arg(argtype, arg, argname):
                      "Provide a '%s', for the '%s' argument" % \
                      (argtype.__name__, argname))
     
-def get_dolfin_include_dir():
-    """
-    Get system installation of dolfin
-    """
-    # FIXME: Implement reading of CMake files in instant
-    (dolfin_include_dirs,
-     dummy,
-     dummy,
-     dummy) = instant.header_and_libs_from_pkgconfig("dolfin")
-
-    # Let swig see the installed dolfin swig files
-    dolfin_include_found = False
-    for inc_dir in dolfin_include_dirs:
-        # Check if dolfin.h is installed in dolfin_include_dir
-        if os.path.exists(os.path.join(inc_dir, "dolfin.h")):
-            return os.path.abspath(inc_dir)
-        
-    cpp.dolfin_error("compilemodule.py",
-                     "find installed dolfin.h",
-                     "Could not find 'dolfin.h', make sure it is installed in a "\
-                     "directory that 'pkg-config --cflags dolfin' returns.")
+def check_swig_version(compiled_module):
+    
+    # Check swig version of compiled module
+    if compiled_module and compiled_module.swigversion != cpp.__swigversion__:
+        cpp.dolfin_error("compilemodule.py",
+                         "compiling extension module",
+                         "Incompatible swig versions detected. DOLFIN swig "\
+                         "version is not the same as extension module swig "\
+                         "version: '%s' != '%s' " % \
+                         (cpp.__swigversion__, compiled_module.swigversion))
 
 @mpi_jit_decorator
 def compile_extension_module(code, module_name="",
                              additional_declarations="",
                              additional_system_headers=None,
-                             config=None):
+                             **instant_kwargs):
     """
     Just In Time compile DOLFIN C++ code into a Python module.
 
@@ -334,22 +334,13 @@ def compile_extension_module(code, module_name="",
         codelines += ["}"]
         code = "\n".join(codelines)
 
-    # Check and set swig binary
-    if not instant.check_and_set_swig_binary(dolfin.parameters["swig_binary"], \
-                                             dolfin.parameters["swig_path"]):
-        cpp.dolfin_error("compilemodule.py",
-                         "ensure correct swig version",
-                         "Could not find swig installation. Pass an existing "\
-                         "swig binary or install SWIG version 2.0 or higher")
-
     # Create unique module name for this application run
     if module_name is "":
         module_name = "dolfin_compile_code_%s" % \
-                      hashlib.md5(repr(code) + instant.get_swig_version() +\
-                                  dolfin.__version__ + str(_interface_version)+\
+                      hashlib.md5(repr(code) + dolfin.__version__ + \
+                                  str(_interface_version)+\
                                   additional_declarations +\
-                                  str(additional_system_headers) + str(config)\
-                                  ).hexdigest()
+                                  str(additional_system_headers)).hexdigest()
 
     # Extract dolfin dependencies and class names
     used_types, declared_types = parse_and_extract_type_info(code)
@@ -405,31 +396,38 @@ def compile_extension_module(code, module_name="",
 
     # Check the handed import files
     interface_import_files = []
-    dolfin_include_dir = get_dolfin_include_dir()
 
     # Check cache
     compiled_module = instant.import_module(module_name)
 
     if compiled_module:
+        # Check that the swig version of the compiled module is the same as
+        # dolfin was compiled with
+        check_swig_version(compiled_module)
         return compiled_module
 
     sys.stdout.flush()
     dolfin.info("Calling DOLFIN just-in-time (JIT) compiler, this may take some time.")
     
     # Configure instant and add additional system headers
-    instant_kwargs = {}
     
     # Add dolfin system headers
-    instant_kwargs['system_headers'] = ["cmath", "iostream","complex",
+    instant_kwargs["system_headers"] = ["cmath", "iostream","complex",
                                         "stdexcept","numpy/arrayobject.h",
                                         "boost/shared_ptr.hpp",
                                         "dolfin/common/types.h",
-                                        "dolfin/math/basic.h"]
+                                        "dolfin/math/basic.h"] + \
+                                        instant_kwargs.get("system_headers", [])
     instant_kwargs["system_headers"] += dolfin_system_headers
 
     # Add user specified system headers
     instant_kwargs["system_headers"] += additional_system_headers
 
+    # Add cmake packages
+    instant_kwargs["cmake_packages"]  = ["DOLFIN"] + \
+                                        instant_kwargs.get("cmake_packages", [])
+    instant_kwargs["signature"] = module_name
+
     declaration_strs = {"additional_declarations":""}
     declaration_strs["dolfin_import_statement"] = \
                     "\n".join(import_lines)
@@ -445,13 +443,16 @@ def compile_extension_module(code, module_name="",
 
     # Compile extension module with instant
     compiled_module = instant.build_module(\
-             code              = code,
-             additional_declarations = _additional_declarations%declaration_strs,
-             signature         = module_name,
-             cmake_packages    = ["DOLFIN"],
-             **instant_kwargs)
+        code              = code,
+        additional_declarations = _additional_declarations % declaration_strs,
+        **instant_kwargs)
 
     sys.stdout.flush()
+
+    # Check that the swig version of the compiled module is the same as
+    # dolfin was compiled with
+    check_swig_version(compiled_module)
+    
     return compiled_module
 
 def extract_shared_ptr_declaration(declared_types, used_dolfin_types, shared_ptr_classes):
