@@ -36,12 +36,6 @@ from dolfin.cpp import MPI, info, parameters, warning, info
 import ufl
 ufl.set_level(ufl.INFO)
 
-# Import check for correct swig version from instant
-from instant import check_swig_version, get_swig_version, check_and_set_swig_binary
-
-# Cached swig check
-_swig_version_ok = False
-
 def mpi_jit_decorator(local_jit, *args, **kwargs):
     """A decorator for jit compilation
 
@@ -94,28 +88,6 @@ def jit(form, form_compiler_parameters=None, common_cell=None):
         if form.integrals() == ():
             raise RuntimeError, "Form is empty. Cannot pass to JIT compiler."
 
-    global _swig_version_ok
-
-    # Check and set swig binary
-    if not _swig_version_ok and not check_and_set_swig_binary(\
-        parameters["swig_binary"], parameters["swig_path"]):
-        raise OSError, "Could not find swig installation. Pass an existing "\
-              "swig binary or install SWIG version 2.0 or higher.\n"
-
-    # Check that the form compiler will use the same swig version
-    # that PyDOLFIN was compiled with
-    _swig_version_ok = _swig_version_ok or \
-                       check_swig_version(cpp.__swigversion__, same=True)
-
-    if not _swig_version_ok:
-        raise OSError, """\
-PyDOLFIN was not compiled with the present version of swig.
-Install swig version %s or recompiled PyDOLFIN with present swig
-"""%cpp.__swigversion__
-
-    # Cache swig version test
-    _swig_version_ok = True
-
     # Import form compiler
     form_compiler_name = cpp.parameters["form_compiler"]["name"]
     try:
@@ -141,10 +113,6 @@ Install swig version %s or recompiled PyDOLFIN with present swig
     if form_compiler_parameters:
         p.update(form_compiler_parameters)
 
-    # Set the swig binary and path
-    p["swig_binary"] = parameters["swig_binary"]
-    p["swig_path"] = parameters["swig_path"]
-
     # Get jit function
     try:
         jit_compile = form_compiler.jit
