@@ -34,7 +34,7 @@ rely on the dolfin::Form class which is not used on the Python side."""
 # First added:  2007-08-15
 # Last changed: 2013-02-18
 
-__all__ = ["assemble", "assemble_system"]
+__all__ = ["assemble", "assemble_system", "SystemAssembler"]
 
 import types
 
@@ -62,8 +62,7 @@ def assemble(form,
              keep_diagonal=False,
              backend=None,
              form_compiler_parameters=None,
-             bcs=None,
-             symmetric_mod=None):
+             bcs=None):
     """
     Assemble the given form and return the corresponding tensor.
 
@@ -158,7 +157,7 @@ def assemble(form,
 
         # Then we just try to use that one
         dolfin_form = form
-        
+
     else:
 
         # Wrap form
@@ -182,8 +181,7 @@ def assemble(form,
                          exterior_facet_domains,
                          interior_facet_domains)
 
-    # Attach domains to form (from Mesh, in other cases form already
-    # has domain data attached)
+    # Attach domains to form 
     if cell_domains is not None:
         dolfin_form.set_cell_domains(cell_domains);
     if interior_facet_domains is not None:
@@ -205,13 +203,13 @@ def assemble(form,
         tensor = tensor.getval()
 
     # Apply (possibly list of) boundary conditions
-    for bc in _wrap_in_list(bcs, 'bcs', cpp.DirichletBC):
+    bcs = _wrap_in_list(bcs, 'bcs', cpp.DirichletBC)
+    if bcs:
+        cpp.deprecation("Passing \"bcs\" to assemble", "1.3.0",
+                        "Apply DirichletBC manually after an assemble.")
+    for bc in bcs:
         bc.apply(tensor)
 
-    # Apply symmetric modification
-    if symmetric_mod:
-        tensor -= symmetric_mod*tensor
-
     # Return value
     return tensor
 
@@ -294,31 +292,31 @@ def assemble_system(A_form,
     # Attach domains to form (from Mesh, in other cases form already
     # has domain data attached)
     if cell_domains is not None:
-        dolfin_form.set_cell_domains(cell_domains);
+        A_dolfin_form.set_cell_domains(cell_domains);
+        b_dolfin_form.set_cell_domains(cell_domains);
     if interior_facet_domains is not None:
-        dolfin_form.set_interior_facet_domains(interior_facet_domains);
+        A_dolfin_form.set_interior_facet_domains(interior_facet_domains);
+        b_dolfin_form.set_interior_facet_domains(interior_facet_domains);
     if exterior_facet_domains is not None:
-        dolfin_form.set_exterior_facet_domains(exterior_facet_domains);
+        A_dolfin_form.set_exterior_facet_domains(exterior_facet_domains);
+        b_dolfin_form.set_exterior_facet_domains(exterior_facet_domains);
 
     # Check bcs
     bcs = _wrap_in_list(bcs, 'bcs', cpp.DirichletBC)
 
     # Call C++ assemble function
-    assembler = cpp.SystemAssembler()
+    assembler = cpp.SystemAssembler(A_dolfin_form, b_dolfin_form, bcs)
     assembler.reset_sparsity = reset_sparsity
     assembler.add_values = add_values
     assembler.finalize_tensor = finalize_tensor
     assembler.keep_diagonal = keep_diagonal
-    assembler.assemble(A_tensor,
-                       b_tensor,
-                       A_dolfin_form,
-                       b_dolfin_form,
-                       bcs,
-                       x0)
+    if x0 is not None:
+        assembler.assemble(A_tensor, b_tensor, x0)
+    else:
+        assembler.assemble(A_tensor, b_tensor)
 
     return A_tensor, b_tensor
 
-
 def _wrap_in_list(obj, name, types=type):
     if obj is None:
         lst = []
@@ -361,8 +359,8 @@ def _extract_domains(mesh,
                      exterior_facet_domains,
                      interior_facet_domains):
 
-    def check_domain_type(domain,domain_type):
-        if not isinstance(domain,(cpp.SubDomain,cpp.MeshFunctionSizet,types.NoneType)):
+    def check_domain_type(domain, domain_type):
+        if not isinstance(domain, (cpp.SubDomain,cpp.MeshFunctionSizet, types.NoneType)):
             raise TypeError, "expected a 'SubDomain', 'MeshFunction' of 'Sizet' or 'None', for the '%s'"%domain_type
 
     def build_mf(subdomain, dim):
@@ -385,9 +383,7 @@ def _extract_domains(mesh,
         cell_domains = build_mf(cell_domains, cell_dim)
 
     # Get exterior_facet_domains (may be stored as part of the mesh)
-    if exterior_facet_domains is None:
-        exterior_facet_domains = mesh.data().mesh_function("exterior facet domains")
-    elif isinstance(exterior_facet_domains, cpp.SubDomain):
+    if isinstance(exterior_facet_domains, cpp.SubDomain):
         exterior_facet_domains = build_mf(exterior_facet_domains, cell_dim-1)
 
     # Get interior_facet_domains
@@ -395,3 +391,74 @@ def _extract_domains(mesh,
         interior_facet_domains = build_mf(interior_facet_domains, cell_dim-1)
 
     return cell_domains, exterior_facet_domains, interior_facet_domains
+
+class SystemAssembler(cpp.SystemAssembler):
+    __doc__ = cpp.SystemAssembler.__doc__
+    def __init__(self, A_form, b_form,
+                 bcs=None,
+                 A_coefficients=None,
+                 b_coefficients=None,
+                 A_function_spaces=None,
+                 b_function_spaces=None,
+                 cell_domains=None,
+                 exterior_facet_domains=None,
+                 interior_facet_domains=None,
+                 form_compiler_parameters=None):
+        """
+        Create a SystemAssembler
+
+        * Arguments *
+           a (ufl.Form, _Form_)
+              Bilinear form
+           L (ufl.Form, _Form_)
+              Linear form
+           bcs (_DirichletBC_)
+              A list or a single DirichletBC (optional)
+        """
+        # Extract subdomains
+        subdomains = { "cell": cell_domains,
+                       "exterior_facet": exterior_facet_domains,
+                       "interior_facet": interior_facet_domains}
+
+        # Wrap forms
+        # First check if we got a cpp.Form which originates from cpp layer
+        if isinstance(A_form, cpp.Form) and not hasattr(A_form, "_compiled_form"):
+
+            # Then we just try to use that one
+            A_dolfin_form = A_form
+        else:
+            A_dolfin_form = Form(A_form, A_function_spaces, A_coefficients,
+                                 subdomains, form_compiler_parameters)
+            
+        if isinstance(b_form, cpp.Form) and not hasattr(b_form, "_compiled_form"):
+
+            # Then we just try to use that one
+            b_dolfin_form = b_form
+        else:
+            b_dolfin_form = Form(b_form, b_function_spaces, b_coefficients,
+                                 subdomains, form_compiler_parameters)
+        
+        # Extract domains
+        cell_domains, exterior_facet_domains, interior_facet_domains = \
+                      _extract_domains(A_dolfin_form.mesh(),
+                                       cell_domains,
+                                       exterior_facet_domains,
+                                       interior_facet_domains)
+
+        # Attach domains to form (from Mesh, in other cases form already
+        # has domain data attached)
+        if cell_domains is not None:
+            A_dolfin_form.set_cell_domains(cell_domains);
+            b_dolfin_form.set_cell_domains(cell_domains);
+        if interior_facet_domains is not None:
+            A_dolfin_form.set_interior_facet_domains(interior_facet_domains);
+            b_dolfin_form.set_interior_facet_domains(interior_facet_domains);
+        if exterior_facet_domains is not None:
+            A_dolfin_form.set_exterior_facet_domains(exterior_facet_domains);
+            b_dolfin_form.set_exterior_facet_domains(exterior_facet_domains);
+
+        # Check bcs
+        bcs = _wrap_in_list(bcs, 'bcs', cpp.DirichletBC)
+
+        # Call C++ assemble function
+        cpp.SystemAssembler.__init__(self, A_dolfin_form, b_dolfin_form, bcs)
