@@ -29,6 +29,9 @@ __all__ = ["Form"]
 # Import SWIG-generated extension module (DOLFIN C++)
 import dolfin.cpp as cpp
 
+# Import ufl and ufc
+import ufl, ufc
+
 # Import JIT compiler
 from dolfin.compilemodules.jit import jit
 
@@ -46,16 +49,25 @@ class Form(cpp.Form):
                  common_cell=None):
         "Create JIT-compiled form from any given form (compiled or not)."
 
-        # Compile form if necessary
-        if not hasattr(form, "create_cell_integral"):
-            (self._compiled_form, module, self.form_data, prefix) \
-                = jit(form,
-                      form_compiler_parameters,
-                      common_cell)
-        else:
+        # Check form argument
+        if isinstance(form, ufl.Form):
+            self._compiled_form, module, self.form_data, prefix \
+                                 = jit(form, form_compiler_parameters,
+                                       common_cell)
+
+        elif isinstance(form, ufc.form):
             self._compiled_form = form
             self.form_data = None
 
+        elif isinstance(form, cpp.Form):
+            self._compiled_form = form._compiled_form
+            self.form_data = form.form_data
+
+        else:
+            cpp.dolfin_error("form.py",
+                             "creating dolfin.Form",
+                             "Expected a ufl.Form, ufc.form or a dolfin.Form")
+
         # Extract function spaces
         self.function_spaces = _extract_function_spaces(self.form_data,
                                                         self._compiled_form,
@@ -86,85 +98,103 @@ class Form(cpp.Form):
 def _extract_function_spaces(form_data, compiled_form, given_function_spaces):
     "Extract list of test spaces."
 
+    # Note: Most of this function is error checking,
+    # look for 'function_spaces' to see where stuff happens
+
     function_space_error = "Error while extracting test and/or trial spaces. "
 
     function_spaces = []
 
-    if given_function_spaces is None:
-        if not hasattr(form_data,"original_arguments"):
-            raise TypeError, function_space_error + \
-                  "Missing data about basis functions in form data."
-        for func in form_data.original_arguments:
-            if not isinstance(func.function_space(), cpp.FunctionSpace):
-                raise TypeError, function_space_error
-            function_spaces.append(func.function_space())
-    else:
-        if not isinstance(given_function_spaces, (list, cpp.FunctionSpace)):
-            raise TypeError, function_space_error
-        if isinstance(given_function_spaces, list):
-            if len(given_function_spaces) != compiled_form.rank():
-                raise ValueError, function_space_error + \
-                      " Wrong number of test spaces (should be %d)." % compiled_form.rank()
-            for V in given_function_spaces:
-                function_spaces.append(V)
+    r = compiled_form.rank()
+
+    if given_function_spaces:
+        # Given function spaces are necessary for assembling pure UFC forms,
+        # and possibly also convenient for other rare scenarios.
+        if isinstance(given_function_spaces, cpp.FunctionSpace):
+            if r > 0:
+                # Repeat a single given space
+                function_spaces = [given_function_spaces]*r
+            else:
+                raise ValueError(function_space_error +
+                                 "Superfluous test spaces given for a functional.")
+
+        elif isinstance(given_function_spaces, (list,tuple)):
+            if all(isinstance(fs, cpp.FunctionSpace) for fs in given_function_spaces):
+                # Take given list of spaces
+                function_spaces = list(given_function_spaces)
+            else:
+                raise ValueError(function_space_error +
+                                 "Invalid given test spaces.")
+
         else:
-            for i in xrange(compiled_form.rank()):
-                function_spaces.append(given_function_spaces)
+            raise ValueError(function_space_error +
+                             "Expecting given_function_spaces to be one or more function spaces.")
+    else:
+        # No given function spaces is the norm in pydolfin, which means
+        # they are to be extracted from the ufl form
+        if hasattr(form_data, 'original_arguments'):
+            # Get spaces from Arguments found in ufl form
+            function_spaces = [func.function_space() for func in form_data.original_arguments]
+
+        elif r == 0:
+            # No given spaces, no form_data, but this is a functional, so no spaces needed
+            function_spaces = []
+
+        else:
+            raise ValueError(function_space_error +
+                             "Missing data about basis functions in form data.")
+
+    # Consistency checks
+    if len(function_spaces) != r:
+        raise ValueError(function_space_error +
+              " Wrong number of test spaces (should be %d)." % r)
+    if not all(isinstance(fs, cpp.FunctionSpace) for fs in function_spaces):
+        raise ValueError(function_space_error +
+              " Invalid type of test spaces.")
 
     return function_spaces
 
 def _extract_coefficients(form_data, given_coefficients):
     "Extract list of coefficients."
 
+    # Note: Most of this function is error checking,
+    # look for 'coefficients' and '_compiled_coefficients' to see where stuff happens
+
     coefficient_error = "Error while extracting coefficients. "
 
     coefficients = []
     _compiled_coefficients = []
 
-    # Return if nothing to extract
-    if form_data is None and given_coefficients is None:
-        return (coefficients,  _compiled_coefficients)
-
-    if given_coefficients is None:
-        if not hasattr(form_data, "original_coefficients"):
-            raise TypeError, coefficient_error + \
-                  "Missing data about coefficients in form data."
-        for c in form_data.original_coefficients:
-            if not isinstance(c, cpp.GenericFunction):
-                raise TypeError, coefficient_error + \
-                      "Either provide a dict of cpp.GenericFunctions, or use Function to define your form."
-            coefficients.append(c)
-    else:
-        # FIXME: I have disabled compiled_functions based on strings for now
-        #       We could ofcourse add it back, but they need a FunctionSpace to
-        #       be initialized.
-        ## Compile all strings as dolfin::Function
-        #string_expressions = []
-        #for c in coefficients:
-        #    # Note: To allow tuples of floats or ints below, this logic becomes more involved...
-        #    if isinstance(c, (tuple, str)):
-        #        string_expressions.append(c)
-        #if string_expressions:
-        #    compiled_functions = compile_functions(string_expressions, mesh)
-        #    compiled_functions.reverse()
-        #
-        # Build list of coefficients
+    if given_coefficients:
+        # Type checking given coefficients
         error_info = "Provide a 'list' with cpp.GenericFunctions"
         if not isinstance(given_coefficients, list):
-            raise TypeError, coefficient_error + error_info
-        for c in given_coefficients:
-            # FIXME: I have turned of these for now. Should probably add something for
-            #       at least constant functions
-            # Note: We could generalize this to support more objects
-            # like sympy expressions, tuples for constant vectors, etc...
-            #if isinstance(c, (float, int)):
-            #    c = cpp.Function(mesh, float(c))
-            #elif isinstance(c, (tuple, str)):
-            #    c = compiled_functions.pop()
-            if not isinstance(c, cpp.GenericFunction):
-                raise TypeError, coefficient_error
-            coefficients.append(c)
-            _compiled_coefficients.append(c)
+            raise TypeError(coefficient_error + error_info)
+        if not all(isinstance(c, cpp.GenericFunction) for c in given_coefficients):
+            raise TypeError(coefficient_error)
+
+        # Just use the given list
+        coefficients = list(given_coefficients)
+        _compiled_coefficients = list(given_coefficients)
+
+    elif form_data is None:
+        # Nothing to extract
+        coefficients = []
+        _compiled_coefficients = []
+
+    else:
+        # Type checking form data
+        if not hasattr(form_data, "original_coefficients"):
+            raise TypeError(coefficient_error +
+                  "Missing data about coefficients in form data.")
+        if not all(isinstance(c, cpp.GenericFunction) for c in form_data.original_coefficients):
+            raise TypeError(coefficient_error +
+                            "Either provide a dict of cpp.GenericFunctions, " +
+                            "or use Function to define your form.")
+
+        # Just use the list from form data
+        coefficients = list(form_data.original_coefficients)
+        _compiled_coefficients = [] # Is this correct? No need to store double references.
 
     return (coefficients, _compiled_coefficients)
 
