@@ -47,8 +47,8 @@ def project(v, V=None, bcs=None, mesh=None,
             a :py:class:`Function <dolfin.functions.function.Function>` or
             an :py:class:`Expression <dolfin.functions.expression.Expression>`
         bcs
-            Optional argument :py:class:`list of BoundaryCondition
-            <dolfin.fem.bcs.BoundaryCondition>`
+            Optional argument :py:class:`list of DirichletBC
+            <dolfin.fem.bcs.DirichletBC>`
         V
             Optional argument :py:class:`FunctionSpace
             <dolfin.functions.functionspace.FunctionSpace>`
