@@ -200,7 +200,7 @@ def solve(*args, **kwargs):
 
     For available choices for the 'solver_parameters' kwarg, look at:
 
-        .. code-block:: python
+    .. code-block:: python
 
         info(LinearVariationalSolver.default_parameters(), 1)
 
@@ -449,7 +449,7 @@ def _extract_bcs(bcs):
     elif not isinstance(bcs, (list, tuple)):
         bcs = [bcs]
     for bc in bcs:
-        if not isinstance(bc, cpp.BoundaryCondition):
+        if not isinstance(bc, cpp.DirichletBC):
             cpp.dolfin_error("solving.py",
                              "solve variational problem",
                              "Unable to extract boundary condition arguments")
