@@ -32,7 +32,8 @@ import numpy
 
 class Constant(ufl.Coefficient, cpp.Constant):
 
-    def __init__(self, value, cell=None): # TODO: Change to domain
+    # TODO: [martinal] I want to change cell to domain, but that will break user code...
+    def __init__(self, value, cell=None, name=None):
         """
         Create constant-valued function with given value.
 
@@ -47,6 +48,10 @@ class Constant(ufl.Coefficient, cpp.Constant):
                 <ufl.Cell>` which defines the geometrical
                 dimensions the Constant is defined for.
 
+            name
+                Optional argument. A str which overrules the default
+                name of the Constant.
+                
         The data type Constant represents a constant value that is
         unknown at compile-time. Its values can thus be changed
         without requiring re-generation and re-compilation of C++
@@ -87,8 +92,17 @@ class Constant(ufl.Coefficient, cpp.Constant):
         # Initialize base classes
         ufl.Coefficient.__init__(self, self._ufl_element)
 
+        # Set name as given or automatic
+        name = name or "f_%d" % self.count()
+        self.rename(name, "a Constant")
+
     def __float__(self):
         # Overriding UFL operator in this particular case.
         if self.shape() != ():
             raise TypeError("Cannot convert nonscalar constant to float.")
         return cpp.Constant.__float__(self)
+
+    def __str__(self):
+        "x.__str__() <==> print(x)"
+        return self.name()
+        
