@@ -77,12 +77,38 @@ from dolfin import warning, error
 # Local imports
 from dolfin.compilemodules.expressions import compile_expressions
 
+# Local help class
+class UserDefinedParameters(dict):
+    """
+    Help class to set user defined parameters in Expressions
+    """
+    def __init__(self, expr, **kwargs):
+        assert(isinstance(expr, cpp.Expression))
+        self._expr = expr
+        dict.__init__(self, **kwargs)
+        
+    def __setitem__(self, name, value):
+        __doc__ = dict.__setitem__.__doc__
+        if name not in self:
+            raise KeyError("'%s' is not a parameter name" % name)
+        setattr(self._expr, name, value)
+        dict.__setattr__(self, name, value)
+
+    def update(self, other):
+        __doc__ = dict.update.__doc__
+        if hasattr(other, "keys"):
+            for name in other.keys():
+                self[name] = other[name]
+        else:
+            for name, value in other:
+                self[name] = value
+            
 def create_compiled_expression_class(cpp_base):
     # Check the cpp_base
     assert(isinstance(cpp_base, (types.ClassType, type)))
 
     def __init__(self, cppcode, element=None, cell=None, \
-                 degree=None, **kwargs):
+                 degree=None, name=None, label=None, **kwargs):
         """Initialize the Expression """
         # Initialize the cpp base class first and extract value_shape
         cpp_base.__init__(self)
@@ -115,20 +141,28 @@ def create_compiled_expression_class(cpp_base):
         for member, value in kwargs.items():
             setattr(self, member, value)
 
+        name = name or "f_" + str(ufl.Coefficient.count(self))
+        label = label or "User defined expression"
+
+        self.rename(name, label)
+
+        # Store the rest of the kwargs (parameters)
+        self.user_parameters = UserDefinedParameters(self, **kwargs)
+
     # Create and return the class
     return type("CompiledExpression", (Expression, ufl.Coefficient, cpp_base),\
                 {"__init__":__init__})
 
-def create_python_derived_expression_class(name, user_bases, user_dict):
+def create_python_derived_expression_class(class_name, user_bases, user_dict):
     """Return Expression class
 
     This function is used to create all the dynamically created Expression
-    classes. It takes a name, and a compiled cpp.Expression and returns
+    classes. It takes a class_name, and a compiled cpp.Expression and returns
     a class that inherits the compiled class together with dolfin.Expression
     and ufl.Coefficient.
 
     *Arguments*
-        name
+        class_name
             The name of the class
         user_bases
             User defined bases
@@ -137,7 +171,7 @@ def create_python_derived_expression_class(name, user_bases, user_dict):
     """
 
     # Check args
-    assert(isinstance(name, str))
+    assert(isinstance(class_name, str))
     assert(isinstance(user_bases, list))
     assert(isinstance(user_dict, dict))
 
@@ -158,6 +192,8 @@ def create_python_derived_expression_class(name, user_bases, user_dict):
         element = kwargs.get("element", None)
         degree = kwargs.get("degree", None)
         cell = kwargs.get("cell", None)
+        name = kwargs.get("name", None)
+        label = kwargs.get("label", None)
 
         # Check if user has passed too many arguments if no
         # user_init is provided
@@ -165,10 +201,10 @@ def create_python_derived_expression_class(name, user_bases, user_dict):
             from operator import add
             # First count how many valid kwargs is passed
             num_valid_kwargs = reduce(add, [kwarg is not None \
-                                      for kwarg in [element, degree, cell]])
+                                      for kwarg in [element, degree, cell, name, label]])
             if len(kwargs) != num_valid_kwargs:
                 raise TypeError, "expected only 'kwargs' from one of "\
-                      "'element', 'degree' or 'cell'"
+                      "'element', 'degree', 'cell', 'name' or 'label'"
             if len(args) != 0:
                 raise TypeError, "expected no 'args'"
 
@@ -193,6 +229,11 @@ def create_python_derived_expression_class(name, user_bases, user_dict):
         if user_init is not None:
             user_init(self, *args, **kwargs)
 
+        name = name or "f_" + str(ufl.Coefficient.count(self))
+        label = label or "User defined expression"
+
+        self.rename(name, label)
+
     # NOTE: Do not prevent the user to overload attributes "reserved" by PyDOLFIN
     # NOTE: Why not?
 
@@ -214,19 +255,19 @@ def create_python_derived_expression_class(name, user_bases, user_dict):
     user_dict["__init__"]  = __init__
 
     # Create the class and return it
-    return type(name, bases, user_dict)
+    return type(class_name, bases, user_dict)
 
 class ExpressionMetaClass(type):
     """Meta Class for Expression"""
-    def __new__(mcs, name, bases, dict_):
+    def __new__(mcs, class_name, bases, dict_):
         """Returns a new Expression class"""
 
-        assert(isinstance(name, str)), "Expecting a 'str'"
+        assert(isinstance(class_name, str)), "Expecting a 'str'"
         assert(isinstance(bases, tuple)), "Expecting a 'tuple'"
         assert(isinstance(dict_, dict)), "Expecting a 'dict'"
 
         # First check if we are creating the Expression class
-        if name == "Expression":
+        if class_name == "Expression":
             # Assert that the class is _not_ a subclass of Expression,
             # i.e., a user have tried to:
             #
@@ -238,7 +279,7 @@ class ExpressionMetaClass(type):
 
             # Return the new class, which just is the original Expression defined in
             # this module
-            return type.__new__(mcs, name, bases, dict_)
+            return type.__new__(mcs, class_name, bases, dict_)
 
         # If creating a fullfledged derived expression class, i.e, inheriting
         # dolfin.Expression, ufl.Coefficient and cpp.Expression (or a subclass)
@@ -247,7 +288,7 @@ class ExpressionMetaClass(type):
                bases[1] == ufl.Coefficient and issubclass(bases[2], \
                                                           cpp.Expression):
             # Return the instantiated class
-            return type.__new__(mcs, name, bases, dict_)
+            return type.__new__(mcs, class_name, bases, dict_)
 
         # Handle any user provided base classes
         user_bases = list(bases)
@@ -275,7 +316,7 @@ class ExpressionMetaClass(type):
             raise TypeError, "The overloaded '%s' function must "\
                   "use three arguments"%eval_name
 
-        return create_python_derived_expression_class(name, user_bases, dict_)
+        return create_python_derived_expression_class(class_name, user_bases, dict_)
 
 #--- The user interface ---
 
@@ -324,14 +365,27 @@ class Expression(object):
         evaluated. All math functions defined in <cmath> are available
         to the user.
 
-        Expression parameters can be included as follows:
+        User defined parameters can be included as follows:
 
         .. code-block:: python
 
-            f = Expression('A*sin(x[0]) + B*cos(x[1])', A=2.0, B=4.0)
+            f = Expression('A*sin(x[0]) + B*cos(x[1])', A=2.0, B=Constant(4.0))
 
-        The parameters can only be scalars, and are all initialized to
-        the passed default value.
+        The parameters can be scalars and any scalar valued
+        GenericFunction and are all initialized to the passed default
+        value. The user defined parameters can be accessed and set
+        as attributes or via the dict-like user_parameters attribute:
+
+        .. code-block:: python
+
+            f.A = 5.0
+            f.B = Expression("value", value=6.0)
+            f.user_parameters["A"] = 1.0
+            f.user_parameters["B"] = Constant(5.0)
+
+        A parameter can only be updated with its original
+        value-type. So if a parameter is a float, it can only be
+        updated with float.
 
     *2. Complex user-defined JIT-compiled Expressions*
         One may also define an Expression using more complicated logic
@@ -508,7 +562,7 @@ class Expression(object):
     __metaclass__ = ExpressionMetaClass
 
     def __new__(cls, cppcode=None, element=None, cell=None, degree=None, \
-                **kwargs):
+                name=None, label=None, **kwargs):
 
         # If the __new__ function is called because we are instantiating
         # a python sub class of Expression, then just return a new instant
@@ -520,15 +574,18 @@ class Expression(object):
         _check_cppcode(cppcode)
 
         # Extract any Constants from the kwargs
-        constant_members = [name for name, value in kwargs.items() \
-                            if isinstance(value, cpp.Constant)]
+        generic_function_members = [arg_name for arg_name, value in kwargs.items() \
+                                    if isinstance(value, cpp.GenericFunction)]
 
         # Compile module and get the cpp.Expression class
-        cpp_base, members = compile_expressions([cppcode], [constant_members])
+        cpp_base, members = compile_expressions([cppcode],
+                                                [generic_function_members])
         cpp_base, members = cpp_base[0], members[0]
         
-        # Check passed default arguments
-        _check_default_kwargs(members, kwargs)
+        # Check passed default arguments 
+        not_allowed = [n for n in dir(cls) if n[0] !="_"]
+        not_allowed += ["cppcode", "user_parameters"]
+        _check_kwargs(members, kwargs, not_allowed)
 
         # Store compile arguments for later use
         cpp_base.cppcode = cppcode
@@ -539,7 +596,7 @@ class Expression(object):
     # This method is only included so a user can check what arguments
     # one should use in IPython using tab completion
     def __init__(self, cppcode=None, element=None, cell=None, degree=None, \
-                 **kwargs): pass
+                 name=None, label=None, **kwargs): pass
 
     # Reuse the docstring from __new__
     __init__.__doc__ = __new__.__doc__
@@ -550,7 +607,7 @@ class Expression(object):
 
     def __str__(self):
         "x.__str__() <==> print(x)"
-        return ufl.Coefficient.__str__(self)
+        return self.name()
 
     def str(self, verbose=False):
         "x.str() <==> info(x)"
@@ -740,11 +797,12 @@ def _auto_select_element_from_shape(shape, degree=None, cell=None):
 
     return element
 
-def _check_default_kwargs(members, kwargs):
+def _check_kwargs(members, kwargs, not_allowed):
     """
-    Check that all kwargs passed is either scalars or scalar Constants
+    Check that all kwargs passed is either scalars or scalar Constants,
+    and that the name is allowed
     """
-
+    
     # Check passed default values
     if not all(member in kwargs for member in members):
         missing = []
@@ -754,10 +812,15 @@ def _check_default_kwargs(members, kwargs):
         missing = ", ".join("'%s'" % miss for miss in missing)
         raise RuntimeError("expected a default value to all member "\
                            "variables in the Expression. Missing: %s." % missing)
-    
+
+    for name in kwargs.keys():
+        if name in not_allowed:
+            raise RuntimeError("Parameter name: '%s' is not allowed. It is "\
+                               "part of the interface of Expression" % name)
+            
     if not (all(isinstance(value, (int, float)) or \
-                (isinstance(value, cpp.Constant) and value.value_size()==1) \
+                (isinstance(value, cpp.GenericFunction) and value.value_size()==1) \
                 for value in kwargs.values())):
         raise TypeError, "expected default arguments for member variables "\
-              "to be scalars or a scalar Constant."
+              "to be scalars or a scalar GenericFunctions."
 
