@@ -31,6 +31,153 @@ import dolfin.cpp as cpp
 import numpy
 
 from dolfin.functions.functionspace import FunctionSpaceBase
+from dolfin.functions.constant import Constant
+
+def _assign_error():
+    cpp.dolfin_error("function.py",
+                     "assign function",
+                     "Expects only linear combinations of Functions in "\
+                     "the same FunctionSpaces")
+
+def _check_mul_and_division(e, linear_comb, scalar_weight=1.0, multi_index=None):
+    """
+    Utility func for checking division and multiplication of a Function
+    with scalars in linear combinations of Functions
+    """
+    from ufl.constantvalue import ScalarValue
+    from ufl.classes import ComponentTensor, MultiIndex, Indexed
+    from ufl.algebra import Division, Product, Sum
+    #ops = e.operands()
+
+    # FIXME: What should be checked!?
+    same_multi_index = lambda x, y: len(x.free_indices()) == len(y.free_indices()) \
+                and x.index_dimensions().values() == y.index_dimensions().values()
+
+    assert(isinstance(scalar_weight, float))
+
+    # Split passed expression into scalar and expr
+    if isinstance(e, Product):
+        for i, op in enumerate(e.operands()):
+            if isinstance(op, ScalarValue) or \
+                   (isinstance(op, Constant) and op.value_size()==1):
+                scalar = op
+                expr = e.operands()[1-i]
+                break
+        else:
+            _assign_error()
+
+        scalar_weight *= float(scalar)
+    elif isinstance(e, Division):
+        expr, scalar = e.operands()
+        if not (isinstance(scalar, ScalarValue) or \
+                isinstance(scalar, Constant) and scalar.value_rank()==1):
+            _assign_error()
+        scalar_weight /= float(scalar)
+    else:
+        _assign_error()
+
+    # If a CoefficientTensor is passed we expect the expr to be either a
+    # Function or another ComponentTensor, where the latter wil result
+    # in a recursive call
+    if multi_index:
+        assert(isinstance(multi_index, MultiIndex))
+        assert(isinstance(expr, Indexed))
+
+        # Unpack Indexed and check equality with passed multi_index
+        expr, multi_index2 = expr.operands()
+        assert(isinstance(multi_index2, MultiIndex))
+        if not same_multi_index(multi_index, multi_index2):
+            _assign_error()
+
+    if isinstance(expr, Function):
+        linear_comb.append((expr, scalar_weight))
+
+    elif isinstance(expr, (ComponentTensor, Product, Division, Sum)):
+        # If componentTensor we need to unpack the MultiIndices
+        if isinstance(expr, ComponentTensor):
+            expr, multi_index = expr.operands()
+            if not same_multi_index(multi_index, multi_index2):
+                _error()
+
+        if isinstance(expr, (Product, Division)):
+            linear_comb = _check_mul_and_division(expr, linear_comb, \
+                                                  scalar_weight, multi_index)
+        elif isinstance(expr, Sum):
+            linear_comb = _check_and_extract_functions(expr, linear_comb, \
+                                                       scalar_weight, multi_index)
+        else:
+            _assign_error()
+    else:
+        _assign_error()
+
+    return linear_comb
+
+def _check_and_extract_functions(e, linear_comb=None, scalar_weight=1.0,
+                                 multi_index=None):
+    """
+    Utility func for extracting Functions and scalars in linear
+    combinations of Functions
+    """
+    from ufl.algebra import Sum, Product, Division
+    from ufl.classes import ComponentTensor
+    linear_comb = linear_comb or []
+
+    # First check u
+    if isinstance(e, Function):
+        linear_comb.append((e, scalar_weight))
+        return linear_comb
+
+    # Second check a*u*b, u/a/b, a*u/b where a and b are scalars
+    elif isinstance(e, (Product, Division)):
+        linear_comb = _check_mul_and_division(e, linear_comb, scalar_weight, multi_index)
+        return linear_comb
+
+    # Third check a*u*b, u/a/b, a*u/b where a and b are scalars and u is a Tensor
+    elif isinstance(e, ComponentTensor):
+        e, multi_index = e.operands()
+        linear_comb = _check_mul_and_division(e, linear_comb, scalar_weight, multi_index)
+        return linear_comb
+
+    # If not Product or Division we expect Sum
+    elif isinstance(e, Sum):
+        for op in e.operands():
+            linear_comb = _check_and_extract_functions(op, linear_comb, \
+                                                       scalar_weight, multi_index)
+
+    else:
+        _assign_error()
+
+    return linear_comb
+
+def _check_and_contract_linear_comb(expr, self, multi_index):
+    """
+    Utility func for checking and contracting linear combinations of
+    Functions
+    """
+    linear_comb = _check_and_extract_functions(expr, multi_index=multi_index)
+    funcs = []
+    weights = []
+    funcspace = None
+    for func, weight in linear_comb:
+        funcspace = funcspace or func.function_space()
+        if func not in funcspace:
+            _assign_error()
+        try:
+            # Check if the exact same Function is already present
+            ind = funcs.index(func)
+            weights[ind] += weight
+        except:
+            funcs.append(func)
+            weights.append(weight)
+
+    # Check that rhs does not include self
+    for ind, func in enumerate(funcs):
+        if func == self:
+            # If so make a copy
+            funcs[ind] = self.copy(deepcopy=True)
+            break
+
+    return zip(funcs, weights)
 
 class MetaNoEvalOverloading(type):
     def __init__(mcs, name, bases, dictionary):
@@ -51,7 +198,7 @@ class Function(ufl.Coefficient, cpp.Function):
     :math:`u_h`.
 
     *Arguments*
-        There is a maximum of two arguments. The first argument must be a
+        There is a maximum of three arguments. The first argument must be a
         Function or a :py:class:`FunctionSpace
         <dolfin.functions.functionspace.FunctionSpace>`.
 
@@ -59,6 +206,8 @@ class Function(ufl.Coefficient, cpp.Function):
         second argument must be an integer denoting the number
         of sub functions to extract.
 
+        In addition can a name argument be passed overruling the default name
+
     *Examples*
         Create a Function:
 
@@ -96,7 +245,7 @@ class Function(ufl.Coefficient, cpp.Function):
 
     __metaclass__ = MetaNoEvalOverloading
 
-    def __init__(self, *args):
+    def __init__(self, *args, **kwargs):
         """Initialize Function."""
         # Check arguments
         if len(args) == 0:
@@ -135,11 +284,11 @@ class Function(ufl.Coefficient, cpp.Function):
         # If creating a dolfin.Function from a cpp.Function
         elif isinstance(args[0], cpp.Function):
             if  len(args) == 1:
-                
+
                 # Lets be agressive in abusing dynamic typing shall we...
                 self.__class__ = Function
                 self.__dict__ = args[0].__dict__
-                
+
                 # Instantiate base classes
                 V = args[0].function_space()
                 ufl.Coefficient.__init__(self, V.ufl_element())
@@ -171,14 +320,25 @@ class Function(ufl.Coefficient, cpp.Function):
         else:
             raise TypeError("too many arguments")
 
+        # Set name as given or automatic
+        name = kwargs.get("name") or "f_%d" % self.count()
+        self.rename(name, "a Function")
+
     def _sub(self, i, deepcopy = False):
-        """Return a sub function.
+        cpp.deprecation("Using Function._sub", "1.3.0",
+                        "Use Function.sub instead")
+        self.sub(i, deepcopy)
+
+
+    def sub(self, i, deepcopy = False):
+        """
+        Return a sub function.
 
         The sub functions are numbered from i = 0..N-1, where N is the
         total number of sub spaces.
 
         *Arguments*
-            i
+            i : int
                 The number of the sub function
 
         """
@@ -192,10 +352,64 @@ class Function(ufl.Coefficient, cpp.Function):
 
         # Create and instantiate the Function
         if deepcopy:
-            return Function(self.function_space().sub(i), cpp.Function._sub(self, i))
+            return Function(self.function_space().sub(i), cpp.Function.sub(self, i))
         else:
             return Function(self, i)
 
+    def assign(self, rhs):
+        """
+        Assign either a Function or linear combination of Functions.
+
+        *Arguments*
+            rhs (_Function_)
+                A Function or a linear combination of Functions. If a linear
+                combination is passed all Functions need to be in the same
+                FunctionSpaces.
+        """
+        from ufl.operatorbase import AlgebraOperator
+        from ufl.classes import ComponentTensor
+        multi_index = None
+        if isinstance(rhs, (cpp.Function, cpp.Expression, cpp.FunctionAXPY)):
+            # Avoid self assignment
+            if self == rhs:
+                return
+
+            self._assign(rhs)
+        elif isinstance(rhs, (AlgebraOperator, ComponentTensor)):
+            if isinstance(rhs, ComponentTensor):
+                rhs, multi_index = rhs.operands()
+            linear_comb = _check_and_contract_linear_comb(rhs, self, multi_index)
+            assert(linear_comb)
+
+            # If the assigned Function lives in a different FunctionSpace
+            # we cannot operate on this function directly
+            same_func_space = linear_comb[0][0] in self.function_space()
+            func, weight = linear_comb.pop()
+
+            # Assign values from first func
+            if not same_func_space:
+                self._assign(func)
+                vector = self.vector()
+            else:
+                vector = self.vector()
+                vector[:] = func.vector()
+
+            # If first weight is not 1 scale
+            if weight != 1.0:
+                vector *= weight
+
+            # AXPY the other functions
+            for func, weight in linear_comb:
+                if weight == 0.0:
+                    continue
+                vector.axpy(weight, func.vector())
+
+        else:
+            cpp.dolfin_error("function.py",
+                             "function assignment",
+                             "Expects a Function or linear combinations of "\
+                             "Functions in the same FunctionSpaces")
+
     def split(self, deepcopy=False):
         """
         Extract any sub functions.
@@ -216,18 +430,16 @@ class Function(ufl.Coefficient, cpp.Function):
         num_sub_spaces = self.function_space().num_sub_spaces()
         if num_sub_spaces == 1:
             raise RuntimeError("No subfunctions to extract")
-        return tuple(self._sub(i, deepcopy) for i in xrange(num_sub_spaces))
+        return tuple(self.sub(i, deepcopy) for i in xrange(num_sub_spaces))
 
     def ufl_element(self):
         """Return ufl element"""
         return self._element
 
     def __str__(self):
-        """Return a pertty print representation of it self.
-
-        Use ufl.__str__ is used for this.
+        """Return a pretty print representation of it self.
         """
-        return ufl.Coefficient.__str__(self)
+        return self.name()
 
     def __repr__(self):
         """Return a str repr of it self.
@@ -235,7 +447,7 @@ class Function(ufl.Coefficient, cpp.Function):
         Must use ufl.__repr__ for this"""
         return ufl.Coefficient.__repr__(self)
 
-    def str(self, verose=False):
+    def str(self, verbose=False):
         """Return an informative str representation of itself"""
         # FIXME: We might change this using rank and dimension instead
         return "<Function in %s>" % str(self.function_space())
@@ -361,14 +573,14 @@ class Function(ufl.Coefficient, cpp.Function):
         # If only one x argument has been provided, unpack it if it's an iterable
         if len(x) == 1:
             if isinstance(x[0], cpp.Point):
-                x = (x[0][i] for i in xrange(dim))
+                x = [x[0][i] for i in xrange(dim)]
             elif hasattr(x[0], '__iter__'):
                 x = x[0]
 
         # Convert it to an 1D numpy array
         try:
             x = numpy.fromiter(x, 'd')
-        except (TypeError, ValueError, AssertionError):
+        except (TypeError, ValueError, AssertionError), e:
             raise TypeError("expected scalar arguments for the coordinates")
 
         if len(x) == 0:
