@@ -25,21 +25,20 @@
 # First added:  2008-12-08
 # Last changed: 2011-11-15
 
-__all__ = ["MeshCoordinates", "FacetArea", "FacetNormal", "CellSize"]
+__all__ = ["MeshCoordinates", "FacetArea", "FacetNormal", "CellSize", "CellVolume"]
 
 # Import UFL and SWIG-generated extension module (DOLFIN C++)
 import ufl
 import dolfin.cpp as cpp
 
 # Local imports
-from dolfin.functions.functionspace import dim2domain
 from dolfin.functions.expression import Expression
 
 class MeshCoordinates(Expression, ufl.Coefficient, cpp.MeshCoordinates):
     def __init__(self, mesh):
         "Create function that evaluates to the mesh coordinates at each vertex."
 
-        domain = dim2domain[mesh.topology().dim()]
+        domain = mesh.ufl_cell()
         self._ufl_element = ufl.VectorElement("Lagrange", domain, 1)
 
         ufl.Coefficient.__init__(self, self._ufl_element)
@@ -66,7 +65,7 @@ class FacetArea(Expression, ufl.Coefficient, cpp.FacetArea):
 
         """
 
-        domain = dim2domain[mesh.topology().dim()]
+        domain = mesh.ufl_cell()
         self._ufl_element = ufl.FiniteElement("Discontinuous Lagrange", domain, 0)
 
         ufl.Coefficient.__init__(self, self._ufl_element)
@@ -92,16 +91,8 @@ def FacetNormal(mesh):
             n = FacetNormal(mesh)
 
     """
-    if mesh.topology().dim() == 1:
-        return ufl.interval.n
-    elif mesh.topology().dim() == 2:
-        return ufl.triangle.n
-    elif mesh.topology().dim() == 3:
-        return ufl.tetrahedron.n
-    else:
-        cpp.dolfin_error("specialfunctions.py",
-                         "create facet normal function",
-                         "Unhandled topological dimension (%s)" % str(mesh.topology().dim()))
+    cell = mesh.ufl_cell()
+    return cell.n
 
 # Simple definition of CellSize via UFL
 def CellSize(mesh):
@@ -120,13 +111,25 @@ def CellSize(mesh):
             h = CellSize(mesh)
 
     """
-    if mesh.topology().dim() == 1:
-        return 2.0*ufl.interval.circumradius
-    elif mesh.topology().dim() == 2:
-        return 2.0*ufl.triangle.circumradius
-    elif mesh.topology().dim() == 3:
-        return 2.0*ufl.tetrahedron.circumradius
-    else:
-        cpp.dolfin_error("specialfunctions.py",
-                         "create cell size function",
-                         "Unhandled topological dimension (%s)" % str(mesh.topology().dim()))
+    cell = mesh.ufl_cell()
+    return 2.0*cell.circumradius
+
+# Simple definition of CellVolume via UFL
+def CellVolume(mesh):
+    """
+    Return cell volume function for given mesh.
+
+    *Arguments*
+        mesh
+            a :py:class:`Mesh <dolfin.cpp.Mesh>`.
+
+    *Example of usage*
+
+        .. code-block:: python
+
+            mesh = UnitSquare(4,4)
+            vol = CellVolume(mesh)
+
+    """
+    cell = mesh.ufl_cell()
+    return cell.volume
