@@ -25,6 +25,8 @@
 
 import re
 
+_compiled_cache = {}
+
 def indent(string, num_spaces):
     "Indent given text block given number of spaces"
     return "\n".join(num_spaces*" " + l for l in string.split("\n"))
@@ -32,7 +34,12 @@ def indent(string, num_spaces):
 def add_links(text, classnames, link_type):
     "Add crosslinks for classes"
     for classname in classnames:
-        p = re.compile(r"\b_%s_\b" % classname)
+        if classname not in text:
+            continue
+        p = _compiled_cache.get(classname)
+        if not p:
+            p = re.compile(r"\b_%s_\b" % classname)
+            _compiled_cache[classname] = p
         text = p.sub("%s`%s`" % (link_type, classname), text)
 
     # Escape pointer arguments: replace * by \* after class names
