@@ -12,23 +12,25 @@ source tree."""
 #
 # DOLFIN is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+# along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 #
-# Modified by Kristian B. Oelgaard, 2010.
+# Modified by Kristian B. Oelgaard, 2011.
+# Modified by Marie E. Rognes, 2011.
+# Modified by Anders E. Johansen, 2011.
 #
 # First added:  2010-08-26
-# Last changed: 2010-10-06
+# Last changed: 2011-07-10
 
 import os
 
 def extract_documentation(dolfin_dir, header, module):
     "Extract documentation for given header in given module"
 
-    print "Extracting documentation for %s..." % header
+    # print "Extracting documentation for %s..." % header
 
     # List of classes with documentation
     classnames = []
@@ -36,7 +38,7 @@ def extract_documentation(dolfin_dir, header, module):
 
     # Class name and parent class name
     classname = None
-    parent = None
+    parents = None
 
     # Comment and signature
     comment = None
@@ -67,24 +69,27 @@ def extract_documentation(dolfin_dir, header, module):
                 comment += "\n" + c
 
         # Check for class
-        elif " class " in line and not ";" in line and not "//" in line:
+        # If anything goes wrong, remove the last '<' after template.
+        elif " class " in line and not ";" in line and not "//" in line and not "template<" in line:
 
             # Get class name and parent
             classname = line.split(" class ")[1].split(":")[0].strip()
-            # TODO: KBO: multiple inheritance not handled!
             if "public" in line:
-                # Look for '<' to handle template classes ('<T>')
-                parent = line.split("public")[1].strip()#.split("<")[0].strip()
-            else:
-                parent = None
+                # Strip of each parent of additional commas, blanks
+                # and newlines
+                parents = [p.strip(", \n") for p in line.split("public")[1:]]
+
+                # Remove virtual modifier
+                parents = [p.replace("virtual ", "") for p in parents]
 
             # Store documentation
             # TODO: KBO: we don't check if a given classname is in the dolfin
             # namepace.
             classnames.append(classname)
-            documentation.append((classname, parent, comment, []))
+            documentation.append((classname, parents, comment, []))
+
             classname = None
-            parent = None
+            parents = None
             comment = None
 
         # If we encounter a '//' commented line we reset comment and proceed
@@ -116,7 +121,7 @@ def extract_documentation(dolfin_dir, header, module):
                 signature = signature.split("{")[0]
                 signature = signature.strip()
 
-                # Remove stuff Spinx can't handle
+                # Remove stuff Sphinx can't handle
                 signature = signature.replace("virtual ", "")
                 signature = signature.replace("inline ", "")
 
@@ -190,7 +195,7 @@ def extract_doc_representation(dolfin_dir):
     documentation = {}
     classnames = []
     for module in modules:
-#        if not module == "mesh":
+#        if not module == "la":
 #            continue
         # Extract header files from dolfin_foo.h
         f = open(os.path.join(dolfin_dir, "dolfin", module, "dolfin_%s.h" % module))
@@ -200,7 +205,7 @@ def extract_doc_representation(dolfin_dir):
             # Generate documentation for header file
             if line.startswith("#include <dolfin/"):
                 header = line.split("/")[2].split(">")[0]
-#                if not header == "Vertex.h":
+#                if not header == "GenericTensor.h":
 #                    continue
                 doc, cls = extract_documentation(dolfin_dir, header, module)
                 documentation[module].append((header, doc))
