@@ -38,7 +38,7 @@
 
 import getopt
 import sys
-from dolfin_utils.commands import getstatusoutput
+from instant import get_status_output
 import re
 import warnings
 import os.path
@@ -498,7 +498,7 @@ def gmsh2xml(ifilename, handler):
                     except IndexError:
                         raise Exception ( "The facet (%d) was not found to mark: %s" % (i, nodes) )
 
-#            # Create and initialise the mesh function
+            # Create and initialise the mesh function
             handler.start_meshfunction("facet_region", highest_dim-1, mesh.num_facets() )
             for index, physical_region in enumerate ( data ):
                 handler.add_entity_meshfunction(index, physical_region)
@@ -1038,7 +1038,7 @@ class DataHandler(object):
         assert self._state == self.State_Init
         self._state = self.State_MeshValueCollection
 
-    def add_entity_mesh_value_collection(self, dim, index, value):
+    def add_entity_mesh_value_collection(self, dim, index, value, local_entity=0):
         assert self._state == self.State_MeshValueCollection
 
     def end_mesh_value_collection(self):
@@ -1135,9 +1135,9 @@ class XmlHandler(DataHandler):
         DataHandler.start_mesh_value_collection(self, name, dim, size, etype)
         xml_writer.write_header_meshvaluecollection(self.__ofile, name, dim, size, etype)
 
-    def add_entity_mesh_value_collection(self, dim, index, value):
+    def add_entity_mesh_value_collection(self, dim, index, value, local_entity=0):
         DataHandler.add_entity_mesh_value_collection(self, dim, index, value)
-        xml_writer.write_entity_meshvaluecollection(self.__ofile, dim, index, value)
+        xml_writer.write_entity_meshvaluecollection(self.__ofile, dim, index, value, local_entity=local_entity)
 
     def end_mesh_value_collection(self):
         DataHandler.end_mesh_value_collection(self)
@@ -1272,7 +1272,7 @@ def exodus2xml(ifilename,ofilename):
 
     name = ifilename.split(".")[0]
     netcdffilename = name +".ncdf"
-    status, output = getstatusoutput('ncdump '+ifilename + ' > '+netcdffilename)
+    status, output = get_status_output('ncdump '+ifilename + ' > '+netcdffilename)
     if status != 0:
         raise IOError, "Something wrong while executing ncdump. Is ncdump "\
               "installed on the system?"
