@@ -18,22 +18,29 @@
 # along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 
 # Modified Johan Hake 2011
+# Modified Johannes Ring 2013
 
 import torque
 import sge
+import slurm
 import os
 import subprocess
+import re
 
-def check_mem_argument(mem):
-    allowed_mem_suffices = ["kb","mb","gb"]
+def check_mem_argument(mem, backend):
+    if backend == "slurm":
+        allowed_mem_suffices = ["k","m","g","K","M","G"]
+    else:
+        allowed_mem_suffices = ["kb","mb","gb"]
     if not mem is None:
         assert isinstance(mem,str)
-        if len(mem) < 3:
+        match = re.match("(\d+)(\w+)", mem)
+        if not match:
             return False
-        if mem[-2:] not in allowed_mem_suffices:
+        if match.groups()[1] not in allowed_mem_suffices:
             return False
         try:
-            memory = int(mem[:-2])
+            memory = int(match.groups()[0])
             if memory < 0:
                 return False
         except:
@@ -49,7 +56,7 @@ def submit(jobs, nodes=1, ppn=1, walltime=3, mem=None, vmem=None, name="myjob",
            workdir=".", email=None, paths=(), setup="", \
            keep_environment=True, serial=None, nice=None, dryrun=False, \
            queue=None, parallel_environment=None, backend="torque"): 
-    """Submit a sequence of commands to the pbs queue using qsub.
+    """Submit a sequence of commands to the queue using qsub/sbatch.
     
     Example use:
         from pjobs import submit, sjoin
@@ -74,10 +81,13 @@ def submit(jobs, nodes=1, ppn=1, walltime=3, mem=None, vmem=None, name="myjob",
     @param mem:
         Optional maximum amount of physical memory the process will need.
         The syntax is mem='100mb', or mem='4gb', with allowed suffices 
-        one of 'kb', 'mb' or 'gb' and only int values.
+        one of 'kb', 'mb' or 'gb' for the torque and the sge backends, and
+        one of 'k', 'm', 'g', 'K', 'M', 'G' for the slurm backend. Only int
+        values is allowed.
     @param vmem:
         Optional maximum amount of virtual memory the process will need.
         For syntax see mem.
+        (not available for the slurm backend)
     @param name:
         Basename of the job, just for the queue system.
         If a single string this will be combined with a
@@ -118,7 +128,7 @@ def submit(jobs, nodes=1, ppn=1, walltime=3, mem=None, vmem=None, name="myjob",
         (only available for the sge backend)
     @param backend:
         Set the name of the actuall submitter.
-        Available backends: 'torque' (default) and 'sge'
+        Available backends: 'torque' (default), 'sge' and 'slurm'
     """
     if isinstance(jobs, str):
         jobs = [jobs]
@@ -126,9 +136,9 @@ def submit(jobs, nodes=1, ppn=1, walltime=3, mem=None, vmem=None, name="myjob",
     assert isinstance(nodes, int)
     assert isinstance(ppn, int)
     assert isinstance(walltime, (int, float))
-    if not check_mem_argument(mem):
+    if not check_mem_argument(mem, backend):
         raise TypeError, "Wrong format of mem attribute, see docstring" 
-    if not check_mem_argument(vmem):
+    if not check_mem_argument(vmem, backend):
         raise TypeError, "Wrong format of vmem attribute, see docstring"
     assert isinstance(name, (str, list, tuple))
     assert isinstance(workdir, str)
@@ -146,7 +156,7 @@ def submit(jobs, nodes=1, ppn=1, walltime=3, mem=None, vmem=None, name="myjob",
 
     # Check backend
     assert isinstance(backend, str)
-    assert (backend in ["torque", "sge"])
+    assert (backend in ["torque", "sge", "slurm"])
     
     # Shared setup
     paths = "PATH=$PATH:" + ":".join(paths) if paths else ""
@@ -205,7 +215,10 @@ def submit(jobs, nodes=1, ppn=1, walltime=3, mem=None, vmem=None, name="myjob",
                 print "Wrote file ", scriptfilename
                 
                 # Queue the generated job script
-                cmd = ["qsub"] + [scriptfilename]
+                if backend == "slurm":
+                    cmd = ["sbatch"] + [scriptfilename]
+                else:
+                    cmd = ["qsub"] + [scriptfilename]
                 if dryrun:
                     print "NOT calling queue command:", " ".join(cmd)
                 else:
