@@ -20,7 +20,8 @@
 # First added:  2007-06-09
 # Last changed: 2011-11-14
 
-import re, sys, os
+import re, sys, os, subprocess
+from instant import get_status_output
 
 pwd = os.path.dirname(os.path.abspath(__file__))
 
@@ -34,16 +35,15 @@ if len(sys.argv) == 2 and sys.argv[1] == "--enable-memory-test":
 failed = []
 
 # Command to run
-command = "python test.py" + " " + " ".join(sys.argv[1:])
+command = [sys.executable, "test.py"] + sys.argv[1:]
 
 # Run tests
 for test in tests:
     print "Running tests: %s" % test
     print "----------------------------------------------------------------------"
     os.chdir(os.path.join(pwd, test))
-    fail = os.system(command)
-    if fail:
-        failed.append(fail)
-    print ""
+    status = subprocess.Popen(command, shell=False).wait()
+    if status:
+        failed.append(status)
 
 sys.exit(len(failed))
