@@ -1,4 +1,4 @@
-"""Unit tests for adaptivity"""
+"""Unit tests for error control"""
 
 # Copyright (C) 2011 Marie E. Rognes
 #
@@ -11,52 +11,51 @@
 #
 # DOLFIN is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+# along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
 #
 # First added:  2011-04-05
-# Last changed: 2011-04-06
+# Last changed: 2011-06-17
 
 import unittest
 #from unittest import skipIf # Awaiting Python 2.7
-from dolfin import *
 from ufl.algorithms import replace
 
+from dolfin import *
+from dolfin.fem.adaptivesolving import *
+
 #@skipIf("Skipping error control test in parallel", MPI.num_processes() > 1)
 class ErrorControlTest(unittest.TestCase):
 
     def setUp(self):
 
         # Define variational problem
-        mesh = UnitSquare(8, 8)
+        mesh = UnitSquareMesh(8, 8)
         V = FunctionSpace(mesh, "Lagrange", 1)
-        bc = DirichletBC(V, 0.0, "x[0] < DOLFIN_EPS || x[0] > 1.0 - DOLFIN_EPS")
+        bc = [DirichletBC(V, 0.0, "x[0] < DOLFIN_EPS || x[0] > 1.0 - DOLFIN_EPS")]
 
         u = TrialFunction(V)
         v = TestFunction(V)
         f = Expression("10*exp(-(pow(x[0] - 0.5, 2) + pow(x[1] - 0.5, 2)) / 0.02)", degree=1)
         g = Expression("sin(5*x[0])", degree=1)
-        a = inner(grad(u), grad(v))*dx
-        L = f*v*dx + g*v*ds
-        problem = VariationalProblem(a, L, bc)
+        a = inner(grad(u), grad(v))*dx()
+        L = f*v*dx() + g*v*ds()
+
+        # Define solution function
+        u = Function(V)
+
+        # Define LinearVariationalProblem
+        problem = LinearVariationalProblem(a, L, u, bc)
 
         # Define goal
-        u = Function(V)
-        M = u*dx
+        M = u*dx()
         self.goal = M
 
-        # Generate error control forms
-        ufl_forms = problem.generate_error_control_forms(u, M)
-
-        # Compile generated forms
-        forms = [Form(form) for form in ufl_forms]
-
-        # Initialize error control object
-        forms += [problem.is_linear]
-        ec = cpp.ErrorControl(*forms)
+        # Generate ErrorControl object
+        ec = generate_error_control(problem, M)
 
         # Store created stuff
         self.problem = problem
@@ -69,10 +68,11 @@ class ErrorControlTest(unittest.TestCase):
             return
 
         # Solve variational problem once
-        self.problem.solve(self.u)
+        solver = LinearVariationalSolver(self.problem)
+        solver.solve()
 
         # Compute error estimate
-        error_estimate = self.ec.estimate_error(self.u, self.problem.bcs)
+        error_estimate = self.ec.estimate_error(self.u, self.problem.bcs())
 
         # Compare estimate with defined reference
         reference = 0.0011789985750808342
@@ -84,7 +84,8 @@ class ErrorControlTest(unittest.TestCase):
             return
 
         # Solve variational problem once
-        self.problem.solve(self.u)
+        solver = LinearVariationalSolver(self.problem)
+        solver.solve()
 
         # Compute error indicators
         indicators = Vector(self.u.function_space().mesh().num_cells())
@@ -100,13 +101,13 @@ class ErrorControlTest(unittest.TestCase):
             return
 
         # Solve problem adaptively
-        self.problem.parameters["adaptivity"]["plot_mesh"] = False
+        solver = AdaptiveLinearVariationalSolver(self.problem, self.goal)
         tol = 0.00087
-        self.problem.solve(self.u, tol, self.goal)
+        solver.solve(tol)
 
         # Extract solution and update goal
-        w = Function(self.u.fine().function_space())
-        w.assign(self.u.fine())
+        w = Function(self.u.leaf_node().function_space())
+        w.assign(self.u.leaf_node())
         M = replace(self.goal, {self.u: w})
 
         # Compare computed goal with reference
