@@ -193,7 +193,7 @@ class DofMapTest(unittest.TestCase):
         W = MixedFunctionSpace([V, R])
         W = MixedFunctionSpace([R, V])
 
-    def test_vertex_to_dof_map(self):
+    def test_dof_to_vertex_map(self):
 
         # Check for both reordered and UFC ordered dofs
         for reorder_dofs in [True, False]:
@@ -209,7 +209,7 @@ class DofMapTest(unittest.TestCase):
 
             vert_values = self.mesh.coordinates().sum(1)
             func_values = -1*np.ones(len(vert_values))
-            func_values[V.dofmap().vertex_to_dof_map(self.mesh)] = u.vector().array()
+            func_values[dof_to_vertex_map(V)] = u.vector().array()
 
             for v_val, f_val in zip(vert_values, func_values):
                 # Do not compare dofs owned by other process
@@ -225,16 +225,18 @@ class DofMapTest(unittest.TestCase):
             vert_values[::2] = 1
             vert_values[1::2] = 2
 
-            u1.vector().set_local(vert_values[Q.dofmap().vertex_to_dof_map(self.mesh)].copy())
+            u1.vector().set_local(vert_values[dof_to_vertex_map(Q)].copy())
             self.assertAlmostEqual((u0.vector()-u1.vector()).sum(), 0.0)
 
             W = FunctionSpace(self.mesh, "DG", 0)
-            self.assertRaises(RuntimeError, lambda : W.dofmap().vertex_to_dof_map(self.mesh))
+            self.assertRaises(RuntimeError, lambda : dof_to_vertex_map(W))
 
             W = Q*FunctionSpace(self.mesh, "R", 0)
-            self.assertRaises(RuntimeError, lambda : W.dofmap().vertex_to_dof_map(self.mesh))
+            self.assertRaises(RuntimeError, lambda : dof_to_vertex_map(W))
             W = FunctionSpace(self.mesh, "CG", 2)
-            self.assertRaises(RuntimeError, lambda : W.dofmap().vertex_to_dof_map(self.mesh))
+            self.assertRaises(RuntimeError, lambda : dof_to_vertex_map(W))
+            W = VectorFunctionSpace(self.mesh, "CG", 1)
+            self.assertRaises(RuntimeError, lambda : dof_to_vertex_map(W.sub(0)))
 
 
     def test_entity_dofs(self):
@@ -279,6 +281,21 @@ class DofMapTest(unittest.TestCase):
             dofs = V.dofmap().tabulate_entity_dofs(0, i)
             self.assertTrue(all(d==cd for d, cd in zip(dofs, cdofs)))
 
+    def test_mpi_dofmap_stats(self):
+        if MPI.num_processes() > 1:
+            
+            V = FunctionSpace(self.mesh, "CG", 1)
+            self.assertTrue(len(V.dofmap().shared_dofs())>0)
+            self.assertTrue(len(V.dofmap().off_process_owner())>0)
+            neighbours = V.dofmap().neighbours()
+            for processes in V.dofmap().shared_dofs().values():
+                for process in processes:
+                    self.assertTrue(process in neighbours)
+
+            for owner in V.dofmap().off_process_owner().values():
+                self.assertTrue(owner in neighbours)
+                
+        
 if __name__ == "__main__":
     print ""
     print "Testing PyDOLFIN DofMap operations"
