@@ -28,7 +28,7 @@ from dolfin import *
 class LocalMeshDataXML_IO(unittest.TestCase):
 
     def testRead(self):
-        file = File("../../../../data/meshes/snake.xml.gz")
+        file = File("../snake.xml.gz")
         localdata = cpp.LocalMeshData()
         file >> localdata
 
