@@ -105,19 +105,19 @@ class XMLMesh(unittest.TestCase):
             input_file >> input_mesh
 
             # Get some data and check that it matches
-            self.assertEqual(input_mesh.domains().markers(0).size(),
-                             output_mesh.domains().markers(0).size());
-            self.assertEqual(input_mesh.domains().markers(1).size(),
-                             output_mesh.domains().markers(1).size());
-            self.assertEqual(input_mesh.domains().markers(2).size(),
-                             output_mesh.domains().markers(2).size());
-            self.assertEqual(input_mesh.domains().markers(3).size(),
-                             output_mesh.domains().markers(3).size());
+            self.assertEqual(len(input_mesh.domains().markers(0)),
+                             len(output_mesh.domains().markers(0)));
+            self.assertEqual(len(input_mesh.domains().markers(1)),
+                             len(output_mesh.domains().markers(1)));
+            self.assertEqual(len(input_mesh.domains().markers(2)),
+                             len(output_mesh.domains().markers(2)));
+            self.assertEqual(len(input_mesh.domains().markers(3)),
+                             len(output_mesh.domains().markers(3)));
 
 class LocalMeshDataXML_IO(unittest.TestCase):
 
     def testRead(self):
-        file = File("../../../../data/meshes/snake.xml.gz")
+        file = File("../snake.xml.gz")
         localdata = cpp.LocalMeshData()
         file >> localdata
 
