@@ -25,26 +25,76 @@ from dolfin import *
 
 # VTK file options
 file_options = ["ascii", "base64", "compressed"]
+mesh_functions = [CellFunction, FacetFunction, FaceFunction, EdgeFunction, VertexFunction]
+mesh_function_types = ["size_t", "int", "double", "bool"]
+
+class VTK_MeshFunction_Output(unittest.TestCase):
+    """Test output of MeshFunctions to VTK files"""
+    def test_save_1d_meshfunctions(self):
+        #if MPI.num_processes() == 1:
+        mesh = UnitIntervalMesh(32)
+        for F in mesh_functions:
+            if F in [FaceFunction, EdgeFunction]: continue
+            for t in mesh_function_types:
+                mf = F(t, mesh, 1)
+                File("mf.pvd") << mf
+                f = File("mf.pvd")
+                f << (mf, 0.)
+                f << (mf, 1.)
+                for file_option in file_options:
+                    File("mf.pvd", file_option) << mf
+
+    def test_save_2d_meshfunctions(self):
+        mesh = UnitSquareMesh(32, 32)
+        for F in mesh_functions:
+            for t in mesh_function_types:
+                mf = F(t, mesh, 1)
+                File("mf.pvd") << mf
+                f = File("mf.pvd")
+                f << (mf, 0.)
+                f << (mf, 1.)
+                for file_option in file_options:
+                    File("mf.pvd", file_option) << mf
+
+    def test_save_3d_meshfunctions(self):
+        mesh = UnitCubeMesh(8, 8, 8)
+        for F in mesh_functions:
+            for t in mesh_function_types:
+                mf = F(t, mesh, 1)
+                File("mf.pvd") << mf
+                f = File("mf.pvd")
+                f << (mf, 0.)
+                f << (mf, 1.)
+                for file_option in file_options:
+                    File("mf.pvd", file_option) << mf
 
 class VTK_Mesh_Output(unittest.TestCase):
     """Test output of Meshes to VTK files"""
 
     def test_save_1d_mesh(self):
-        if MPI.num_processes() == 1:
-            mesh = UnitIntervalMesh(32)
-            File("mesh.pvd") << mesh
-            for file_option in file_options:
-                File("mesh.pvd", file_option) << mesh
+        mesh = UnitIntervalMesh(32)
+        File("mesh.pvd") << mesh
+        f = File("mesh.pvd")
+        f << (mesh, 0.)
+        f << (mesh, 1.)
+        for file_option in file_options:
+            File("mesh.pvd", file_option) << mesh
 
     def test_save_2d_mesh(self):
         mesh = UnitSquareMesh(32, 32)
         File("mesh.pvd") << mesh
+        f = File("mesh.pvd")
+        f << (mesh, 0.)
+        f << (mesh, 1.)
         for file_option in file_options:
             File("mesh.pvd", file_option) << mesh
 
     def test_save_3d_mesh(self):
         mesh = UnitCubeMesh(8, 8, 8)
         File("mesh.pvd") << mesh
+        f = File("mesh.pvd")
+        f << (mesh, 0.)
+        f << (mesh, 1.)
         for file_option in file_options:
             File("mesh.pvd", file_option) << mesh
 
@@ -58,6 +108,9 @@ class VTK_Point_Function_Output(unittest.TestCase):
             u = Function(FunctionSpace(mesh, "Lagrange", 2))
             u.vector()[:] = 1.0
             File("u.pvd") << u
+            f = File("u.pvd")
+            f << (u, 0.)
+            f << (u, 1.)
             for file_option in file_options:
                 File("u.pvd", file_option) << u
 
@@ -66,6 +119,9 @@ class VTK_Point_Function_Output(unittest.TestCase):
         u = Function(FunctionSpace(mesh, "Lagrange", 2))
         u.vector()[:] = 1.0
         File("u.pvd") << u
+        f = File("u.pvd")
+        f << (u, 0.)
+        f << (u, 1.)
         for file_option in file_options:
             File("u.pvd", file_option) << u
 
@@ -74,6 +130,9 @@ class VTK_Point_Function_Output(unittest.TestCase):
         u = Function(FunctionSpace(mesh, "Lagrange", 2))
         u.vector()[:] = 1.0
         File("u.pvd") << u
+        f = File("u.pvd")
+        f << (u, 0.)
+        f << (u, 1.)
         for file_option in file_options:
             File("u.pvd", file_option) << u
 
@@ -92,6 +151,9 @@ class VTK_Point_Function_Output(unittest.TestCase):
         u = Function(VectorFunctionSpace(mesh, "Lagrange", 2))
         u.vector()[:] = 1.0
         File("u.pvd") << u
+        f = File("u.pvd")
+        f << (u, 0.)
+        f << (u, 1.)
         for file_option in file_options:
             File("u.pvd", file_option) << u
 
@@ -100,6 +162,9 @@ class VTK_Point_Function_Output(unittest.TestCase):
         u = Function(VectorFunctionSpace(mesh, "Lagrange", 2))
         u.vector()[:] = 1.0
         File("u.pvd") << u
+        f = File("u.pvd")
+        f << (u, 0.)
+        f << (u, 1.)
         for file_option in file_options:
             File("u.pvd", file_option) << u
 
@@ -118,6 +183,9 @@ class VTK_Point_Function_Output(unittest.TestCase):
         u = Function(TensorFunctionSpace(mesh, "Lagrange", 2))
         u.vector()[:] = 1.0
         File("u.pvd") << u
+        f = File("u.pvd")
+        f << (u, 0.)
+        f << (u, 1.)
         for file_option in file_options:
             File("u.pvd", file_option) << u
 
@@ -126,6 +194,9 @@ class VTK_Point_Function_Output(unittest.TestCase):
         u = Function(TensorFunctionSpace(mesh, "Lagrange", 2))
         u.vector()[:] = 1.0
         File("u.pvd") << u
+        f = File("u.pvd")
+        f << (u, 0.)
+        f << (u, 1.)
         for file_option in file_options:
             File("u.pvd", file_option) << u
 
