@@ -25,13 +25,6 @@ from dolfin import *
 
 class ScalarTest(unittest.TestCase):
 
-    def test_distributed(self):
-        a = Scalar()
-        if MPI.num_processes() > 1:
-             self.assertTrue(a.distributed())
-        else:
-             self.assertFalse(a.distributed())
-
     def test_parallel_sum(self):
         a = Scalar()
         b = 1.0
@@ -39,9 +32,9 @@ class ScalarTest(unittest.TestCase):
         a.apply("add")
         self.assertAlmostEqual(a.getval(), b*MPI.num_processes())
 
-
 if __name__ == "__main__":
-    # Turn of DOLFIN output
+
+    # Turn off DOLFIN output
     set_log_active(False)
 
     print ""
