@@ -37,7 +37,7 @@ class AbstractBaseTest(object):
             print "\nRunning:",type(self).__name__
 
     def assemble_vectors(self):
-        mesh = UnitSquare(7, 4)
+        mesh = UnitSquareMesh(7, 4)
 
         V = FunctionSpace(mesh, "Lagrange", 2)
         W = FunctionSpace(mesh, "Lagrange", 1)
@@ -47,16 +47,6 @@ class AbstractBaseTest(object):
 
         return assemble(v*dx), assemble(t*dx)
 
-    def test_distributed(self):
-        a, b = self.assemble_vectors()
-        if self.backend == "PETSc" or self.backend == "Epetra":
-          if MPI.num_processes() > 1:
-               self.assertTrue(a.distributed())
-          else:
-               self.assertFalse(a.distributed())
-        else:
-           self.assertFalse(a.distributed())
-
     def test_create_empty_vector(self):
         v0 = Vector()
         info(v0)
@@ -144,10 +134,7 @@ class AbstractBaseTest(object):
         from numpy import empty
         n = 301
         v0 = Vector(n)
-        data = empty((v0.local_size()), dtype='d')
-        v0.get_local(data)
-        data = empty((v0.local_size()*2), dtype='d')
-        self.assertRaises(TypeError, v0.get_local, data[::2])
+        data = v0.get_local()
 
     def test_set_local(self):
         from numpy import zeros
@@ -156,7 +143,6 @@ class AbstractBaseTest(object):
         data = zeros((v0.local_size()), dtype='d')
         v0.set_local(data)
         data = zeros((v0.local_size()*2), dtype='d')
-        self.assertRaises(TypeError, v0.get_local, data[::2])
 
     def test_add_local(self):
         from numpy import zeros
@@ -165,7 +151,7 @@ class AbstractBaseTest(object):
         data = zeros((v0.local_size()), dtype='d')
         v0.add_local(data)
         data = zeros((v0.local_size()*2), dtype='d')
-        self.assertRaises(TypeError, v0.get_local, data[::2])
+        self.assertRaises(TypeError, v0.add_local, data[::2])
 
     #def test_gather(self):
 
@@ -221,7 +207,7 @@ class AbstractBaseTest(object):
         n = 301
         v0 = Vector(n)
         v0[:] = -2.0
-        entries = zeros(5, dtype='I')
+        entries = zeros(5, dtype='uintp')
         self.assertEqual(v0.sum(entries), -2.0)
         entries[0] = 2
         entries[1] = 1
@@ -262,6 +248,22 @@ class AbstractBaseTest(object):
         v0 += v1
         self.assertEqual(v0.sum(), n)
 
+    def test_scalar_add(self):
+        #if self.backend == "Epetra":
+        #    return
+        n = 301
+        v0 = Vector(n)
+        v1 = Vector(n)
+        v0[:] = -1.0
+        v0 += 2.0
+        self.assertEqual(v0.sum(), n)
+        v0 -= 2.0
+        self.assertEqual(v0.sum(), -n)
+        v0 = v0 + 3.0
+        self.assertEqual(v0.sum(), 2*n)
+        v0 = v0 - 1.0
+        self.assertEqual(v0.sum(), n)
+
     def test_vector_subtract(self):
         n = 301
         v0 = Vector(n)
@@ -297,9 +299,9 @@ class AbstractBaseTest(object):
             print "local range", local_range0[0], local_range0[1]
 
             # Shift parallel partitiong but preserve global size
-            if MPI.process_number() == 0: 
+            if MPI.process_number() == 0:
                 local_range1 = (local_range0[0], local_range0[1] + 1)
-            elif MPI.process_number() == MPI.num_processes() - 1: 
+            elif MPI.process_number() == MPI.num_processes() - 1:
                 local_range1 = (local_range0[0] + 1, local_range0[1])
             else:
                 local_range1 = (local_range0[0] + 1, local_range0[1] + 1)
@@ -316,7 +318,7 @@ class AbstractBaseTest(object):
 
 
 # A DataTester class that test the acces of the raw data through pointers
-# This is only available for uBLAS and MTL4 backends
+# This is only available for uBLAS backend
 class DataTester:
     def test_vector_data(self):
         # Test for ordinary Vector
@@ -329,20 +331,19 @@ class DataTester:
         data = v.data(False)
         def write_data(data):
             data[0] = 1
-        self.assertRaises(RuntimeError, write_data, data)
+        self.assertRaises(StandardError, write_data, data)
 
-        # Test for down_casted Vector
-        v = down_cast(v)
+        # Test for as_backend_typeed Vector
+        v = as_backend_type(v)
         data = v.data()
         self.assertTrue((data==array).all())
 
-
 class DataNotWorkingTester:
     def test_vector_data(self):
         v = Vector(301)
         self.assertRaises(RuntimeError, v.data)
 
-        v = down_cast(v)
+        v = as_backend_type(v)
         def no_attribute():
             v.data()
         self.assertRaises(AttributeError,no_attribute)
@@ -356,9 +357,9 @@ if MPI.num_processes() == 1:
         backend     = "uBLAS"
         sub_backend = "Dense"
 
-    if has_linear_algebra_backend("MTL4"):
-        class MTL4Tester(DataTester, AbstractBaseTest, unittest.TestCase):
-            backend    = "MTL4"
+    if has_linear_algebra_backend("PETScCusp"):
+        class PETScCuspTester(DataNotWorkingTester, AbstractBaseTest, unittest.TestCase):
+            backend    = "PETScCusp"
 
 if has_linear_algebra_backend("PETSc"):
     class PETScTester(DataNotWorkingTester, AbstractBaseTest, unittest.TestCase):
@@ -368,8 +369,19 @@ if has_linear_algebra_backend("Epetra"):
     class EpetraTester(DataNotWorkingTester, AbstractBaseTest, unittest.TestCase):
         backend    = "Epetra"
 
+# If we have PETSc or Epetra STL Vector gets typedefed to one of these and
+# data test will not work. If none of these backends are available
+# STLVector defaults to uBLASVEctor, which data will work
+if has_linear_algebra_backend("Epetra") or has_linear_algebra_backend("PETSc"):
+    class STLTester(DataNotWorkingTester, AbstractBaseTest, unittest.TestCase):
+        backend    = "STL"
+else:
+    class STLTester(AbstractBaseTest, unittest.TestCase):
+        backend    = "STL"
+
 if __name__ == "__main__":
-    # Turn of DOLFIN output
+
+    # Turn off DOLFIN output
     set_log_active(False)
 
     print ""
