@@ -25,7 +25,7 @@
 from unittest import TestCase as _TestCase
 import unittest
 import os
-import glob 
+import glob
 import tempfile
 
 from dolfin_utils.meshconvert import meshconvert
@@ -205,6 +205,38 @@ class AbaqusTest(_ConverterTest):
 #        convert(fname, """*MATERIAL, NAME=MAT
 #*SOLID SECTION, ELSET=NONE, MATERIAL=MAT""", error=True)
 
+    def test_facet_success(self):
+        """ Test facet export.
+        """
+        dim = 3
+        nb_facets = 1170  # The total number of facets in the mesh
+        marker_counter = {0: 990,
+                          1: 42,
+                          2: 42,
+                          3: 96,
+                          4: 0}
+        handler = self.__convert("abaqus_facet.inp")
+        self.assert_(handler.vertices_ended)
+        self.assert_(handler.cells_ended)
+
+        self.assert_("facet_region" in handler.functions.keys())
+        cell_type = DataHandler.CellType_Triangle
+        function_dim, sz, entries, ended = handler.functions["facet_region"]
+
+        # the dimension of the meshfunction should be dim-1
+        self.assertEqual(function_dim, dim - 1)
+        # There should be size facets in the mesh function
+        self.assertEqual(len(entries), nb_facets)
+        self.assertEqual(sz, nb_facets)
+
+
+        # Check that the right number of facets are marked
+        for marker, count in marker_counter.iteritems():
+            self.assert_(len([i for i in entries if i == marker]) == count)
+
+        self.assert_(ended)
+        self.assert_(handler.closed)
+
     def __convert(self, fname):
         handler = _TestHandler(DataHandler.CellType_Tetrahedron, 3, self)
         if not os.path.isabs(fname):
@@ -355,7 +387,7 @@ class TriangleTester(_TestCase):
             return
         fname = os.path.join("data", "triangle")
         dfname = fname+".xml"
-        
+
         # Read triangle file and convert to a dolfin xml mesh file
         meshconvert.triangle2xml(fname, dfname)
 
@@ -405,25 +437,31 @@ class TriangleTester(_TestCase):
         # Check that all cells in the two domains are either above or below y=0
         self.assertTrue(all(cell.midpoint().y()<0 for cell in SubsetIterator(cf, 0)))
         self.assertTrue(all(cell.midpoint().y()>0 for cell in SubsetIterator(cf, 1)))
-        
+
         # Check that the areas add up
         self.assertAlmostEqual(area0+area1, total_area)
-        
+
         # Measure the edge length of the two edge domains
-        edge_markers = mesh.domains().facet_domains()
+        #edge_markers = mesh.domains().facet_domains()
+        edge_markers = mesh.domains().markers(mesh.topology().dim()-1)
         self.assertTrue(edge_markers is not None)
-        length0 = reduce(add, (Edge(mesh, e.index()).length() \
-                            for e in SubsetIterator(edge_markers, 0)), 0.0)
-        length1 = reduce(add, (Edge(mesh, e.index()).length() \
-                            for e in SubsetIterator(edge_markers, 1)), 0.0)
-        
+        #length0 = reduce(add, (Edge(mesh, e.index()).length() \
+        #                    for e in SubsetIterator(edge_markers, 0)), 0.0)
+        length0, length1 = 0.0, 0.0
+        for item in edge_markers.items():
+            if item[1] == 0:
+                e = Edge(mesh, int(item[0]))
+                length0 +=  Edge(mesh, int(item[0])).length()
+            elif item [1] == 1:
+                length1 +=  Edge(mesh, int(item[0])).length()
+
         # Total length of all edges and total length of boundary edges
         total_length = reduce(add, (e.length() for e in edges(mesh)), 0.0)
         boundary_length = reduce(add, (Edge(mesh, f.index()).length() \
                           for f in facets(mesh) if f.exterior()), 0.0)
-        
+
         # Check that the edges add up
-        self.assertAlmostEqual(length0+length1, total_length)
+        self.assertAlmostEqual(length0 + length1, total_length)
         self.assertAlmostEqual(length1, boundary_length)
 
         # Clean up
@@ -437,7 +475,7 @@ class DiffPackTester(_TestCase):
             return
         fname = os.path.join("data", "diffpack_tet")
         dfname = fname+".xml"
-        
+
         # Read triangle file and convert to a dolfin xml mesh file
         meshconvert.diffpack2xml(fname+".grid", dfname)
 
@@ -445,8 +483,8 @@ class DiffPackTester(_TestCase):
         mesh = Mesh(dfname)
         self.assertEqual(mesh.num_vertices(), 27)
         self.assertEqual(mesh.num_cells(), 48)
-        self.assertEqual(mesh.domains().markers(3).size(), 48)
-        self.assertEqual(mesh.domains().markers(2).size(), 16)
+        self.assertEqual(len(mesh.domains().markers(3)), 48)
+        self.assertEqual(len(mesh.domains().markers(2)), 16)
 
         mf_basename = dfname.replace(".xml", "_marker_%d.xml")
         for marker, num in [(3, 9), (6, 9), (7, 3), (8, 1)]:
@@ -455,7 +493,7 @@ class DiffPackTester(_TestCase):
             mf = MeshFunction("uint", mesh, mf_name)
             self.assertEqual(sum(mf.array()==marker), num)
             os.unlink(mf_name)
-        
+
         # Clean up
         os.unlink(dfname)
 
