@@ -27,19 +27,19 @@ class MeshRefinement(unittest.TestCase):
 
     def test_uniform_refine1D(self):
         if MPI.num_processes() == 1:
-            mesh = UnitInterval(2)
+            mesh = UnitIntervalMesh(2)
             mesh2 = refine(mesh)
             self.assertEqual(mesh.hmax(), 0.5)
             self.assertEqual(mesh2.hmax(), 0.25)
 
     def test_uniform_refine2D(self):
         if MPI.num_processes() == 1:
-            mesh = UnitSquare(4, 6)
+            mesh = UnitSquareMesh(4, 6)
             mesh = refine(mesh)
 
     def test_uniform_refine3D(self):
         if MPI.num_processes() == 1:
-            mesh = UnitCube(4, 4, 6)
+            mesh = UnitCubeMesh(4, 4, 6)
             mesh = refine(mesh)
 
 if __name__ == "__main__":
